# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: webuimessages_bluetooth.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import steam.protobufs.enums_pb2 as enums__pb2
import steam.protobufs.steammessages_base_pb2 as steammessages__base__pb2
import steam.protobufs.webuimessages_base_pb2 as webuimessages__base__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1dwebuimessages_bluetooth.proto\x1a\x0b\x65nums.proto\x1a\x18steammessages_base.proto\x1a\x18webuimessages_base.proto\"$\n\"CBluetoothManager_GetState_Request\"-\n\x1f\x43MsgBluetoothManagerAdapterInfo\x12\n\n\x02id\x18\x01 \x01(\r\"\xca\x01\n\x1e\x43MsgBluetoothManagerDeviceInfo\x12\n\n\x02id\x18\x01 \x01(\r\x12\x18\n\x10should_hide_hint\x18\x02 \x01(\x08\x12\x43\n\x05\x65type\x18\x03 \x01(\x0e\x32\x15.EBluetoothDeviceType:\x1dk_BluetoothDeviceType_Invalid\x12\x14\n\x0cis_connected\x18\x04 \x01(\x08\x12\x11\n\tis_paired\x18\x05 \x01(\x08\x12\x14\n\x0cstrength_raw\x18\x06 \x01(\x05\"\xd5\x01\n#CBluetoothManager_GetState_Response\x12\x1c\n\x14is_service_available\x18\x01 \x01(\x08\x12\x12\n\nis_enabled\x18\x02 \x01(\x08\x12\x16\n\x0eis_discovering\x18\x03 \x01(\x08\x12\x32\n\x08\x61\x64\x61pters\x18\x04 \x03(\x0b\x32 .CMsgBluetoothManagerAdapterInfo\x12\x30\n\x07\x64\x65vices\x18\x05 \x03(\x0b\x32\x1f.CMsgBluetoothManagerDeviceInfo\"9\n+CBluetoothManager_GetAdapterDetails_Request\x12\n\n\x02id\x18\x01 \x01(\r\"z\n\"CMsgBluetoothManagerAdapterDetails\x12\r\n\x02id\x18\x01 \x01(\r:\x01\x30\x12\x0b\n\x03mac\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x12\n\nis_enabled\x18\x04 \x01(\x08\x12\x16\n\x0eis_discovering\x18\x05 \x01(\x08\"d\n,CBluetoothManager_GetAdapterDetails_Response\x12\x34\n\x07\x61\x64\x61pter\x18\x01 \x01(\x0b\x32#.CMsgBluetoothManagerAdapterDetails\"8\n*CBluetoothManager_GetDeviceDetails_Request\x12\n\n\x02id\x18\x01 \x01(\r\"\xe8\x02\n!CMsgBluetoothManagerDeviceDetails\x12\r\n\x02id\x18\x01 \x01(\r:\x01\x30\x12\x15\n\nadapter_id\x18\x02 \x01(\r:\x01\x30\x12\x43\n\x05\x65type\x18\x03 \x01(\x0e\x32\x15.EBluetoothDeviceType:\x1dk_BluetoothDeviceType_Invalid\x12\x0b\n\x03mac\x18\x04 \x01(\t\x12\x0c\n\x04name\x18\x05 \x01(\t\x12\x14\n\x0cis_connected\x18\x06 \x01(\x08\x12\x11\n\tis_paired\x18\x07 \x01(\x08\x12\x12\n\nis_pairing\x18\x08 \x01(\x08\x12\x14\n\x0cwake_allowed\x18\t \x01(\x08\x12\x1e\n\x16wake_allowed_supported\x18\n \x01(\x08\x12\x17\n\x0f\x62\x61ttery_percent\x18\x0b \x01(\x05\x12\x1d\n\x15operation_in_progress\x18\x0c \x01(\x08\x12\x12\n\nis_trusted\x18\r \x01(\x08\"a\n+CBluetoothManager_GetDeviceDetails_Response\x12\x32\n\x06\x64\x65vice\x18\x01 \x01(\x0b\x32\".CMsgBluetoothManagerDeviceDetails\"-\n+CBluetoothManager_StateChanged_Notification\";\n(CBluetoothManager_SetDiscovering_Request\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\"+\n)CBluetoothManager_SetDiscovering_Response\"0\n\x1e\x43\x42luetoothManager_Pair_Request\x12\x0e\n\x06\x64\x65vice\x18\x01 \x01(\r\"!\n\x1f\x43\x42luetoothManager_Pair_Response\"6\n$CBluetoothManager_CancelPair_Request\x12\x0e\n\x06\x64\x65vice\x18\x01 \x01(\r\"\'\n%CBluetoothManager_CancelPair_Response\"2\n CBluetoothManager_Forget_Request\x12\x0e\n\x06\x64\x65vice\x18\x01 \x01(\r\"#\n!CBluetoothManager_Forget_Response\"3\n!CBluetoothManager_Connect_Request\x12\x0e\n\x06\x64\x65vice\x18\x01 \x01(\r\"$\n\"CBluetoothManager_Connect_Response\"6\n$CBluetoothManager_Disconnect_Request\x12\x0e\n\x06\x64\x65vice\x18\x01 \x01(\r\"\'\n%CBluetoothManager_Disconnect_Response\"K\n(CBluetoothManager_SetWakeAllowed_Request\x12\x0e\n\x06\x64\x65vice\x18\x01 \x01(\r\x12\x0f\n\x07\x61llowed\x18\x02 \x01(\x08\"+\n)CBluetoothManager_SetWakeAllowed_Response\"G\n$CBluetoothManager_SetTrusted_Request\x12\x0e\n\x06\x64\x65vice\x18\x01 \x01(\r\x12\x0f\n\x07trusted\x18\x02 \x01(\x08\"\'\n%CBluetoothManager_SetTrusted_Response2\xff\x08\n\x10\x42luetoothManager\x12U\n\x08GetState\x12#.CBluetoothManager_GetState_Request\x1a$.CBluetoothManager_GetState_Response\x12p\n\x11GetAdapterDetails\x12,.CBluetoothManager_GetAdapterDetails_Request\x1a-.CBluetoothManager_GetAdapterDetails_Response\x12m\n\x10GetDeviceDetails\x12+.CBluetoothManager_GetDeviceDetails_Request\x1a,.CBluetoothManager_GetDeviceDetails_Response\x12T\n\x12NotifyStateChanged\x12,.CBluetoothManager_StateChanged_Notification\x1a\x10.WebUINoResponse\x12g\n\x0eSetDiscovering\x12).CBluetoothManager_SetDiscovering_Request\x1a*.CBluetoothManager_SetDiscovering_Response\x12I\n\x04Pair\x12\x1f.CBluetoothManager_Pair_Request\x1a .CBluetoothManager_Pair_Response\x12[\n\nCancelPair\x12%.CBluetoothManager_CancelPair_Request\x1a&.CBluetoothManager_CancelPair_Response\x12O\n\x06\x46orget\x12!.CBluetoothManager_Forget_Request\x1a\".CBluetoothManager_Forget_Response\x12R\n\x07\x43onnect\x12\".CBluetoothManager_Connect_Request\x1a#.CBluetoothManager_Connect_Response\x12[\n\nDisconnect\x12%.CBluetoothManager_Disconnect_Request\x1a&.CBluetoothManager_Disconnect_Response\x12g\n\x0eSetWakeAllowed\x12).CBluetoothManager_SetWakeAllowed_Request\x1a*.CBluetoothManager_SetWakeAllowed_Response\x12[\n\nSetTrusted\x12%.CBluetoothManager_SetTrusted_Request\x1a&.CBluetoothManager_SetTrusted_Response\x1a\x04\x80\x97\"\x01\x42\x05H\x01\x90\x01\x01')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'webuimessages_bluetooth_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'H\001\220\001\001'
  _BLUETOOTHMANAGER._options = None
  _BLUETOOTHMANAGER._serialized_options = b'\200\227\"\001'
  _CBLUETOOTHMANAGER_GETSTATE_REQUEST._serialized_start=98
  _CBLUETOOTHMANAGER_GETSTATE_REQUEST._serialized_end=134
  _CMSGBLUETOOTHMANAGERADAPTERINFO._serialized_start=136
  _CMSGBLUETOOTHMANAGERADAPTERINFO._serialized_end=181
  _CMSGBLUETOOTHMANAGERDEVICEINFO._serialized_start=184
  _CMSGBLUETOOTHMANAGERDEVICEINFO._serialized_end=386
  _CBLUETOOTHMANAGER_GETSTATE_RESPONSE._serialized_start=389
  _CBLUETOOTHMANAGER_GETSTATE_RESPONSE._serialized_end=602
  _CBLUETOOTHMANAGER_GETADAPTERDETAILS_REQUEST._serialized_start=604
  _CBLUETOOTHMANAGER_GETADAPTERDETAILS_REQUEST._serialized_end=661
  _CMSGBLUETOOTHMANAGERADAPTERDETAILS._serialized_start=663
  _CMSGBLUETOOTHMANAGERADAPTERDETAILS._serialized_end=785
  _CBLUETOOTHMANAGER_GETADAPTERDETAILS_RESPONSE._serialized_start=787
  _CBLUETOOTHMANAGER_GETADAPTERDETAILS_RESPONSE._serialized_end=887
  _CBLUETOOTHMANAGER_GETDEVICEDETAILS_REQUEST._serialized_start=889
  _CBLUETOOTHMANAGER_GETDEVICEDETAILS_REQUEST._serialized_end=945
  _CMSGBLUETOOTHMANAGERDEVICEDETAILS._serialized_start=948
  _CMSGBLUETOOTHMANAGERDEVICEDETAILS._serialized_end=1308
  _CBLUETOOTHMANAGER_GETDEVICEDETAILS_RESPONSE._serialized_start=1310
  _CBLUETOOTHMANAGER_GETDEVICEDETAILS_RESPONSE._serialized_end=1407
  _CBLUETOOTHMANAGER_STATECHANGED_NOTIFICATION._serialized_start=1409
  _CBLUETOOTHMANAGER_STATECHANGED_NOTIFICATION._serialized_end=1454
  _CBLUETOOTHMANAGER_SETDISCOVERING_REQUEST._serialized_start=1456
  _CBLUETOOTHMANAGER_SETDISCOVERING_REQUEST._serialized_end=1515
  _CBLUETOOTHMANAGER_SETDISCOVERING_RESPONSE._serialized_start=1517
  _CBLUETOOTHMANAGER_SETDISCOVERING_RESPONSE._serialized_end=1560
  _CBLUETOOTHMANAGER_PAIR_REQUEST._serialized_start=1562
  _CBLUETOOTHMANAGER_PAIR_REQUEST._serialized_end=1610
  _CBLUETOOTHMANAGER_PAIR_RESPONSE._serialized_start=1612
  _CBLUETOOTHMANAGER_PAIR_RESPONSE._serialized_end=1645
  _CBLUETOOTHMANAGER_CANCELPAIR_REQUEST._serialized_start=1647
  _CBLUETOOTHMANAGER_CANCELPAIR_REQUEST._serialized_end=1701
  _CBLUETOOTHMANAGER_CANCELPAIR_RESPONSE._serialized_start=1703
  _CBLUETOOTHMANAGER_CANCELPAIR_RESPONSE._serialized_end=1742
  _CBLUETOOTHMANAGER_FORGET_REQUEST._serialized_start=1744
  _CBLUETOOTHMANAGER_FORGET_REQUEST._serialized_end=1794
  _CBLUETOOTHMANAGER_FORGET_RESPONSE._serialized_start=1796
  _CBLUETOOTHMANAGER_FORGET_RESPONSE._serialized_end=1831
  _CBLUETOOTHMANAGER_CONNECT_REQUEST._serialized_start=1833
  _CBLUETOOTHMANAGER_CONNECT_REQUEST._serialized_end=1884
  _CBLUETOOTHMANAGER_CONNECT_RESPONSE._serialized_start=1886
  _CBLUETOOTHMANAGER_CONNECT_RESPONSE._serialized_end=1922
  _CBLUETOOTHMANAGER_DISCONNECT_REQUEST._serialized_start=1924
  _CBLUETOOTHMANAGER_DISCONNECT_REQUEST._serialized_end=1978
  _CBLUETOOTHMANAGER_DISCONNECT_RESPONSE._serialized_start=1980
  _CBLUETOOTHMANAGER_DISCONNECT_RESPONSE._serialized_end=2019
  _CBLUETOOTHMANAGER_SETWAKEALLOWED_REQUEST._serialized_start=2021
  _CBLUETOOTHMANAGER_SETWAKEALLOWED_REQUEST._serialized_end=2096
  _CBLUETOOTHMANAGER_SETWAKEALLOWED_RESPONSE._serialized_start=2098
  _CBLUETOOTHMANAGER_SETWAKEALLOWED_RESPONSE._serialized_end=2141
  _CBLUETOOTHMANAGER_SETTRUSTED_REQUEST._serialized_start=2143
  _CBLUETOOTHMANAGER_SETTRUSTED_REQUEST._serialized_end=2214
  _CBLUETOOTHMANAGER_SETTRUSTED_RESPONSE._serialized_start=2216
  _CBLUETOOTHMANAGER_SETTRUSTED_RESPONSE._serialized_end=2255
  _BLUETOOTHMANAGER._serialized_start=2258
  _BLUETOOTHMANAGER._serialized_end=3409
_builder.BuildServices(DESCRIPTOR, 'webuimessages_bluetooth_pb2', globals())
# @@protoc_insertion_point(module_scope)
