# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: steammessages_community.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import steam.protobufs.steammessages_base_pb2 as steammessages__base__pb2
import steam.protobufs.steammessages_unified_base_pb2 as steammessages__unified__base__pb2
import steam.protobufs.enums_pb2 as enums__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1dsteammessages_community.proto\x1a\x18steammessages_base.proto\x1a steammessages_unified_base.proto\x1a\x0b\x65nums.proto\">\n\x1a\x43\x43ommunity_GetApps_Request\x12\x0e\n\x06\x61ppids\x18\x01 \x03(\x05\x12\x10\n\x08language\x18\x02 \x01(\r\"B\n\x1b\x43\x43ommunity_GetApps_Response\x12#\n\x04\x61pps\x18\x01 \x03(\x0b\x32\x15.CCDDBAppDetailCommon\"T\n1CCommunity_GetAppRichPresenceLocalization_Request\x12\r\n\x05\x61ppid\x18\x01 \x01(\x05\x12\x10\n\x08language\x18\x02 \x01(\t\"\xa7\x02\n2CCommunity_GetAppRichPresenceLocalization_Response\x12\r\n\x05\x61ppid\x18\x01 \x01(\x05\x12R\n\x0btoken_lists\x18\x02 \x03(\x0b\x32=.CCommunity_GetAppRichPresenceLocalization_Response.TokenList\x1a$\n\x05Token\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\x1ah\n\tTokenList\x12\x10\n\x08language\x18\x01 \x01(\t\x12I\n\x06tokens\x18\x02 \x03(\x0b\x32\x39.CCommunity_GetAppRichPresenceLocalization_Response.Token\"\xcf\x02\n#CCommunity_GetCommentThread_Request\x12\x0f\n\x07steamid\x18\x01 \x01(\x06\x12M\n\x13\x63omment_thread_type\x18\x02 \x01(\x0e\x32\x13.ECommentThreadType:\x1bk_ECommentThreadTypeInvalid\x12\x12\n\ngidfeature\x18\x03 \x01(\x06\x12\x13\n\x0bgidfeature2\x18\x04 \x01(\x06\x12\x17\n\x0f\x63ommentthreadid\x18\x05 \x01(\x06\x12\r\n\x05start\x18\x06 \x01(\x05\x12\r\n\x05\x63ount\x18\x07 \x01(\x05\x12\x10\n\x08upvoters\x18\x08 \x01(\x05\x12\x17\n\x0finclude_deleted\x18\t \x01(\x08\x12\x12\n\ngidcomment\x18\n \x01(\x06\x12\x13\n\x0btime_oldest\x18\x0b \x01(\r\x12\x14\n\x0coldest_first\x18\x0c \x01(\x08\"\xf0\x02\n\x12\x43\x43ommunity_Comment\x12\x12\n\ngidcomment\x18\x01 \x01(\x06\x12\x0f\n\x07steamid\x18\x02 \x01(\x06\x12\x11\n\ttimestamp\x18\x03 \x01(\r\x12\x0c\n\x04text\x18\x04 \x01(\t\x12\x0f\n\x07upvotes\x18\x05 \x01(\x05\x12\x0e\n\x06hidden\x18\x06 \x01(\x08\x12\x16\n\x0ehidden_by_user\x18\x07 \x01(\x08\x12\x0f\n\x07\x64\x65leted\x18\x08 \x01(\x08\x12!\n\tipaddress\x18\t \x01(\x0b\x32\x0e.CMsgIPAddress\x12\x14\n\x0ctotal_hidden\x18\n \x01(\x05\x12\x17\n\x0fupvoted_by_user\x18\x0b \x01(\x08\x12/\n\treactions\x18\x0c \x03(\x0b\x32\x1c.CCommunity_Comment.Reaction\x12\x18\n\x10gidparentcomment\x18\r \x01(\x06\x1a-\n\x08Reaction\x12\x12\n\nreactionid\x18\x01 \x01(\r\x12\r\n\x05\x63ount\x18\x02 \x01(\r\"\xce\x03\n$CCommunity_GetCommentThread_Response\x12%\n\x08\x63omments\x18\x01 \x03(\x0b\x32\x13.CCommunity_Comment\x12-\n\x10\x64\x65leted_comments\x18\x02 \x03(\x0b\x32\x13.CCommunity_Comment\x12\x0f\n\x07steamid\x18\x03 \x01(\x06\x12\x17\n\x0f\x63ommentthreadid\x18\x04 \x01(\x06\x12\r\n\x05start\x18\x05 \x01(\x05\x12\r\n\x05\x63ount\x18\x06 \x01(\x05\x12\x13\n\x0btotal_count\x18\x07 \x01(\x05\x12\x0f\n\x07upvotes\x18\x08 \x01(\x05\x12\x10\n\x08upvoters\x18\t \x03(\r\x12\x17\n\x0fuser_subscribed\x18\n \x01(\x08\x12\x14\n\x0cuser_upvoted\x18\x0b \x01(\x08\x12\x18\n\x10\x61nswer_commentid\x18\x0c \x01(\x06\x12\x14\n\x0c\x61nswer_actor\x18\r \x01(\r\x12\x19\n\x11\x61nswer_actor_rank\x18\x0e \x01(\x05\x12\x10\n\x08\x63\x61n_post\x18\x0f \x01(\x08\x12\x1b\n\x13\x63omment_thread_type\x18\x10 \x01(\r\x12\x12\n\ngidfeature\x18\x11 \x01(\x06\x12\x13\n\x0bgidfeature2\x18\x12 \x01(\x06\"\xa2\x02\n&CCommunity_PostCommentToThread_Request\x12\x0f\n\x07steamid\x18\x01 \x01(\x06\x12M\n\x13\x63omment_thread_type\x18\x02 \x01(\x0e\x32\x13.ECommentThreadType:\x1bk_ECommentThreadTypeInvalid\x12\x12\n\ngidfeature\x18\x03 \x01(\x06\x12\x13\n\x0bgidfeature2\x18\x04 \x01(\x06\x12\x0c\n\x04text\x18\x06 \x01(\t\x12\x18\n\x10gidparentcomment\x18\x07 \x01(\x06\x12\x1e\n\x16suppress_notifications\x18\x08 \x01(\x08\x12\x11\n\tis_report\x18\t \x01(\x08\x12\x14\n\x0cstart_hidden\x18\n \x01(\x08\"v\n\'CCommunity_PostCommentToThread_Response\x12\x12\n\ngidcomment\x18\x01 \x01(\x06\x12\x17\n\x0f\x63ommentthreadid\x18\x02 \x01(\x06\x12\r\n\x05\x63ount\x18\x03 \x01(\x05\x12\x0f\n\x07upvotes\x18\x04 \x01(\x05\"\xdb\x01\n*CCommunity_DeleteCommentFromThread_Request\x12\x0f\n\x07steamid\x18\x01 \x01(\x06\x12M\n\x13\x63omment_thread_type\x18\x02 \x01(\x0e\x32\x13.ECommentThreadType:\x1bk_ECommentThreadTypeInvalid\x12\x12\n\ngidfeature\x18\x03 \x01(\x06\x12\x13\n\x0bgidfeature2\x18\x04 \x01(\x06\x12\x12\n\ngidcomment\x18\x05 \x01(\x06\x12\x10\n\x08undelete\x18\x06 \x01(\x08\"-\n+CCommunity_DeleteCommentFromThread_Response\"\xc0\x01\n$CCommunity_RateCommentThread_Request\x12\x19\n\x11\x63ommentthreadtype\x18\x01 \x01(\t\x12\x0f\n\x07steamid\x18\x02 \x01(\x04\x12\x12\n\ngidfeature\x18\x03 \x01(\x04\x12\x13\n\x0bgidfeature2\x18\x04 \x01(\x04\x12\x12\n\ngidcomment\x18\x05 \x01(\x04\x12\x0f\n\x07rate_up\x18\x06 \x01(\x08\x12\x1e\n\x16suppress_notifications\x18\x07 \x01(\x08\"\x89\x01\n%CCommunity_RateCommentThread_Response\x12\x12\n\ngidcomment\x18\x01 \x01(\x04\x12\x17\n\x0f\x63ommentthreadid\x18\x02 \x01(\x04\x12\r\n\x05\x63ount\x18\x03 \x01(\r\x12\x0f\n\x07upvotes\x18\x04 \x01(\r\x12\x13\n\x0bhas_upvoted\x18\x05 \x01(\x08\"\xaa\x01\n*CCommunity_GetCommentThreadRatings_Request\x12\x19\n\x11\x63ommentthreadtype\x18\x01 \x01(\t\x12\x0f\n\x07steamid\x18\x02 \x01(\x04\x12\x12\n\ngidfeature\x18\x03 \x01(\x04\x12\x13\n\x0bgidfeature2\x18\x04 \x01(\x04\x12\x12\n\ngidcomment\x18\x05 \x01(\x04\x12\x13\n\x0bmax_results\x18\x06 \x01(\r\"\x9c\x01\n+CCommunity_GetCommentThreadRatings_Response\x12\x17\n\x0f\x63ommentthreadid\x18\x01 \x01(\x04\x12\x12\n\ngidcomment\x18\x02 \x01(\x04\x12\x0f\n\x07upvotes\x18\x03 \x01(\r\x12\x13\n\x0bhas_upvoted\x18\x04 \x01(\x08\x12\x1a\n\x12upvoter_accountids\x18\x05 \x03(\r\"j\n\'CCommunity_RateClanAnnouncement_Request\x12\x16\n\x0e\x61nnouncementid\x18\x01 \x01(\x04\x12\x0f\n\x07vote_up\x18\x02 \x01(\x08\x12\x16\n\x0e\x63lan_accountid\x18\x03 \x01(\r\"*\n(CCommunity_RateClanAnnouncement_Response\"K\n1CCommunity_GetClanAnnouncementVoteForUser_Request\x12\x16\n\x0e\x61nnouncementid\x18\x01 \x01(\x04\"Z\n2CCommunity_GetClanAnnouncementVoteForUser_Response\x12\x10\n\x08voted_up\x18\x01 \x01(\x08\x12\x12\n\nvoted_down\x18\x02 \x01(\x08\"\x9d\x01\n(CCommunity_GetClanLocGroupImages_Request\x12\x0f\n\x07steamid\x18\x01 \x01(\x04\x12\x37\n\x05group\x18\x02 \x01(\x0e\x32\x10.EClanImageGroup:\x16k_EClanImageGroup_None\x12\x10\n\x08language\x18\x03 \x01(\r\x12\x15\n\rloc_group_ids\x18\x04 \x03(\x04\"\x92\x02\n\x1c\x43\x43ommunity_ClanLocGroupImage\x12\x14\n\x0cloc_group_id\x18\x01 \x01(\x04\x12\x12\n\nimage_hash\x18\x02 \x01(\t\x12\x16\n\x0ethumbnail_hash\x18\x03 \x01(\t\x12\x44\n\tfile_type\x18\x04 \x01(\x0e\x32\x13.EClanImageFileType:\x1ck_EClanImageFileType_Unknown\x12\x37\n\x05group\x18\x05 \x01(\x0e\x32\x10.EClanImageGroup:\x16k_EClanImageGroup_None\x12\r\n\x05width\x18\x06 \x01(\r\x12\x0e\n\x06height\x18\x07 \x01(\r\x12\x12\n\nextensions\x18\x08 \x01(\t\"Z\n)CCommunity_GetClanLocGroupImages_Response\x12-\n\x06images\x18\x01 \x03(\x0b\x32\x1d.CCommunity_ClanLocGroupImage\"Y\n#CCommunity_GetAvatarHistory_Request\x12\x0f\n\x07steamid\x18\x01 \x01(\x06\x12!\n\x19\x66ilter_user_uploaded_only\x18\x02 \x01(\x08\"\xb6\x01\n$CCommunity_GetAvatarHistory_Response\x12\x41\n\x07\x61vatars\x18\x01 \x03(\x0b\x32\x30.CCommunity_GetAvatarHistory_Response.AvatarData\x1aK\n\nAvatarData\x12\x13\n\x0b\x61vatar_sha1\x18\x01 \x01(\t\x12\x15\n\ruser_uploaded\x18\x02 \x01(\x08\x12\x11\n\ttimestamp\x18\x03 \x01(\r\"Q\n.CCommunity_GetClanEventCrowdInMetadata_Request\x12\x0f\n\x07steamid\x18\x01 \x01(\x06\x12\x0e\n\x06itemid\x18\x02 \x01(\x04\"f\n/CCommunity_GetClanEventCrowdInMetadata_Response\x12\x1a\n\x12\x63rowdin_project_id\x18\x01 \x01(\x04\x12\x17\n\x0f\x63rowdin_file_id\x18\x02 \x01(\x04\"<\n)CCommunity_GetClanCrowdInMetadata_Request\x12\x0f\n\x07steamid\x18\x01 \x01(\x06\"\x7f\n*CCommunity_GetClanCrowdInMetadata_Response\x12\x1a\n\x12\x63rowdin_project_id\x18\x01 \x01(\x04\x12\x1c\n\x14\x63rowdin_directory_id\x18\x02 \x01(\x04\x12\x17\n\x0fpush_by_default\x18\x03 \x01(\x08\"c\n.CCommunity_FetchTranslationFromCrowdIn_Request\x12\x0f\n\x07steamid\x18\x01 \x01(\x06\x12\x0e\n\x06itemid\x18\x02 \x01(\x04\x12\x10\n\x08language\x18\x03 \x01(\x05\"1\n/CCommunity_FetchTranslationFromCrowdIn_Response\"\x83\x02\n\'CCommunity_HideAndReportComment_Request\x12\x12\n\ngidfeature\x18\x01 \x01(\x04\x12\x13\n\x0bgidfeature2\x18\x02 \x01(\x04\x12\x12\n\ngidcomment\x18\x03 \x01(\x04\x12\x0f\n\x07steamid\x18\x04 \x01(\x06\x12\x19\n\x11\x63ommentthreadtype\x18\x05 \x01(\t\x12\x0c\n\x04hide\x18\x06 \x01(\x08\x12L\n\rreport_reason\x18\x07 \x01(\x0e\x32\x15.EContentReportReason:\x1ek_EContentReportReason_Invalid\x12\x13\n\x0breport_text\x18\x08 \x01(\t\"*\n(CCommunity_HideAndReportComment_Response\"/\n\x0c\x43\x41ppPriority\x12\x10\n\x08priority\x18\x01 \x01(\r\x12\r\n\x05\x61ppid\x18\x02 \x03(\r\"\xba\x02\n*CCommunity_GetUserPartnerEventNews_Request\x12\r\n\x05\x63ount\x18\x01 \x01(\r\x12\x0e\n\x06offset\x18\x02 \x01(\r\x12\x1a\n\x12rtime32_start_time\x18\x03 \x01(\r\x12\x18\n\x10rtime32_end_time\x18\x04 \x01(\r\x12\x1b\n\x13language_preference\x18\x05 \x03(\r\x12/\n\x11\x66ilter_event_type\x18\x06 \x03(\x0e\x32\x14.EProtoClanEventType\x12\x17\n\x0f\x66ilter_to_appid\x18\x07 \x01(\x08\x12\x1f\n\x08\x61pp_list\x18\x08 \x03(\x0b\x32\r.CAppPriority\x12\x16\n\x0b\x63ount_after\x18\t \x01(\r:\x01\x30\x12\x17\n\x0c\x63ount_before\x18\n \x01(\r:\x01\x30\"W\n+CCommunity_GetUserPartnerEventNews_Response\x12(\n\x07results\x18\x01 \x03(\x0b\x32\x17.CClanMatchEventByRange\"\x8e\x01\n\'CCommunity_GetBestEventsForUser_Request\x12\x1a\n\x12include_steam_blog\x18\x01 \x01(\x08\x12$\n\x1c\x66ilter_to_played_within_days\x18\x02 \x01(\r\x12!\n\x19include_only_game_updates\x18\x03 \x01(\x08\"\xc3\x01\n\x1d\x43\x43ommunity_PartnerEventResult\x12\x0e\n\x06\x63lanid\x18\x01 \x01(\r\x12\x11\n\tevent_gid\x18\x02 \x01(\x06\x12\x18\n\x10\x61nnouncement_gid\x18\x03 \x01(\x06\x12\r\n\x05\x61ppid\x18\x04 \x01(\r\x12\x19\n\x11possible_takeover\x18\x05 \x01(\x08\x12 \n\x15rtime32_last_modified\x18\x06 \x01(\r:\x01\x30\x12\x19\n\x11user_app_priority\x18\x07 \x01(\x05\"[\n(CCommunity_GetBestEventsForUser_Response\x12/\n\x07results\x18\x01 \x03(\x0b\x32\x1e.CCommunity_PartnerEventResult\"\xc4\x02\n+CCommunity_MarkPartnerEventsForUser_Request\x12R\n\x08markings\x18\x01 \x03(\x0b\x32@.CCommunity_MarkPartnerEventsForUser_Request.PartnerEventMarking\x1a\xc0\x01\n\x13PartnerEventMarking\x12\x0e\n\x06\x63lanid\x18\x01 \x01(\r\x12\x11\n\tevent_gid\x18\x02 \x01(\x06\x12_\n\x10\x64isplay_location\x18\x03 \x01(\x0e\x32\x1d.EPartnerEventDisplayLocation:&k_EPartnerEventDisplayLocation_Invalid\x12\x12\n\nmark_shown\x18\x04 \x01(\x08\x12\x11\n\tmark_read\x18\x05 \x01(\x08\".\n,CCommunity_MarkPartnerEventsForUser_Response\"h\n0CCommunity_GetUserPartnerEventViewStatus_Request\x12\x12\n\nevent_gids\x18\x01 \x03(\x06\x12 \n\x18include_read_events_only\x18\x02 \x01(\x08\"\xf1\x01\n1CCommunity_GetUserPartnerEventViewStatus_Response\x12O\n\x06\x65vents\x18\x01 \x03(\x0b\x32?.CCommunity_GetUserPartnerEventViewStatus_Response.PartnerEvent\x1ak\n\x0cPartnerEvent\x12\x11\n\tevent_gid\x18\x01 \x01(\x06\x12\x17\n\x0flast_shown_time\x18\x02 \x01(\r\x12\x16\n\x0elast_read_time\x18\x03 \x01(\r\x12\x17\n\x0f\x63lan_account_id\x18\x04 \x01(\r\"?\n.CCommunity_PartnerEventsShowMoreForApp_Request\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\"1\n/CCommunity_PartnerEventsShowMoreForApp_Response\"?\n.CCommunity_PartnerEventsShowLessForApp_Request\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\"1\n/CCommunity_PartnerEventsShowLessForApp_Response\"8\n6CCommunity_ClearUserPartnerEventsAppPriorities_Request\"9\n7CCommunity_ClearUserPartnerEventsAppPriorities_Response\"6\n4CCommunity_GetUserPartnerEventsAppPriorities_Request\"O\n#CCommunity_PartnerEventsAppPriority\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x19\n\x11user_app_priority\x18\x02 \x01(\x05\"q\n5CCommunity_GetUserPartnerEventsAppPriorities_Response\x12\x38\n\npriorities\x18\x01 \x03(\x0b\x32$.CCommunity_PartnerEventsAppPriority\"G\n6CCommunity_ClearSinglePartnerEventsAppPriority_Request\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\"9\n7CCommunity_ClearSinglePartnerEventsAppPriority_Response\"\xdd\x01\n3CCommunity_SetRecommendationBotReviewStatus_Request\x12W\n\rreview_labels\x18\x01 \x03(\x0b\x32@.CCommunity_SetRecommendationBotReviewStatus_Request.ReviewLabel\x1aM\n\x0bReviewLabel\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x18\n\x10recommendationid\x18\x02 \x01(\x04\x12\x15\n\ris_bot_review\x18\x03 \x01(\x08\"6\n4CCommunity_SetRecommendationBotReviewStatus_Response\"c\n5CCommunity_GetBotReviewScoreForRecommendation_Request\x12\x1a\n\x12recommendation_ids\x18\x01 \x03(\x04\x12\x0e\n\x06\x61pp_id\x18\x02 \x01(\r\"\xd2\x01\n6CCommunity_GetBotReviewScoreForRecommendation_Response\x12\x65\n\x10\x62ot_review_score\x18\x01 \x03(\x0b\x32K.CCommunity_GetBotReviewScoreForRecommendation_Response.BotReviewScoreEntry\x1a\x31\n\x13\x42otReviewScoreEntry\x12\x0b\n\x03key\x18\x01 \x01(\x04\x12\r\n\x05value\x18\x02 \x01(\r*p\n\x0f\x45\x43lanImageGroup\x12\x1a\n\x16k_EClanImageGroup_None\x10\x00\x12\"\n\x1ek_EClanImageGroup_Announcement\x10\x01\x12\x1d\n\x19k_EClanImageGroup_Curator\x10\x02*\xe5\x02\n\x12\x45\x43lanImageFileType\x12 \n\x1ck_EClanImageFileType_Unknown\x10\x00\x12\x1d\n\x19k_EClanImageFileType_JPEG\x10\x01\x12\x1c\n\x18k_EClanImageFileType_GIF\x10\x02\x12\x1c\n\x18k_EClanImageFileType_PNG\x10\x03\x12\x1c\n\x18k_EClanImageFileType_MP4\x10\x04\x12\x1d\n\x19k_EClanImageFileType_WEBM\x10\x05\x12\x1c\n\x18k_EClanImageFileType_VTT\x10\x06\x12\x1c\n\x18k_EClanImageFileType_SRT\x10\x07\x12\x1c\n\x18k_EClanImageFileType_SVG\x10\x08\x12\x1c\n\x18k_EClanImageFileType_XML\x10\t\x12\x1d\n\x19k_EClanImageFileType_WEBP\x10\n*\xbd\x04\n\x1c\x45PartnerEventDisplayLocation\x12*\n&k_EPartnerEventDisplayLocation_Invalid\x10\x00\x12\x36\n2k_EPartnerEventDisplayLocation_AppDetailsSpotlight\x10\x01\x12\x32\n.k_EPartnerEventDisplayLocation_LibraryOverview\x10\x02\x12/\n+k_EPartnerEventDisplayLocation_StoreAppPage\x10\x03\x12\x30\n,k_EPartnerEventDisplayLocation_EventScroller\x10\x04\x12\x35\n1k_EPartnerEventDisplayLocation_AppDetailsActivity\x10\x05\x12/\n+k_EPartnerEventDisplayLocation_CommunityHub\x10\x06\x12\x31\n-k_EPartnerEventDisplayLocation_StoreFrontPage\x10\x07\x12*\n&k_EPartnerEventDisplayLocation_NewsHub\x10\x08\x12.\n*k_EPartnerEventDisplayLocation_GamepadHome\x10\t\x12+\n\'k_EPartnerEventDisplayLocation_StoreHub\x10\n2\x88\x19\n\tCommunity\x12\x44\n\x07GetApps\x12\x1b.CCommunity_GetApps_Request\x1a\x1c.CCommunity_GetApps_Response\x12\x89\x01\n\x1eGetAppRichPresenceLocalization\x12\x32.CCommunity_GetAppRichPresenceLocalization_Request\x1a\x33.CCommunity_GetAppRichPresenceLocalization_Response\x12_\n\x10GetCommentThread\x12$.CCommunity_GetCommentThread_Request\x1a%.CCommunity_GetCommentThread_Response\x12h\n\x13PostCommentToThread\x12\'.CCommunity_PostCommentToThread_Request\x1a(.CCommunity_PostCommentToThread_Response\x12t\n\x17\x44\x65leteCommentFromThread\x12+.CCommunity_DeleteCommentFromThread_Request\x1a,.CCommunity_DeleteCommentFromThread_Response\x12\x62\n\x11RateCommentThread\x12%.CCommunity_RateCommentThread_Request\x1a&.CCommunity_RateCommentThread_Response\x12t\n\x17GetCommentThreadRatings\x12+.CCommunity_GetCommentThreadRatings_Request\x1a,.CCommunity_GetCommentThreadRatings_Response\x12k\n\x14RateClanAnnouncement\x12(.CCommunity_RateClanAnnouncement_Request\x1a).CCommunity_RateClanAnnouncement_Response\x12\x89\x01\n\x1eGetClanAnnouncementVoteForUser\x12\x32.CCommunity_GetClanAnnouncementVoteForUser_Request\x1a\x33.CCommunity_GetClanAnnouncementVoteForUser_Response\x12n\n\x15GetClanLocGroupImages\x12).CCommunity_GetClanLocGroupImages_Request\x1a*.CCommunity_GetClanLocGroupImages_Response\x12_\n\x10GetAvatarHistory\x12$.CCommunity_GetAvatarHistory_Request\x1a%.CCommunity_GetAvatarHistory_Response\x12\x80\x01\n\x1bGetClanEventCrowdInMetadata\x12/.CCommunity_GetClanEventCrowdInMetadata_Request\x1a\x30.CCommunity_GetClanEventCrowdInMetadata_Response\x12q\n\x16GetClanCrowdInMetadata\x12*.CCommunity_GetClanCrowdInMetadata_Request\x1a+.CCommunity_GetClanCrowdInMetadata_Response\x12\x80\x01\n\x1b\x46\x65tchTranslationFromCrowdIn\x12/.CCommunity_FetchTranslationFromCrowdIn_Request\x1a\x30.CCommunity_FetchTranslationFromCrowdIn_Response\x12k\n\x14HideAndReportComment\x12(.CCommunity_HideAndReportComment_Request\x1a).CCommunity_HideAndReportComment_Response\x12t\n\x17GetUserPartnerEventNews\x12+.CCommunity_GetUserPartnerEventNews_Request\x1a,.CCommunity_GetUserPartnerEventNews_Response\x12k\n\x14GetBestEventsForUser\x12(.CCommunity_GetBestEventsForUser_Request\x1a).CCommunity_GetBestEventsForUser_Response\x12w\n\x18MarkPartnerEventsForUser\x12,.CCommunity_MarkPartnerEventsForUser_Request\x1a-.CCommunity_MarkPartnerEventsForUser_Response\x12\x86\x01\n\x1dGetUserPartnerEventViewStatus\x12\x31.CCommunity_GetUserPartnerEventViewStatus_Request\x1a\x32.CCommunity_GetUserPartnerEventViewStatus_Response\x12\x80\x01\n\x1bPartnerEventsShowMoreForApp\x12/.CCommunity_PartnerEventsShowMoreForApp_Request\x1a\x30.CCommunity_PartnerEventsShowMoreForApp_Response\x12\x80\x01\n\x1bPartnerEventsShowLessForApp\x12/.CCommunity_PartnerEventsShowLessForApp_Request\x1a\x30.CCommunity_PartnerEventsShowLessForApp_Response\x12\x98\x01\n#ClearUserPartnerEventsAppPriorities\x12\x37.CCommunity_ClearUserPartnerEventsAppPriorities_Request\x1a\x38.CCommunity_ClearUserPartnerEventsAppPriorities_Response\x12\x92\x01\n!GetUserPartnerEventsAppPriorities\x12\x35.CCommunity_GetUserPartnerEventsAppPriorities_Request\x1a\x36.CCommunity_GetUserPartnerEventsAppPriorities_Response\x12\x98\x01\n#ClearSinglePartnerEventsAppPriority\x12\x37.CCommunity_ClearSinglePartnerEventsAppPriority_Request\x1a\x38.CCommunity_ClearSinglePartnerEventsAppPriority_Response\x12\x8f\x01\n SetRecommendationBotReviewStatus\x12\x34.CCommunity_SetRecommendationBotReviewStatus_Request\x1a\x35.CCommunity_SetRecommendationBotReviewStatus_Response\x12\x95\x01\n\"GetBotReviewScoreForRecommendation\x12\x36.CCommunity_GetBotReviewScoreForRecommendation_Request\x1a\x37.CCommunity_GetBotReviewScoreForRecommendation_ResponseB\x03\x90\x01\x01')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'steammessages_community_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\220\001\001'
  _ECLANIMAGEGROUP._serialized_start=8050
  _ECLANIMAGEGROUP._serialized_end=8162
  _ECLANIMAGEFILETYPE._serialized_start=8165
  _ECLANIMAGEFILETYPE._serialized_end=8522
  _EPARTNEREVENTDISPLAYLOCATION._serialized_start=8525
  _EPARTNEREVENTDISPLAYLOCATION._serialized_end=9098
  _CCOMMUNITY_GETAPPS_REQUEST._serialized_start=106
  _CCOMMUNITY_GETAPPS_REQUEST._serialized_end=168
  _CCOMMUNITY_GETAPPS_RESPONSE._serialized_start=170
  _CCOMMUNITY_GETAPPS_RESPONSE._serialized_end=236
  _CCOMMUNITY_GETAPPRICHPRESENCELOCALIZATION_REQUEST._serialized_start=238
  _CCOMMUNITY_GETAPPRICHPRESENCELOCALIZATION_REQUEST._serialized_end=322
  _CCOMMUNITY_GETAPPRICHPRESENCELOCALIZATION_RESPONSE._serialized_start=325
  _CCOMMUNITY_GETAPPRICHPRESENCELOCALIZATION_RESPONSE._serialized_end=620
  _CCOMMUNITY_GETAPPRICHPRESENCELOCALIZATION_RESPONSE_TOKEN._serialized_start=478
  _CCOMMUNITY_GETAPPRICHPRESENCELOCALIZATION_RESPONSE_TOKEN._serialized_end=514
  _CCOMMUNITY_GETAPPRICHPRESENCELOCALIZATION_RESPONSE_TOKENLIST._serialized_start=516
  _CCOMMUNITY_GETAPPRICHPRESENCELOCALIZATION_RESPONSE_TOKENLIST._serialized_end=620
  _CCOMMUNITY_GETCOMMENTTHREAD_REQUEST._serialized_start=623
  _CCOMMUNITY_GETCOMMENTTHREAD_REQUEST._serialized_end=958
  _CCOMMUNITY_COMMENT._serialized_start=961
  _CCOMMUNITY_COMMENT._serialized_end=1329
  _CCOMMUNITY_COMMENT_REACTION._serialized_start=1284
  _CCOMMUNITY_COMMENT_REACTION._serialized_end=1329
  _CCOMMUNITY_GETCOMMENTTHREAD_RESPONSE._serialized_start=1332
  _CCOMMUNITY_GETCOMMENTTHREAD_RESPONSE._serialized_end=1794
  _CCOMMUNITY_POSTCOMMENTTOTHREAD_REQUEST._serialized_start=1797
  _CCOMMUNITY_POSTCOMMENTTOTHREAD_REQUEST._serialized_end=2087
  _CCOMMUNITY_POSTCOMMENTTOTHREAD_RESPONSE._serialized_start=2089
  _CCOMMUNITY_POSTCOMMENTTOTHREAD_RESPONSE._serialized_end=2207
  _CCOMMUNITY_DELETECOMMENTFROMTHREAD_REQUEST._serialized_start=2210
  _CCOMMUNITY_DELETECOMMENTFROMTHREAD_REQUEST._serialized_end=2429
  _CCOMMUNITY_DELETECOMMENTFROMTHREAD_RESPONSE._serialized_start=2431
  _CCOMMUNITY_DELETECOMMENTFROMTHREAD_RESPONSE._serialized_end=2476
  _CCOMMUNITY_RATECOMMENTTHREAD_REQUEST._serialized_start=2479
  _CCOMMUNITY_RATECOMMENTTHREAD_REQUEST._serialized_end=2671
  _CCOMMUNITY_RATECOMMENTTHREAD_RESPONSE._serialized_start=2674
  _CCOMMUNITY_RATECOMMENTTHREAD_RESPONSE._serialized_end=2811
  _CCOMMUNITY_GETCOMMENTTHREADRATINGS_REQUEST._serialized_start=2814
  _CCOMMUNITY_GETCOMMENTTHREADRATINGS_REQUEST._serialized_end=2984
  _CCOMMUNITY_GETCOMMENTTHREADRATINGS_RESPONSE._serialized_start=2987
  _CCOMMUNITY_GETCOMMENTTHREADRATINGS_RESPONSE._serialized_end=3143
  _CCOMMUNITY_RATECLANANNOUNCEMENT_REQUEST._serialized_start=3145
  _CCOMMUNITY_RATECLANANNOUNCEMENT_REQUEST._serialized_end=3251
  _CCOMMUNITY_RATECLANANNOUNCEMENT_RESPONSE._serialized_start=3253
  _CCOMMUNITY_RATECLANANNOUNCEMENT_RESPONSE._serialized_end=3295
  _CCOMMUNITY_GETCLANANNOUNCEMENTVOTEFORUSER_REQUEST._serialized_start=3297
  _CCOMMUNITY_GETCLANANNOUNCEMENTVOTEFORUSER_REQUEST._serialized_end=3372
  _CCOMMUNITY_GETCLANANNOUNCEMENTVOTEFORUSER_RESPONSE._serialized_start=3374
  _CCOMMUNITY_GETCLANANNOUNCEMENTVOTEFORUSER_RESPONSE._serialized_end=3464
  _CCOMMUNITY_GETCLANLOCGROUPIMAGES_REQUEST._serialized_start=3467
  _CCOMMUNITY_GETCLANLOCGROUPIMAGES_REQUEST._serialized_end=3624
  _CCOMMUNITY_CLANLOCGROUPIMAGE._serialized_start=3627
  _CCOMMUNITY_CLANLOCGROUPIMAGE._serialized_end=3901
  _CCOMMUNITY_GETCLANLOCGROUPIMAGES_RESPONSE._serialized_start=3903
  _CCOMMUNITY_GETCLANLOCGROUPIMAGES_RESPONSE._serialized_end=3993
  _CCOMMUNITY_GETAVATARHISTORY_REQUEST._serialized_start=3995
  _CCOMMUNITY_GETAVATARHISTORY_REQUEST._serialized_end=4084
  _CCOMMUNITY_GETAVATARHISTORY_RESPONSE._serialized_start=4087
  _CCOMMUNITY_GETAVATARHISTORY_RESPONSE._serialized_end=4269
  _CCOMMUNITY_GETAVATARHISTORY_RESPONSE_AVATARDATA._serialized_start=4194
  _CCOMMUNITY_GETAVATARHISTORY_RESPONSE_AVATARDATA._serialized_end=4269
  _CCOMMUNITY_GETCLANEVENTCROWDINMETADATA_REQUEST._serialized_start=4271
  _CCOMMUNITY_GETCLANEVENTCROWDINMETADATA_REQUEST._serialized_end=4352
  _CCOMMUNITY_GETCLANEVENTCROWDINMETADATA_RESPONSE._serialized_start=4354
  _CCOMMUNITY_GETCLANEVENTCROWDINMETADATA_RESPONSE._serialized_end=4456
  _CCOMMUNITY_GETCLANCROWDINMETADATA_REQUEST._serialized_start=4458
  _CCOMMUNITY_GETCLANCROWDINMETADATA_REQUEST._serialized_end=4518
  _CCOMMUNITY_GETCLANCROWDINMETADATA_RESPONSE._serialized_start=4520
  _CCOMMUNITY_GETCLANCROWDINMETADATA_RESPONSE._serialized_end=4647
  _CCOMMUNITY_FETCHTRANSLATIONFROMCROWDIN_REQUEST._serialized_start=4649
  _CCOMMUNITY_FETCHTRANSLATIONFROMCROWDIN_REQUEST._serialized_end=4748
  _CCOMMUNITY_FETCHTRANSLATIONFROMCROWDIN_RESPONSE._serialized_start=4750
  _CCOMMUNITY_FETCHTRANSLATIONFROMCROWDIN_RESPONSE._serialized_end=4799
  _CCOMMUNITY_HIDEANDREPORTCOMMENT_REQUEST._serialized_start=4802
  _CCOMMUNITY_HIDEANDREPORTCOMMENT_REQUEST._serialized_end=5061
  _CCOMMUNITY_HIDEANDREPORTCOMMENT_RESPONSE._serialized_start=5063
  _CCOMMUNITY_HIDEANDREPORTCOMMENT_RESPONSE._serialized_end=5105
  _CAPPPRIORITY._serialized_start=5107
  _CAPPPRIORITY._serialized_end=5154
  _CCOMMUNITY_GETUSERPARTNEREVENTNEWS_REQUEST._serialized_start=5157
  _CCOMMUNITY_GETUSERPARTNEREVENTNEWS_REQUEST._serialized_end=5471
  _CCOMMUNITY_GETUSERPARTNEREVENTNEWS_RESPONSE._serialized_start=5473
  _CCOMMUNITY_GETUSERPARTNEREVENTNEWS_RESPONSE._serialized_end=5560
  _CCOMMUNITY_GETBESTEVENTSFORUSER_REQUEST._serialized_start=5563
  _CCOMMUNITY_GETBESTEVENTSFORUSER_REQUEST._serialized_end=5705
  _CCOMMUNITY_PARTNEREVENTRESULT._serialized_start=5708
  _CCOMMUNITY_PARTNEREVENTRESULT._serialized_end=5903
  _CCOMMUNITY_GETBESTEVENTSFORUSER_RESPONSE._serialized_start=5905
  _CCOMMUNITY_GETBESTEVENTSFORUSER_RESPONSE._serialized_end=5996
  _CCOMMUNITY_MARKPARTNEREVENTSFORUSER_REQUEST._serialized_start=5999
  _CCOMMUNITY_MARKPARTNEREVENTSFORUSER_REQUEST._serialized_end=6323
  _CCOMMUNITY_MARKPARTNEREVENTSFORUSER_REQUEST_PARTNEREVENTMARKING._serialized_start=6131
  _CCOMMUNITY_MARKPARTNEREVENTSFORUSER_REQUEST_PARTNEREVENTMARKING._serialized_end=6323
  _CCOMMUNITY_MARKPARTNEREVENTSFORUSER_RESPONSE._serialized_start=6325
  _CCOMMUNITY_MARKPARTNEREVENTSFORUSER_RESPONSE._serialized_end=6371
  _CCOMMUNITY_GETUSERPARTNEREVENTVIEWSTATUS_REQUEST._serialized_start=6373
  _CCOMMUNITY_GETUSERPARTNEREVENTVIEWSTATUS_REQUEST._serialized_end=6477
  _CCOMMUNITY_GETUSERPARTNEREVENTVIEWSTATUS_RESPONSE._serialized_start=6480
  _CCOMMUNITY_GETUSERPARTNEREVENTVIEWSTATUS_RESPONSE._serialized_end=6721
  _CCOMMUNITY_GETUSERPARTNEREVENTVIEWSTATUS_RESPONSE_PARTNEREVENT._serialized_start=6614
  _CCOMMUNITY_GETUSERPARTNEREVENTVIEWSTATUS_RESPONSE_PARTNEREVENT._serialized_end=6721
  _CCOMMUNITY_PARTNEREVENTSSHOWMOREFORAPP_REQUEST._serialized_start=6723
  _CCOMMUNITY_PARTNEREVENTSSHOWMOREFORAPP_REQUEST._serialized_end=6786
  _CCOMMUNITY_PARTNEREVENTSSHOWMOREFORAPP_RESPONSE._serialized_start=6788
  _CCOMMUNITY_PARTNEREVENTSSHOWMOREFORAPP_RESPONSE._serialized_end=6837
  _CCOMMUNITY_PARTNEREVENTSSHOWLESSFORAPP_REQUEST._serialized_start=6839
  _CCOMMUNITY_PARTNEREVENTSSHOWLESSFORAPP_REQUEST._serialized_end=6902
  _CCOMMUNITY_PARTNEREVENTSSHOWLESSFORAPP_RESPONSE._serialized_start=6904
  _CCOMMUNITY_PARTNEREVENTSSHOWLESSFORAPP_RESPONSE._serialized_end=6953
  _CCOMMUNITY_CLEARUSERPARTNEREVENTSAPPPRIORITIES_REQUEST._serialized_start=6955
  _CCOMMUNITY_CLEARUSERPARTNEREVENTSAPPPRIORITIES_REQUEST._serialized_end=7011
  _CCOMMUNITY_CLEARUSERPARTNEREVENTSAPPPRIORITIES_RESPONSE._serialized_start=7013
  _CCOMMUNITY_CLEARUSERPARTNEREVENTSAPPPRIORITIES_RESPONSE._serialized_end=7070
  _CCOMMUNITY_GETUSERPARTNEREVENTSAPPPRIORITIES_REQUEST._serialized_start=7072
  _CCOMMUNITY_GETUSERPARTNEREVENTSAPPPRIORITIES_REQUEST._serialized_end=7126
  _CCOMMUNITY_PARTNEREVENTSAPPPRIORITY._serialized_start=7128
  _CCOMMUNITY_PARTNEREVENTSAPPPRIORITY._serialized_end=7207
  _CCOMMUNITY_GETUSERPARTNEREVENTSAPPPRIORITIES_RESPONSE._serialized_start=7209
  _CCOMMUNITY_GETUSERPARTNEREVENTSAPPPRIORITIES_RESPONSE._serialized_end=7322
  _CCOMMUNITY_CLEARSINGLEPARTNEREVENTSAPPPRIORITY_REQUEST._serialized_start=7324
  _CCOMMUNITY_CLEARSINGLEPARTNEREVENTSAPPPRIORITY_REQUEST._serialized_end=7395
  _CCOMMUNITY_CLEARSINGLEPARTNEREVENTSAPPPRIORITY_RESPONSE._serialized_start=7397
  _CCOMMUNITY_CLEARSINGLEPARTNEREVENTSAPPPRIORITY_RESPONSE._serialized_end=7454
  _CCOMMUNITY_SETRECOMMENDATIONBOTREVIEWSTATUS_REQUEST._serialized_start=7457
  _CCOMMUNITY_SETRECOMMENDATIONBOTREVIEWSTATUS_REQUEST._serialized_end=7678
  _CCOMMUNITY_SETRECOMMENDATIONBOTREVIEWSTATUS_REQUEST_REVIEWLABEL._serialized_start=7601
  _CCOMMUNITY_SETRECOMMENDATIONBOTREVIEWSTATUS_REQUEST_REVIEWLABEL._serialized_end=7678
  _CCOMMUNITY_SETRECOMMENDATIONBOTREVIEWSTATUS_RESPONSE._serialized_start=7680
  _CCOMMUNITY_SETRECOMMENDATIONBOTREVIEWSTATUS_RESPONSE._serialized_end=7734
  _CCOMMUNITY_GETBOTREVIEWSCOREFORRECOMMENDATION_REQUEST._serialized_start=7736
  _CCOMMUNITY_GETBOTREVIEWSCOREFORRECOMMENDATION_REQUEST._serialized_end=7835
  _CCOMMUNITY_GETBOTREVIEWSCOREFORRECOMMENDATION_RESPONSE._serialized_start=7838
  _CCOMMUNITY_GETBOTREVIEWSCOREFORRECOMMENDATION_RESPONSE._serialized_end=8048
  _CCOMMUNITY_GETBOTREVIEWSCOREFORRECOMMENDATION_RESPONSE_BOTREVIEWSCOREENTRY._serialized_start=7999
  _CCOMMUNITY_GETBOTREVIEWSCOREFORRECOMMENDATION_RESPONSE_BOTREVIEWSCOREENTRY._serialized_end=8048
  _COMMUNITY._serialized_start=9101
  _COMMUNITY._serialized_end=12309
_builder.BuildServices(DESCRIPTOR, 'steammessages_community_pb2', globals())
# @@protoc_insertion_point(module_scope)
