# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: steammessages_contentsystem.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import steam.protobufs.steammessages_base_pb2 as steammessages__base__pb2
import steam.protobufs.steammessages_unified_base_pb2 as steammessages__unified__base__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!steammessages_contentsystem.proto\x1a\x18steammessages_base.proto\x1a steammessages_unified_base.proto\"i\n4CContentServerDirectory_ConnectedSteamPipeServerInfo\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x11\n\tsource_id\x18\x02 \x01(\x05\x12\x10\n\x08hostname\x18\x03 \x01(\t\"\xfa\x01\n6CContentServerDirectory_GetServersForSteamPipe_Request\x12\x0f\n\x07\x63\x65ll_id\x18\x01 \x01(\r\x12\x17\n\x0bmax_servers\x18\x02 \x01(\r:\x02\x32\x30\x12\x13\n\x0bip_override\x18\x03 \x01(\t\x12\x18\n\rlauncher_type\x18\x04 \x01(\x05:\x01\x30\x12\x13\n\x0bipv6_public\x18\x05 \x01(\t\x12R\n\x13\x63urrent_connections\x18\x06 \x03(\x0b\x32\x35.CContentServerDirectory_ConnectedSteamPipeServerInfo\"\xf9\x02\n\"CContentServerDirectory_ServerInfo\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x11\n\tsource_id\x18\x02 \x01(\x05\x12\x0f\n\x07\x63\x65ll_id\x18\x03 \x01(\x05\x12\x0c\n\x04load\x18\x04 \x01(\x05\x12\x15\n\rweighted_load\x18\x05 \x01(\x02\x12\"\n\x1anum_entries_in_client_list\x18\x06 \x01(\x05\x12\x18\n\x10steam_china_only\x18\x07 \x01(\x08\x12\x0c\n\x04host\x18\x08 \x01(\t\x12\r\n\x05vhost\x18\t \x01(\t\x12\x14\n\x0cuse_as_proxy\x18\n \x01(\x08\x12#\n\x1bproxy_request_path_template\x18\x0b \x01(\t\x12\x15\n\rhttps_support\x18\x0c \x01(\t\x12\x17\n\x0f\x61llowed_app_ids\x18\r \x03(\r\x12\x16\n\x0epriority_class\x18\x0f \x01(\r\x12\x1e\n\x16\x62ypass_proxies_of_type\x18\x10 \x03(\t\"\x82\x01\n7CContentServerDirectory_GetServersForSteamPipe_Response\x12\x34\n\x07servers\x18\x01 \x03(\x0b\x32#.CContentServerDirectory_ServerInfo\x12\x11\n\tno_change\x18\x02 \x01(\x08\"\x89\x01\n1CContentServerDirectory_GetDepotPatchInfo_Request\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x0f\n\x07\x64\x65potid\x18\x02 \x01(\r\x12\x19\n\x11source_manifestid\x18\x03 \x01(\x04\x12\x19\n\x11target_manifestid\x18\x04 \x01(\x04\"{\n2CContentServerDirectory_GetDepotPatchInfo_Response\x12\x14\n\x0cis_available\x18\x01 \x01(\x08\x12\x12\n\npatch_size\x18\x02 \x01(\x04\x12\x1b\n\x13patched_chunks_size\x18\x03 \x01(\x04\"P\n4CContentServerDirectory_GetClientUpdateHosts_Request\x12\x18\n\x10\x63\x61\x63hed_signature\x18\x01 \x01(\t\"w\n5CContentServerDirectory_GetClientUpdateHosts_Response\x12\x10\n\x08hosts_kv\x18\x01 \x01(\t\x12\x18\n\x10valid_until_time\x18\x02 \x01(\x04\x12\x12\n\nip_country\x18\x03 \x01(\t\"\xa1\x01\n6CContentServerDirectory_GetManifestRequestCode_Request\x12\x0e\n\x06\x61pp_id\x18\x01 \x01(\r\x12\x10\n\x08\x64\x65pot_id\x18\x02 \x01(\r\x12\x13\n\x0bmanifest_id\x18\x03 \x01(\x04\x12\x12\n\napp_branch\x18\x04 \x01(\t\x12\x1c\n\x14\x62ranch_password_hash\x18\x05 \x01(\t\"X\n7CContentServerDirectory_GetManifestRequestCode_Response\x12\x1d\n\x15manifest_request_code\x18\x01 \x01(\x04\"f\n/CContentServerDirectory_GetCDNAuthToken_Request\x12\x10\n\x08\x64\x65pot_id\x18\x01 \x01(\r\x12\x11\n\thost_name\x18\x02 \x01(\t\x12\x0e\n\x06\x61pp_id\x18\x03 \x01(\r\"Z\n0CContentServerDirectory_GetCDNAuthToken_Response\x12\r\n\x05token\x18\x01 \x01(\t\x12\x17\n\x0f\x65xpiration_time\x18\x02 \x01(\r\"\xb0\x01\n8CContentServerDirectory_RequestPeerContentServer_Request\x12\x18\n\x10remote_client_id\x18\x01 \x01(\x04\x12\x0f\n\x07steamid\x18\x02 \x01(\x04\x12\x1f\n\x17server_remote_client_id\x18\x03 \x01(\x04\x12\x0e\n\x06\x61pp_id\x18\x04 \x01(\r\x12\x18\n\x10\x63urrent_build_id\x18\x05 \x01(\r\"\x80\x01\n9CContentServerDirectory_RequestPeerContentServer_Response\x12\x13\n\x0bserver_port\x18\x01 \x01(\r\x12\x18\n\x10installed_depots\x18\x02 \x03(\r\x12\x14\n\x0c\x61\x63\x63\x65ss_token\x18\x03 \x01(\x04\"\x80\x01\n2CContentServerDirectory_GetPeerContentInfo_Request\x12\x18\n\x10remote_client_id\x18\x01 \x01(\x04\x12\x0f\n\x07steamid\x18\x02 \x01(\x04\x12\x1f\n\x17server_remote_client_id\x18\x03 \x01(\x04\"X\n3CContentServerDirectory_GetPeerContentInfo_Response\x12\x0e\n\x06\x61ppids\x18\x01 \x03(\r\x12\x11\n\tip_public\x18\x02 \x01(\t\"\x8d\x01\n7CDepotContentDetection_GetAllDetectedAppContent_Request\x12R\n\x0e\x64\x65tection_type\x18\x01 \x01(\x0e\x32\x19.EAppContentDetectionType:\x1fk_EAppContentDetectionType_None\"P\n\x12\x44\x65tectedAppContent\x12\x0e\n\x06\x61pp_id\x18\x01 \x01(\r\x12\x10\n\x08\x64\x65pot_id\x18\x02 \x01(\r\x12\x18\n\x10\x64\x65tected_content\x18\x03 \x01(\x05\"m\n8CDepotContentDetection_GetAllDetectedAppContent_Response\x12\x31\n\x14\x64\x65tected_app_content\x18\x01 \x03(\x0b\x32\x13.DetectedAppContent\"K\n:CDepotContentDetection_GetDetectedContentSingleApp_Request\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\"\xd2\x01\n;CDepotContentDetection_GetDetectedContentSingleApp_Response\x12G\n\x12\x64\x65tected_anticheat\x18\x01 \x01(\x0e\x32\x12.EAppAntiCheatType:\x17k_EAppAntiCheatTypeNone\x12J\n\x13\x64\x65tected_gameengine\x18\x02 \x01(\x0e\x32\x13.EAppGameEngineType:\x18k_EAppGameEngineTypeNone*\x94\x01\n\x18\x45\x41ppContentDetectionType\x12#\n\x1fk_EAppContentDetectionType_None\x10\x00\x12(\n$k_EAppContentDetectionType_AntiCheat\x10\x01\x12)\n%k_EAppContentDetectionType_GameEngine\x10\x02*\xfa\x02\n\x11\x45\x41ppAntiCheatType\x12\x1b\n\x17k_EAppAntiCheatTypeNone\x10\x00\x12\x1d\n\x19k_EAppAntiCheatTypeEasyAC\x10\x01\x12\x1d\n\x19k_EAppAntiCheatTypeDenuvo\x10\x02\x12\x1f\n\x1bk_EAppAntiCheatTypeBattlEye\x10\x03\x12\x1f\n\x1bk_EAppAntiCheatTypeXignCode\x10\x04\x12!\n\x1dk_EAppAntiCheatTypePunkBuster\x10\x05\x12\x1a\n\x16k_EAppAntiCheatTypeVAC\x10\x06\x12 \n\x1ck_EAppAntiCheatTypeGameGuard\x10\x07\x12!\n\x1dk_EAppAntiCheatTypeHackShield\x10\x08\x12&\n\"k_EAppAntiCheatTypeAntiCheatExpert\x10\t\x12\x1c\n\x18k_EAppAntiCheatTypeOther\x10\n*R\n\x12\x45\x41ppGameEngineType\x12\x1c\n\x18k_EAppGameEngineTypeNone\x10\x00\x12\x1e\n\x1ak_EAppGameEngineTypeUnreal\x10\x01\x32\xc7\x07\n\x16\x43ontentServerDirectory\x12\x8b\x01\n\x16GetServersForSteamPipe\x12\x37.CContentServerDirectory_GetServersForSteamPipe_Request\x1a\x38.CContentServerDirectory_GetServersForSteamPipe_Response\x12|\n\x11GetDepotPatchInfo\x12\x32.CContentServerDirectory_GetDepotPatchInfo_Request\x1a\x33.CContentServerDirectory_GetDepotPatchInfo_Response\x12\x85\x01\n\x14GetClientUpdateHosts\x12\x35.CContentServerDirectory_GetClientUpdateHosts_Request\x1a\x36.CContentServerDirectory_GetClientUpdateHosts_Response\x12\x8b\x01\n\x16GetManifestRequestCode\x12\x37.CContentServerDirectory_GetManifestRequestCode_Request\x1a\x38.CContentServerDirectory_GetManifestRequestCode_Response\x12v\n\x0fGetCDNAuthToken\x12\x30.CContentServerDirectory_GetCDNAuthToken_Request\x1a\x31.CContentServerDirectory_GetCDNAuthToken_Response\x12\x91\x01\n\x18RequestPeerContentServer\x12\x39.CContentServerDirectory_RequestPeerContentServer_Request\x1a:.CContentServerDirectory_RequestPeerContentServer_Response\x12\x7f\n\x12GetPeerContentInfo\x12\x33.CContentServerDirectory_GetPeerContentInfo_Request\x1a\x34.CContentServerDirectory_GetPeerContentInfo_Response2\xc4\x02\n\x15\x44\x65potContentDetection\x12\x8f\x01\n\x18GetAllDetectedAppContent\x12\x38.CDepotContentDetection_GetAllDetectedAppContent_Request\x1a\x39.CDepotContentDetection_GetAllDetectedAppContent_Response\x12\x98\x01\n\x1bGetDetectedContentSingleApp\x12;.CDepotContentDetection_GetDetectedContentSingleApp_Request\x1a<.CDepotContentDetection_GetDetectedContentSingleApp_ResponseB\x03\x90\x01\x01')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'steammessages_contentsystem_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\220\001\001'
  _EAPPCONTENTDETECTIONTYPE._serialized_start=3047
  _EAPPCONTENTDETECTIONTYPE._serialized_end=3195
  _EAPPANTICHEATTYPE._serialized_start=3198
  _EAPPANTICHEATTYPE._serialized_end=3576
  _EAPPGAMEENGINETYPE._serialized_start=3578
  _EAPPGAMEENGINETYPE._serialized_end=3660
  _CCONTENTSERVERDIRECTORY_CONNECTEDSTEAMPIPESERVERINFO._serialized_start=97
  _CCONTENTSERVERDIRECTORY_CONNECTEDSTEAMPIPESERVERINFO._serialized_end=202
  _CCONTENTSERVERDIRECTORY_GETSERVERSFORSTEAMPIPE_REQUEST._serialized_start=205
  _CCONTENTSERVERDIRECTORY_GETSERVERSFORSTEAMPIPE_REQUEST._serialized_end=455
  _CCONTENTSERVERDIRECTORY_SERVERINFO._serialized_start=458
  _CCONTENTSERVERDIRECTORY_SERVERINFO._serialized_end=835
  _CCONTENTSERVERDIRECTORY_GETSERVERSFORSTEAMPIPE_RESPONSE._serialized_start=838
  _CCONTENTSERVERDIRECTORY_GETSERVERSFORSTEAMPIPE_RESPONSE._serialized_end=968
  _CCONTENTSERVERDIRECTORY_GETDEPOTPATCHINFO_REQUEST._serialized_start=971
  _CCONTENTSERVERDIRECTORY_GETDEPOTPATCHINFO_REQUEST._serialized_end=1108
  _CCONTENTSERVERDIRECTORY_GETDEPOTPATCHINFO_RESPONSE._serialized_start=1110
  _CCONTENTSERVERDIRECTORY_GETDEPOTPATCHINFO_RESPONSE._serialized_end=1233
  _CCONTENTSERVERDIRECTORY_GETCLIENTUPDATEHOSTS_REQUEST._serialized_start=1235
  _CCONTENTSERVERDIRECTORY_GETCLIENTUPDATEHOSTS_REQUEST._serialized_end=1315
  _CCONTENTSERVERDIRECTORY_GETCLIENTUPDATEHOSTS_RESPONSE._serialized_start=1317
  _CCONTENTSERVERDIRECTORY_GETCLIENTUPDATEHOSTS_RESPONSE._serialized_end=1436
  _CCONTENTSERVERDIRECTORY_GETMANIFESTREQUESTCODE_REQUEST._serialized_start=1439
  _CCONTENTSERVERDIRECTORY_GETMANIFESTREQUESTCODE_REQUEST._serialized_end=1600
  _CCONTENTSERVERDIRECTORY_GETMANIFESTREQUESTCODE_RESPONSE._serialized_start=1602
  _CCONTENTSERVERDIRECTORY_GETMANIFESTREQUESTCODE_RESPONSE._serialized_end=1690
  _CCONTENTSERVERDIRECTORY_GETCDNAUTHTOKEN_REQUEST._serialized_start=1692
  _CCONTENTSERVERDIRECTORY_GETCDNAUTHTOKEN_REQUEST._serialized_end=1794
  _CCONTENTSERVERDIRECTORY_GETCDNAUTHTOKEN_RESPONSE._serialized_start=1796
  _CCONTENTSERVERDIRECTORY_GETCDNAUTHTOKEN_RESPONSE._serialized_end=1886
  _CCONTENTSERVERDIRECTORY_REQUESTPEERCONTENTSERVER_REQUEST._serialized_start=1889
  _CCONTENTSERVERDIRECTORY_REQUESTPEERCONTENTSERVER_REQUEST._serialized_end=2065
  _CCONTENTSERVERDIRECTORY_REQUESTPEERCONTENTSERVER_RESPONSE._serialized_start=2068
  _CCONTENTSERVERDIRECTORY_REQUESTPEERCONTENTSERVER_RESPONSE._serialized_end=2196
  _CCONTENTSERVERDIRECTORY_GETPEERCONTENTINFO_REQUEST._serialized_start=2199
  _CCONTENTSERVERDIRECTORY_GETPEERCONTENTINFO_REQUEST._serialized_end=2327
  _CCONTENTSERVERDIRECTORY_GETPEERCONTENTINFO_RESPONSE._serialized_start=2329
  _CCONTENTSERVERDIRECTORY_GETPEERCONTENTINFO_RESPONSE._serialized_end=2417
  _CDEPOTCONTENTDETECTION_GETALLDETECTEDAPPCONTENT_REQUEST._serialized_start=2420
  _CDEPOTCONTENTDETECTION_GETALLDETECTEDAPPCONTENT_REQUEST._serialized_end=2561
  _DETECTEDAPPCONTENT._serialized_start=2563
  _DETECTEDAPPCONTENT._serialized_end=2643
  _CDEPOTCONTENTDETECTION_GETALLDETECTEDAPPCONTENT_RESPONSE._serialized_start=2645
  _CDEPOTCONTENTDETECTION_GETALLDETECTEDAPPCONTENT_RESPONSE._serialized_end=2754
  _CDEPOTCONTENTDETECTION_GETDETECTEDCONTENTSINGLEAPP_REQUEST._serialized_start=2756
  _CDEPOTCONTENTDETECTION_GETDETECTEDCONTENTSINGLEAPP_REQUEST._serialized_end=2831
  _CDEPOTCONTENTDETECTION_GETDETECTEDCONTENTSINGLEAPP_RESPONSE._serialized_start=2834
  _CDEPOTCONTENTDETECTION_GETDETECTEDCONTENTSINGLEAPP_RESPONSE._serialized_end=3044
  _CONTENTSERVERDIRECTORY._serialized_start=3663
  _CONTENTSERVERDIRECTORY._serialized_end=4630
  _DEPOTCONTENTDETECTION._serialized_start=4633
  _DEPOTCONTENTDETECTION._serialized_end=4957
_builder.BuildServices(DESCRIPTOR, 'steammessages_contentsystem_pb2', globals())
# @@protoc_insertion_point(module_scope)
