# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: steammessages_parties.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import steam.protobufs.steammessages_base_pb2 as steammessages__base__pb2
import steam.protobufs.steammessages_unified_base_pb2 as steammessages__unified__base__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1bsteammessages_parties.proto\x1a\x18steammessages_base.proto\x1a steammessages_unified_base.proto\"@\n\x1a\x43Parties_JoinParty_Request\x12\x0f\n\x07steamid\x18\x01 \x01(\x06\x12\x11\n\tbeacon_id\x18\x02 \x01(\x04\"H\n\x1b\x43Parties_JoinParty_Response\x12\x11\n\tbeacon_id\x18\x01 \x01(\x04\x12\x16\n\x0e\x63onnect_string\x18\x02 \x01(\t\"E\n\x17\x43Parties_BeaconLocation\x12\x15\n\rlocation_type\x18\x01 \x01(\r\x12\x13\n\x0blocation_id\x18\x02 \x01(\x04\"\x9d\x01\n\x1d\x43Parties_CreateBeacon_Request\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x16\n\x0enum_open_slots\x18\x02 \x01(\r\x12+\n\tlocations\x18\x03 \x03(\x0b\x32\x18.CParties_BeaconLocation\x12\x16\n\x0e\x63onnect_string\x18\x04 \x01(\t\x12\x10\n\x08metadata\x18\x05 \x01(\t\"3\n\x1e\x43Parties_CreateBeacon_Response\x12\x11\n\tbeacon_id\x18\x01 \x01(\x04\"R\n\'CParties_OnReservationCompleted_Request\x12\x11\n\tbeacon_id\x18\x01 \x01(\x04\x12\x14\n\x0cuser_steamid\x18\x02 \x01(\x06\"=\n(CParties_OnReservationCompleted_Response\x12\x11\n\tbeacon_id\x18\x01 \x01(\x04\"M\n\"CParties_CancelReservation_Request\x12\x11\n\tbeacon_id\x18\x01 \x01(\x04\x12\x14\n\x0cuser_steamid\x18\x02 \x01(\x06\"8\n#CParties_CancelReservation_Response\x12\x11\n\tbeacon_id\x18\x01 \x01(\x04\"P\n#CParties_ChangeNumOpenSlots_Request\x12\x11\n\tbeacon_id\x18\x01 \x01(\x04\x12\x16\n\x0enum_open_slots\x18\x02 \x01(\r\"9\n$CParties_ChangeNumOpenSlots_Response\x12\x11\n\tbeacon_id\x18\x01 \x01(\x04\"3\n\x1e\x43Parties_DestroyBeacon_Request\x12\x11\n\tbeacon_id\x18\x01 \x01(\x04\"4\n\x1f\x43Parties_DestroyBeacon_Response\x12\x11\n\tbeacon_id\x18\x01 \x01(\x04\x32\xa8\x04\n\x07Parties\x12\x46\n\tJoinParty\x12\x1b.CParties_JoinParty_Request\x1a\x1c.CParties_JoinParty_Response\x12O\n\x0c\x43reateBeacon\x12\x1e.CParties_CreateBeacon_Request\x1a\x1f.CParties_CreateBeacon_Response\x12m\n\x16OnReservationCompleted\x12(.CParties_OnReservationCompleted_Request\x1a).CParties_OnReservationCompleted_Response\x12^\n\x11\x43\x61ncelReservation\x12#.CParties_CancelReservation_Request\x1a$.CParties_CancelReservation_Response\x12\x61\n\x12\x43hangeNumOpenSlots\x12$.CParties_ChangeNumOpenSlots_Request\x1a%.CParties_ChangeNumOpenSlots_Response\x12R\n\rDestroyBeacon\x12\x1f.CParties_DestroyBeacon_Request\x1a .CParties_DestroyBeacon_ResponseB\x03\x90\x01\x01')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'steammessages_parties_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\220\001\001'
  _CPARTIES_JOINPARTY_REQUEST._serialized_start=91
  _CPARTIES_JOINPARTY_REQUEST._serialized_end=155
  _CPARTIES_JOINPARTY_RESPONSE._serialized_start=157
  _CPARTIES_JOINPARTY_RESPONSE._serialized_end=229
  _CPARTIES_BEACONLOCATION._serialized_start=231
  _CPARTIES_BEACONLOCATION._serialized_end=300
  _CPARTIES_CREATEBEACON_REQUEST._serialized_start=303
  _CPARTIES_CREATEBEACON_REQUEST._serialized_end=460
  _CPARTIES_CREATEBEACON_RESPONSE._serialized_start=462
  _CPARTIES_CREATEBEACON_RESPONSE._serialized_end=513
  _CPARTIES_ONRESERVATIONCOMPLETED_REQUEST._serialized_start=515
  _CPARTIES_ONRESERVATIONCOMPLETED_REQUEST._serialized_end=597
  _CPARTIES_ONRESERVATIONCOMPLETED_RESPONSE._serialized_start=599
  _CPARTIES_ONRESERVATIONCOMPLETED_RESPONSE._serialized_end=660
  _CPARTIES_CANCELRESERVATION_REQUEST._serialized_start=662
  _CPARTIES_CANCELRESERVATION_REQUEST._serialized_end=739
  _CPARTIES_CANCELRESERVATION_RESPONSE._serialized_start=741
  _CPARTIES_CANCELRESERVATION_RESPONSE._serialized_end=797
  _CPARTIES_CHANGENUMOPENSLOTS_REQUEST._serialized_start=799
  _CPARTIES_CHANGENUMOPENSLOTS_REQUEST._serialized_end=879
  _CPARTIES_CHANGENUMOPENSLOTS_RESPONSE._serialized_start=881
  _CPARTIES_CHANGENUMOPENSLOTS_RESPONSE._serialized_end=938
  _CPARTIES_DESTROYBEACON_REQUEST._serialized_start=940
  _CPARTIES_DESTROYBEACON_REQUEST._serialized_end=991
  _CPARTIES_DESTROYBEACON_RESPONSE._serialized_start=993
  _CPARTIES_DESTROYBEACON_RESPONSE._serialized_end=1045
  _PARTIES._serialized_start=1048
  _PARTIES._serialized_end=1600
_builder.BuildServices(DESCRIPTOR, 'steammessages_parties_pb2', globals())
# @@protoc_insertion_point(module_scope)
