# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: enums_productinfo.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17\x65nums_productinfo.proto*\xa2\x02\n\x14\x45\x43ontentDescriptorID\x12.\n*k_EContentDescriptor_NudityOrSexualContent\x10\x01\x12/\n+k_EContentDescriptor_FrequentViolenceOrGore\x10\x02\x12/\n+k_EContentDescriptor_AdultOnlySexualContent\x10\x03\x12\x30\n,k_EContentDescriptor_GratuitousSexualContent\x10\x04\x12)\n%k_EContentDescriptor_AnyMatureContent\x10\x05\x12\x1b\n\x17k_EContentDescriptorMAX\x10\x06\x42\x02H\x01')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'enums_productinfo_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'H\001'
  _ECONTENTDESCRIPTORID._serialized_start=28
  _ECONTENTDESCRIPTORID._serialized_end=318
# @@protoc_insertion_point(module_scope)
