# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: steammessages_remoteclient_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import steam.protobufs.steammessages_base_pb2 as steammessages__base__pb2
import steam.protobufs.steammessages_unified_base_pb2 as steammessages__unified__base__pb2
import steam.protobufs.steammessages_remoteclient_service_messages_pb2 as steammessages__remoteclient__service__messages__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(steammessages_remoteclient_service.proto\x1a\x18steammessages_base.proto\x1a steammessages_unified_base.proto\x1a\x31steammessages_remoteclient_service_messages.proto2\x85\x0b\n\x0cRemoteClient\x12_\n\x0eGetPairingInfo\x12%.CRemoteClient_GetPairingInfo_Request\x1a&.CRemoteClient_GetPairingInfo_Response\x12?\n\x0cNotifyOnline\x12\".CRemoteClient_Online_Notification\x1a\x0b.NoResponse\x12\x65\n\x10GetRecentClients\x12\'.CRemoteClient_GetRecentClients_Request\x1a(.CRemoteClient_GetRecentClients_Response\x12\x65\n\x10MarkTaskComplete\x12\'.CRemoteClient_MarkTaskComplete_Request\x1a(.CRemoteClient_MarkTaskComplete_Response\x12I\n\x11NotifyReplyPacket\x12\'.CRemoteClient_ReplyPacket_Notification\x1a\x0b.NoResponse\x12n\n\x13\x41llocateRelayServer\x12*.CRemoteClient_AllocateRelayServer_Request\x1a+.CRemoteClient_AllocateRelayServer_Response\x12V\n\x0b\x41llocateSDR\x12\".CRemoteClient_AllocateSDR_Request\x1a#.CRemoteClient_AllocateSDR_Response\x12S\n\x18SendSteamBroadcastPacket\x12*.CRemoteClient_SteamBroadcast_Notification\x1a\x0b.NoResponse\x12O\n\x16SendSteamToSteamPacket\x12(.CRemoteClient_SteamToSteam_Notification\x1a\x0b.NoResponse\x12i\n\x1cSendRemotePlaySessionStarted\x12#.CRemotePlay_SessionStarted_Request\x1a$.CRemotePlay_SessionStarted_Response\x12U\n\x1cSendRemotePlaySessionStopped\x12(.CRemotePlay_SessionStopped_Notification\x1a\x0b.NoResponse\x12N\n\x1cSendRemotePlayTogetherPacket\x12!.CRemotePlayTogether_Notification\x1a\x0b.NoResponse\x12\x9b\x01\n\"CreateRemotePlayTogetherInvitation\x12\x39.CRemoteClient_CreateRemotePlayTogetherInvitation_Request\x1a:.CRemoteClient_CreateRemotePlayTogetherInvitation_Response\x12\x9b\x01\n\"DeleteRemotePlayTogetherInvitation\x12\x39.CRemoteClient_DeleteRemotePlayTogetherInvitation_Request\x1a:.CRemoteClient_DeleteRemotePlayTogetherInvitation_Response2\xeb\x04\n\x17RemoteClientSteamClient\x12[\n\x1aNotifyRegisterStatusUpdate\x12\x30.CRemoteClient_RegisterStatusUpdate_Notification\x1a\x0b.NoResponse\x12_\n\x1cNotifyUnregisterStatusUpdate\x12\x32.CRemoteClient_UnregisterStatusUpdate_Notification\x1a\x0b.NoResponse\x12K\n\x12NotifyRemotePacket\x12(.CRemoteClient_RemotePacket_Notification\x1a\x0b.NoResponse\x12U\n\x1aNotifySteamBroadcastPacket\x12*.CRemoteClient_SteamBroadcast_Notification\x1a\x0b.NoResponse\x12Q\n\x18NotifySteamToSteamPacket\x12(.CRemoteClient_SteamToSteam_Notification\x1a\x0b.NoResponse\x12P\n\x1eNotifyRemotePlayTogetherPacket\x12!.CRemotePlayTogether_Notification\x1a\x0b.NoResponse\x12\x43\n\x0eNotifyTaskList\x12$.CRemoteClient_TaskList_Notification\x1a\x0b.NoResponse\x1a\x04\xc0\xb5\x18\x02\x42\x03\x90\x01\x01')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'steammessages_remoteclient_service_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\220\001\001'
  _REMOTECLIENTSTEAMCLIENT._options = None
  _REMOTECLIENTSTEAMCLIENT._serialized_options = b'\300\265\030\002'
  _REMOTECLIENT._serialized_start=156
  _REMOTECLIENT._serialized_end=1569
  _REMOTECLIENTSTEAMCLIENT._serialized_start=1572
  _REMOTECLIENTSTEAMCLIENT._serialized_end=2191
_builder.BuildServices(DESCRIPTOR, 'steammessages_remoteclient_service_pb2', globals())
# @@protoc_insertion_point(module_scope)
