# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: webuimessages_steamos.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import steam.protobufs.enums_pb2 as enums__pb2
import steam.protobufs.steammessages_base_pb2 as steammessages__base__pb2
import steam.protobufs.webuimessages_base_pb2 as webuimessages__base__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1bwebuimessages_steamos.proto\x1a\x0b\x65nums.proto\x1a\x18steammessages_base.proto\x1a\x18webuimessages_base.proto\"}\n\x15\x43MsgFactoryResetState\x12\x12\n\nis_running\x18\x01 \x01(\x08\x12\x10\n\x08progress\x18\x02 \x01(\x05\x12\x1a\n\x12is_restart_pending\x18\x03 \x01(\x08\x12\"\n\x1artime_estimated_completion\x18\x04 \x01(\x07\"\x83\x07\n\x14\x43SteamOSManagerState\x12\x1c\n\x14is_service_available\x18\x01 \x01(\x08\x12\x12\n\nos_version\x18\x02 \x01(\t\x12%\n\x1dis_mandatory_update_available\x18\x03 \x01(\x08\x12T\n\x15startup_movie_variant\x18\x04 \x01(\x0e\x32\x15.EStartupMovieVariant:\x1ek_EStartupMovieVariant_Invalid\x12\'\n\x1fis_status_led_control_available\x18\x05 \x01(\x08\x12\x33\n\x13\x66\x61\x63tory_reset_state\x18\x06 \x01(\x0b\x32\x16.CMsgFactoryResetState\x12\x1e\n\x16is_tdp_limit_available\x18\x07 \x01(\x08\x12\x15\n\rtdp_limit_min\x18\x08 \x01(\x05\x12\x15\n\rtdp_limit_max\x18\t \x01(\x05\x12\x18\n\x10is_cec_available\x18\n \x01(\x08\x12\x1f\n\x17is_wifi_debug_supported\x18\x0b \x01(\x08\x12$\n\x1cis_wifi_debug_force_disabled\x18\x0c \x01(\x08\x12.\n&is_wifi_force_wpa_supplicant_supported\x18\r \x01(\x08\x12%\n\x1dis_manual_gpu_clock_available\x18\x0e \x01(\x08\x12\x1c\n\x14manual_gpu_clock_min\x18\x0f \x01(\x05\x12\x1c\n\x14manual_gpu_clock_max\x18\x10 \x01(\x05\x12/\n\'platform_performance_profiles_available\x18\x11 \x03(\t\x12,\n$platform_performance_profile_default\x18\x12 \x01(\t\x12$\n\x1cplatform_performance_profile\x18\x13 \x01(\t\x12!\n\x19is_charge_limit_available\x18\x14 \x01(\x08\x12\x18\n\x10\x63harge_limit_min\x18\x15 \x01(\x05\x12\x18\n\x10\x63harge_limit_max\x18\x16 \x01(\x05\x12\x1c\n\x14\x63harge_limit_default\x18\x17 \x01(\x05\x12\"\n\x1ais_screen_reader_supported\x18\x18 \x01(\x08\"\"\n CSteamOSManager_GetState_Request\"I\n!CSteamOSManager_GetState_Response\x12$\n\x05state\x18\x01 \x01(\x0b\x32\x15.CSteamOSManagerState\"+\n)CSteamOSManager_StateChanged_Notification\"f\n2CSteamOSManager_IsTelemetryHelperAvailable_Request\x12\x30\n\x05\x65type\x18\x01 \x01(\x0e\x32\x0b.ESLSHelper:\x14k_ESLSHelper_Invalid\"H\n3CSteamOSManager_IsTelemetryHelperAvailable_Response\x12\x11\n\tavailable\x18\x01 \x01(\x08\"2\n0CSteamOSManager_OptOutOfSideloadedClient_Request\"3\n1CSteamOSManager_OptOutOfSideloadedClient_Response\".\n,CSteamOSManager_ApplyMandatoryUpdate_Request\"/\n-CSteamOSManager_ApplyMandatoryUpdate_Response\"Q\n$CSteamOSManager_FactoryReset_Request\x12\x10\n\x08reset_os\x18\x01 \x01(\x08\x12\x17\n\x0freset_user_data\x18\x02 \x01(\x08\"\'\n%CSteamOSManager_FactoryReset_Response\"o\n\x11\x43SteamOSSLSPlugin\x12\x30\n\x05\x65type\x18\x01 \x01(\x0e\x32\x0b.ESLSHelper:\x14k_ESLSHelper_Invalid\x12\x14\n\x0cis_available\x18\x02 \x01(\x08\x12\x12\n\nis_enabled\x18\x03 \x01(\x08\"a\n\x10\x43SteamOSSLSState\x12\x14\n\x0cis_available\x18\x01 \x01(\x08\x12\x12\n\nis_enabled\x18\x02 \x01(\x08\x12#\n\x07plugins\x18\x03 \x03(\x0b\x32\x12.CSteamOSSLSPlugin\"\x1e\n\x1c\x43SteamOSSLS_GetState_Request\"A\n\x1d\x43SteamOSSLS_GetState_Response\x12 \n\x05state\x18\x01 \x01(\x0b\x32\x11.CSteamOSSLSState\"\'\n%CSteamOSSLS_StateChanged_Notification\"1\n\x1e\x43SteamOSSLS_SetEnabled_Request\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\"!\n\x1f\x43SteamOSSLS_SetEnabled_Response\"i\n$CSteamOSSLS_SetPluginEnabled_Request\x12\x30\n\x05\x65type\x18\x01 \x01(\x0e\x32\x0b.ESLSHelper:\x14k_ESLSHelper_Invalid\x12\x0f\n\x07\x65nabled\x18\x02 \x01(\x08\"\'\n%CSteamOSSLS_SetPluginEnabled_Response2\x97\x04\n\x0eSteamOSManager\x12Q\n\x08GetState\x12!.CSteamOSManager_GetState_Request\x1a\".CSteamOSManager_GetState_Response\x12R\n\x12NotifyStateChanged\x12*.CSteamOSManager_StateChanged_Notification\x1a\x10.WebUINoResponse\x12\x81\x01\n\x18OptOutOfSideloadedClient\x12\x31.CSteamOSManager_OptOutOfSideloadedClient_Request\x1a\x32.CSteamOSManager_OptOutOfSideloadedClient_Response\x12u\n\x14\x41pplyMandatoryUpdate\x12-.CSteamOSManager_ApplyMandatoryUpdate_Request\x1a..CSteamOSManager_ApplyMandatoryUpdate_Response\x12]\n\x0c\x46\x61\x63toryReset\x12%.CSteamOSManager_FactoryReset_Request\x1a&.CSteamOSManager_FactoryReset_Response\x1a\x04\x80\x97\"\x01\x32\xe1\x02\n\nSteamOSSLS\x12I\n\x08GetState\x12\x1d.CSteamOSSLS_GetState_Request\x1a\x1e.CSteamOSSLS_GetState_Response\x12N\n\x12NotifyStateChanged\x12&.CSteamOSSLS_StateChanged_Notification\x1a\x10.WebUINoResponse\x12O\n\nSetEnabled\x12\x1f.CSteamOSSLS_SetEnabled_Request\x1a .CSteamOSSLS_SetEnabled_Response\x12\x61\n\x10SetPluginEnabled\x12%.CSteamOSSLS_SetPluginEnabled_Request\x1a&.CSteamOSSLS_SetPluginEnabled_Response\x1a\x04\x80\x97\"\x01\x42\x05H\x01\x90\x01\x01')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'webuimessages_steamos_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'H\001\220\001\001'
  _STEAMOSMANAGER._options = None
  _STEAMOSMANAGER._serialized_options = b'\200\227\"\001'
  _STEAMOSSLS._options = None
  _STEAMOSSLS._serialized_options = b'\200\227\"\001'
  _CMSGFACTORYRESETSTATE._serialized_start=96
  _CMSGFACTORYRESETSTATE._serialized_end=221
  _CSTEAMOSMANAGERSTATE._serialized_start=224
  _CSTEAMOSMANAGERSTATE._serialized_end=1123
  _CSTEAMOSMANAGER_GETSTATE_REQUEST._serialized_start=1125
  _CSTEAMOSMANAGER_GETSTATE_REQUEST._serialized_end=1159
  _CSTEAMOSMANAGER_GETSTATE_RESPONSE._serialized_start=1161
  _CSTEAMOSMANAGER_GETSTATE_RESPONSE._serialized_end=1234
  _CSTEAMOSMANAGER_STATECHANGED_NOTIFICATION._serialized_start=1236
  _CSTEAMOSMANAGER_STATECHANGED_NOTIFICATION._serialized_end=1279
  _CSTEAMOSMANAGER_ISTELEMETRYHELPERAVAILABLE_REQUEST._serialized_start=1281
  _CSTEAMOSMANAGER_ISTELEMETRYHELPERAVAILABLE_REQUEST._serialized_end=1383
  _CSTEAMOSMANAGER_ISTELEMETRYHELPERAVAILABLE_RESPONSE._serialized_start=1385
  _CSTEAMOSMANAGER_ISTELEMETRYHELPERAVAILABLE_RESPONSE._serialized_end=1457
  _CSTEAMOSMANAGER_OPTOUTOFSIDELOADEDCLIENT_REQUEST._serialized_start=1459
  _CSTEAMOSMANAGER_OPTOUTOFSIDELOADEDCLIENT_REQUEST._serialized_end=1509
  _CSTEAMOSMANAGER_OPTOUTOFSIDELOADEDCLIENT_RESPONSE._serialized_start=1511
  _CSTEAMOSMANAGER_OPTOUTOFSIDELOADEDCLIENT_RESPONSE._serialized_end=1562
  _CSTEAMOSMANAGER_APPLYMANDATORYUPDATE_REQUEST._serialized_start=1564
  _CSTEAMOSMANAGER_APPLYMANDATORYUPDATE_REQUEST._serialized_end=1610
  _CSTEAMOSMANAGER_APPLYMANDATORYUPDATE_RESPONSE._serialized_start=1612
  _CSTEAMOSMANAGER_APPLYMANDATORYUPDATE_RESPONSE._serialized_end=1659
  _CSTEAMOSMANAGER_FACTORYRESET_REQUEST._serialized_start=1661
  _CSTEAMOSMANAGER_FACTORYRESET_REQUEST._serialized_end=1742
  _CSTEAMOSMANAGER_FACTORYRESET_RESPONSE._serialized_start=1744
  _CSTEAMOSMANAGER_FACTORYRESET_RESPONSE._serialized_end=1783
  _CSTEAMOSSLSPLUGIN._serialized_start=1785
  _CSTEAMOSSLSPLUGIN._serialized_end=1896
  _CSTEAMOSSLSSTATE._serialized_start=1898
  _CSTEAMOSSLSSTATE._serialized_end=1995
  _CSTEAMOSSLS_GETSTATE_REQUEST._serialized_start=1997
  _CSTEAMOSSLS_GETSTATE_REQUEST._serialized_end=2027
  _CSTEAMOSSLS_GETSTATE_RESPONSE._serialized_start=2029
  _CSTEAMOSSLS_GETSTATE_RESPONSE._serialized_end=2094
  _CSTEAMOSSLS_STATECHANGED_NOTIFICATION._serialized_start=2096
  _CSTEAMOSSLS_STATECHANGED_NOTIFICATION._serialized_end=2135
  _CSTEAMOSSLS_SETENABLED_REQUEST._serialized_start=2137
  _CSTEAMOSSLS_SETENABLED_REQUEST._serialized_end=2186
  _CSTEAMOSSLS_SETENABLED_RESPONSE._serialized_start=2188
  _CSTEAMOSSLS_SETENABLED_RESPONSE._serialized_end=2221
  _CSTEAMOSSLS_SETPLUGINENABLED_REQUEST._serialized_start=2223
  _CSTEAMOSSLS_SETPLUGINENABLED_REQUEST._serialized_end=2328
  _CSTEAMOSSLS_SETPLUGINENABLED_RESPONSE._serialized_start=2330
  _CSTEAMOSSLS_SETPLUGINENABLED_RESPONSE._serialized_end=2369
  _STEAMOSMANAGER._serialized_start=2372
  _STEAMOSMANAGER._serialized_end=2907
  _STEAMOSSLS._serialized_start=2910
  _STEAMOSSLS._serialized_end=3263
_builder.BuildServices(DESCRIPTOR, 'webuimessages_steamos_pb2', globals())
# @@protoc_insertion_point(module_scope)
