# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: steammessages_publishedfile.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import steam.protobufs.steammessages_base_pb2 as steammessages__base__pb2
import steam.protobufs.steammessages_unified_base_pb2 as steammessages__unified__base__pb2
import steam.protobufs.enums_productinfo_pb2 as enums__productinfo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!steammessages_publishedfile.proto\x1a\x18steammessages_base.proto\x1a steammessages_unified_base.proto\x1a\x17\x65nums_productinfo.proto\"G\n\x1b\x43PublishedFile_Vote_Request\x12\x17\n\x0fpublishedfileid\x18\x01 \x01(\x04\x12\x0f\n\x07vote_up\x18\x02 \x01(\x08\"\x1e\n\x1c\x43PublishedFile_Vote_Response\"\x92\x01\n CPublishedFile_Subscribe_Request\x12\x17\n\x0fpublishedfileid\x18\x01 \x01(\x04\x12\x11\n\tlist_type\x18\x02 \x01(\r\x12\r\n\x05\x61ppid\x18\x03 \x01(\x05\x12\x15\n\rnotify_client\x18\x04 \x01(\x08\x12\x1c\n\x14include_dependencies\x18\x05 \x01(\x08\"#\n!CPublishedFile_Subscribe_Response\"v\n\"CPublishedFile_Unsubscribe_Request\x12\x17\n\x0fpublishedfileid\x18\x01 \x01(\x04\x12\x11\n\tlist_type\x18\x02 \x01(\r\x12\r\n\x05\x61ppid\x18\x03 \x01(\x05\x12\x15\n\rnotify_client\x18\x04 \x01(\x08\"%\n#CPublishedFile_Unsubscribe_Response\">\n#CPublishedFile_CanSubscribe_Request\x12\x17\n\x0fpublishedfileid\x18\x01 \x01(\x04\"=\n$CPublishedFile_CanSubscribe_Response\x12\x15\n\rcan_subscribe\x18\x01 \x01(\x08\"\xd3\x01\n(CPublishedFile_GetSubSectionData_Request\x12\x17\n\x0fpublishedfileid\x18\x01 \x01(\x04\x12\x1d\n\x15\x66or_table_of_contents\x18\x02 \x01(\x08\x12\x1a\n\x12specific_sectionid\x18\x03 \x01(\x04\x12S\n\x10\x64\x65sired_revision\x18\x04 \x01(\x0e\x32\x17.EPublishedFileRevision: k_EPublishedFileRevision_Default\"i\n\x17PublishedFileSubSection\x12\x11\n\tsectionid\x18\x01 \x01(\x04\x12\r\n\x05title\x18\x02 \x01(\t\x12\x18\n\x10\x64\x65scription_text\x18\x03 \x01(\t\x12\x12\n\nsort_order\x18\x04 \x01(\r\"[\n)CPublishedFile_GetSubSectionData_Response\x12.\n\x0csub_sections\x18\x01 \x03(\x0b\x32\x18.PublishedFileSubSection\"\xfd\x02\n\x1e\x43PublishedFile_Publish_Request\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x16\n\x0e\x63onsumer_appid\x18\x02 \x01(\r\x12\x15\n\rcloudfilename\x18\x03 \x01(\t\x12\x1d\n\x15preview_cloudfilename\x18\x04 \x01(\t\x12\r\n\x05title\x18\x05 \x01(\t\x12\x18\n\x10\x66ile_description\x18\x06 \x01(\t\x12\x11\n\tfile_type\x18\x07 \x01(\r\x12\x1e\n\x16\x63onsumer_shortcut_name\x18\x08 \x01(\t\x12\x18\n\x10youtube_username\x18\t \x01(\t\x12\x17\n\x0fyoutube_videoid\x18\n \x01(\t\x12\x12\n\nvisibility\x18\x0b \x01(\r\x12\x14\n\x0credirect_uri\x18\x0c \x01(\t\x12\x0c\n\x04tags\x18\r \x03(\t\x12\x17\n\x0f\x63ollection_type\x18\x0e \x01(\t\x12\x11\n\tgame_type\x18\x0f \x01(\t\x12\x0b\n\x03url\x18\x10 \x01(\t\"P\n\x1f\x43PublishedFile_Publish_Response\x12\x17\n\x0fpublishedfileid\x18\x01 \x01(\x04\x12\x14\n\x0credirect_uri\x18\x02 \x01(\t\"\xfb\x03\n!CPublishedFile_GetDetails_Request\x12\x18\n\x10publishedfileids\x18\x01 \x03(\x06\x12\x13\n\x0bincludetags\x18\x02 \x01(\x08\x12!\n\x19includeadditionalpreviews\x18\x03 \x01(\x08\x12\x17\n\x0fincludechildren\x18\x04 \x01(\x08\x12\x15\n\rincludekvtags\x18\x05 \x01(\x08\x12\x14\n\x0cincludevotes\x18\x06 \x01(\x08\x12\x19\n\x11short_description\x18\x08 \x01(\x08\x12\x1a\n\x12includeforsaledata\x18\n \x01(\x08\x12\x17\n\x0fincludemetadata\x18\x0b \x01(\x08\x12\x13\n\x08language\x18\x0c \x01(\x05:\x01\x30\x12\x1d\n\x15return_playtime_stats\x18\r \x01(\r\x12\r\n\x05\x61ppid\x18\x0e \x01(\r\x12 \n\x18strip_description_bbcode\x18\x0f \x01(\x08\x12S\n\x10\x64\x65sired_revision\x18\x10 \x01(\x0e\x32\x17.EPublishedFileRevision: k_EPublishedFileRevision_Default\x12\x1f\n\x10includereactions\x18\x11 \x01(\x08:\x05\x66\x61lse\x12\x13\n\x0b\x61\x64min_query\x18\x12 \x01(\x08\"v\n\x1bPublishedFileAuthorSnapshot\x12\x11\n\ttimestamp\x18\x01 \x01(\r\x12\x17\n\x0fgame_branch_min\x18\x02 \x01(\t\x12\x17\n\x0fgame_branch_max\x18\x03 \x01(\t\x12\x12\n\nmanifestid\x18\x04 \x01(\x06\"\x8a\x17\n\x14PublishedFileDetails\x12\x0e\n\x06result\x18\x01 \x01(\r\x12\x17\n\x0fpublishedfileid\x18\x02 \x01(\x04\x12\x0f\n\x07\x63reator\x18\x03 \x01(\x06\x12\x15\n\rcreator_appid\x18\x04 \x01(\r\x12\x16\n\x0e\x63onsumer_appid\x18\x05 \x01(\r\x12\x1b\n\x13\x63onsumer_shortcutid\x18\x06 \x01(\r\x12\x10\n\x08\x66ilename\x18\x07 \x01(\t\x12\x11\n\tfile_size\x18\x08 \x01(\x04\x12\x19\n\x11preview_file_size\x18\t \x01(\x04\x12\x10\n\x08\x66ile_url\x18\n \x01(\t\x12\x13\n\x0bpreview_url\x18\x0b \x01(\t\x12\x16\n\x0eyoutubevideoid\x18\x0c \x01(\t\x12\x0b\n\x03url\x18\r \x01(\t\x12\x15\n\rhcontent_file\x18\x0e \x01(\x06\x12\x18\n\x10hcontent_preview\x18\x0f \x01(\x06\x12\r\n\x05title\x18\x10 \x01(\t\x12\x18\n\x10\x66ile_description\x18\x11 \x01(\t\x12\x19\n\x11short_description\x18\x12 \x01(\t\x12\x14\n\x0ctime_created\x18\x13 \x01(\r\x12\x14\n\x0ctime_updated\x18\x14 \x01(\r\x12\x12\n\nvisibility\x18\x15 \x01(\r\x12\r\n\x05\x66lags\x18\x16 \x01(\r\x12\x15\n\rworkshop_file\x18\x17 \x01(\x08\x12\x19\n\x11workshop_accepted\x18\x18 \x01(\x08\x12\x1a\n\x12show_subscribe_all\x18\x19 \x01(\x08\x12\x1e\n\x16num_comments_developer\x18\x1a \x01(\x05\x12\x1b\n\x13num_comments_public\x18\x1b \x01(\x05\x12\x0e\n\x06\x62\x61nned\x18\x1c \x01(\x08\x12\x12\n\nban_reason\x18\x1d \x01(\t\x12\x0e\n\x06\x62\x61nner\x18\x1e \x01(\x06\x12\x16\n\x0e\x63\x61n_be_deleted\x18\x1f \x01(\x08\x12\x14\n\x0cincompatible\x18  \x01(\x08\x12\x10\n\x08\x61pp_name\x18! \x01(\t\x12\x11\n\tfile_type\x18\" \x01(\r\x12\x15\n\rcan_subscribe\x18# \x01(\x08\x12\x15\n\rsubscriptions\x18$ \x01(\r\x12\x11\n\tfavorited\x18% \x01(\r\x12\x11\n\tfollowers\x18& \x01(\r\x12\x1e\n\x16lifetime_subscriptions\x18\' \x01(\r\x12\x1a\n\x12lifetime_favorited\x18( \x01(\r\x12\x1a\n\x12lifetime_followers\x18) \x01(\r\x12\x19\n\x11lifetime_playtime\x18> \x01(\x04\x12\"\n\x1alifetime_playtime_sessions\x18? \x01(\x04\x12\r\n\x05views\x18* \x01(\r\x12\x13\n\x0bimage_width\x18+ \x01(\r\x12\x14\n\x0cimage_height\x18, \x01(\r\x12\x11\n\timage_url\x18- \x01(\t\x12\x13\n\x0bspoiler_tag\x18. \x01(\x08\x12\x12\n\nshortcutid\x18/ \x01(\r\x12\x14\n\x0cshortcutname\x18\x30 \x01(\t\x12\x14\n\x0cnum_children\x18\x31 \x01(\r\x12\x13\n\x0bnum_reports\x18\x32 \x01(\r\x12/\n\x08previews\x18\x33 \x03(\x0b\x32\x1d.PublishedFileDetails.Preview\x12\'\n\x04tags\x18\x34 \x03(\x0b\x32\x19.PublishedFileDetails.Tag\x12-\n\x08\x63hildren\x18\x35 \x03(\x0b\x32\x1b.PublishedFileDetails.Child\x12+\n\x06kvtags\x18\x36 \x03(\x0b\x32\x1b.PublishedFileDetails.KVTag\x12\x31\n\tvote_data\x18\x37 \x01(\x0b\x32\x1e.PublishedFileDetails.VoteData\x12;\n\x0eplaytime_stats\x18@ \x01(\x0b\x32#.PublishedFileDetails.PlaytimeStats\x12\x17\n\x0ftime_subscribed\x18\x38 \x01(\r\x12\x38\n\rfor_sale_data\x18\x39 \x01(\x0b\x32!.PublishedFileDetails.ForSaleData\x12\x10\n\x08metadata\x18: \x01(\t\x12\x13\n\x08language\x18= \x01(\x05:\x01\x30\x12\x1f\n\x17maybe_inappropriate_sex\x18\x41 \x01(\x08\x12$\n\x1cmaybe_inappropriate_violence\x18\x42 \x01(\x08\x12\x34\n\x15\x63ontent_descriptorids\x18H \x03(\x0e\x32\x15.EContentDescriptorID\x12\x1e\n\x16revision_change_number\x18\x43 \x01(\x04\x12K\n\x08revision\x18\x44 \x01(\x0e\x32\x17.EPublishedFileRevision: k_EPublishedFileRevision_Default\x12\x34\n\x13\x61vailable_revisions\x18\x45 \x03(\x0e\x32\x17.EPublishedFileRevision\x12\x31\n\treactions\x18\x46 \x03(\x0b\x32\x1e.PublishedFileDetails.Reaction\x12[\n\x15\x62\x61n_text_check_result\x18G \x01(\x0e\x32\x17.EBanContentCheckResult:#k_EBanContentCheckResult_NotScanned\x12\x14\n\x0csearch_score\x18I \x01(\x02\x12\x19\n\x11\x65xternal_asset_id\x18J \x01(\x04\x12\x36\n\x10\x61uthor_snapshots\x18K \x03(\x0b\x32\x1c.PublishedFileAuthorSnapshot\x1a;\n\x03Tag\x12\x0b\n\x03tag\x18\x01 \x01(\t\x12\x11\n\tadminonly\x18\x02 \x01(\x08\x12\x14\n\x0c\x64isplay_name\x18\x03 \x01(\t\x1a\xa6\x01\n\x07Preview\x12\x11\n\tpreviewid\x18\x01 \x01(\x04\x12\x11\n\tsortorder\x18\x02 \x01(\r\x12\x0b\n\x03url\x18\x03 \x01(\t\x12\x0c\n\x04size\x18\x04 \x01(\r\x12\x10\n\x08\x66ilename\x18\x05 \x01(\t\x12\x16\n\x0eyoutubevideoid\x18\x06 \x01(\t\x12\x14\n\x0cpreview_type\x18\x07 \x01(\r\x12\x1a\n\x12\x65xternal_reference\x18\x08 \x01(\t\x1a\x46\n\x05\x43hild\x12\x17\n\x0fpublishedfileid\x18\x01 \x01(\x04\x12\x11\n\tsortorder\x18\x02 \x01(\r\x12\x11\n\tfile_type\x18\x03 \x01(\r\x1a#\n\x05KVTag\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\x1a\x8c\x01\n\x08VoteData\x12\r\n\x05score\x18\x01 \x01(\x02\x12\x10\n\x08votes_up\x18\x02 \x01(\r\x12\x12\n\nvotes_down\x18\x03 \x01(\r\x12\x15\n\rtrusted_score\x18\x04 \x01(\x02\x12\x18\n\x10trusted_votes_up\x18\x05 \x01(\r\x12\x1a\n\x12trusted_votes_down\x18\x06 \x01(\r\x1a\xdc\x01\n\x0b\x46orSaleData\x12\x13\n\x0bis_for_sale\x18\x01 \x01(\x08\x12\x16\n\x0eprice_category\x18\x02 \x01(\r\x12\x41\n\x07\x65status\x18\x03 \x01(\x0e\x32\x1c.EPublishedFileForSaleStatus:\x12k_PFFSS_NotForSale\x12\x1c\n\x14price_category_floor\x18\x04 \x01(\r\x12\"\n\x1aprice_is_pay_what_you_want\x18\x05 \x01(\x08\x12\x1b\n\x13\x64iscount_percentage\x18\x06 \x01(\r\x1a?\n\rPlaytimeStats\x12\x18\n\x10playtime_seconds\x18\x01 \x01(\x04\x12\x14\n\x0cnum_sessions\x18\x02 \x01(\x04\x1a-\n\x08Reaction\x12\x12\n\nreactionid\x18\x01 \x01(\r\x12\r\n\x05\x63ount\x18\x02 \x01(\r\"Y\n\"CPublishedFile_GetDetails_Response\x12\x33\n\x14publishedfiledetails\x18\x01 \x03(\x0b\x32\x15.PublishedFileDetails\"\xaf\x02\n\"CPublishedFile_GetItemInfo_Request\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x19\n\x11last_time_updated\x18\x02 \x01(\r\x12H\n\x0eworkshop_items\x18\x03 \x03(\x0b\x32\x30.CPublishedFile_GetItemInfo_Request.WorkshopItem\x1a\x94\x01\n\x0cWorkshopItem\x12\x19\n\x11published_file_id\x18\x01 \x01(\x06\x12\x14\n\x0ctime_updated\x18\x02 \x01(\r\x12S\n\x10\x64\x65sired_revision\x18\x03 \x01(\x0e\x32\x17.EPublishedFileRevision: k_EPublishedFileRevision_Default\"\x8f\x03\n#CPublishedFile_GetItemInfo_Response\x12\x13\n\x0bupdate_time\x18\x01 \x01(\r\x12M\n\x0eworkshop_items\x18\x02 \x03(\x0b\x32\x35.CPublishedFile_GetItemInfo_Response.WorkshopItemInfo\x12\x15\n\rprivate_items\x18\x03 \x03(\x06\x1a\xec\x01\n\x10WorkshopItemInfo\x12\x19\n\x11published_file_id\x18\x01 \x01(\x06\x12\x14\n\x0ctime_updated\x18\x02 \x01(\r\x12\x13\n\x0bmanifest_id\x18\x03 \x01(\x06\x12\r\n\x05\x66lags\x18\x04 \x01(\r\x12K\n\x08revision\x18\x05 \x01(\x0e\x32\x17.EPublishedFileRevision: k_EPublishedFileRevision_Default\x12\x36\n\x10\x61uthor_snapshots\x18\x06 \x03(\x0b\x32\x1c.PublishedFileAuthorSnapshot\"\x86\t\n#CPublishedFile_GetUserFiles_Request\x12\x0f\n\x07steamid\x18\x01 \x01(\x06\x12\r\n\x05\x61ppid\x18\x02 \x01(\r\x12\x12\n\nshortcutid\x18\x03 \x01(\r\x12\x0f\n\x04page\x18\x04 \x01(\r:\x01\x31\x12\x15\n\nnumperpage\x18\x05 \x01(\r:\x01\x31\x12\x15\n\x04type\x18\x06 \x01(\t:\x07myfiles\x12\x1f\n\nsortmethod\x18\x07 \x01(\t:\x0blastupdated\x12\x0f\n\x07privacy\x18\t \x01(\r\x12\x14\n\x0crequiredtags\x18\n \x03(\t\x12\x14\n\x0c\x65xcludedtags\x18\x0b \x03(\t\x12\x44\n\x10required_kv_tags\x18\x1e \x03(\x0b\x32*.CPublishedFile_GetUserFiles_Request.KVTag\x12\x10\n\x08\x66iletype\x18\x0e \x01(\r\x12\x15\n\rcreator_appid\x18\x0f \x01(\r\x12\x1c\n\x14match_cloud_filename\x18\x10 \x01(\t\x12 \n\x15\x63\x61\x63he_max_age_seconds\x18\x1b \x01(\r:\x01\x30\x12\x13\n\x08language\x18\x1d \x01(\x05:\x01\x30\x12@\n\ttaggroups\x18\" \x03(\x0b\x32-.CPublishedFile_GetUserFiles_Request.TagGroup\x12;\n\x1c\x65xcluded_content_descriptors\x18% \x03(\x0e\x32\x15.EContentDescriptorID\x12\x13\n\x0b\x61\x64min_query\x18& \x01(\x08\x12\x11\n\ttotalonly\x18\x11 \x01(\x08\x12\x10\n\x08ids_only\x18\x12 \x01(\x08\x12\x1e\n\x10return_vote_data\x18\x13 \x01(\x08:\x04true\x12\x13\n\x0breturn_tags\x18\x14 \x01(\x08\x12\x1c\n\x0ereturn_kv_tags\x18\x15 \x01(\x08:\x04true\x12\x17\n\x0freturn_previews\x18\x16 \x01(\x08\x12\x17\n\x0freturn_children\x18\x17 \x01(\x08\x12&\n\x18return_short_description\x18\x18 \x01(\x08:\x04true\x12\x1c\n\x14return_for_sale_data\x18\x1a \x01(\x08\x12\x1e\n\x0freturn_metadata\x18\x1c \x01(\x08:\x05\x66\x61lse\x12\x1d\n\x15return_playtime_stats\x18\x1f \x01(\r\x12 \n\x18strip_description_bbcode\x18  \x01(\x08\x12\x1f\n\x10return_reactions\x18# \x01(\x08:\x05\x66\x61lse\x12\x1b\n\x13startindex_override\x18\x19 \x01(\r\x12S\n\x10\x64\x65sired_revision\x18! \x01(\x0e\x32\x17.EPublishedFileRevision: k_EPublishedFileRevision_Default\x12\x13\n\x0breturn_apps\x18$ \x01(\x08\x1a#\n\x05KVTag\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\x1a\x18\n\x08TagGroup\x12\x0c\n\x04tags\x18\x01 \x03(\t\"\x80\x02\n$CPublishedFile_GetUserFiles_Response\x12\r\n\x05total\x18\x01 \x01(\r\x12\x12\n\nstartindex\x18\x02 \x01(\r\x12\x33\n\x14publishedfiledetails\x18\x03 \x03(\x0b\x32\x15.PublishedFileDetails\x12\x37\n\x04\x61pps\x18\x04 \x03(\x0b\x32).CPublishedFile_GetUserFiles_Response.App\x1aG\n\x03\x41pp\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x12\n\nshortcutid\x18\x03 \x01(\r\x12\x0f\n\x07private\x18\x04 \x01(\x08\"\x9a\x01\n1CPublishedFile_AreFilesInSubscriptionList_Request\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x18\n\x10publishedfileids\x18\x02 \x03(\x06\x12\x10\n\x08listtype\x18\x03 \x01(\r\x12\x10\n\x08\x66iletype\x18\x04 \x01(\r\x12\x18\n\x10workshopfiletype\x18\x05 \x01(\r\"\xb2\x01\n2CPublishedFile_AreFilesInSubscriptionList_Response\x12I\n\x05\x66iles\x18\x01 \x03(\x0b\x32:.CPublishedFile_AreFilesInSubscriptionList_Response.InList\x1a\x31\n\x06InList\x12\x17\n\x0fpublishedfileid\x18\x01 \x01(\x06\x12\x0e\n\x06inlist\x18\x02 \x01(\x08\"\x90\x02\n\x1d\x43PublishedFile_Update_Request\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x17\n\x0fpublishedfileid\x18\x02 \x01(\x06\x12\r\n\x05title\x18\x03 \x01(\t\x12\x18\n\x10\x66ile_description\x18\x04 \x01(\t\x12\x12\n\nvisibility\x18\x05 \x01(\r\x12\x0c\n\x04tags\x18\x06 \x03(\t\x12\x10\n\x08\x66ilename\x18\x07 \x01(\t\x12\x18\n\x10preview_filename\x18\x08 \x01(\t\x12\x13\n\x0bspoiler_tag\x18\n \x01(\x08\x12\x13\n\x0bimage_width\x18\x0f \x01(\r\x12\x14\n\x0cimage_height\x18\x10 \x01(\r\x12\x10\n\x08language\x18\x11 \x01(\x05\" \n\x1e\x43PublishedFile_Update_Response\"G\n\x1d\x43PublishedFile_Delete_Request\x12\x17\n\x0fpublishedfileid\x18\x01 \x01(\x06\x12\r\n\x05\x61ppid\x18\x05 \x01(\r\" \n\x1e\x43PublishedFile_Delete_Response\"l\n,CPublishedFile_GetChangeHistoryEntry_Request\x12\x17\n\x0fpublishedfileid\x18\x01 \x01(\x06\x12\x11\n\ttimestamp\x18\x02 \x01(\r\x12\x10\n\x08language\x18\x03 \x01(\x05\"\xce\x01\n-CPublishedFile_GetChangeHistoryEntry_Response\x12\x1a\n\x12\x63hange_description\x18\x01 \x01(\t\x12\x10\n\x08language\x18\x02 \x01(\x05\x12\x16\n\x0esaved_snapshot\x18\x03 \x01(\x08\x12 \n\x18snapshot_game_branch_min\x18\x04 \x01(\t\x12 \n\x18snapshot_game_branch_max\x18\x05 \x01(\t\x12\x13\n\x0bmanifest_id\x18\x06 \x01(\x06\"\x8e\x01\n\'CPublishedFile_GetChangeHistory_Request\x12\x17\n\x0fpublishedfileid\x18\x01 \x01(\x06\x12\x12\n\ntotal_only\x18\x02 \x01(\x08\x12\x12\n\nstartindex\x18\x03 \x01(\r\x12\r\n\x05\x63ount\x18\x04 \x01(\r\x12\x13\n\x08language\x18\x05 \x01(\x05:\x01\x30\"\xbf\x02\n(CPublishedFile_GetChangeHistory_Response\x12\x44\n\x07\x63hanges\x18\x01 \x03(\x0b\x32\x33.CPublishedFile_GetChangeHistory_Response.ChangeLog\x12\r\n\x05total\x18\x02 \x01(\r\x1a\xbd\x01\n\tChangeLog\x12\x11\n\ttimestamp\x18\x01 \x01(\r\x12\x1a\n\x12\x63hange_description\x18\x02 \x01(\t\x12\x10\n\x08language\x18\x03 \x01(\x05\x12\x16\n\x0esaved_snapshot\x18\x04 \x01(\x08\x12 \n\x18snapshot_game_branch_min\x18\x05 \x01(\t\x12 \n\x18snapshot_game_branch_max\x18\x06 \x01(\t\x12\x13\n\x0bmanifest_id\x18\x07 \x01(\x06\"\x8a\x02\n)CPublishedFile_RefreshVotingQueue_Request\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x1a\n\x12matching_file_type\x18\x02 \x01(\r\x12\x0c\n\x04tags\x18\x03 \x03(\t\x12\x1c\n\x0ematch_all_tags\x18\x04 \x01(\x08:\x04true\x12\x15\n\rexcluded_tags\x18\x05 \x03(\t\x12\x1a\n\x12\x64\x65sired_queue_size\x18\x06 \x01(\r\x12S\n\x10\x64\x65sired_revision\x18\x08 \x01(\x0e\x32\x17.EPublishedFileRevision: k_EPublishedFileRevision_Default\",\n*CPublishedFile_RefreshVotingQueue_Response\"\xec\n\n!CPublishedFile_QueryFiles_Request\x12\x12\n\nquery_type\x18\x01 \x01(\r\x12\x0c\n\x04page\x18\x02 \x01(\r\x12\x0e\n\x06\x63ursor\x18\' \x01(\t\x12\x15\n\nnumperpage\x18\x03 \x01(\r:\x01\x31\x12\x15\n\rcreator_appid\x18\x04 \x01(\r\x12\r\n\x05\x61ppid\x18\x05 \x01(\r\x12\x14\n\x0crequiredtags\x18\x06 \x03(\t\x12\x14\n\x0c\x65xcludedtags\x18\x07 \x03(\t\x12\x1c\n\x0ematch_all_tags\x18\x08 \x01(\x08:\x04true\x12\x16\n\x0erequired_flags\x18\t \x03(\t\x12\x15\n\romitted_flags\x18\n \x03(\t\x12\x13\n\x0bsearch_text\x18\x0b \x01(\t\x12\x10\n\x08\x66iletype\x18\x0c \x01(\r\x12\x1d\n\x15\x63hild_publishedfileid\x18\r \x01(\x06\x12\x0c\n\x04\x64\x61ys\x18\x0e \x01(\r\x12!\n\x19include_recent_votes_only\x18\x0f \x01(\x08\x12 \n\x15\x63\x61\x63he_max_age_seconds\x18\x1f \x01(\r:\x01\x30\x12\x13\n\x08language\x18! \x01(\x05:\x01\x30\x12\x42\n\x10required_kv_tags\x18\" \x03(\x0b\x32(.CPublishedFile_QueryFiles_Request.KVTag\x12>\n\ttaggroups\x18* \x03(\x0b\x32+.CPublishedFile_QueryFiles_Request.TagGroup\x12H\n\x12\x64\x61te_range_created\x18, \x01(\x0b\x32,.CPublishedFile_QueryFiles_Request.DateRange\x12H\n\x12\x64\x61te_range_updated\x18- \x01(\x0b\x32,.CPublishedFile_QueryFiles_Request.DateRange\x12;\n\x1c\x65xcluded_content_descriptors\x18. \x03(\x0e\x32\x15.EContentDescriptorID\x12\x13\n\x0b\x61\x64min_query\x18/ \x01(\x08\x12\x11\n\ttotalonly\x18\x10 \x01(\x08\x12\x10\n\x08ids_only\x18# \x01(\x08\x12\x18\n\x10return_vote_data\x18\x11 \x01(\x08\x12\x13\n\x0breturn_tags\x18\x12 \x01(\x08\x12\x16\n\x0ereturn_kv_tags\x18\x13 \x01(\x08\x12\x17\n\x0freturn_previews\x18\x14 \x01(\x08\x12\x17\n\x0freturn_children\x18\x15 \x01(\x08\x12 \n\x18return_short_description\x18\x16 \x01(\x08\x12\x1c\n\x14return_for_sale_data\x18\x1e \x01(\x08\x12\x1e\n\x0freturn_metadata\x18  \x01(\x08:\x05\x66\x61lse\x12\x1d\n\x15return_playtime_stats\x18$ \x01(\r\x12\x16\n\x0ereturn_details\x18% \x01(\x08\x12 \n\x18strip_description_bbcode\x18& \x01(\x08\x12S\n\x10\x64\x65sired_revision\x18( \x01(\x0e\x32\x17.EPublishedFileRevision: k_EPublishedFileRevision_Default\x12\x1f\n\x10return_reactions\x18+ \x01(\x08:\x05\x66\x61lse\x1a#\n\x05KVTag\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\x1a\x18\n\x08TagGroup\x12\x0c\n\x04tags\x18\x01 \x03(\t\x1a;\n\tDateRange\x12\x17\n\x0ftimestamp_start\x18\x01 \x01(\r\x12\x15\n\rtimestamp_end\x18\x02 \x01(\r\"}\n\"CPublishedFile_QueryFiles_Response\x12\r\n\x05total\x18\x01 \x01(\r\x12\x33\n\x14publishedfiledetails\x18\x02 \x03(\x0b\x32\x15.PublishedFileDetails\x12\x13\n\x0bnext_cursor\x18\x03 \x01(\t\"i\n)CPublishedFile_AddAppRelationship_Request\x12\x17\n\x0fpublishedfileid\x18\x01 \x01(\x04\x12\r\n\x05\x61ppid\x18\x02 \x01(\r\x12\x14\n\x0crelationship\x18\x03 \x01(\r\",\n*CPublishedFile_AddAppRelationship_Response\"l\n,CPublishedFile_RemoveAppRelationship_Request\x12\x17\n\x0fpublishedfileid\x18\x01 \x01(\x04\x12\r\n\x05\x61ppid\x18\x02 \x01(\r\x12\x14\n\x0crelationship\x18\x03 \x01(\r\"/\n-CPublishedFile_RemoveAppRelationship_Response\"E\n*CPublishedFile_GetAppRelationships_Request\x12\x17\n\x0fpublishedfileid\x18\x01 \x01(\x04\"\xbe\x01\n+CPublishedFile_GetAppRelationships_Response\x12W\n\x11\x61pp_relationships\x18\x03 \x03(\x0b\x32<.CPublishedFile_GetAppRelationships_Response.AppRelationship\x1a\x36\n\x0f\x41ppRelationship\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x14\n\x0crelationship\x18\x02 \x01(\r\"j\n1CPublishedFile_GetAppRelationshipsBatched_Request\x12\x18\n\x10publishedfileids\x18\x01 \x03(\x04\x12\x1b\n\x13\x66ilter_relationship\x18\x02 \x01(\r\"\xff\x02\n2CPublishedFile_GetAppRelationshipsBatched_Response\x12g\n\rrelationships\x18\x01 \x03(\x0b\x32P.CPublishedFile_GetAppRelationshipsBatched_Response.PublishedFileAppRelationship\x1a\x36\n\x0f\x41ppRelationship\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x14\n\x0crelationship\x18\x02 \x01(\r\x1a\xa7\x01\n\x1cPublishedFileAppRelationship\x12\x17\n\x0fpublishedfileid\x18\x01 \x01(\x04\x12\x0e\n\x06result\x18\x02 \x01(\r\x12^\n\x11\x61pp_relationships\x18\x03 \x03(\x0b\x32\x43.CPublishedFile_GetAppRelationshipsBatched_Response.AppRelationship\"W\n,CPublishedFile_StartPlaytimeTracking_Request\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x18\n\x10publishedfileids\x18\x02 \x03(\x04\"/\n-CPublishedFile_StartPlaytimeTracking_Response\"V\n+CPublishedFile_StopPlaytimeTracking_Request\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x18\n\x10publishedfileids\x18\x02 \x03(\x04\".\n,CPublishedFile_StopPlaytimeTracking_Response\"J\n9CPublishedFile_StopPlaytimeTrackingForAllAppItems_Request\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\"<\n:CPublishedFile_StopPlaytimeTrackingForAllAppItems_Response\"\x81\x02\n6CPublishedFile_SetPlaytimeForControllerConfigs_Request\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12n\n\x17\x63ontroller_config_usage\x18\x02 \x03(\x0b\x32M.CPublishedFile_SetPlaytimeForControllerConfigs_Request.ControllerConfigUsage\x1aH\n\x15\x43ontrollerConfigUsage\x12\x17\n\x0fpublishedfileid\x18\x01 \x01(\x04\x12\x16\n\x0eseconds_active\x18\x02 \x01(\x02\"9\n7CPublishedFile_SetPlaytimeForControllerConfigs_Response\"Y\n\x1f\x43PublishedFile_AddChild_Request\x12\x17\n\x0fpublishedfileid\x18\x01 \x01(\x04\x12\x1d\n\x15\x63hild_publishedfileid\x18\x02 \x01(\x04\"\"\n CPublishedFile_AddChild_Response\"\\\n\"CPublishedFile_RemoveChild_Request\x12\x17\n\x0fpublishedfileid\x18\x01 \x01(\x04\x12\x1d\n\x15\x63hild_publishedfileid\x18\x02 \x01(\x04\"%\n#CPublishedFile_RemoveChild_Response\"h\n,CPublishedFile_SetCollectionChildren_Request\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x17\n\x0fpublishedfileid\x18\x02 \x01(\x04\x12\x10\n\x08\x63hildren\x18\x03 \x03(\x04\"/\n-CPublishedFile_SetCollectionChildren_Response\"\x87\x01\n8CPublishedFile_SetSubscriptionListFromCollection_Request\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x11\n\tlist_type\x18\x02 \x01(\r\x12\x17\n\x0fpublishedfileid\x18\x03 \x01(\x04\x12\x10\n\x08\x61\x64\x64_only\x18\x04 \x01(\x08\";\n9CPublishedFile_SetSubscriptionListFromCollection_Response\"E\n)CPublishedFile_GetUserVoteSummary_Request\x12\x18\n\x10publishedfileids\x18\x01 \x03(\x06\"\xda\x01\n*CPublishedFile_GetUserVoteSummary_Response\x12J\n\tsummaries\x18\x01 \x03(\x0b\x32\x37.CPublishedFile_GetUserVoteSummary_Response.VoteSummary\x1a`\n\x0bVoteSummary\x12\x17\n\x0fpublishedfileid\x18\x01 \x01(\x06\x12\x10\n\x08vote_for\x18\x02 \x01(\x08\x12\x14\n\x0cvote_against\x18\x03 \x01(\x08\x12\x10\n\x08reported\x18\x04 \x01(\x08\"\xbd\x01\n%CPublishedFile_GetItemChanges_Request\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x19\n\x11last_time_updated\x18\x02 \x01(\r\x12\x15\n\rnum_items_max\x18\x03 \x01(\r\x12S\n\x10\x64\x65sired_revision\x18\x04 \x01(\x0e\x32\x17.EPublishedFileRevision: k_EPublishedFileRevision_Default\"\xa2\x02\n&CPublishedFile_GetItemChanges_Response\x12\x13\n\x0bupdate_time\x18\x01 \x01(\r\x12P\n\x0eworkshop_items\x18\x02 \x03(\x0b\x32\x38.CPublishedFile_GetItemChanges_Response.WorkshopItemInfo\x1a\x90\x01\n\x10WorkshopItemInfo\x12\x19\n\x11published_file_id\x18\x01 \x01(\x06\x12\x14\n\x0ctime_updated\x18\x02 \x01(\r\x12\x13\n\x0bmanifest_id\x18\x03 \x01(\x06\x12\x36\n\x10\x61uthor_snapshots\x18\x04 \x03(\x0b\x32\x1c.PublishedFileAuthorSnapshot\"G\n,CPublishedFile_GetContentDescriptors_Request\x12\x17\n\x0fpublishedfileid\x18\x01 \x01(\x06\"\xba\x02\n-CPublishedFile_GetContentDescriptors_Response\x12]\n\x13\x63ontent_descriptors\x18\x01 \x03(\x0b\x32@.CPublishedFile_GetContentDescriptors_Response.ContentDescriptor\x1a\xa9\x01\n\x11\x43ontentDescriptor\x12W\n\x0c\x64\x65scriptorid\x18\x01 \x01(\x0e\x32\x15.EContentDescriptorID:*k_EContentDescriptor_NudityOrSexualContent\x12\x11\n\taccountid\x18\x02 \x01(\r\x12\x11\n\ttimestamp\x18\x03 \x01(\r\x12\x15\n\rmoderator_set\x18\x04 \x01(\x08\"\xb3\x01\n/CPublishedFile_UpdateContentDescriptors_Request\x12\x17\n\x0fpublishedfileid\x18\x01 \x01(\x06\x12\x31\n\x12\x64\x65scriptors_to_add\x18\x02 \x03(\x0e\x32\x15.EContentDescriptorID\x12\x34\n\x15\x64\x65scriptors_to_remove\x18\x03 \x03(\x0e\x32\x15.EContentDescriptorID\"M\n0CPublishedFile_UpdateContentDescriptors_Response\x12\x19\n\x11timestamp_updated\x18\x01 \x01(\r\"\xa4\x04\n*CPublishedFile_FileSubscribed_Notification\x12\x19\n\x11published_file_id\x18\x01 \x01(\x06\x12\x0e\n\x06\x61pp_id\x18\x02 \x01(\r\x12\x15\n\rfile_hcontent\x18\x03 \x01(\x06\x12\x11\n\tfile_size\x18\x04 \x01(\r\x12\x18\n\x10rtime_subscribed\x18\x05 \x01(\r\x12\x18\n\x10is_depot_content\x18\x06 \x01(\x08\x12\x15\n\rrtime_updated\x18\x07 \x01(\r\x12K\n\x08revision\x18\t \x01(\x0e\x32\x17.EPublishedFileRevision: k_EPublishedFileRevision_Default\x12K\n\trevisions\x18\x08 \x03(\x0b\x32\x38.CPublishedFile_FileSubscribed_Notification.RevisionData\x1a\xbb\x01\n\x0cRevisionData\x12K\n\x08revision\x18\x01 \x01(\x0e\x32\x17.EPublishedFileRevision: k_EPublishedFileRevision_Default\x12\x15\n\rfile_hcontent\x18\x02 \x01(\x06\x12\x15\n\rrtime_updated\x18\x03 \x01(\r\x12\x17\n\x0fgame_branch_min\x18\x04 \x01(\t\x12\x17\n\x0fgame_branch_max\x18\x05 \x01(\t\"Y\n,CPublishedFile_FileUnsubscribed_Notification\x12\x19\n\x11published_file_id\x18\x01 \x01(\x06\x12\x0e\n\x06\x61pp_id\x18\x02 \x01(\r\"[\n.CPublishedFile_FileDeleted_Client_Notification\x12\x19\n\x11published_file_id\x18\x01 \x01(\x06\x12\x0e\n\x06\x61pp_id\x18\x02 \x01(\r*\xd8\x02\n\x16\x45PublishedFileRevision\x12$\n k_EPublishedFileRevision_Default\x10\x00\x12#\n\x1fk_EPublishedFileRevision_Latest\x10\x01\x12-\n)k_EPublishedFileRevision_ApprovedSnapshot\x10\x02\x12\x33\n/k_EPublishedFileRevision_ApprovedSnapshot_China\x10\x03\x12-\n)k_EPublishedFileRevision_RejectedSnapshot\x10\x04\x12\x33\n/k_EPublishedFileRevision_RejectedSnapshot_China\x10\x05\x12+\n\'k_EPublishedFileRevision_AuthorSnapshot\x10\x06*\xc8\x01\n\x1b\x45PublishedFileForSaleStatus\x12\x16\n\x12k_PFFSS_NotForSale\x10\x00\x12\x1b\n\x17k_PFFSS_PendingApproval\x10\x01\x12\x1b\n\x17k_PFFSS_ApprovedForSale\x10\x02\x12\x1b\n\x17k_PFFSS_RejectedForSale\x10\x03\x12\x1b\n\x17k_PFFSS_NoLongerForSale\x10\x04\x12\x1d\n\x19k_PFFSS_TentativeApproval\x10\x05\x32\xdd\x1b\n\rPublishedFile\x12\x43\n\x04Vote\x12\x1c.CPublishedFile_Vote_Request\x1a\x1d.CPublishedFile_Vote_Response\x12R\n\tSubscribe\x12!.CPublishedFile_Subscribe_Request\x1a\".CPublishedFile_Subscribe_Response\x12X\n\x0bUnsubscribe\x12#.CPublishedFile_Unsubscribe_Request\x1a$.CPublishedFile_Unsubscribe_Response\x12[\n\x0c\x43\x61nSubscribe\x12$.CPublishedFile_CanSubscribe_Request\x1a%.CPublishedFile_CanSubscribe_Response\x12j\n\x11GetSubSectionData\x12).CPublishedFile_GetSubSectionData_Request\x1a*.CPublishedFile_GetSubSectionData_Response\x12L\n\x07Publish\x12\x1f.CPublishedFile_Publish_Request\x1a .CPublishedFile_Publish_Response\x12U\n\nGetDetails\x12\".CPublishedFile_GetDetails_Request\x1a#.CPublishedFile_GetDetails_Response\x12X\n\x0bGetItemInfo\x12#.CPublishedFile_GetItemInfo_Request\x1a$.CPublishedFile_GetItemInfo_Response\x12[\n\x0cGetUserFiles\x12$.CPublishedFile_GetUserFiles_Request\x1a%.CPublishedFile_GetUserFiles_Response\x12_\n\x10GetUserFileCount\x12$.CPublishedFile_GetUserFiles_Request\x1a%.CPublishedFile_GetUserFiles_Response\x12\x85\x01\n\x1a\x41reFilesInSubscriptionList\x12\x32.CPublishedFile_AreFilesInSubscriptionList_Request\x1a\x33.CPublishedFile_AreFilesInSubscriptionList_Response\x12I\n\x06Update\x12\x1e.CPublishedFile_Update_Request\x1a\x1f.CPublishedFile_Update_Response\x12I\n\x06\x44\x65lete\x12\x1e.CPublishedFile_Delete_Request\x1a\x1f.CPublishedFile_Delete_Response\x12v\n\x15GetChangeHistoryEntry\x12-.CPublishedFile_GetChangeHistoryEntry_Request\x1a..CPublishedFile_GetChangeHistoryEntry_Response\x12g\n\x10GetChangeHistory\x12(.CPublishedFile_GetChangeHistory_Request\x1a).CPublishedFile_GetChangeHistory_Response\x12m\n\x12RefreshVotingQueue\x12*.CPublishedFile_RefreshVotingQueue_Request\x1a+.CPublishedFile_RefreshVotingQueue_Response\x12U\n\nQueryFiles\x12\".CPublishedFile_QueryFiles_Request\x1a#.CPublishedFile_QueryFiles_Response\x12m\n\x12\x41\x64\x64\x41ppRelationship\x12*.CPublishedFile_AddAppRelationship_Request\x1a+.CPublishedFile_AddAppRelationship_Response\x12v\n\x15RemoveAppRelationship\x12-.CPublishedFile_RemoveAppRelationship_Request\x1a..CPublishedFile_RemoveAppRelationship_Response\x12p\n\x13GetAppRelationships\x12+.CPublishedFile_GetAppRelationships_Request\x1a,.CPublishedFile_GetAppRelationships_Response\x12\x85\x01\n\x1aGetAppRelationshipsBatched\x12\x32.CPublishedFile_GetAppRelationshipsBatched_Request\x1a\x33.CPublishedFile_GetAppRelationshipsBatched_Response\x12v\n\x15StartPlaytimeTracking\x12-.CPublishedFile_StartPlaytimeTracking_Request\x1a..CPublishedFile_StartPlaytimeTracking_Response\x12s\n\x14StopPlaytimeTracking\x12,.CPublishedFile_StopPlaytimeTracking_Request\x1a-.CPublishedFile_StopPlaytimeTracking_Response\x12\x9d\x01\n\"StopPlaytimeTrackingForAllAppItems\x12:.CPublishedFile_StopPlaytimeTrackingForAllAppItems_Request\x1a;.CPublishedFile_StopPlaytimeTrackingForAllAppItems_Response\x12\x94\x01\n\x1fSetPlaytimeForControllerConfigs\x12\x37.CPublishedFile_SetPlaytimeForControllerConfigs_Request\x1a\x38.CPublishedFile_SetPlaytimeForControllerConfigs_Response\x12O\n\x08\x41\x64\x64\x43hild\x12 .CPublishedFile_AddChild_Request\x1a!.CPublishedFile_AddChild_Response\x12X\n\x0bRemoveChild\x12#.CPublishedFile_RemoveChild_Request\x1a$.CPublishedFile_RemoveChild_Response\x12v\n\x15SetCollectionChildren\x12-.CPublishedFile_SetCollectionChildren_Request\x1a..CPublishedFile_SetCollectionChildren_Response\x12\x9a\x01\n!SetSubscriptionListFromCollection\x12\x39.CPublishedFile_SetSubscriptionListFromCollection_Request\x1a:.CPublishedFile_SetSubscriptionListFromCollection_Response\x12m\n\x12GetUserVoteSummary\x12*.CPublishedFile_GetUserVoteSummary_Request\x1a+.CPublishedFile_GetUserVoteSummary_Response\x12\x61\n\x0eGetItemChanges\x12&.CPublishedFile_GetItemChanges_Request\x1a\'.CPublishedFile_GetItemChanges_Response\x12v\n\x15GetContentDescriptors\x12-.CPublishedFile_GetContentDescriptors_Request\x1a..CPublishedFile_GetContentDescriptors_Response\x12\x7f\n\x18UpdateContentDescriptors\x12\x30.CPublishedFile_UpdateContentDescriptors_Request\x1a\x31.CPublishedFile_UpdateContentDescriptors_Response2\x96\x02\n\x13PublishedFileClient\x12P\n\x14NotifyFileSubscribed\x12+.CPublishedFile_FileSubscribed_Notification\x1a\x0b.NoResponse\x12T\n\x16NotifyFileUnsubscribed\x12-.CPublishedFile_FileUnsubscribed_Notification\x1a\x0b.NoResponse\x12Q\n\x11NotifyFileDeleted\x12/.CPublishedFile_FileDeleted_Client_Notification\x1a\x0b.NoResponse\x1a\x04\xc0\xb5\x18\x02\x42\x03\x90\x01\x01')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'steammessages_publishedfile_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\220\001\001'
  _PUBLISHEDFILECLIENT._options = None
  _PUBLISHEDFILECLIENT._serialized_options = b'\300\265\030\002'
  _EPUBLISHEDFILEREVISION._serialized_start=15337
  _EPUBLISHEDFILEREVISION._serialized_end=15681
  _EPUBLISHEDFILEFORSALESTATUS._serialized_start=15684
  _EPUBLISHEDFILEFORSALESTATUS._serialized_end=15884
  _CPUBLISHEDFILE_VOTE_REQUEST._serialized_start=122
  _CPUBLISHEDFILE_VOTE_REQUEST._serialized_end=193
  _CPUBLISHEDFILE_VOTE_RESPONSE._serialized_start=195
  _CPUBLISHEDFILE_VOTE_RESPONSE._serialized_end=225
  _CPUBLISHEDFILE_SUBSCRIBE_REQUEST._serialized_start=228
  _CPUBLISHEDFILE_SUBSCRIBE_REQUEST._serialized_end=374
  _CPUBLISHEDFILE_SUBSCRIBE_RESPONSE._serialized_start=376
  _CPUBLISHEDFILE_SUBSCRIBE_RESPONSE._serialized_end=411
  _CPUBLISHEDFILE_UNSUBSCRIBE_REQUEST._serialized_start=413
  _CPUBLISHEDFILE_UNSUBSCRIBE_REQUEST._serialized_end=531
  _CPUBLISHEDFILE_UNSUBSCRIBE_RESPONSE._serialized_start=533
  _CPUBLISHEDFILE_UNSUBSCRIBE_RESPONSE._serialized_end=570
  _CPUBLISHEDFILE_CANSUBSCRIBE_REQUEST._serialized_start=572
  _CPUBLISHEDFILE_CANSUBSCRIBE_REQUEST._serialized_end=634
  _CPUBLISHEDFILE_CANSUBSCRIBE_RESPONSE._serialized_start=636
  _CPUBLISHEDFILE_CANSUBSCRIBE_RESPONSE._serialized_end=697
  _CPUBLISHEDFILE_GETSUBSECTIONDATA_REQUEST._serialized_start=700
  _CPUBLISHEDFILE_GETSUBSECTIONDATA_REQUEST._serialized_end=911
  _PUBLISHEDFILESUBSECTION._serialized_start=913
  _PUBLISHEDFILESUBSECTION._serialized_end=1018
  _CPUBLISHEDFILE_GETSUBSECTIONDATA_RESPONSE._serialized_start=1020
  _CPUBLISHEDFILE_GETSUBSECTIONDATA_RESPONSE._serialized_end=1111
  _CPUBLISHEDFILE_PUBLISH_REQUEST._serialized_start=1114
  _CPUBLISHEDFILE_PUBLISH_REQUEST._serialized_end=1495
  _CPUBLISHEDFILE_PUBLISH_RESPONSE._serialized_start=1497
  _CPUBLISHEDFILE_PUBLISH_RESPONSE._serialized_end=1577
  _CPUBLISHEDFILE_GETDETAILS_REQUEST._serialized_start=1580
  _CPUBLISHEDFILE_GETDETAILS_REQUEST._serialized_end=2087
  _PUBLISHEDFILEAUTHORSNAPSHOT._serialized_start=2089
  _PUBLISHEDFILEAUTHORSNAPSHOT._serialized_end=2207
  _PUBLISHEDFILEDETAILS._serialized_start=2210
  _PUBLISHEDFILEDETAILS._serialized_end=5164
  _PUBLISHEDFILEDETAILS_TAG._serialized_start=4349
  _PUBLISHEDFILEDETAILS_TAG._serialized_end=4408
  _PUBLISHEDFILEDETAILS_PREVIEW._serialized_start=4411
  _PUBLISHEDFILEDETAILS_PREVIEW._serialized_end=4577
  _PUBLISHEDFILEDETAILS_CHILD._serialized_start=4579
  _PUBLISHEDFILEDETAILS_CHILD._serialized_end=4649
  _PUBLISHEDFILEDETAILS_KVTAG._serialized_start=4651
  _PUBLISHEDFILEDETAILS_KVTAG._serialized_end=4686
  _PUBLISHEDFILEDETAILS_VOTEDATA._serialized_start=4689
  _PUBLISHEDFILEDETAILS_VOTEDATA._serialized_end=4829
  _PUBLISHEDFILEDETAILS_FORSALEDATA._serialized_start=4832
  _PUBLISHEDFILEDETAILS_FORSALEDATA._serialized_end=5052
  _PUBLISHEDFILEDETAILS_PLAYTIMESTATS._serialized_start=5054
  _PUBLISHEDFILEDETAILS_PLAYTIMESTATS._serialized_end=5117
  _PUBLISHEDFILEDETAILS_REACTION._serialized_start=5119
  _PUBLISHEDFILEDETAILS_REACTION._serialized_end=5164
  _CPUBLISHEDFILE_GETDETAILS_RESPONSE._serialized_start=5166
  _CPUBLISHEDFILE_GETDETAILS_RESPONSE._serialized_end=5255
  _CPUBLISHEDFILE_GETITEMINFO_REQUEST._serialized_start=5258
  _CPUBLISHEDFILE_GETITEMINFO_REQUEST._serialized_end=5561
  _CPUBLISHEDFILE_GETITEMINFO_REQUEST_WORKSHOPITEM._serialized_start=5413
  _CPUBLISHEDFILE_GETITEMINFO_REQUEST_WORKSHOPITEM._serialized_end=5561
  _CPUBLISHEDFILE_GETITEMINFO_RESPONSE._serialized_start=5564
  _CPUBLISHEDFILE_GETITEMINFO_RESPONSE._serialized_end=5963
  _CPUBLISHEDFILE_GETITEMINFO_RESPONSE_WORKSHOPITEMINFO._serialized_start=5727
  _CPUBLISHEDFILE_GETITEMINFO_RESPONSE_WORKSHOPITEMINFO._serialized_end=5963
  _CPUBLISHEDFILE_GETUSERFILES_REQUEST._serialized_start=5966
  _CPUBLISHEDFILE_GETUSERFILES_REQUEST._serialized_end=7124
  _CPUBLISHEDFILE_GETUSERFILES_REQUEST_KVTAG._serialized_start=4651
  _CPUBLISHEDFILE_GETUSERFILES_REQUEST_KVTAG._serialized_end=4686
  _CPUBLISHEDFILE_GETUSERFILES_REQUEST_TAGGROUP._serialized_start=7100
  _CPUBLISHEDFILE_GETUSERFILES_REQUEST_TAGGROUP._serialized_end=7124
  _CPUBLISHEDFILE_GETUSERFILES_RESPONSE._serialized_start=7127
  _CPUBLISHEDFILE_GETUSERFILES_RESPONSE._serialized_end=7383
  _CPUBLISHEDFILE_GETUSERFILES_RESPONSE_APP._serialized_start=7312
  _CPUBLISHEDFILE_GETUSERFILES_RESPONSE_APP._serialized_end=7383
  _CPUBLISHEDFILE_AREFILESINSUBSCRIPTIONLIST_REQUEST._serialized_start=7386
  _CPUBLISHEDFILE_AREFILESINSUBSCRIPTIONLIST_REQUEST._serialized_end=7540
  _CPUBLISHEDFILE_AREFILESINSUBSCRIPTIONLIST_RESPONSE._serialized_start=7543
  _CPUBLISHEDFILE_AREFILESINSUBSCRIPTIONLIST_RESPONSE._serialized_end=7721
  _CPUBLISHEDFILE_AREFILESINSUBSCRIPTIONLIST_RESPONSE_INLIST._serialized_start=7672
  _CPUBLISHEDFILE_AREFILESINSUBSCRIPTIONLIST_RESPONSE_INLIST._serialized_end=7721
  _CPUBLISHEDFILE_UPDATE_REQUEST._serialized_start=7724
  _CPUBLISHEDFILE_UPDATE_REQUEST._serialized_end=7996
  _CPUBLISHEDFILE_UPDATE_RESPONSE._serialized_start=7998
  _CPUBLISHEDFILE_UPDATE_RESPONSE._serialized_end=8030
  _CPUBLISHEDFILE_DELETE_REQUEST._serialized_start=8032
  _CPUBLISHEDFILE_DELETE_REQUEST._serialized_end=8103
  _CPUBLISHEDFILE_DELETE_RESPONSE._serialized_start=8105
  _CPUBLISHEDFILE_DELETE_RESPONSE._serialized_end=8137
  _CPUBLISHEDFILE_GETCHANGEHISTORYENTRY_REQUEST._serialized_start=8139
  _CPUBLISHEDFILE_GETCHANGEHISTORYENTRY_REQUEST._serialized_end=8247
  _CPUBLISHEDFILE_GETCHANGEHISTORYENTRY_RESPONSE._serialized_start=8250
  _CPUBLISHEDFILE_GETCHANGEHISTORYENTRY_RESPONSE._serialized_end=8456
  _CPUBLISHEDFILE_GETCHANGEHISTORY_REQUEST._serialized_start=8459
  _CPUBLISHEDFILE_GETCHANGEHISTORY_REQUEST._serialized_end=8601
  _CPUBLISHEDFILE_GETCHANGEHISTORY_RESPONSE._serialized_start=8604
  _CPUBLISHEDFILE_GETCHANGEHISTORY_RESPONSE._serialized_end=8923
  _CPUBLISHEDFILE_GETCHANGEHISTORY_RESPONSE_CHANGELOG._serialized_start=8734
  _CPUBLISHEDFILE_GETCHANGEHISTORY_RESPONSE_CHANGELOG._serialized_end=8923
  _CPUBLISHEDFILE_REFRESHVOTINGQUEUE_REQUEST._serialized_start=8926
  _CPUBLISHEDFILE_REFRESHVOTINGQUEUE_REQUEST._serialized_end=9192
  _CPUBLISHEDFILE_REFRESHVOTINGQUEUE_RESPONSE._serialized_start=9194
  _CPUBLISHEDFILE_REFRESHVOTINGQUEUE_RESPONSE._serialized_end=9238
  _CPUBLISHEDFILE_QUERYFILES_REQUEST._serialized_start=9241
  _CPUBLISHEDFILE_QUERYFILES_REQUEST._serialized_end=10629
  _CPUBLISHEDFILE_QUERYFILES_REQUEST_KVTAG._serialized_start=4651
  _CPUBLISHEDFILE_QUERYFILES_REQUEST_KVTAG._serialized_end=4686
  _CPUBLISHEDFILE_QUERYFILES_REQUEST_TAGGROUP._serialized_start=7100
  _CPUBLISHEDFILE_QUERYFILES_REQUEST_TAGGROUP._serialized_end=7124
  _CPUBLISHEDFILE_QUERYFILES_REQUEST_DATERANGE._serialized_start=10570
  _CPUBLISHEDFILE_QUERYFILES_REQUEST_DATERANGE._serialized_end=10629
  _CPUBLISHEDFILE_QUERYFILES_RESPONSE._serialized_start=10631
  _CPUBLISHEDFILE_QUERYFILES_RESPONSE._serialized_end=10756
  _CPUBLISHEDFILE_ADDAPPRELATIONSHIP_REQUEST._serialized_start=10758
  _CPUBLISHEDFILE_ADDAPPRELATIONSHIP_REQUEST._serialized_end=10863
  _CPUBLISHEDFILE_ADDAPPRELATIONSHIP_RESPONSE._serialized_start=10865
  _CPUBLISHEDFILE_ADDAPPRELATIONSHIP_RESPONSE._serialized_end=10909
  _CPUBLISHEDFILE_REMOVEAPPRELATIONSHIP_REQUEST._serialized_start=10911
  _CPUBLISHEDFILE_REMOVEAPPRELATIONSHIP_REQUEST._serialized_end=11019
  _CPUBLISHEDFILE_REMOVEAPPRELATIONSHIP_RESPONSE._serialized_start=11021
  _CPUBLISHEDFILE_REMOVEAPPRELATIONSHIP_RESPONSE._serialized_end=11068
  _CPUBLISHEDFILE_GETAPPRELATIONSHIPS_REQUEST._serialized_start=11070
  _CPUBLISHEDFILE_GETAPPRELATIONSHIPS_REQUEST._serialized_end=11139
  _CPUBLISHEDFILE_GETAPPRELATIONSHIPS_RESPONSE._serialized_start=11142
  _CPUBLISHEDFILE_GETAPPRELATIONSHIPS_RESPONSE._serialized_end=11332
  _CPUBLISHEDFILE_GETAPPRELATIONSHIPS_RESPONSE_APPRELATIONSHIP._serialized_start=11278
  _CPUBLISHEDFILE_GETAPPRELATIONSHIPS_RESPONSE_APPRELATIONSHIP._serialized_end=11332
  _CPUBLISHEDFILE_GETAPPRELATIONSHIPSBATCHED_REQUEST._serialized_start=11334
  _CPUBLISHEDFILE_GETAPPRELATIONSHIPSBATCHED_REQUEST._serialized_end=11440
  _CPUBLISHEDFILE_GETAPPRELATIONSHIPSBATCHED_RESPONSE._serialized_start=11443
  _CPUBLISHEDFILE_GETAPPRELATIONSHIPSBATCHED_RESPONSE._serialized_end=11826
  _CPUBLISHEDFILE_GETAPPRELATIONSHIPSBATCHED_RESPONSE_APPRELATIONSHIP._serialized_start=11278
  _CPUBLISHEDFILE_GETAPPRELATIONSHIPSBATCHED_RESPONSE_APPRELATIONSHIP._serialized_end=11332
  _CPUBLISHEDFILE_GETAPPRELATIONSHIPSBATCHED_RESPONSE_PUBLISHEDFILEAPPRELATIONSHIP._serialized_start=11659
  _CPUBLISHEDFILE_GETAPPRELATIONSHIPSBATCHED_RESPONSE_PUBLISHEDFILEAPPRELATIONSHIP._serialized_end=11826
  _CPUBLISHEDFILE_STARTPLAYTIMETRACKING_REQUEST._serialized_start=11828
  _CPUBLISHEDFILE_STARTPLAYTIMETRACKING_REQUEST._serialized_end=11915
  _CPUBLISHEDFILE_STARTPLAYTIMETRACKING_RESPONSE._serialized_start=11917
  _CPUBLISHEDFILE_STARTPLAYTIMETRACKING_RESPONSE._serialized_end=11964
  _CPUBLISHEDFILE_STOPPLAYTIMETRACKING_REQUEST._serialized_start=11966
  _CPUBLISHEDFILE_STOPPLAYTIMETRACKING_REQUEST._serialized_end=12052
  _CPUBLISHEDFILE_STOPPLAYTIMETRACKING_RESPONSE._serialized_start=12054
  _CPUBLISHEDFILE_STOPPLAYTIMETRACKING_RESPONSE._serialized_end=12100
  _CPUBLISHEDFILE_STOPPLAYTIMETRACKINGFORALLAPPITEMS_REQUEST._serialized_start=12102
  _CPUBLISHEDFILE_STOPPLAYTIMETRACKINGFORALLAPPITEMS_REQUEST._serialized_end=12176
  _CPUBLISHEDFILE_STOPPLAYTIMETRACKINGFORALLAPPITEMS_RESPONSE._serialized_start=12178
  _CPUBLISHEDFILE_STOPPLAYTIMETRACKINGFORALLAPPITEMS_RESPONSE._serialized_end=12238
  _CPUBLISHEDFILE_SETPLAYTIMEFORCONTROLLERCONFIGS_REQUEST._serialized_start=12241
  _CPUBLISHEDFILE_SETPLAYTIMEFORCONTROLLERCONFIGS_REQUEST._serialized_end=12498
  _CPUBLISHEDFILE_SETPLAYTIMEFORCONTROLLERCONFIGS_REQUEST_CONTROLLERCONFIGUSAGE._serialized_start=12426
  _CPUBLISHEDFILE_SETPLAYTIMEFORCONTROLLERCONFIGS_REQUEST_CONTROLLERCONFIGUSAGE._serialized_end=12498
  _CPUBLISHEDFILE_SETPLAYTIMEFORCONTROLLERCONFIGS_RESPONSE._serialized_start=12500
  _CPUBLISHEDFILE_SETPLAYTIMEFORCONTROLLERCONFIGS_RESPONSE._serialized_end=12557
  _CPUBLISHEDFILE_ADDCHILD_REQUEST._serialized_start=12559
  _CPUBLISHEDFILE_ADDCHILD_REQUEST._serialized_end=12648
  _CPUBLISHEDFILE_ADDCHILD_RESPONSE._serialized_start=12650
  _CPUBLISHEDFILE_ADDCHILD_RESPONSE._serialized_end=12684
  _CPUBLISHEDFILE_REMOVECHILD_REQUEST._serialized_start=12686
  _CPUBLISHEDFILE_REMOVECHILD_REQUEST._serialized_end=12778
  _CPUBLISHEDFILE_REMOVECHILD_RESPONSE._serialized_start=12780
  _CPUBLISHEDFILE_REMOVECHILD_RESPONSE._serialized_end=12817
  _CPUBLISHEDFILE_SETCOLLECTIONCHILDREN_REQUEST._serialized_start=12819
  _CPUBLISHEDFILE_SETCOLLECTIONCHILDREN_REQUEST._serialized_end=12923
  _CPUBLISHEDFILE_SETCOLLECTIONCHILDREN_RESPONSE._serialized_start=12925
  _CPUBLISHEDFILE_SETCOLLECTIONCHILDREN_RESPONSE._serialized_end=12972
  _CPUBLISHEDFILE_SETSUBSCRIPTIONLISTFROMCOLLECTION_REQUEST._serialized_start=12975
  _CPUBLISHEDFILE_SETSUBSCRIPTIONLISTFROMCOLLECTION_REQUEST._serialized_end=13110
  _CPUBLISHEDFILE_SETSUBSCRIPTIONLISTFROMCOLLECTION_RESPONSE._serialized_start=13112
  _CPUBLISHEDFILE_SETSUBSCRIPTIONLISTFROMCOLLECTION_RESPONSE._serialized_end=13171
  _CPUBLISHEDFILE_GETUSERVOTESUMMARY_REQUEST._serialized_start=13173
  _CPUBLISHEDFILE_GETUSERVOTESUMMARY_REQUEST._serialized_end=13242
  _CPUBLISHEDFILE_GETUSERVOTESUMMARY_RESPONSE._serialized_start=13245
  _CPUBLISHEDFILE_GETUSERVOTESUMMARY_RESPONSE._serialized_end=13463
  _CPUBLISHEDFILE_GETUSERVOTESUMMARY_RESPONSE_VOTESUMMARY._serialized_start=13367
  _CPUBLISHEDFILE_GETUSERVOTESUMMARY_RESPONSE_VOTESUMMARY._serialized_end=13463
  _CPUBLISHEDFILE_GETITEMCHANGES_REQUEST._serialized_start=13466
  _CPUBLISHEDFILE_GETITEMCHANGES_REQUEST._serialized_end=13655
  _CPUBLISHEDFILE_GETITEMCHANGES_RESPONSE._serialized_start=13658
  _CPUBLISHEDFILE_GETITEMCHANGES_RESPONSE._serialized_end=13948
  _CPUBLISHEDFILE_GETITEMCHANGES_RESPONSE_WORKSHOPITEMINFO._serialized_start=13804
  _CPUBLISHEDFILE_GETITEMCHANGES_RESPONSE_WORKSHOPITEMINFO._serialized_end=13948
  _CPUBLISHEDFILE_GETCONTENTDESCRIPTORS_REQUEST._serialized_start=13950
  _CPUBLISHEDFILE_GETCONTENTDESCRIPTORS_REQUEST._serialized_end=14021
  _CPUBLISHEDFILE_GETCONTENTDESCRIPTORS_RESPONSE._serialized_start=14024
  _CPUBLISHEDFILE_GETCONTENTDESCRIPTORS_RESPONSE._serialized_end=14338
  _CPUBLISHEDFILE_GETCONTENTDESCRIPTORS_RESPONSE_CONTENTDESCRIPTOR._serialized_start=14169
  _CPUBLISHEDFILE_GETCONTENTDESCRIPTORS_RESPONSE_CONTENTDESCRIPTOR._serialized_end=14338
  _CPUBLISHEDFILE_UPDATECONTENTDESCRIPTORS_REQUEST._serialized_start=14341
  _CPUBLISHEDFILE_UPDATECONTENTDESCRIPTORS_REQUEST._serialized_end=14520
  _CPUBLISHEDFILE_UPDATECONTENTDESCRIPTORS_RESPONSE._serialized_start=14522
  _CPUBLISHEDFILE_UPDATECONTENTDESCRIPTORS_RESPONSE._serialized_end=14599
  _CPUBLISHEDFILE_FILESUBSCRIBED_NOTIFICATION._serialized_start=14602
  _CPUBLISHEDFILE_FILESUBSCRIBED_NOTIFICATION._serialized_end=15150
  _CPUBLISHEDFILE_FILESUBSCRIBED_NOTIFICATION_REVISIONDATA._serialized_start=14963
  _CPUBLISHEDFILE_FILESUBSCRIBED_NOTIFICATION_REVISIONDATA._serialized_end=15150
  _CPUBLISHEDFILE_FILEUNSUBSCRIBED_NOTIFICATION._serialized_start=15152
  _CPUBLISHEDFILE_FILEUNSUBSCRIBED_NOTIFICATION._serialized_end=15241
  _CPUBLISHEDFILE_FILEDELETED_CLIENT_NOTIFICATION._serialized_start=15243
  _CPUBLISHEDFILE_FILEDELETED_CLIENT_NOTIFICATION._serialized_end=15334
  _PUBLISHEDFILE._serialized_start=15887
  _PUBLISHEDFILE._serialized_end=19436
  _PUBLISHEDFILECLIENT._serialized_start=19439
  _PUBLISHEDFILECLIENT._serialized_end=19717
_builder.BuildServices(DESCRIPTOR, 'steammessages_publishedfile_pb2', globals())
# @@protoc_insertion_point(module_scope)
