# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: steammessages_unified_test.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import steam.protobufs.steammessages_base_pb2 as steammessages__base__pb2
import steam.protobufs.steammessages_unified_base_pb2 as steammessages__unified__base__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n steammessages_unified_test.proto\x1a\x18steammessages_base.proto\x1a steammessages_unified_base.proto\"5\n CMsgTest_MessageToClient_Request\x12\x11\n\tsome_text\x18\x01 \x01(\t\"6\n!CMsgTest_MessageToClient_Response\x12\x11\n\tsome_text\x18\x01 \x01(\t\"7\n\"CMsgTest_NotifyClient_Notification\x12\x11\n\tsome_text\x18\x01 \x01(\t\"5\n CMsgTest_MessageToServer_Request\x12\x11\n\tsome_text\x18\x01 \x01(\t\"6\n!CMsgTest_MessageToServer_Response\x12\x11\n\tsome_text\x18\x01 \x01(\t\"7\n\"CMsgTest_NotifyServer_Notification\x12\x11\n\tsome_text\x18\x01 \x01(\t\"0\n\x1f\x43MsgTest_TestClientCall_Request\x12\r\n\x05param\x18\x01 \x01(\x05\"2\n CMsgTest_TestClientCall_Response\x12\x0e\n\x06result\x18\x01 \x01(\x05\"\x19\n\x17\x43MsgTest_NoBody_Request\"1\n\x1c\x43MsgTest_CallClient_Response\x12\x11\n\ttestvalue\x18\x01 \x01(\x05\x32\xb3\x01\n\x0fTestSteamClient\x12X\n\x0fMessageToClient\x12!.CMsgTest_MessageToClient_Request\x1a\".CMsgTest_MessageToClient_Response\x12@\n\x0cNotifyClient\x12#.CMsgTest_NotifyClient_Notification\x1a\x0b.NoResponse\x1a\x04\xc0\xb5\x18\x02\x32\x9a\x04\n\x14TestServerFromClient\x12X\n\x0fMessageToServer\x12!.CMsgTest_MessageToServer_Request\x1a\".CMsgTest_MessageToServer_Response\x12@\n\x0cNotifyServer\x12#.CMsgTest_NotifyServer_Notification\x1a\x0b.NoResponse\x12X\n\x11\x43lientCallAuthed1\x12 .CMsgTest_TestClientCall_Request\x1a!.CMsgTest_TestClientCall_Response\x12X\n\x11\x43lientCallAuthed2\x12 .CMsgTest_TestClientCall_Request\x1a!.CMsgTest_TestClientCall_Response\x12X\n\x11\x43lientCallAuthed3\x12 .CMsgTest_TestClientCall_Request\x1a!.CMsgTest_TestClientCall_Response\x12X\n\x11\x43lientCallAuthed4\x12 .CMsgTest_TestClientCall_Request\x1a!.CMsgTest_TestClientCall_Response2^\n\x15TestExternalPrivilege\x12\x45\n\nCallClient\x12\x18.CMsgTest_NoBody_Request\x1a\x1d.CMsgTest_CallClient_ResponseB\x03\x90\x01\x01')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'steammessages_unified_test_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\220\001\001'
  _TESTSTEAMCLIENT._options = None
  _TESTSTEAMCLIENT._serialized_options = b'\300\265\030\002'
  _CMSGTEST_MESSAGETOCLIENT_REQUEST._serialized_start=96
  _CMSGTEST_MESSAGETOCLIENT_REQUEST._serialized_end=149
  _CMSGTEST_MESSAGETOCLIENT_RESPONSE._serialized_start=151
  _CMSGTEST_MESSAGETOCLIENT_RESPONSE._serialized_end=205
  _CMSGTEST_NOTIFYCLIENT_NOTIFICATION._serialized_start=207
  _CMSGTEST_NOTIFYCLIENT_NOTIFICATION._serialized_end=262
  _CMSGTEST_MESSAGETOSERVER_REQUEST._serialized_start=264
  _CMSGTEST_MESSAGETOSERVER_REQUEST._serialized_end=317
  _CMSGTEST_MESSAGETOSERVER_RESPONSE._serialized_start=319
  _CMSGTEST_MESSAGETOSERVER_RESPONSE._serialized_end=373
  _CMSGTEST_NOTIFYSERVER_NOTIFICATION._serialized_start=375
  _CMSGTEST_NOTIFYSERVER_NOTIFICATION._serialized_end=430
  _CMSGTEST_TESTCLIENTCALL_REQUEST._serialized_start=432
  _CMSGTEST_TESTCLIENTCALL_REQUEST._serialized_end=480
  _CMSGTEST_TESTCLIENTCALL_RESPONSE._serialized_start=482
  _CMSGTEST_TESTCLIENTCALL_RESPONSE._serialized_end=532
  _CMSGTEST_NOBODY_REQUEST._serialized_start=534
  _CMSGTEST_NOBODY_REQUEST._serialized_end=559
  _CMSGTEST_CALLCLIENT_RESPONSE._serialized_start=561
  _CMSGTEST_CALLCLIENT_RESPONSE._serialized_end=610
  _TESTSTEAMCLIENT._serialized_start=613
  _TESTSTEAMCLIENT._serialized_end=792
  _TESTSERVERFROMCLIENT._serialized_start=795
  _TESTSERVERFROMCLIENT._serialized_end=1333
  _TESTEXTERNALPRIVILEGE._serialized_start=1335
  _TESTEXTERNALPRIVILEGE._serialized_end=1429
_builder.BuildServices(DESCRIPTOR, 'steammessages_unified_test_pb2', globals())
# @@protoc_insertion_point(module_scope)
