# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: clientmetrics.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x13\x63lientmetrics.proto\"\x8e\x02\n*CClientMetrics_ClientBootstrap_RequestInfo\x12\x19\n\x11original_hostname\x18\x01 \x01(\t\x12\x17\n\x0f\x61\x63tual_hostname\x18\x02 \x01(\t\x12\x0c\n\x04path\x18\x03 \x01(\t\x12\x11\n\tbase_name\x18\x04 \x01(\t\x12\x0f\n\x07success\x18\x05 \x01(\x08\x12\x13\n\x0bstatus_code\x18\x06 \x01(\r\x12\x1e\n\x16\x61\x64\x64ress_of_request_url\x18\x07 \x01(\t\x12\x18\n\x10response_time_ms\x18\x08 \x01(\r\x12\x16\n\x0e\x62ytes_received\x18\t \x01(\x04\x12\x13\n\x0bnum_retries\x18\n \x01(\r\"\xa9\x02\n&CClientMetrics_ClientBootstrap_Summary\x12\x15\n\rlauncher_type\x18\x01 \x01(\r\x12\x13\n\x0bsteam_realm\x18\x02 \x01(\r\x12\x11\n\tbeta_name\x18\x03 \x01(\t\x12\x1a\n\x12\x64ownload_completed\x18\x04 \x01(\x08\x12\x15\n\rtotal_time_ms\x18\x06 \x01(\r\x12\x46\n\x11manifest_requests\x18\x07 \x03(\x0b\x32+.CClientMetrics_ClientBootstrap_RequestInfo\x12\x45\n\x10package_requests\x18\x08 \x03(\x0b\x32+.CClientMetrics_ClientBootstrap_RequestInfo\"\xba\x01\n-CClientMetrics_ContentDownloadResponse_Counts\x12\x11\n\tclass_100\x18\x01 \x01(\r\x12\x11\n\tclass_200\x18\x02 \x01(\r\x12\x11\n\tclass_300\x18\x03 \x01(\r\x12\x11\n\tclass_400\x18\x04 \x01(\r\x12\x11\n\tclass_500\x18\x05 \x01(\r\x12\x13\n\x0bno_response\x18\x06 \x01(\r\x12\x15\n\rclass_unknown\x18\x07 \x01(\r\"\x9a\x01\n1CClientMetrics_ContentDownloadResponse_HostCounts\x12\x10\n\x08hostname\x18\x01 \x01(\t\x12\x13\n\x0bsource_type\x18\x02 \x01(\r\x12>\n\x06\x63ounts\x18\x03 \x01(\x0b\x32..CClientMetrics_ContentDownloadResponse_Counts\"q\n,CClientMetrics_ContentDownloadResponse_Hosts\x12\x41\n\x05hosts\x18\x01 \x03(\x0b\x32\x32.CClientMetrics_ContentDownloadResponse_HostCountsB\x05H\x01\x90\x01\x00')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'clientmetrics_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'H\001\220\001\000'
  _CCLIENTMETRICS_CLIENTBOOTSTRAP_REQUESTINFO._serialized_start=24
  _CCLIENTMETRICS_CLIENTBOOTSTRAP_REQUESTINFO._serialized_end=294
  _CCLIENTMETRICS_CLIENTBOOTSTRAP_SUMMARY._serialized_start=297
  _CCLIENTMETRICS_CLIENTBOOTSTRAP_SUMMARY._serialized_end=594
  _CCLIENTMETRICS_CONTENTDOWNLOADRESPONSE_COUNTS._serialized_start=597
  _CCLIENTMETRICS_CONTENTDOWNLOADRESPONSE_COUNTS._serialized_end=783
  _CCLIENTMETRICS_CONTENTDOWNLOADRESPONSE_HOSTCOUNTS._serialized_start=786
  _CCLIENTMETRICS_CONTENTDOWNLOADRESPONSE_HOSTCOUNTS._serialized_end=940
  _CCLIENTMETRICS_CONTENTDOWNLOADRESPONSE_HOSTS._serialized_start=942
  _CCLIENTMETRICS_CONTENTDOWNLOADRESPONSE_HOSTS._serialized_end=1055
# @@protoc_insertion_point(module_scope)
