# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: steammessages_clientserver_video.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import steam.protobufs.steammessages_base_pb2 as steammessages__base__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&steammessages_clientserver_video.proto\x1a\x18steammessages_base.proto\"\xc1\x02\n$CMsgVideoGameRecordingRepresentation\x12\x1b\n\x13representation_name\x18\x02 \x01(\t\x12\x1d\n\x15horizontal_resolution\x18\x03 \x01(\r\x12\x1b\n\x13vertical_resolution\x18\x04 \x01(\r\x12\x12\n\nframe_rate\x18\x05 \x01(\x01\x12\x11\n\tbandwidth\x18\x06 \x01(\r\x12\x19\n\x11\x61udio_sample_rate\x18\x07 \x01(\r\x12\x19\n\x11\x66rame_rate_string\x18\x08 \x01(\t\x12\r\n\x05\x63odec\x18\t \x01(\t\x12\x1c\n\x14\x61udio_channel_config\x18\n \x01(\r\x12\x36\n\x0csegment_info\x18\x0b \x03(\x0b\x32 .CVideo_GameRecordingSegmentInfo\"\xb4\x01\n\x1f\x43MsgVideoGameRecordingComponent\x12\x16\n\x0e\x63omponent_name\x18\x01 \x01(\t\x12\x10\n\x08\x63ontents\x18\x02 \x01(\r\x12\x14\n\x0csegment_size\x18\x03 \x01(\r\x12\x11\n\tfile_type\x18\x04 \x01(\t\x12>\n\x0frepresentations\x18\x05 \x03(\x0b\x32%.CMsgVideoGameRecordingRepresentation\"\x9f\x02\n\x19\x43MsgVideoGameRecordingDef\x12\x0f\n\x07steamid\x18\x01 \x01(\x04\x12\x0e\n\x06\x61pp_id\x18\x02 \x01(\r\x12\x14\n\x0cnum_segments\x18\x03 \x01(\r\x12\x1b\n\x13length_milliseconds\x18\x04 \x01(\r\x12\"\n\x1asegment_duration_timescale\x18\x05 \x01(\r\x12\x18\n\x10segment_duration\x18\x06 \x01(\r\x12\x34\n\ncomponents\x18\x07 \x03(\x0b\x32 .CMsgVideoGameRecordingComponent\x12\x15\n\rstart_time_ms\x18\x08 \x01(\r\x12#\n\x1bstart_offset_in_timeline_ms\x18\t \x01(\r\"\x8a\x01\n\x1f\x43Video_GameRecordingSegmentInfo\x12\x16\n\x0esegment_number\x18\x01 \x01(\r\x12\x1a\n\x12segment_size_bytes\x18\x02 \x01(\x04\x12\x16\n\x0e\x63omponent_name\x18\x03 \x01(\t\x12\x1b\n\x13representation_name\x18\x04 \x01(\t\"\x8f\x02\n%CVideo_GameRecordingSegmentUploadInfo\x12\x36\n\x0csegment_info\x18\x01 \x01(\x0b\x32 .CVideo_GameRecordingSegmentInfo\x12\x10\n\x08url_host\x18\x02 \x01(\t\x12\x10\n\x08url_path\x18\x03 \x01(\t\x12\x11\n\tuse_https\x18\x04 \x01(\x08\x12K\n\x0frequest_headers\x18\x05 \x03(\x0b\x32\x32.CVideo_GameRecordingSegmentUploadInfo.HTTPHeaders\x1a*\n\x0bHTTPHeaders\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\tB\x05H\x01\x90\x01\x00')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'steammessages_clientserver_video_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'H\001\220\001\000'
  _CMSGVIDEOGAMERECORDINGREPRESENTATION._serialized_start=69
  _CMSGVIDEOGAMERECORDINGREPRESENTATION._serialized_end=390
  _CMSGVIDEOGAMERECORDINGCOMPONENT._serialized_start=393
  _CMSGVIDEOGAMERECORDINGCOMPONENT._serialized_end=573
  _CMSGVIDEOGAMERECORDINGDEF._serialized_start=576
  _CMSGVIDEOGAMERECORDINGDEF._serialized_end=863
  _CVIDEO_GAMERECORDINGSEGMENTINFO._serialized_start=866
  _CVIDEO_GAMERECORDINGSEGMENTINFO._serialized_end=1004
  _CVIDEO_GAMERECORDINGSEGMENTUPLOADINFO._serialized_start=1007
  _CVIDEO_GAMERECORDINGSEGMENTUPLOADINFO._serialized_end=1278
  _CVIDEO_GAMERECORDINGSEGMENTUPLOADINFO_HTTPHEADERS._serialized_start=1236
  _CVIDEO_GAMERECORDINGSEGMENTUPLOADINFO_HTTPHEADERS._serialized_end=1278
# @@protoc_insertion_point(module_scope)
