# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: steammessages_childprocessquery.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import steam.protobufs.enums_pb2 as enums__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%steammessages_childprocessquery.proto\x1a\x0b\x65nums.proto\"f\n\x1d\x43MsgChildProcessQueryResponse\x12\x39\n\x0cgpu_topology\x18\x01 \x01(\x0b\x32!.CMsgChildProcessQueryGpuTopologyH\x00\x42\n\n\x08response\"\xd4\x02\n CMsgChildProcessQueryGpuTopology\x12\x37\n\x04gpus\x18\x01 \x03(\x0b\x32).CMsgChildProcessQueryGpuTopology.GpuInfo\x12\x16\n\x0e\x64\x65\x66\x61ult_gpu_id\x18\x02 \x01(\r\x1a\xde\x01\n\x07GpuInfo\x12\n\n\x02id\x18\x01 \x01(\r\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x17\n\x0fvram_size_bytes\x18\x03 \x01(\x04\x12\x38\n\tdriver_id\x18\x04 \x01(\x0e\x32\r.EGpuDriverId:\x16k_EGpuDriverId_Invalid\x12\x1c\n\x14\x64river_version_major\x18\x05 \x01(\x05\x12\x1c\n\x14\x64river_version_minor\x18\x06 \x01(\x05\x12\x1c\n\x14\x64river_version_patch\x18\x07 \x01(\x05\x12\x0c\n\x04luid\x18\x08 \x01(\x04\x42\x05H\x01\x90\x01\x00')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'steammessages_childprocessquery_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'H\001\220\001\000'
  _CMSGCHILDPROCESSQUERYRESPONSE._serialized_start=54
  _CMSGCHILDPROCESSQUERYRESPONSE._serialized_end=156
  _CMSGCHILDPROCESSQUERYGPUTOPOLOGY._serialized_start=159
  _CMSGCHILDPROCESSQUERYGPUTOPOLOGY._serialized_end=499
  _CMSGCHILDPROCESSQUERYGPUTOPOLOGY_GPUINFO._serialized_start=277
  _CMSGCHILDPROCESSQUERYGPUTOPOLOGY_GPUINFO._serialized_end=499
# @@protoc_insertion_point(module_scope)
