# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: webuimessages_achievements.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import steam.protobufs.steammessages_base_pb2 as steammessages__base__pb2
import steam.protobufs.webuimessages_base_pb2 as webuimessages__base__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n webuimessages_achievements.proto\x1a\x18steammessages_base.proto\x1a\x18webuimessages_base.proto\"/\n\x1d\x43\x41\x63hievements_GetInfo_Request\x12\x0e\n\x06gameid\x18\x01 \x01(\x04\"\xf0\x01\n\x1e\x43\x41\x63hievements_GetInfo_Response\x12:\n\x0c\x61\x63hievements\x18\x01 \x03(\x0b\x32$.CAchievements_GetInfo_Response.Info\x1a\x91\x01\n\x04Info\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04\x64\x65sc\x18\x03 \x01(\t\x12\x1a\n\x12image_url_achieved\x18\x04 \x01(\t\x12\x1e\n\x16image_url_not_achieved\x18\x05 \x01(\t\x12\x10\n\x08\x61\x63hieved\x18\x06 \x01(\x08\x12\x13\n\x0bunlock_time\x18\x07 \x01(\r2`\n\x0c\x41\x63hievements\x12J\n\x07GetInfo\x12\x1e.CAchievements_GetInfo_Request\x1a\x1f.CAchievements_GetInfo_Response\x1a\x04\x80\x97\"\x02\x42\x05H\x01\x90\x01\x01')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'webuimessages_achievements_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'H\001\220\001\001'
  _ACHIEVEMENTS._options = None
  _ACHIEVEMENTS._serialized_options = b'\200\227\"\002'
  _CACHIEVEMENTS_GETINFO_REQUEST._serialized_start=88
  _CACHIEVEMENTS_GETINFO_REQUEST._serialized_end=135
  _CACHIEVEMENTS_GETINFO_RESPONSE._serialized_start=138
  _CACHIEVEMENTS_GETINFO_RESPONSE._serialized_end=378
  _CACHIEVEMENTS_GETINFO_RESPONSE_INFO._serialized_start=233
  _CACHIEVEMENTS_GETINFO_RESPONSE_INFO._serialized_end=378
  _ACHIEVEMENTS._serialized_start=380
  _ACHIEVEMENTS._serialized_end=476
_builder.BuildServices(DESCRIPTOR, 'webuimessages_achievements_pb2', globals())
# @@protoc_insertion_point(module_scope)
