# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: steammessages_clientserver_uds.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import steam.protobufs.steammessages_base_pb2 as steammessages__base__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$steammessages_clientserver_uds.proto\x1a\x18steammessages_base.proto\"G\n\x1e\x43MsgClientUDSP2PSessionStarted\x12\x16\n\x0esteamid_remote\x18\x01 \x01(\x06\x12\r\n\x05\x61ppid\x18\x02 \x01(\x05\"\x81\x02\n\x1c\x43MsgClientUDSP2PSessionEnded\x12\x16\n\x0esteamid_remote\x18\x01 \x01(\x06\x12\r\n\x05\x61ppid\x18\x02 \x01(\x05\x12\x1a\n\x12session_length_sec\x18\x03 \x01(\x05\x12\x15\n\rsession_error\x18\x04 \x01(\x05\x12\x0f\n\x07nattype\x18\x05 \x01(\x05\x12\x12\n\nbytes_recv\x18\x06 \x01(\x05\x12\x12\n\nbytes_sent\x18\x07 \x01(\x05\x12\x18\n\x10\x62ytes_sent_relay\x18\x08 \x01(\x05\x12\x18\n\x10\x62ytes_recv_relay\x18\t \x01(\x05\x12\x1a\n\x12time_to_connect_ms\x18\n \x01(\x05\"\x1c\n\x1a\x43MsgClientGetClientDetails\"\xf0\x02\n\"CMsgClientGetClientDetailsResponse\x12\x17\n\x0fpackage_version\x18\x01 \x01(\r\x12\n\n\x02os\x18\x02 \x01(\t\x12\x14\n\x0cmachine_name\x18\x03 \x01(\t\x12\x11\n\tip_public\x18\x04 \x01(\t\x12\x12\n\nip_private\x18\x05 \x01(\t\x12?\n\rgames_running\x18\x06 \x03(\x0b\x32(.CMsgClientGetClientDetailsResponse.Game\x12\x17\n\x0f\x62ytes_available\x18\x07 \x01(\x04\x12\x18\n\x10protocol_version\x18\x08 \x01(\r\x12\x1a\n\x12\x63lientcomm_version\x18\t \x01(\r\x12\x13\n\x0blocal_users\x18\n \x03(\r\x1a\x43\n\x04Game\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x12\n\nextra_info\x18\x02 \x01(\t\x12\x18\n\x10time_running_sec\x18\x03 \x01(\r\"\xbc\x01\n\x1a\x43MsgClientGetClientAppList\x12\r\n\x05media\x18\x01 \x01(\x08\x12\r\n\x05tools\x18\x02 \x01(\x08\x12\r\n\x05games\x18\x03 \x01(\x08\x12\x16\n\x0eonly_installed\x18\x04 \x01(\x08\x12\x15\n\ronly_changing\x18\x05 \x01(\x08\x12\x0e\n\x06\x63omics\x18\x06 \x01(\x08\x12\x1b\n\x13include_client_info\x18\x07 \x01(\x08\x12\x15\n\rfilter_appids\x18\x08 \x03(\r\"\xcc\x06\n\"CMsgClientGetClientAppListResponse\x12\x35\n\x04\x61pps\x18\x01 \x03(\x0b\x32\'.CMsgClientGetClientAppListResponse.App\x12\x17\n\x0f\x62ytes_available\x18\x02 \x01(\x04\x12\x38\n\x0b\x63lient_info\x18\x03 \x01(\x0b\x32#.CMsgClientGetClientDetailsResponse\x1a\x9b\x05\n\x03\x41pp\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x10\n\x08\x63\x61tegory\x18\x02 \x01(\t\x12\x10\n\x08\x61pp_type\x18\n \x01(\t\x12\x10\n\x08\x66\x61vorite\x18\x03 \x01(\x08\x12\x11\n\tinstalled\x18\x04 \x01(\x08\x12\x13\n\x0b\x61uto_update\x18\x05 \x01(\x08\x12\x18\n\x10\x62ytes_downloaded\x18\x06 \x01(\x04\x12\x19\n\x11\x62ytes_to_download\x18\x07 \x01(\x04\x12\x1b\n\x13\x62ytes_download_rate\x18\x08 \x01(\r\x12\x39\n\x04\x64lcs\x18\t \x03(\x0b\x32+.CMsgClientGetClientAppListResponse.App.DLC\x12\x17\n\x0f\x64ownload_paused\x18\x0b \x01(\x08\x12\x17\n\x0fnum_downloading\x18\x0c \x01(\r\x12\x10\n\x08\x63hanging\x18\x0e \x01(\x08\x12\x1d\n\x15\x61vailable_on_platform\x18\x0f \x01(\x08\x12\x14\n\x0c\x62ytes_staged\x18\x10 \x01(\x04\x12\x16\n\x0e\x62ytes_to_stage\x18\x11 \x01(\x04\x12\x16\n\x0e\x62ytes_required\x18\x12 \x01(\x04\x12\x16\n\x0esource_buildid\x18\x13 \x01(\r\x12\x16\n\x0etarget_buildid\x18\x14 \x01(\r\x12#\n\x1b\x65stimated_seconds_remaining\x18\x15 \x01(\r\x12\x16\n\x0equeue_position\x18\x16 \x01(\x05\x12\x14\n\x0cuninstalling\x18\x17 \x01(\x08\x12\x19\n\x11rt_time_scheduled\x18\x18 \x01(\r\x12\x0f\n\x07running\x18\x19 \x01(\x08\x12\x19\n\x11update_percentage\x18\x1a \x01(\r\x1a\'\n\x03\x44LC\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x11\n\tinstalled\x18\x02 \x01(\x08\"+\n\x1a\x43MsgClientInstallClientApp\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\"4\n\"CMsgClientInstallClientAppResponse\x12\x0e\n\x06result\x18\x01 \x01(\r\"-\n\x1c\x43MsgClientUninstallClientApp\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\"6\n$CMsgClientUninstallClientAppResponse\x12\x0e\n\x06result\x18\x01 \x01(\r\"B\n!CMsgClientSetClientAppUpdateState\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x0e\n\x06update\x18\x02 \x01(\x08\";\n)CMsgClientSetClientAppUpdateStateResponse\x12\x0e\n\x06result\x18\x01 \x01(\r\"\xaa\x01\n\x19\x43MsgClientLaunchClientApp\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x10\n\x08language\x18\x02 \x01(\r\x12\x1a\n\x12launch_option_type\x18\x03 \x01(\r\x12\x15\n\rlaunch_option\x18\x04 \x01(\r\x12\x15\n\rlaunch_source\x18\x05 \x01(\r\x12\x0c\n\x04\x61rgs\x18\x06 \x01(\t\x12\x14\n\x0cquery_params\x18\x07 \x01(\t\"3\n!CMsgClientLaunchClientAppResponse\x12\x0e\n\x06result\x18\x01 \x01(\r\"4\n\"CMsgClientEnableOrDisableDownloads\x12\x0e\n\x06\x65nable\x18\x01 \x01(\x08\"<\n*CMsgClientEnableOrDisableDownloadsResponse\x12\x0e\n\x06result\x18\x01 \x01(\rB\x05H\x01\x90\x01\x00')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'steammessages_clientserver_uds_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'H\001\220\001\000'
  _CMSGCLIENTUDSP2PSESSIONSTARTED._serialized_start=66
  _CMSGCLIENTUDSP2PSESSIONSTARTED._serialized_end=137
  _CMSGCLIENTUDSP2PSESSIONENDED._serialized_start=140
  _CMSGCLIENTUDSP2PSESSIONENDED._serialized_end=397
  _CMSGCLIENTGETCLIENTDETAILS._serialized_start=399
  _CMSGCLIENTGETCLIENTDETAILS._serialized_end=427
  _CMSGCLIENTGETCLIENTDETAILSRESPONSE._serialized_start=430
  _CMSGCLIENTGETCLIENTDETAILSRESPONSE._serialized_end=798
  _CMSGCLIENTGETCLIENTDETAILSRESPONSE_GAME._serialized_start=731
  _CMSGCLIENTGETCLIENTDETAILSRESPONSE_GAME._serialized_end=798
  _CMSGCLIENTGETCLIENTAPPLIST._serialized_start=801
  _CMSGCLIENTGETCLIENTAPPLIST._serialized_end=989
  _CMSGCLIENTGETCLIENTAPPLISTRESPONSE._serialized_start=992
  _CMSGCLIENTGETCLIENTAPPLISTRESPONSE._serialized_end=1836
  _CMSGCLIENTGETCLIENTAPPLISTRESPONSE_APP._serialized_start=1169
  _CMSGCLIENTGETCLIENTAPPLISTRESPONSE_APP._serialized_end=1836
  _CMSGCLIENTGETCLIENTAPPLISTRESPONSE_APP_DLC._serialized_start=1797
  _CMSGCLIENTGETCLIENTAPPLISTRESPONSE_APP_DLC._serialized_end=1836
  _CMSGCLIENTINSTALLCLIENTAPP._serialized_start=1838
  _CMSGCLIENTINSTALLCLIENTAPP._serialized_end=1881
  _CMSGCLIENTINSTALLCLIENTAPPRESPONSE._serialized_start=1883
  _CMSGCLIENTINSTALLCLIENTAPPRESPONSE._serialized_end=1935
  _CMSGCLIENTUNINSTALLCLIENTAPP._serialized_start=1937
  _CMSGCLIENTUNINSTALLCLIENTAPP._serialized_end=1982
  _CMSGCLIENTUNINSTALLCLIENTAPPRESPONSE._serialized_start=1984
  _CMSGCLIENTUNINSTALLCLIENTAPPRESPONSE._serialized_end=2038
  _CMSGCLIENTSETCLIENTAPPUPDATESTATE._serialized_start=2040
  _CMSGCLIENTSETCLIENTAPPUPDATESTATE._serialized_end=2106
  _CMSGCLIENTSETCLIENTAPPUPDATESTATERESPONSE._serialized_start=2108
  _CMSGCLIENTSETCLIENTAPPUPDATESTATERESPONSE._serialized_end=2167
  _CMSGCLIENTLAUNCHCLIENTAPP._serialized_start=2170
  _CMSGCLIENTLAUNCHCLIENTAPP._serialized_end=2340
  _CMSGCLIENTLAUNCHCLIENTAPPRESPONSE._serialized_start=2342
  _CMSGCLIENTLAUNCHCLIENTAPPRESPONSE._serialized_end=2393
  _CMSGCLIENTENABLEORDISABLEDOWNLOADS._serialized_start=2395
  _CMSGCLIENTENABLEORDISABLEDOWNLOADS._serialized_end=2447
  _CMSGCLIENTENABLEORDISABLEDOWNLOADSRESPONSE._serialized_start=2449
  _CMSGCLIENTENABLEORDISABLEDOWNLOADSRESPONSE._serialized_end=2509
# @@protoc_insertion_point(module_scope)
