# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: steammessages_remoteclient.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import steam.protobufs.steammessages_base_pb2 as steammessages__base__pb2
import steam.protobufs.steammessages_remoteclient_discovery_pb2 as steammessages__remoteclient__discovery__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n steammessages_remoteclient.proto\x1a\x18steammessages_base.proto\x1a*steammessages_remoteclient_discovery.proto\"r\n\x16\x43MsgRemoteClientStatus\x12\x11\n\tclient_id\x18\x01 \x01(\x04\x12\x13\n\x0binstance_id\x18\x02 \x01(\x04\x12\x30\n\x06status\x18\x03 \x01(\x0b\x32 .CMsgRemoteClientBroadcastStatus\"\xe4\x04\n\x19\x43MsgRemoteClientAppStatus\x12<\n\x0estatus_updates\x18\x01 \x03(\x0b\x32$.CMsgRemoteClientAppStatus.AppStatus\x1a\xe8\x01\n\rAppUpdateInfo\x12\x19\n\x11time_update_start\x18\x01 \x01(\x07\x12\x19\n\x11\x62ytes_to_download\x18\x02 \x01(\x04\x12\x18\n\x10\x62ytes_downloaded\x18\x03 \x01(\x04\x12\x18\n\x10\x62ytes_to_process\x18\x04 \x01(\x04\x12\x17\n\x0f\x62ytes_processed\x18\x05 \x01(\x04\x12\'\n\x1b\x65stimated_seconds_remaining\x18\x06 \x01(\x05:\x02-1\x12\x15\n\rupdate_result\x18\x07 \x01(\x05\x12\x14\n\x0cupdate_state\x18\x08 \x01(\r\x1aO\n\x0cShortcutInfo\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04icon\x18\x02 \x01(\t\x12\x12\n\ncategories\x18\x03 \x03(\t\x12\x0f\n\x07\x65xepath\x18\x04 \x01(\t\x1a\xcc\x01\n\tAppStatus\x12\x0e\n\x06\x61pp_id\x18\x01 \x01(\r\x12\x11\n\tapp_state\x18\x02 \x01(\r\x12=\n\x0bupdate_info\x18\x03 \x01(\x0b\x32(.CMsgRemoteClientAppStatus.AppUpdateInfo\x12>\n\rshortcut_info\x18\x04 \x01(\x0b\x32\'.CMsgRemoteClientAppStatus.ShortcutInfo\x12\x1d\n\x0fvr_not_required\x18\x05 \x01(\x08:\x04true\"\xc9\x03\n\x1b\x43MsgRemoteClientStartStream\x12\x0e\n\x06\x61pp_id\x18\x01 \x01(\r\x12\x13\n\x0b\x65nvironment\x18\x02 \x01(\x05\x12\x15\n\rgamepad_count\x18\x03 \x01(\x05\x12\x19\n\rlaunch_option\x18\x04 \x01(\x05:\x02-1\x12!\n\x12lock_parental_lock\x18\x05 \x01(\x08:\x05\x66\x61lse\x12\x1c\n\x14unlock_parental_lock\x18\x06 \x01(\t\x12\x1c\n\x14maximum_resolution_x\x18\x07 \x01(\x05\x12\x1c\n\x14maximum_resolution_y\x18\x08 \x01(\x05\x12>\n\x08gamepads\x18\t \x03(\x0b\x32,.CMsgRemoteClientStartStream.ReservedGamepad\x12\x1e\n\x13\x61udio_channel_count\x18\n \x01(\x05:\x01\x32\x12.\n\x13supported_transport\x18\x0b \x03(\x0e\x32\x11.EStreamTransport\x1a\x46\n\x0fReservedGamepad\x12\x17\n\x0f\x63ontroller_type\x18\x01 \x01(\r\x12\x1a\n\x12\x63ontroller_subtype\x18\x02 \x01(\r\"\xdb\x02\n#CMsgRemoteClientStartStreamResponse\x12\x1a\n\x0f\x65_launch_result\x18\x01 \x01(\x05:\x01\x32\x12\x13\n\x0bstream_port\x18\x02 \x01(\r\x12\x16\n\x0elaunch_options\x18\x03 \x03(\x05\x12\x12\n\nauth_token\x18\x04 \x01(\x0c\x12;\n\ttransport\x18\x05 \x01(\x0e\x32\x11.EStreamTransport:\x15k_EStreamTransportUDP\x12\x14\n\x0crelay_server\x18\x06 \x01(\t\x12\x13\n\x0blaunch_task\x18\x07 \x01(\t\x12\x1a\n\x12launch_task_detail\x18\x08 \x01(\t\x12\x19\n\x11launch_tasks_done\x18\t \x01(\x05\x12\x1a\n\x12launch_tasks_total\x18\n \x01(\x05\x12\x1c\n\x14vr_connection_params\x18\x0b \x01(\t\"\x16\n\x14\x43MsgRemoteClientPing\"\x1e\n\x1c\x43MsgRemoteClientPingResponse\"S\n\x1a\x43MsgRemoteClientAcceptEULA\x12\x0e\n\x06\x61pp_id\x18\x01 \x03(\r\x12\x0f\n\x07\x65ula_id\x18\x02 \x03(\t\x12\x14\n\x0c\x65ula_version\x18\x03 \x03(\r\"O\n#CMsgRemoteClientGetControllerConfig\x12\x0e\n\x06\x61pp_id\x18\x01 \x01(\r\x12\x18\n\x10\x63ontroller_index\x18\x03 \x01(\r\"U\n+CMsgRemoteClientGetControllerConfigResponse\x12\x12\n\x07\x65result\x18\x01 \x01(\x05:\x01\x32\x12\x12\n\nconfig_vdf\x18\x02 \x01(\x0c\"3\n CMsgRemoteClientStreamingEnabled\x12\x0f\n\x07\x65nabled\x18\x01 \x02(\x08\"L\n\x1c\x43MsgRemoteClientWifiAPStatus\x12\x0c\n\x04ssid\x18\x01 \x01(\t\x12\x10\n\x08password\x18\x02 \x01(\t\x12\x0c\n\x04wpa2\x18\x03 \x01(\x08\x42\x05H\x01\x90\x01\x00')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'steammessages_remoteclient_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'H\001\220\001\000'
  _CMSGREMOTECLIENTSTATUS._serialized_start=106
  _CMSGREMOTECLIENTSTATUS._serialized_end=220
  _CMSGREMOTECLIENTAPPSTATUS._serialized_start=223
  _CMSGREMOTECLIENTAPPSTATUS._serialized_end=835
  _CMSGREMOTECLIENTAPPSTATUS_APPUPDATEINFO._serialized_start=315
  _CMSGREMOTECLIENTAPPSTATUS_APPUPDATEINFO._serialized_end=547
  _CMSGREMOTECLIENTAPPSTATUS_SHORTCUTINFO._serialized_start=549
  _CMSGREMOTECLIENTAPPSTATUS_SHORTCUTINFO._serialized_end=628
  _CMSGREMOTECLIENTAPPSTATUS_APPSTATUS._serialized_start=631
  _CMSGREMOTECLIENTAPPSTATUS_APPSTATUS._serialized_end=835
  _CMSGREMOTECLIENTSTARTSTREAM._serialized_start=838
  _CMSGREMOTECLIENTSTARTSTREAM._serialized_end=1295
  _CMSGREMOTECLIENTSTARTSTREAM_RESERVEDGAMEPAD._serialized_start=1225
  _CMSGREMOTECLIENTSTARTSTREAM_RESERVEDGAMEPAD._serialized_end=1295
  _CMSGREMOTECLIENTSTARTSTREAMRESPONSE._serialized_start=1298
  _CMSGREMOTECLIENTSTARTSTREAMRESPONSE._serialized_end=1645
  _CMSGREMOTECLIENTPING._serialized_start=1647
  _CMSGREMOTECLIENTPING._serialized_end=1669
  _CMSGREMOTECLIENTPINGRESPONSE._serialized_start=1671
  _CMSGREMOTECLIENTPINGRESPONSE._serialized_end=1701
  _CMSGREMOTECLIENTACCEPTEULA._serialized_start=1703
  _CMSGREMOTECLIENTACCEPTEULA._serialized_end=1786
  _CMSGREMOTECLIENTGETCONTROLLERCONFIG._serialized_start=1788
  _CMSGREMOTECLIENTGETCONTROLLERCONFIG._serialized_end=1867
  _CMSGREMOTECLIENTGETCONTROLLERCONFIGRESPONSE._serialized_start=1869
  _CMSGREMOTECLIENTGETCONTROLLERCONFIGRESPONSE._serialized_end=1954
  _CMSGREMOTECLIENTSTREAMINGENABLED._serialized_start=1956
  _CMSGREMOTECLIENTSTREAMINGENABLED._serialized_end=2007
  _CMSGREMOTECLIENTWIFIAPSTATUS._serialized_start=2009
  _CMSGREMOTECLIENTWIFIAPSTATUS._serialized_end=2085
# @@protoc_insertion_point(module_scope)
