# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: steammessages_webui_friends.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import steam.protobufs.steammessages_unified_base_pb2 as steammessages__unified__base__pb2
import steam.protobufs.steammessages_base_pb2 as steammessages__base__pb2
import steam.protobufs.steammessages_clientserver_friends_pb2 as steammessages__clientserver__friends__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!steammessages_webui_friends.proto\x1a steammessages_unified_base.proto\x1a\x18steammessages_base.proto\x1a(steammessages_clientserver_friends.proto\"\x82\x01\n1CHelpRequestLogs_UploadUserApplicationLog_Request\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x10\n\x08log_type\x18\x02 \x01(\t\x12\x16\n\x0eversion_string\x18\x03 \x01(\t\x12\x14\n\x0clog_contents\x18\x04 \x01(\t\"@\n2CHelpRequestLogs_UploadUserApplicationLog_Response\x12\n\n\x02id\x18\x01 \x01(\x04\"n\n\x1e\x43MsgClientAppMinutesPlayedData\x12L\n\x0eminutes_played\x18\x01 \x03(\x0b\x32\x34.CMsgClientAppMinutesPlayedData_AppMinutesPlayedData\"n\n3CMsgClientAppMinutesPlayedData_AppMinutesPlayedData\x12\x0e\n\x06\x61pp_id\x18\x01 \x01(\r\x12\x0f\n\x07\x66orever\x18\x02 \x01(\x05\x12\x16\n\x0elast_two_weeks\x18\x03 \x01(\x05\">\n\x1a\x43\x43ommunity_GetApps_Request\x12\x0e\n\x06\x61ppids\x18\x01 \x03(\x05\x12\x10\n\x08language\x18\x02 \x01(\r\"B\n\x1b\x43\x43ommunity_GetApps_Response\x12#\n\x04\x61pps\x18\x01 \x03(\x0b\x32\x15.CCDDBAppDetailCommon\"T\n1CCommunity_GetAppRichPresenceLocalization_Request\x12\r\n\x05\x61ppid\x18\x01 \x01(\x05\x12\x10\n\x08language\x18\x02 \x01(\t\"\x97\x01\n2CCommunity_GetAppRichPresenceLocalization_Response\x12\r\n\x05\x61ppid\x18\x01 \x01(\x05\x12R\n\x0btoken_lists\x18\x02 \x03(\x0b\x32=.CCommunity_GetAppRichPresenceLocalization_Response_TokenList\"W\n8CCommunity_GetAppRichPresenceLocalization_Response_Token\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\"\x9b\x01\n<CCommunity_GetAppRichPresenceLocalization_Response_TokenList\x12\x10\n\x08language\x18\x01 \x01(\t\x12I\n\x06tokens\x18\x02 \x03(\x0b\x32\x39.CCommunity_GetAppRichPresenceLocalization_Response_Token\"\x9d\x02\n#CCommunity_GetCommentThread_Request\x12\x0f\n\x07steamid\x18\x01 \x01(\x06\x12\x1b\n\x13\x63omment_thread_type\x18\x02 \x01(\r\x12\x12\n\ngidfeature\x18\x03 \x01(\x06\x12\x13\n\x0bgidfeature2\x18\x04 \x01(\x06\x12\x17\n\x0f\x63ommentthreadid\x18\x05 \x01(\x06\x12\r\n\x05start\x18\x06 \x01(\x05\x12\r\n\x05\x63ount\x18\x07 \x01(\x05\x12\x10\n\x08upvoters\x18\x08 \x01(\x05\x12\x17\n\x0finclude_deleted\x18\t \x01(\x08\x12\x12\n\ngidcomment\x18\n \x01(\x06\x12\x13\n\x0btime_oldest\x18\x0b \x01(\r\x12\x14\n\x0coldest_first\x18\x0c \x01(\x08\"\xf6\x01\n\x12\x43\x43ommunity_Comment\x12\x12\n\ngidcomment\x18\x01 \x01(\x06\x12\x0f\n\x07steamid\x18\x02 \x01(\x06\x12\x11\n\ttimestamp\x18\x03 \x01(\r\x12\x0c\n\x04text\x18\x04 \x01(\t\x12\x0f\n\x07upvotes\x18\x05 \x01(\x05\x12\x0e\n\x06hidden\x18\x06 \x01(\x08\x12\x16\n\x0ehidden_by_user\x18\x07 \x01(\x08\x12\x0f\n\x07\x64\x65leted\x18\x08 \x01(\x08\x12!\n\tipaddress\x18\t \x01(\x0b\x32\x0e.CMsgIPAddress\x12\x14\n\x0ctotal_hidden\x18\n \x01(\x05\x12\x17\n\x0fupvoted_by_user\x18\x0b \x01(\x08\"\x88\x03\n$CCommunity_GetCommentThread_Response\x12%\n\x08\x63omments\x18\x01 \x03(\x0b\x32\x13.CCommunity_Comment\x12-\n\x10\x64\x65leted_comments\x18\x02 \x03(\x0b\x32\x13.CCommunity_Comment\x12\x0f\n\x07steamid\x18\x03 \x01(\x06\x12\x17\n\x0f\x63ommentthreadid\x18\x04 \x01(\x06\x12\r\n\x05start\x18\x05 \x01(\x05\x12\r\n\x05\x63ount\x18\x06 \x01(\x05\x12\x13\n\x0btotal_count\x18\x07 \x01(\x05\x12\x0f\n\x07upvotes\x18\x08 \x01(\x05\x12\x10\n\x08upvoters\x18\t \x03(\r\x12\x17\n\x0fuser_subscribed\x18\n \x01(\x08\x12\x14\n\x0cuser_upvoted\x18\x0b \x01(\x08\x12\x18\n\x10\x61nswer_commentid\x18\x0c \x01(\x06\x12\x14\n\x0c\x61nswer_actor\x18\r \x01(\r\x12\x19\n\x11\x61nswer_actor_rank\x18\x0e \x01(\x05\x12\x10\n\x08\x63\x61n_post\x18\x0f \x01(\x08\"\xc7\x01\n&CCommunity_PostCommentToThread_Request\x12\x0f\n\x07steamid\x18\x01 \x01(\x06\x12\x1b\n\x13\x63omment_thread_type\x18\x02 \x01(\r\x12\x12\n\ngidfeature\x18\x03 \x01(\x06\x12\x13\n\x0bgidfeature2\x18\x04 \x01(\x06\x12\x0c\n\x04text\x18\x06 \x01(\t\x12\x18\n\x10gidparentcomment\x18\x07 \x01(\x06\x12\x1e\n\x16suppress_notifications\x18\x08 \x01(\x08\"v\n\'CCommunity_PostCommentToThread_Response\x12\x12\n\ngidcomment\x18\x01 \x01(\x06\x12\x17\n\x0f\x63ommentthreadid\x18\x02 \x01(\x06\x12\r\n\x05\x63ount\x18\x03 \x01(\x05\x12\x0f\n\x07upvotes\x18\x04 \x01(\x05\"\xa9\x01\n*CCommunity_DeleteCommentFromThread_Request\x12\x0f\n\x07steamid\x18\x01 \x01(\x06\x12\x1b\n\x13\x63omment_thread_type\x18\x02 \x01(\r\x12\x12\n\ngidfeature\x18\x03 \x01(\x06\x12\x13\n\x0bgidfeature2\x18\x04 \x01(\x06\x12\x12\n\ngidcomment\x18\x05 \x01(\x06\x12\x10\n\x08undelete\x18\x06 \x01(\x08\"-\n+CCommunity_DeleteCommentFromThread_Response\"\xc0\x01\n$CCommunity_RateCommentThread_Request\x12\x19\n\x11\x63ommentthreadtype\x18\x01 \x01(\t\x12\x0f\n\x07steamid\x18\x02 \x01(\x04\x12\x12\n\ngidfeature\x18\x03 \x01(\x04\x12\x13\n\x0bgidfeature2\x18\x04 \x01(\x04\x12\x12\n\ngidcomment\x18\x05 \x01(\x04\x12\x0f\n\x07rate_up\x18\x06 \x01(\x08\x12\x1e\n\x16suppress_notifications\x18\x07 \x01(\x08\"\x89\x01\n%CCommunity_RateCommentThread_Response\x12\x12\n\ngidcomment\x18\x01 \x01(\x04\x12\x17\n\x0f\x63ommentthreadid\x18\x02 \x01(\x04\x12\r\n\x05\x63ount\x18\x03 \x01(\r\x12\x0f\n\x07upvotes\x18\x04 \x01(\r\x12\x13\n\x0bhas_upvoted\x18\x05 \x01(\x08\"\xaa\x01\n*CCommunity_GetCommentThreadRatings_Request\x12\x19\n\x11\x63ommentthreadtype\x18\x01 \x01(\t\x12\x0f\n\x07steamid\x18\x02 \x01(\x04\x12\x12\n\ngidfeature\x18\x03 \x01(\x04\x12\x13\n\x0bgidfeature2\x18\x04 \x01(\x04\x12\x12\n\ngidcomment\x18\x05 \x01(\x04\x12\x13\n\x0bmax_results\x18\x06 \x01(\r\"\x9c\x01\n+CCommunity_GetCommentThreadRatings_Response\x12\x17\n\x0f\x63ommentthreadid\x18\x01 \x01(\x04\x12\x12\n\ngidcomment\x18\x02 \x01(\x04\x12\x0f\n\x07upvotes\x18\x03 \x01(\r\x12\x13\n\x0bhas_upvoted\x18\x04 \x01(\x08\x12\x1a\n\x12upvoter_accountids\x18\x05 \x03(\r\"R\n\'CCommunity_RateClanAnnouncement_Request\x12\x16\n\x0e\x61nnouncementid\x18\x01 \x01(\x04\x12\x0f\n\x07vote_up\x18\x02 \x01(\x08\"*\n(CCommunity_RateClanAnnouncement_Response\"K\n1CCommunity_GetClanAnnouncementVoteForUser_Request\x12\x16\n\x0e\x61nnouncementid\x18\x01 \x01(\x04\"Z\n2CCommunity_GetClanAnnouncementVoteForUser_Response\x12\x10\n\x08voted_up\x18\x01 \x01(\x08\x12\x12\n\nvoted_down\x18\x02 \x01(\x08\"/\n\x0c\x43\x41ppPriority\x12\x10\n\x08priority\x18\x01 \x01(\r\x12\r\n\x05\x61ppid\x18\x02 \x03(\r\"\xd8\x02\n*CCommunity_GetUserPartnerEventNews_Request\x12\r\n\x05\x63ount\x18\x01 \x01(\r\x12\x0e\n\x06offset\x18\x02 \x01(\r\x12\x1a\n\x12rtime32_start_time\x18\x03 \x01(\r\x12\x18\n\x10rtime32_end_time\x18\x04 \x01(\r\x12\x1b\n\x13language_preference\x18\x05 \x03(\r\x12M\n\x11\x66ilter_event_type\x18\x06 \x03(\x05\x42\x32\x82\xb5\x18.enum; suggested type: ECommunityWordFilterType\x12\x17\n\x0f\x66ilter_to_appid\x18\x07 \x01(\x08\x12\x1f\n\x08\x61pp_list\x18\x08 \x03(\x0b\x32\r.CAppPriority\x12\x16\n\x0b\x63ount_after\x18\t \x01(\r:\x01\x30\x12\x17\n\x0c\x63ount_before\x18\n \x01(\r:\x01\x30\"W\n+CCommunity_GetUserPartnerEventNews_Response\x12(\n\x07results\x18\x01 \x03(\x0b\x32\x17.CClanMatchEventByRange\"k\n\'CCommunity_GetBestEventsForUser_Request\x12\x1a\n\x12include_steam_blog\x18\x01 \x01(\x08\x12$\n\x1c\x66ilter_to_played_within_days\x18\x02 \x01(\r\"\xc3\x01\n\x1d\x43\x43ommunity_PartnerEventResult\x12\x0e\n\x06\x63lanid\x18\x01 \x01(\r\x12\x11\n\tevent_gid\x18\x02 \x01(\x06\x12\x18\n\x10\x61nnouncement_gid\x18\x03 \x01(\x06\x12\r\n\x05\x61ppid\x18\x04 \x01(\r\x12\x19\n\x11possible_takeover\x18\x05 \x01(\x08\x12 \n\x15rtime32_last_modified\x18\x06 \x01(\r:\x01\x30\x12\x19\n\x11user_app_priority\x18\x07 \x01(\x05\"[\n(CCommunity_GetBestEventsForUser_Response\x12/\n\x07results\x18\x01 \x03(\x0b\x32\x1e.CCommunity_PartnerEventResult\"8\n6CCommunity_ClearUserPartnerEventsAppPriorities_Request\"9\n7CCommunity_ClearUserPartnerEventsAppPriorities_Response\"O\n#CCommunity_PartnerEventsAppPriority\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x19\n\x11user_app_priority\x18\x02 \x01(\x05\"6\n4CCommunity_GetUserPartnerEventsAppPriorities_Request\"q\n5CCommunity_GetUserPartnerEventsAppPriorities_Response\x12\x38\n\npriorities\x18\x01 \x03(\x0b\x32$.CCommunity_PartnerEventsAppPriority\"G\n6CCommunity_ClearSinglePartnerEventsAppPriority_Request\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\"9\n7CCommunity_ClearSinglePartnerEventsAppPriority_Response\"?\n.CCommunity_PartnerEventsShowMoreForApp_Request\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\"1\n/CCommunity_PartnerEventsShowMoreForApp_Response\"?\n.CCommunity_PartnerEventsShowLessForApp_Request\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\"1\n/CCommunity_PartnerEventsShowLessForApp_Response\"\x81\x01\n+CCommunity_MarkPartnerEventsForUser_Request\x12R\n\x08markings\x18\x01 \x03(\x0b\x32@.CCommunity_MarkPartnerEventsForUser_Request_PartnerEventMarking\"\xdd\x01\n?CCommunity_MarkPartnerEventsForUser_Request_PartnerEventMarking\x12\x0e\n\x06\x63lanid\x18\x01 \x01(\r\x12\x11\n\tevent_gid\x18\x02 \x01(\x06\x12P\n\x10\x64isplay_location\x18\x03 \x01(\x05\x42\x36\x82\xb5\x18\x32\x65num; suggested type: EPartnerEventDisplayLocation\x12\x12\n\nmark_shown\x18\x04 \x01(\x08\x12\x11\n\tmark_read\x18\x05 \x01(\x08\".\n,CCommunity_MarkPartnerEventsForUser_Response\"y\n*CProductImpressionsFromClient_Notification\x12K\n\x0bimpressions\x18\x01 \x03(\x0b\x32\x36.CProductImpressionsFromClient_Notification_Impression\"\xa9\x01\n5CProductImpressionsFromClient_Notification_Impression\x12H\n\x04type\x18\x01 \x01(\x05\x42:\x82\xb5\x18\x36\x65num; suggested type: EProductImpressionFromClientType\x12\r\n\x05\x61ppid\x18\x02 \x01(\r\x12\x17\n\x0fnum_impressions\x18\x03 \x01(\r\"P\n\x14\x43\x46riendsListCategory\x12\x0f\n\x07groupid\x18\x01 \x01(\r\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x19\n\x11\x61\x63\x63ountid_members\x18\x03 \x03(\r\"$\n\"CFriendsList_GetCategories_Request\"P\n#CFriendsList_GetCategories_Response\x12)\n\ncategories\x18\x01 \x03(\x0b\x32\x15.CFriendsListCategory\"U\n\x19\x43\x46riendsListFavoriteEntry\x12\x11\n\taccountid\x18\x01 \x01(\r\x12\x0e\n\x06\x63lanid\x18\x02 \x01(\r\x12\x15\n\rchat_group_id\x18\x03 \x01(\x04\"#\n!CFriendsList_GetFavorites_Request\"S\n\"CFriendsList_GetFavorites_Response\x12-\n\tfavorites\x18\x01 \x03(\x0b\x32\x1a.CFriendsListFavoriteEntry\"R\n!CFriendsList_SetFavorites_Request\x12-\n\tfavorites\x18\x01 \x03(\x0b\x32\x1a.CFriendsListFavoriteEntry\"$\n\"CFriendsList_SetFavorites_Response\"[\n*CFriendsList_FavoritesChanged_Notification\x12-\n\tfavorites\x18\x01 \x03(\x0b\x32\x1a.CFriendsListFavoriteEntry\"%\n#CFriendsList_GetFriendsList_Request\"S\n$CFriendsList_GetFriendsList_Response\x12+\n\x0b\x66riendslist\x18\x01 \x01(\x0b\x32\x16.CMsgClientFriendsList\"c\n(CMsgClientUCMEnumerateUserPublishedFiles\x12\x0e\n\x06\x61pp_id\x18\x01 \x01(\r\x12\x13\n\x0bstart_index\x18\x02 \x01(\r\x12\x12\n\nsort_order\x18\x03 \x01(\r\"\xb9\x01\n0CMsgClientUCMEnumerateUserPublishedFilesResponse\x12\x12\n\x07\x65result\x18\x01 \x01(\x05:\x01\x32\x12Z\n\x0fpublished_files\x18\x02 \x03(\x0b\x32\x41.CMsgClientUCMEnumerateUserPublishedFilesResponse_PublishedFileId\x12\x15\n\rtotal_results\x18\x03 \x01(\r\"]\n@CMsgClientUCMEnumerateUserPublishedFilesResponse_PublishedFileId\x12\x19\n\x11published_file_id\x18\x01 \x01(\x06\"\x98\x01\n)CMsgClientUCMEnumerateUserSubscribedFiles\x12\x0e\n\x06\x61pp_id\x18\x01 \x01(\r\x12\x13\n\x0bstart_index\x18\x02 \x01(\r\x12\x14\n\tlist_type\x18\x03 \x01(\r:\x01\x31\x12\x1d\n\x12matching_file_type\x18\x04 \x01(\r:\x01\x30\x12\x11\n\x05\x63ount\x18\x05 \x01(\r:\x02\x35\x30\"\xbc\x01\n1CMsgClientUCMEnumerateUserSubscribedFilesResponse\x12\x12\n\x07\x65result\x18\x01 \x01(\x05:\x01\x32\x12\\\n\x10subscribed_files\x18\x02 \x03(\x0b\x32\x42.CMsgClientUCMEnumerateUserSubscribedFilesResponse_PublishedFileId\x12\x15\n\rtotal_results\x18\x03 \x01(\r\"}\nACMsgClientUCMEnumerateUserSubscribedFilesResponse_PublishedFileId\x12\x19\n\x11published_file_id\x18\x01 \x01(\x06\x12\x1d\n\x12rtime32_subscribed\x18\x02 \x01(\x07:\x01\x30\"N\n!CMsgClientUCMPublishedFileDeleted\x12\x19\n\x11published_file_id\x18\x01 \x01(\x06\x12\x0e\n\x06\x61pp_id\x18\x02 \x01(\r\"\x97\x01\n!CMsgClientWorkshopItemInfoRequest\x12\x0e\n\x06\x61pp_id\x18\x01 \x01(\r\x12\x19\n\x11last_time_updated\x18\x02 \x01(\r\x12G\n\x0eworkshop_items\x18\x03 \x03(\x0b\x32/.CMsgClientWorkshopItemInfoRequest_WorkshopItem\"a\n.CMsgClientWorkshopItemInfoRequest_WorkshopItem\x12\x19\n\x11published_file_id\x18\x01 \x01(\x06\x12\x14\n\x0ctime_updated\x18\x02 \x01(\r\"\xb2\x01\n\"CMsgClientWorkshopItemInfoResponse\x12\x12\n\x07\x65result\x18\x01 \x01(\x05:\x01\x32\x12\x13\n\x0bupdate_time\x18\x02 \x01(\r\x12L\n\x0eworkshop_items\x18\x03 \x03(\x0b\x32\x34.CMsgClientWorkshopItemInfoResponse_WorkshopItemInfo\x12\x15\n\rprivate_items\x18\x04 \x03(\x06\"\x8e\x01\n3CMsgClientWorkshopItemInfoResponse_WorkshopItemInfo\x12\x19\n\x11published_file_id\x18\x01 \x01(\x06\x12\x14\n\x0ctime_updated\x18\x02 \x01(\r\x12\x13\n\x0bmanifest_id\x18\x03 \x01(\x06\x12\x11\n\tis_legacy\x18\x04 \x01(\x08\"\x94\x01\n%CMsgClientUCMGetPublishedFilesForUser\x12\x0e\n\x06\x61pp_id\x18\x01 \x01(\r\x12\x18\n\x10\x63reator_steam_id\x18\x02 \x01(\x06\x12\x15\n\rrequired_tags\x18\x03 \x03(\t\x12\x15\n\rexcluded_tags\x18\x04 \x03(\t\x12\x13\n\x0bstart_index\x18\x05 \x01(\r\"\xb3\x01\n-CMsgClientUCMGetPublishedFilesForUserResponse\x12\x12\n\x07\x65result\x18\x01 \x01(\x05:\x01\x32\x12W\n\x0fpublished_files\x18\x02 \x03(\x0b\x32>.CMsgClientUCMGetPublishedFilesForUserResponse_PublishedFileId\x12\x15\n\rtotal_results\x18\x03 \x01(\r\"Z\n=CMsgClientUCMGetPublishedFilesForUserResponse_PublishedFileId\x12\x19\n\x11published_file_id\x18\x01 \x01(\x06\"\xb7\x01\n\x1e\x43MsgCREEnumeratePublishedFiles\x12\x0e\n\x06\x61pp_id\x18\x01 \x01(\r\x12\x12\n\nquery_type\x18\x02 \x01(\x05\x12\x13\n\x0bstart_index\x18\x03 \x01(\r\x12\x0c\n\x04\x64\x61ys\x18\x04 \x01(\r\x12\r\n\x05\x63ount\x18\x05 \x01(\r\x12\x0c\n\x04tags\x18\x06 \x03(\t\x12\x11\n\tuser_tags\x18\x07 \x03(\t\x12\x1e\n\x12matching_file_type\x18\x08 \x01(\r:\x02\x31\x33\"\xa5\x01\n&CMsgCREEnumeratePublishedFilesResponse\x12\x12\n\x07\x65result\x18\x01 \x01(\x05:\x01\x32\x12P\n\x0fpublished_files\x18\x02 \x03(\x0b\x32\x37.CMsgCREEnumeratePublishedFilesResponse_PublishedFileId\x12\x15\n\rtotal_results\x18\x03 \x01(\r\"\x9d\x01\n6CMsgCREEnumeratePublishedFilesResponse_PublishedFileId\x12\x19\n\x11published_file_id\x18\x01 \x01(\x06\x12\x11\n\tvotes_for\x18\x02 \x01(\x05\x12\x15\n\rvotes_against\x18\x03 \x01(\x05\x12\x0f\n\x07reports\x18\x04 \x01(\x05\x12\r\n\x05score\x18\x05 \x01(\x02\"r\n\x18\x43MsgGameServerPingSample\x12\r\n\x05my_ip\x18\x01 \x01(\x07\x12\x11\n\tgs_app_id\x18\x02 \x01(\x05\x12\x34\n\ngs_samples\x18\x03 \x03(\x0b\x32 .CMsgGameServerPingSample_Sample\"^\n\x1f\x43MsgGameServerPingSample_Sample\x12\n\n\x02ip\x18\x01 \x01(\x07\x12\x13\n\x0b\x61vg_ping_ms\x18\x02 \x01(\r\x12\x1a\n\x12stddev_ping_ms_x10\x18\x03 \x01(\r\"D\n!CClan_RespondToClanInvite_Request\x12\x0f\n\x07steamid\x18\x01 \x01(\x06\x12\x0e\n\x06\x61\x63\x63\x65pt\x18\x02 \x01(\x08\"$\n\"CClan_RespondToClanInvite_Response\"A\n&CVoiceChat_RequestOneOnOneChat_Request\x12\x17\n\x0fsteamid_partner\x18\x01 \x01(\x06\"?\n\'CVoiceChat_RequestOneOnOneChat_Response\x12\x14\n\x0cvoice_chatid\x18\x01 \x01(\x06\"^\n-CVoiceChat_OneOnOneChatRequested_Notification\x12\x14\n\x0cvoice_chatid\x18\x01 \x01(\x06\x12\x17\n\x0fsteamid_partner\x18\x02 \x01(\x06\"p\n%CVoiceChat_AnswerOneOnOneChat_Request\x12\x14\n\x0cvoice_chatid\x18\x01 \x01(\x06\x12\x17\n\x0fsteamid_partner\x18\x02 \x01(\x06\x12\x18\n\x10\x61\x63\x63\x65pted_request\x18\x03 \x01(\x08\"(\n&CVoiceChat_AnswerOneOnOneChat_Response\"~\n3CVoiceChat_OneOnOneChatRequestResponse_Notification\x12\x14\n\x0cvoicechat_id\x18\x01 \x01(\x06\x12\x17\n\x0fsteamid_partner\x18\x02 \x01(\x06\x12\x18\n\x10\x61\x63\x63\x65pted_request\x18\x03 \x01(\x08\"=\n\"CVoiceChat_EndOneOnOneChat_Request\x12\x17\n\x0fsteamid_partner\x18\x01 \x01(\x06\"%\n#CVoiceChat_EndOneOnOneChat_Response\"U\n$CVoiceChat_LeaveOneOnOneChat_Request\x12\x17\n\x0fsteamid_partner\x18\x01 \x01(\x06\x12\x14\n\x0cvoice_chatid\x18\x02 \x01(\x06\"\'\n%CVoiceChat_LeaveOneOnOneChat_Response\"\xdd\x01\n+CVoiceChat_UserJoinedVoiceChat_Notification\x12\x14\n\x0cvoice_chatid\x18\x01 \x01(\x06\x12\x14\n\x0cuser_steamid\x18\x02 \x01(\x06\x12\x0e\n\x06\x63hatid\x18\x03 \x01(\x04\x12 \n\x18one_on_one_steamid_lower\x18\x04 \x01(\x06\x12!\n\x19one_on_one_steamid_higher\x18\x05 \x01(\x06\x12\x15\n\rchat_group_id\x18\x06 \x01(\x04\x12\x16\n\x0euser_sessionid\x18\x07 \x01(\r\"\xe0\x01\n\'CVoiceChat_UserVoiceStatus_Notification\x12\x14\n\x0cvoice_chatid\x18\x01 \x01(\x06\x12\x14\n\x0cuser_steamid\x18\x02 \x01(\x06\x12\x1e\n\x16user_muted_mic_locally\x18\x03 \x01(\x08\x12!\n\x19user_muted_output_locally\x18\x04 \x01(\x08\x12#\n\x1buser_has_no_mic_for_session\x18\x05 \x01(\x08\x12!\n\x19user_webaudio_sample_rate\x18\x06 \x01(\x05\"y\n(CVoiceChat_AllMembersStatus_Notification\x12\x14\n\x0cvoice_chatid\x18\x01 \x01(\x06\x12\x37\n\x05users\x18\x02 \x03(\x0b\x32(.CVoiceChat_UserVoiceStatus_Notification\"\x88\x02\n,CVoiceChat_UpdateVoiceChatWebRTCData_Request\x12\x14\n\x0cvoice_chatid\x18\x01 \x01(\x06\x12\x18\n\x10ip_webrtc_server\x18\x02 \x01(\r\x12\x1a\n\x12port_webrtc_server\x18\x03 \x01(\r\x12\x18\n\x10ip_webrtc_client\x18\x04 \x01(\r\x12\x1a\n\x12port_webrtc_client\x18\x05 \x01(\r\x12\x1e\n\x16ssrc_my_sending_stream\x18\x06 \x01(\r\x12\x12\n\nuser_agent\x18\x07 \x01(\t\x12\"\n\x1ahas_audio_worklets_support\x18\x08 \x01(\x08\"O\n-CVoiceChat_UpdateVoiceChatWebRTCData_Response\x12\x1e\n\x16send_client_voice_logs\x18\x01 \x01(\x08\"i\n,CVoiceChat_UploadClientVoiceChatLogs_Request\x12\x14\n\x0cvoice_chatid\x18\x01 \x01(\x06\x12#\n\x1b\x63lient_voice_logs_new_lines\x18\x02 \x01(\t\"/\n-CVoiceChat_UploadClientVoiceChatLogs_Response\"9\n!CVoiceChat_LeaveVoiceChat_Request\x12\x14\n\x0cvoice_chatid\x18\x01 \x01(\x06\"$\n\"CVoiceChat_LeaveVoiceChat_Response\"\xdb\x01\n)CVoiceChat_UserLeftVoiceChat_Notification\x12\x14\n\x0cvoice_chatid\x18\x01 \x01(\x06\x12\x14\n\x0cuser_steamid\x18\x02 \x01(\x06\x12\x0e\n\x06\x63hatid\x18\x03 \x01(\x04\x12 \n\x18one_on_one_steamid_lower\x18\x04 \x01(\x06\x12!\n\x19one_on_one_steamid_higher\x18\x05 \x01(\x06\x12\x15\n\rchat_group_id\x18\x06 \x01(\x04\x12\x16\n\x0euser_sessionid\x18\x07 \x01(\r\"\xaa\x01\n&CVoiceChat_VoiceChatEnded_Notification\x12\x14\n\x0cvoice_chatid\x18\x01 \x01(\x06\x12 \n\x18one_on_one_steamid_lower\x18\x02 \x01(\x06\x12!\n\x19one_on_one_steamid_higher\x18\x03 \x01(\x06\x12\x0e\n\x06\x63hatid\x18\x04 \x01(\x04\x12\x15\n\rchat_group_id\x18\x05 \x01(\x04\"=\n.CWebRTCClient_InitiateWebRTCConnection_Request\x12\x0b\n\x03sdp\x18\x01 \x01(\t\"M\n/CWebRTCClient_InitiateWebRTCConnection_Response\x12\x1a\n\x12remote_description\x18\x01 \x01(\t\"\x8b\x01\n+CWebRTC_WebRTCSessionConnected_Notification\x12\x0c\n\x04ssrc\x18\x01 \x01(\r\x12\x11\n\tclient_ip\x18\x02 \x01(\r\x12\x13\n\x0b\x63lient_port\x18\x03 \x01(\r\x12\x11\n\tserver_ip\x18\x04 \x01(\r\x12\x13\n\x0bserver_port\x18\x05 \x01(\r\"\xde\x01\n2CWebRTC_WebRTCUpdateRemoteDescription_Notification\x12\x1a\n\x12remote_description\x18\x01 \x01(\t\x12\"\n\x1aremote_description_version\x18\x02 \x01(\x04\x12h\n\x13ssrcs_to_accountids\x18\x03 \x03(\x0b\x32K.CWebRTC_WebRTCUpdateRemoteDescription_Notification_CSSRCToAccountIDMapping\"m\nJCWebRTC_WebRTCUpdateRemoteDescription_Notification_CSSRCToAccountIDMapping\x12\x0c\n\x04ssrc\x18\x01 \x01(\r\x12\x11\n\taccountid\x18\x02 \x01(\r\"\xdb\x01\n9CWebRTCClient_AcknowledgeUpdatedRemoteDescription_Request\x12\x18\n\x10ip_webrtc_server\x18\x01 \x01(\r\x12\x1a\n\x12port_webrtc_server\x18\x02 \x01(\r\x12 \n\x18ip_webrtc_session_client\x18\x03 \x01(\r\x12\"\n\x1aport_webrtc_session_client\x18\x04 \x01(\r\x12\"\n\x1aremote_description_version\x18\x05 \x01(\x04\"<\n:CWebRTCClient_AcknowledgeUpdatedRemoteDescription_Response\"\'\n%CMobilePerAccount_GetSettings_Request\"\xec\x01\n&CMobilePerAccount_GetSettings_Response\x12\x14\n\x0chas_settings\x18\x04 \x01(\x08\x12\x17\n\x0f\x61llow_sale_push\x18\x02 \x01(\x08\x12\x1b\n\x13\x61llow_wishlist_push\x18\x03 \x01(\x08\x12\x1f\n\x17\x63hat_notification_level\x18\x05 \x01(\r\x12\x1a\n\x12notify_direct_chat\x18\x06 \x01(\x08\x12\x19\n\x11notify_group_chat\x18\x07 \x01(\x08\x12\x1e\n\x10\x61llow_event_push\x18\x08 \x01(\x08:\x04true\"\xd5\x01\n%CMobilePerAccount_SetSettings_Request\x12\x17\n\x0f\x61llow_sale_push\x18\x02 \x01(\x08\x12\x1b\n\x13\x61llow_wishlist_push\x18\x03 \x01(\x08\x12\x1f\n\x17\x63hat_notification_level\x18\x04 \x01(\r\x12\x1a\n\x12notify_direct_chat\x18\x05 \x01(\x08\x12\x19\n\x11notify_group_chat\x18\x06 \x01(\x08\x12\x1e\n\x10\x61llow_event_push\x18\x07 \x01(\x08:\x04true\"(\n&CMobilePerAccount_SetSettings_Response\"\x84\x02\n*CMobileDevice_RegisterMobileDevice_Request\x12\x10\n\x08\x64\x65viceid\x18\x01 \x01(\t\x12\x10\n\x08language\x18\x02 \x01(\t\x12\x14\n\x0cpush_enabled\x18\x03 \x01(\x08\x12\x13\n\x0b\x61pp_version\x18\x04 \x01(\t\x12\x12\n\nos_version\x18\x05 \x01(\t\x12\x14\n\x0c\x64\x65vice_model\x18\x06 \x01(\t\x12#\n\x1btwofactor_device_identifier\x18\x07 \x01(\t\x12\x38\n\nmobile_app\x18\x08 \x01(\x05\x42$\x82\xb5\x18 enum; suggested type: EMobileApp\"F\n+CMobileDevice_RegisterMobileDevice_Response\x12\x17\n\x0funique_deviceid\x18\x02 \x01(\r\"E\n1CMobileDevice_DeregisterMobileDevice_Notification\x12\x10\n\x08\x64\x65viceid\x18\x01 \x01(\t\"\x0e\n\x0cUnknownProto2\x97\x01\n\x0fHelpRequestLogs\x12\x83\x01\n\x18UploadUserApplicationLog\x12\x32.CHelpRequestLogs_UploadUserApplicationLog_Request\x1a\x33.CHelpRequestLogs_UploadUserApplicationLog_Response2\x9e\x10\n\tCommunity\x12\x44\n\x07GetApps\x12\x1b.CCommunity_GetApps_Request\x1a\x1c.CCommunity_GetApps_Response\x12\x89\x01\n\x1eGetAppRichPresenceLocalization\x12\x32.CCommunity_GetAppRichPresenceLocalization_Request\x1a\x33.CCommunity_GetAppRichPresenceLocalization_Response\x12_\n\x10GetCommentThread\x12$.CCommunity_GetCommentThread_Request\x1a%.CCommunity_GetCommentThread_Response\x12h\n\x13PostCommentToThread\x12\'.CCommunity_PostCommentToThread_Request\x1a(.CCommunity_PostCommentToThread_Response\x12t\n\x17\x44\x65leteCommentFromThread\x12+.CCommunity_DeleteCommentFromThread_Request\x1a,.CCommunity_DeleteCommentFromThread_Response\x12\x62\n\x11RateCommentThread\x12%.CCommunity_RateCommentThread_Request\x1a&.CCommunity_RateCommentThread_Response\x12t\n\x17GetCommentThreadRatings\x12+.CCommunity_GetCommentThreadRatings_Request\x1a,.CCommunity_GetCommentThreadRatings_Response\x12k\n\x14RateClanAnnouncement\x12(.CCommunity_RateClanAnnouncement_Request\x1a).CCommunity_RateClanAnnouncement_Response\x12\x89\x01\n\x1eGetClanAnnouncementVoteForUser\x12\x32.CCommunity_GetClanAnnouncementVoteForUser_Request\x1a\x33.CCommunity_GetClanAnnouncementVoteForUser_Response\x12t\n\x17GetUserPartnerEventNews\x12+.CCommunity_GetUserPartnerEventNews_Request\x1a,.CCommunity_GetUserPartnerEventNews_Response\x12k\n\x14GetBestEventsForUser\x12(.CCommunity_GetBestEventsForUser_Request\x1a).CCommunity_GetBestEventsForUser_Response\x12w\n\x18MarkPartnerEventsForUser\x12,.CCommunity_MarkPartnerEventsForUser_Request\x1a-.CCommunity_MarkPartnerEventsForUser_Response\x12\x80\x01\n\x1bPartnerEventsShowMoreForApp\x12/.CCommunity_PartnerEventsShowMoreForApp_Request\x1a\x30.CCommunity_PartnerEventsShowMoreForApp_Response\x12\x80\x01\n\x1bPartnerEventsShowLessForApp\x12/.CCommunity_PartnerEventsShowLessForApp_Request\x1a\x30.CCommunity_PartnerEventsShowLessForApp_Response\x12\x98\x01\n#ClearUserPartnerEventsAppPriorities\x12\x37.CCommunity_ClearUserPartnerEventsAppPriorities_Request\x1a\x38.CCommunity_ClearUserPartnerEventsAppPriorities_Response\x12\x92\x01\n!GetUserPartnerEventsAppPriorities\x12\x35.CCommunity_GetUserPartnerEventsAppPriorities_Request\x1a\x36.CCommunity_GetUserPartnerEventsAppPriorities_Response\x12\x98\x01\n#ClearSinglePartnerEventsAppPriority\x12\x37.CCommunity_ClearSinglePartnerEventsAppPriority_Request\x1a\x38.CCommunity_ClearSinglePartnerEventsAppPriority_Response2U\n\x11\x45xperimentService\x12@\n\"ReportProductImpressionsFromClient\x12\r.UnknownProto\x1a\x0b.NoResponse2\xfa\x02\n\x0b\x46riendsList\x12Z\n\rGetCategories\x12#.CFriendsList_GetCategories_Request\x1a$.CFriendsList_GetCategories_Response\x12]\n\x0eGetFriendsList\x12$.CFriendsList_GetFriendsList_Request\x1a%.CFriendsList_GetFriendsList_Response\x12W\n\x0cGetFavorites\x12\".CFriendsList_GetFavorites_Request\x1a#.CFriendsList_GetFavorites_Response\x12W\n\x0cSetFavorites\x12\".CFriendsList_SetFavorites_Request\x1a#.CFriendsList_SetFavorites_Response2a\n\x11\x46riendsListClient\x12L\n\x10\x46\x61voritesChanged\x12+.CFriendsList_FavoritesChanged_Notification\x1a\x0b.NoResponse2f\n\x04\x43lan\x12^\n\x13RespondToClanInvite\x12\".CClan_RespondToClanInvite_Request\x1a#.CClan_RespondToClanInvite_Response2\xc1\x06\n\tVoiceChat\x12z\n\x19UpdateVoiceChatWebRTCData\x12-.CVoiceChat_UpdateVoiceChatWebRTCData_Request\x1a..CVoiceChat_UpdateVoiceChatWebRTCData_Response\x12N\n\x15NotifyUserVoiceStatus\x12(.CVoiceChat_UserVoiceStatus_Notification\x1a\x0b.NoResponse\x12z\n\x19UploadClientVoiceChatLogs\x12-.CVoiceChat_UploadClientVoiceChatLogs_Request\x1a..CVoiceChat_UploadClientVoiceChatLogs_Response\x12Y\n\x0eLeaveVoiceChat\x12\".CVoiceChat_LeaveVoiceChat_Request\x1a#.CVoiceChat_LeaveVoiceChat_Response\x12h\n\x13RequestOneOnOneChat\x12\'.CVoiceChat_RequestOneOnOneChat_Request\x1a(.CVoiceChat_RequestOneOnOneChat_Response\x12\x65\n\x12\x41nswerOneOnOneChat\x12&.CVoiceChat_AnswerOneOnOneChat_Request\x1a\'.CVoiceChat_AnswerOneOnOneChat_Response\x12\\\n\x0f\x45ndOneOnOneChat\x12#.CVoiceChat_EndOneOnOneChat_Request\x1a$.CVoiceChat_EndOneOnOneChat_Response\x12\x62\n\x11LeaveOneOnOneChat\x12%.CVoiceChat_LeaveOneOnOneChat_Request\x1a&.CVoiceChat_LeaveOneOnOneChat_Response2\xed\x04\n\x0fVoiceChatClient\x12V\n\x19NotifyUserJoinedVoiceChat\x12,.CVoiceChat_UserJoinedVoiceChat_Notification\x1a\x0b.NoResponse\x12R\n\x17NotifyUserLeftVoiceChat\x12*.CVoiceChat_UserLeftVoiceChat_Notification\x1a\x0b.NoResponse\x12L\n\x14NotifyVoiceChatEnded\x12\'.CVoiceChat_VoiceChatEnded_Notification\x1a\x0b.NoResponse\x12N\n\x15NotifyUserVoiceStatus\x12(.CVoiceChat_UserVoiceStatus_Notification\x1a\x0b.NoResponse\x12S\n\x19NotifyAllUsersVoiceStatus\x12).CVoiceChat_AllMembersStatus_Notification\x1a\x0b.NoResponse\x12Z\n\x1bNotifyOneOnOneChatRequested\x12..CVoiceChat_OneOnOneChatRequested_Notification\x1a\x0b.NoResponse\x12_\n\x1aNotifyOneOnOneChatResponse\x12\x34.CVoiceChat_OneOnOneChatRequestResponse_Notification\x1a\x0b.NoResponse2\xae\x02\n\x0cWebRTCClient\x12}\n\x18InitiateWebRTCConnection\x12/.CWebRTCClient_InitiateWebRTCConnection_Request\x1a\x30.CWebRTCClient_InitiateWebRTCConnection_Response\x12\x9e\x01\n#AcknowledgeUpdatedRemoteDescription\x12:.CWebRTCClient_AcknowledgeUpdatedRemoteDescription_Request\x1a;.CWebRTCClient_AcknowledgeUpdatedRemoteDescription_Response2\xdf\x01\n\x19WebRTCClientNotifications\x12Y\n\x1cNotifyWebRTCSessionConnected\x12,.CWebRTC_WebRTCSessionConnected_Notification\x1a\x0b.NoResponse\x12g\n#NotifyWebRTCUpdateRemoteDescription\x12\x33.CWebRTC_WebRTCUpdateRemoteDescription_Notification\x1a\x0b.NoResponse2\xd2\x01\n\x10MobilePerAccount\x12^\n\x0bGetSettings\x12&.CMobilePerAccount_GetSettings_Request\x1a\'.CMobilePerAccount_GetSettings_Response\x12^\n\x0bSetSettings\x12&.CMobilePerAccount_SetSettings_Request\x1a\'.CMobilePerAccount_SetSettings_Response2\xdc\x01\n\x0cMobileDevice\x12q\n\x14RegisterMobileDevice\x12+.CMobileDevice_RegisterMobileDevice_Request\x1a,.CMobileDevice_RegisterMobileDevice_Response\x12Y\n\x16\x44\x65registerMobileDevice\x12\x32.CMobileDevice_DeregisterMobileDevice_Notification\x1a\x0b.NoResponseB\x03\x90\x01\x01')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'steammessages_webui_friends_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\220\001\001'
  _CCOMMUNITY_GETUSERPARTNEREVENTNEWS_REQUEST.fields_by_name['filter_event_type']._options = None
  _CCOMMUNITY_GETUSERPARTNEREVENTNEWS_REQUEST.fields_by_name['filter_event_type']._serialized_options = b'\202\265\030.enum; suggested type: ECommunityWordFilterType'
  _CCOMMUNITY_MARKPARTNEREVENTSFORUSER_REQUEST_PARTNEREVENTMARKING.fields_by_name['display_location']._options = None
  _CCOMMUNITY_MARKPARTNEREVENTSFORUSER_REQUEST_PARTNEREVENTMARKING.fields_by_name['display_location']._serialized_options = b'\202\265\0302enum; suggested type: EPartnerEventDisplayLocation'
  _CPRODUCTIMPRESSIONSFROMCLIENT_NOTIFICATION_IMPRESSION.fields_by_name['type']._options = None
  _CPRODUCTIMPRESSIONSFROMCLIENT_NOTIFICATION_IMPRESSION.fields_by_name['type']._serialized_options = b'\202\265\0306enum; suggested type: EProductImpressionFromClientType'
  _CMOBILEDEVICE_REGISTERMOBILEDEVICE_REQUEST.fields_by_name['mobile_app']._options = None
  _CMOBILEDEVICE_REGISTERMOBILEDEVICE_REQUEST.fields_by_name['mobile_app']._serialized_options = b'\202\265\030 enum; suggested type: EMobileApp'
  _CHELPREQUESTLOGS_UPLOADUSERAPPLICATIONLOG_REQUEST._serialized_start=140
  _CHELPREQUESTLOGS_UPLOADUSERAPPLICATIONLOG_REQUEST._serialized_end=270
  _CHELPREQUESTLOGS_UPLOADUSERAPPLICATIONLOG_RESPONSE._serialized_start=272
  _CHELPREQUESTLOGS_UPLOADUSERAPPLICATIONLOG_RESPONSE._serialized_end=336
  _CMSGCLIENTAPPMINUTESPLAYEDDATA._serialized_start=338
  _CMSGCLIENTAPPMINUTESPLAYEDDATA._serialized_end=448
  _CMSGCLIENTAPPMINUTESPLAYEDDATA_APPMINUTESPLAYEDDATA._serialized_start=450
  _CMSGCLIENTAPPMINUTESPLAYEDDATA_APPMINUTESPLAYEDDATA._serialized_end=560
  _CCOMMUNITY_GETAPPS_REQUEST._serialized_start=562
  _CCOMMUNITY_GETAPPS_REQUEST._serialized_end=624
  _CCOMMUNITY_GETAPPS_RESPONSE._serialized_start=626
  _CCOMMUNITY_GETAPPS_RESPONSE._serialized_end=692
  _CCOMMUNITY_GETAPPRICHPRESENCELOCALIZATION_REQUEST._serialized_start=694
  _CCOMMUNITY_GETAPPRICHPRESENCELOCALIZATION_REQUEST._serialized_end=778
  _CCOMMUNITY_GETAPPRICHPRESENCELOCALIZATION_RESPONSE._serialized_start=781
  _CCOMMUNITY_GETAPPRICHPRESENCELOCALIZATION_RESPONSE._serialized_end=932
  _CCOMMUNITY_GETAPPRICHPRESENCELOCALIZATION_RESPONSE_TOKEN._serialized_start=934
  _CCOMMUNITY_GETAPPRICHPRESENCELOCALIZATION_RESPONSE_TOKEN._serialized_end=1021
  _CCOMMUNITY_GETAPPRICHPRESENCELOCALIZATION_RESPONSE_TOKENLIST._serialized_start=1024
  _CCOMMUNITY_GETAPPRICHPRESENCELOCALIZATION_RESPONSE_TOKENLIST._serialized_end=1179
  _CCOMMUNITY_GETCOMMENTTHREAD_REQUEST._serialized_start=1182
  _CCOMMUNITY_GETCOMMENTTHREAD_REQUEST._serialized_end=1467
  _CCOMMUNITY_COMMENT._serialized_start=1470
  _CCOMMUNITY_COMMENT._serialized_end=1716
  _CCOMMUNITY_GETCOMMENTTHREAD_RESPONSE._serialized_start=1719
  _CCOMMUNITY_GETCOMMENTTHREAD_RESPONSE._serialized_end=2111
  _CCOMMUNITY_POSTCOMMENTTOTHREAD_REQUEST._serialized_start=2114
  _CCOMMUNITY_POSTCOMMENTTOTHREAD_REQUEST._serialized_end=2313
  _CCOMMUNITY_POSTCOMMENTTOTHREAD_RESPONSE._serialized_start=2315
  _CCOMMUNITY_POSTCOMMENTTOTHREAD_RESPONSE._serialized_end=2433
  _CCOMMUNITY_DELETECOMMENTFROMTHREAD_REQUEST._serialized_start=2436
  _CCOMMUNITY_DELETECOMMENTFROMTHREAD_REQUEST._serialized_end=2605
  _CCOMMUNITY_DELETECOMMENTFROMTHREAD_RESPONSE._serialized_start=2607
  _CCOMMUNITY_DELETECOMMENTFROMTHREAD_RESPONSE._serialized_end=2652
  _CCOMMUNITY_RATECOMMENTTHREAD_REQUEST._serialized_start=2655
  _CCOMMUNITY_RATECOMMENTTHREAD_REQUEST._serialized_end=2847
  _CCOMMUNITY_RATECOMMENTTHREAD_RESPONSE._serialized_start=2850
  _CCOMMUNITY_RATECOMMENTTHREAD_RESPONSE._serialized_end=2987
  _CCOMMUNITY_GETCOMMENTTHREADRATINGS_REQUEST._serialized_start=2990
  _CCOMMUNITY_GETCOMMENTTHREADRATINGS_REQUEST._serialized_end=3160
  _CCOMMUNITY_GETCOMMENTTHREADRATINGS_RESPONSE._serialized_start=3163
  _CCOMMUNITY_GETCOMMENTTHREADRATINGS_RESPONSE._serialized_end=3319
  _CCOMMUNITY_RATECLANANNOUNCEMENT_REQUEST._serialized_start=3321
  _CCOMMUNITY_RATECLANANNOUNCEMENT_REQUEST._serialized_end=3403
  _CCOMMUNITY_RATECLANANNOUNCEMENT_RESPONSE._serialized_start=3405
  _CCOMMUNITY_RATECLANANNOUNCEMENT_RESPONSE._serialized_end=3447
  _CCOMMUNITY_GETCLANANNOUNCEMENTVOTEFORUSER_REQUEST._serialized_start=3449
  _CCOMMUNITY_GETCLANANNOUNCEMENTVOTEFORUSER_REQUEST._serialized_end=3524
  _CCOMMUNITY_GETCLANANNOUNCEMENTVOTEFORUSER_RESPONSE._serialized_start=3526
  _CCOMMUNITY_GETCLANANNOUNCEMENTVOTEFORUSER_RESPONSE._serialized_end=3616
  _CAPPPRIORITY._serialized_start=3618
  _CAPPPRIORITY._serialized_end=3665
  _CCOMMUNITY_GETUSERPARTNEREVENTNEWS_REQUEST._serialized_start=3668
  _CCOMMUNITY_GETUSERPARTNEREVENTNEWS_REQUEST._serialized_end=4012
  _CCOMMUNITY_GETUSERPARTNEREVENTNEWS_RESPONSE._serialized_start=4014
  _CCOMMUNITY_GETUSERPARTNEREVENTNEWS_RESPONSE._serialized_end=4101
  _CCOMMUNITY_GETBESTEVENTSFORUSER_REQUEST._serialized_start=4103
  _CCOMMUNITY_GETBESTEVENTSFORUSER_REQUEST._serialized_end=4210
  _CCOMMUNITY_PARTNEREVENTRESULT._serialized_start=4213
  _CCOMMUNITY_PARTNEREVENTRESULT._serialized_end=4408
  _CCOMMUNITY_GETBESTEVENTSFORUSER_RESPONSE._serialized_start=4410
  _CCOMMUNITY_GETBESTEVENTSFORUSER_RESPONSE._serialized_end=4501
  _CCOMMUNITY_CLEARUSERPARTNEREVENTSAPPPRIORITIES_REQUEST._serialized_start=4503
  _CCOMMUNITY_CLEARUSERPARTNEREVENTSAPPPRIORITIES_REQUEST._serialized_end=4559
  _CCOMMUNITY_CLEARUSERPARTNEREVENTSAPPPRIORITIES_RESPONSE._serialized_start=4561
  _CCOMMUNITY_CLEARUSERPARTNEREVENTSAPPPRIORITIES_RESPONSE._serialized_end=4618
  _CCOMMUNITY_PARTNEREVENTSAPPPRIORITY._serialized_start=4620
  _CCOMMUNITY_PARTNEREVENTSAPPPRIORITY._serialized_end=4699
  _CCOMMUNITY_GETUSERPARTNEREVENTSAPPPRIORITIES_REQUEST._serialized_start=4701
  _CCOMMUNITY_GETUSERPARTNEREVENTSAPPPRIORITIES_REQUEST._serialized_end=4755
  _CCOMMUNITY_GETUSERPARTNEREVENTSAPPPRIORITIES_RESPONSE._serialized_start=4757
  _CCOMMUNITY_GETUSERPARTNEREVENTSAPPPRIORITIES_RESPONSE._serialized_end=4870
  _CCOMMUNITY_CLEARSINGLEPARTNEREVENTSAPPPRIORITY_REQUEST._serialized_start=4872
  _CCOMMUNITY_CLEARSINGLEPARTNEREVENTSAPPPRIORITY_REQUEST._serialized_end=4943
  _CCOMMUNITY_CLEARSINGLEPARTNEREVENTSAPPPRIORITY_RESPONSE._serialized_start=4945
  _CCOMMUNITY_CLEARSINGLEPARTNEREVENTSAPPPRIORITY_RESPONSE._serialized_end=5002
  _CCOMMUNITY_PARTNEREVENTSSHOWMOREFORAPP_REQUEST._serialized_start=5004
  _CCOMMUNITY_PARTNEREVENTSSHOWMOREFORAPP_REQUEST._serialized_end=5067
  _CCOMMUNITY_PARTNEREVENTSSHOWMOREFORAPP_RESPONSE._serialized_start=5069
  _CCOMMUNITY_PARTNEREVENTSSHOWMOREFORAPP_RESPONSE._serialized_end=5118
  _CCOMMUNITY_PARTNEREVENTSSHOWLESSFORAPP_REQUEST._serialized_start=5120
  _CCOMMUNITY_PARTNEREVENTSSHOWLESSFORAPP_REQUEST._serialized_end=5183
  _CCOMMUNITY_PARTNEREVENTSSHOWLESSFORAPP_RESPONSE._serialized_start=5185
  _CCOMMUNITY_PARTNEREVENTSSHOWLESSFORAPP_RESPONSE._serialized_end=5234
  _CCOMMUNITY_MARKPARTNEREVENTSFORUSER_REQUEST._serialized_start=5237
  _CCOMMUNITY_MARKPARTNEREVENTSFORUSER_REQUEST._serialized_end=5366
  _CCOMMUNITY_MARKPARTNEREVENTSFORUSER_REQUEST_PARTNEREVENTMARKING._serialized_start=5369
  _CCOMMUNITY_MARKPARTNEREVENTSFORUSER_REQUEST_PARTNEREVENTMARKING._serialized_end=5590
  _CCOMMUNITY_MARKPARTNEREVENTSFORUSER_RESPONSE._serialized_start=5592
  _CCOMMUNITY_MARKPARTNEREVENTSFORUSER_RESPONSE._serialized_end=5638
  _CPRODUCTIMPRESSIONSFROMCLIENT_NOTIFICATION._serialized_start=5640
  _CPRODUCTIMPRESSIONSFROMCLIENT_NOTIFICATION._serialized_end=5761
  _CPRODUCTIMPRESSIONSFROMCLIENT_NOTIFICATION_IMPRESSION._serialized_start=5764
  _CPRODUCTIMPRESSIONSFROMCLIENT_NOTIFICATION_IMPRESSION._serialized_end=5933
  _CFRIENDSLISTCATEGORY._serialized_start=5935
  _CFRIENDSLISTCATEGORY._serialized_end=6015
  _CFRIENDSLIST_GETCATEGORIES_REQUEST._serialized_start=6017
  _CFRIENDSLIST_GETCATEGORIES_REQUEST._serialized_end=6053
  _CFRIENDSLIST_GETCATEGORIES_RESPONSE._serialized_start=6055
  _CFRIENDSLIST_GETCATEGORIES_RESPONSE._serialized_end=6135
  _CFRIENDSLISTFAVORITEENTRY._serialized_start=6137
  _CFRIENDSLISTFAVORITEENTRY._serialized_end=6222
  _CFRIENDSLIST_GETFAVORITES_REQUEST._serialized_start=6224
  _CFRIENDSLIST_GETFAVORITES_REQUEST._serialized_end=6259
  _CFRIENDSLIST_GETFAVORITES_RESPONSE._serialized_start=6261
  _CFRIENDSLIST_GETFAVORITES_RESPONSE._serialized_end=6344
  _CFRIENDSLIST_SETFAVORITES_REQUEST._serialized_start=6346
  _CFRIENDSLIST_SETFAVORITES_REQUEST._serialized_end=6428
  _CFRIENDSLIST_SETFAVORITES_RESPONSE._serialized_start=6430
  _CFRIENDSLIST_SETFAVORITES_RESPONSE._serialized_end=6466
  _CFRIENDSLIST_FAVORITESCHANGED_NOTIFICATION._serialized_start=6468
  _CFRIENDSLIST_FAVORITESCHANGED_NOTIFICATION._serialized_end=6559
  _CFRIENDSLIST_GETFRIENDSLIST_REQUEST._serialized_start=6561
  _CFRIENDSLIST_GETFRIENDSLIST_REQUEST._serialized_end=6598
  _CFRIENDSLIST_GETFRIENDSLIST_RESPONSE._serialized_start=6600
  _CFRIENDSLIST_GETFRIENDSLIST_RESPONSE._serialized_end=6683
  _CMSGCLIENTUCMENUMERATEUSERPUBLISHEDFILES._serialized_start=6685
  _CMSGCLIENTUCMENUMERATEUSERPUBLISHEDFILES._serialized_end=6784
  _CMSGCLIENTUCMENUMERATEUSERPUBLISHEDFILESRESPONSE._serialized_start=6787
  _CMSGCLIENTUCMENUMERATEUSERPUBLISHEDFILESRESPONSE._serialized_end=6972
  _CMSGCLIENTUCMENUMERATEUSERPUBLISHEDFILESRESPONSE_PUBLISHEDFILEID._serialized_start=6974
  _CMSGCLIENTUCMENUMERATEUSERPUBLISHEDFILESRESPONSE_PUBLISHEDFILEID._serialized_end=7067
  _CMSGCLIENTUCMENUMERATEUSERSUBSCRIBEDFILES._serialized_start=7070
  _CMSGCLIENTUCMENUMERATEUSERSUBSCRIBEDFILES._serialized_end=7222
  _CMSGCLIENTUCMENUMERATEUSERSUBSCRIBEDFILESRESPONSE._serialized_start=7225
  _CMSGCLIENTUCMENUMERATEUSERSUBSCRIBEDFILESRESPONSE._serialized_end=7413
  _CMSGCLIENTUCMENUMERATEUSERSUBSCRIBEDFILESRESPONSE_PUBLISHEDFILEID._serialized_start=7415
  _CMSGCLIENTUCMENUMERATEUSERSUBSCRIBEDFILESRESPONSE_PUBLISHEDFILEID._serialized_end=7540
  _CMSGCLIENTUCMPUBLISHEDFILEDELETED._serialized_start=7542
  _CMSGCLIENTUCMPUBLISHEDFILEDELETED._serialized_end=7620
  _CMSGCLIENTWORKSHOPITEMINFOREQUEST._serialized_start=7623
  _CMSGCLIENTWORKSHOPITEMINFOREQUEST._serialized_end=7774
  _CMSGCLIENTWORKSHOPITEMINFOREQUEST_WORKSHOPITEM._serialized_start=7776
  _CMSGCLIENTWORKSHOPITEMINFOREQUEST_WORKSHOPITEM._serialized_end=7873
  _CMSGCLIENTWORKSHOPITEMINFORESPONSE._serialized_start=7876
  _CMSGCLIENTWORKSHOPITEMINFORESPONSE._serialized_end=8054
  _CMSGCLIENTWORKSHOPITEMINFORESPONSE_WORKSHOPITEMINFO._serialized_start=8057
  _CMSGCLIENTWORKSHOPITEMINFORESPONSE_WORKSHOPITEMINFO._serialized_end=8199
  _CMSGCLIENTUCMGETPUBLISHEDFILESFORUSER._serialized_start=8202
  _CMSGCLIENTUCMGETPUBLISHEDFILESFORUSER._serialized_end=8350
  _CMSGCLIENTUCMGETPUBLISHEDFILESFORUSERRESPONSE._serialized_start=8353
  _CMSGCLIENTUCMGETPUBLISHEDFILESFORUSERRESPONSE._serialized_end=8532
  _CMSGCLIENTUCMGETPUBLISHEDFILESFORUSERRESPONSE_PUBLISHEDFILEID._serialized_start=8534
  _CMSGCLIENTUCMGETPUBLISHEDFILESFORUSERRESPONSE_PUBLISHEDFILEID._serialized_end=8624
  _CMSGCREENUMERATEPUBLISHEDFILES._serialized_start=8627
  _CMSGCREENUMERATEPUBLISHEDFILES._serialized_end=8810
  _CMSGCREENUMERATEPUBLISHEDFILESRESPONSE._serialized_start=8813
  _CMSGCREENUMERATEPUBLISHEDFILESRESPONSE._serialized_end=8978
  _CMSGCREENUMERATEPUBLISHEDFILESRESPONSE_PUBLISHEDFILEID._serialized_start=8981
  _CMSGCREENUMERATEPUBLISHEDFILESRESPONSE_PUBLISHEDFILEID._serialized_end=9138
  _CMSGGAMESERVERPINGSAMPLE._serialized_start=9140
  _CMSGGAMESERVERPINGSAMPLE._serialized_end=9254
  _CMSGGAMESERVERPINGSAMPLE_SAMPLE._serialized_start=9256
  _CMSGGAMESERVERPINGSAMPLE_SAMPLE._serialized_end=9350
  _CCLAN_RESPONDTOCLANINVITE_REQUEST._serialized_start=9352
  _CCLAN_RESPONDTOCLANINVITE_REQUEST._serialized_end=9420
  _CCLAN_RESPONDTOCLANINVITE_RESPONSE._serialized_start=9422
  _CCLAN_RESPONDTOCLANINVITE_RESPONSE._serialized_end=9458
  _CVOICECHAT_REQUESTONEONONECHAT_REQUEST._serialized_start=9460
  _CVOICECHAT_REQUESTONEONONECHAT_REQUEST._serialized_end=9525
  _CVOICECHAT_REQUESTONEONONECHAT_RESPONSE._serialized_start=9527
  _CVOICECHAT_REQUESTONEONONECHAT_RESPONSE._serialized_end=9590
  _CVOICECHAT_ONEONONECHATREQUESTED_NOTIFICATION._serialized_start=9592
  _CVOICECHAT_ONEONONECHATREQUESTED_NOTIFICATION._serialized_end=9686
  _CVOICECHAT_ANSWERONEONONECHAT_REQUEST._serialized_start=9688
  _CVOICECHAT_ANSWERONEONONECHAT_REQUEST._serialized_end=9800
  _CVOICECHAT_ANSWERONEONONECHAT_RESPONSE._serialized_start=9802
  _CVOICECHAT_ANSWERONEONONECHAT_RESPONSE._serialized_end=9842
  _CVOICECHAT_ONEONONECHATREQUESTRESPONSE_NOTIFICATION._serialized_start=9844
  _CVOICECHAT_ONEONONECHATREQUESTRESPONSE_NOTIFICATION._serialized_end=9970
  _CVOICECHAT_ENDONEONONECHAT_REQUEST._serialized_start=9972
  _CVOICECHAT_ENDONEONONECHAT_REQUEST._serialized_end=10033
  _CVOICECHAT_ENDONEONONECHAT_RESPONSE._serialized_start=10035
  _CVOICECHAT_ENDONEONONECHAT_RESPONSE._serialized_end=10072
  _CVOICECHAT_LEAVEONEONONECHAT_REQUEST._serialized_start=10074
  _CVOICECHAT_LEAVEONEONONECHAT_REQUEST._serialized_end=10159
  _CVOICECHAT_LEAVEONEONONECHAT_RESPONSE._serialized_start=10161
  _CVOICECHAT_LEAVEONEONONECHAT_RESPONSE._serialized_end=10200
  _CVOICECHAT_USERJOINEDVOICECHAT_NOTIFICATION._serialized_start=10203
  _CVOICECHAT_USERJOINEDVOICECHAT_NOTIFICATION._serialized_end=10424
  _CVOICECHAT_USERVOICESTATUS_NOTIFICATION._serialized_start=10427
  _CVOICECHAT_USERVOICESTATUS_NOTIFICATION._serialized_end=10651
  _CVOICECHAT_ALLMEMBERSSTATUS_NOTIFICATION._serialized_start=10653
  _CVOICECHAT_ALLMEMBERSSTATUS_NOTIFICATION._serialized_end=10774
  _CVOICECHAT_UPDATEVOICECHATWEBRTCDATA_REQUEST._serialized_start=10777
  _CVOICECHAT_UPDATEVOICECHATWEBRTCDATA_REQUEST._serialized_end=11041
  _CVOICECHAT_UPDATEVOICECHATWEBRTCDATA_RESPONSE._serialized_start=11043
  _CVOICECHAT_UPDATEVOICECHATWEBRTCDATA_RESPONSE._serialized_end=11122
  _CVOICECHAT_UPLOADCLIENTVOICECHATLOGS_REQUEST._serialized_start=11124
  _CVOICECHAT_UPLOADCLIENTVOICECHATLOGS_REQUEST._serialized_end=11229
  _CVOICECHAT_UPLOADCLIENTVOICECHATLOGS_RESPONSE._serialized_start=11231
  _CVOICECHAT_UPLOADCLIENTVOICECHATLOGS_RESPONSE._serialized_end=11278
  _CVOICECHAT_LEAVEVOICECHAT_REQUEST._serialized_start=11280
  _CVOICECHAT_LEAVEVOICECHAT_REQUEST._serialized_end=11337
  _CVOICECHAT_LEAVEVOICECHAT_RESPONSE._serialized_start=11339
  _CVOICECHAT_LEAVEVOICECHAT_RESPONSE._serialized_end=11375
  _CVOICECHAT_USERLEFTVOICECHAT_NOTIFICATION._serialized_start=11378
  _CVOICECHAT_USERLEFTVOICECHAT_NOTIFICATION._serialized_end=11597
  _CVOICECHAT_VOICECHATENDED_NOTIFICATION._serialized_start=11600
  _CVOICECHAT_VOICECHATENDED_NOTIFICATION._serialized_end=11770
  _CWEBRTCCLIENT_INITIATEWEBRTCCONNECTION_REQUEST._serialized_start=11772
  _CWEBRTCCLIENT_INITIATEWEBRTCCONNECTION_REQUEST._serialized_end=11833
  _CWEBRTCCLIENT_INITIATEWEBRTCCONNECTION_RESPONSE._serialized_start=11835
  _CWEBRTCCLIENT_INITIATEWEBRTCCONNECTION_RESPONSE._serialized_end=11912
  _CWEBRTC_WEBRTCSESSIONCONNECTED_NOTIFICATION._serialized_start=11915
  _CWEBRTC_WEBRTCSESSIONCONNECTED_NOTIFICATION._serialized_end=12054
  _CWEBRTC_WEBRTCUPDATEREMOTEDESCRIPTION_NOTIFICATION._serialized_start=12057
  _CWEBRTC_WEBRTCUPDATEREMOTEDESCRIPTION_NOTIFICATION._serialized_end=12279
  _CWEBRTC_WEBRTCUPDATEREMOTEDESCRIPTION_NOTIFICATION_CSSRCTOACCOUNTIDMAPPING._serialized_start=12281
  _CWEBRTC_WEBRTCUPDATEREMOTEDESCRIPTION_NOTIFICATION_CSSRCTOACCOUNTIDMAPPING._serialized_end=12390
  _CWEBRTCCLIENT_ACKNOWLEDGEUPDATEDREMOTEDESCRIPTION_REQUEST._serialized_start=12393
  _CWEBRTCCLIENT_ACKNOWLEDGEUPDATEDREMOTEDESCRIPTION_REQUEST._serialized_end=12612
  _CWEBRTCCLIENT_ACKNOWLEDGEUPDATEDREMOTEDESCRIPTION_RESPONSE._serialized_start=12614
  _CWEBRTCCLIENT_ACKNOWLEDGEUPDATEDREMOTEDESCRIPTION_RESPONSE._serialized_end=12674
  _CMOBILEPERACCOUNT_GETSETTINGS_REQUEST._serialized_start=12676
  _CMOBILEPERACCOUNT_GETSETTINGS_REQUEST._serialized_end=12715
  _CMOBILEPERACCOUNT_GETSETTINGS_RESPONSE._serialized_start=12718
  _CMOBILEPERACCOUNT_GETSETTINGS_RESPONSE._serialized_end=12954
  _CMOBILEPERACCOUNT_SETSETTINGS_REQUEST._serialized_start=12957
  _CMOBILEPERACCOUNT_SETSETTINGS_REQUEST._serialized_end=13170
  _CMOBILEPERACCOUNT_SETSETTINGS_RESPONSE._serialized_start=13172
  _CMOBILEPERACCOUNT_SETSETTINGS_RESPONSE._serialized_end=13212
  _CMOBILEDEVICE_REGISTERMOBILEDEVICE_REQUEST._serialized_start=13215
  _CMOBILEDEVICE_REGISTERMOBILEDEVICE_REQUEST._serialized_end=13475
  _CMOBILEDEVICE_REGISTERMOBILEDEVICE_RESPONSE._serialized_start=13477
  _CMOBILEDEVICE_REGISTERMOBILEDEVICE_RESPONSE._serialized_end=13547
  _CMOBILEDEVICE_DEREGISTERMOBILEDEVICE_NOTIFICATION._serialized_start=13549
  _CMOBILEDEVICE_DEREGISTERMOBILEDEVICE_NOTIFICATION._serialized_end=13618
  _UNKNOWNPROTO._serialized_start=13620
  _UNKNOWNPROTO._serialized_end=13634
  _HELPREQUESTLOGS._serialized_start=13637
  _HELPREQUESTLOGS._serialized_end=13788
  _COMMUNITY._serialized_start=13791
  _COMMUNITY._serialized_end=15869
  _EXPERIMENTSERVICE._serialized_start=15871
  _EXPERIMENTSERVICE._serialized_end=15956
  _FRIENDSLIST._serialized_start=15959
  _FRIENDSLIST._serialized_end=16337
  _FRIENDSLISTCLIENT._serialized_start=16339
  _FRIENDSLISTCLIENT._serialized_end=16436
  _CLAN._serialized_start=16438
  _CLAN._serialized_end=16540
  _VOICECHAT._serialized_start=16543
  _VOICECHAT._serialized_end=17376
  _VOICECHATCLIENT._serialized_start=17379
  _VOICECHATCLIENT._serialized_end=18000
  _WEBRTCCLIENT._serialized_start=18003
  _WEBRTCCLIENT._serialized_end=18305
  _WEBRTCCLIENTNOTIFICATIONS._serialized_start=18308
  _WEBRTCCLIENTNOTIFICATIONS._serialized_end=18531
  _MOBILEPERACCOUNT._serialized_start=18534
  _MOBILEPERACCOUNT._serialized_end=18744
  _MOBILEDEVICE._serialized_start=18747
  _MOBILEDEVICE._serialized_end=18967
_builder.BuildServices(DESCRIPTOR, 'steammessages_webui_friends_pb2', globals())
# @@protoc_insertion_point(module_scope)
