# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: steammessages_clientlanp2p.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import steam.protobufs.steammessages_base_pb2 as steammessages__base__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n steammessages_clientlanp2p.proto\x1a\x18steammessages_base.proto\"\x87\x01\n\x1d\x43MsgClientLANP2PRequestChunks\x12;\n\nchunk_keys\x18\x01 \x03(\x0b\x32\'.CMsgClientLANP2PRequestChunks.ChunkKey\x1a)\n\x08\x43hunkKey\x12\x10\n\x08\x64\x65pot_id\x18\x01 \x01(\r\x12\x0b\n\x03sha\x18\x02 \x01(\x0c\"\xe9\x01\n%CMsgClientLANP2PRequestChunksResponse\x12I\n\x0f\x63hunk_responses\x18\x01 \x03(\x0b\x32\x30.CMsgClientLANP2PRequestChunksResponse.ChunkData\x1au\n\tChunkData\x12\x0e\n\x06result\x18\x01 \x01(\r\x12\x10\n\x08\x64\x65pot_id\x18\x02 \x01(\r\x12\x0b\n\x03sha\x18\x03 \x01(\x0c\x12\x12\n\nchunk_data\x18\x04 \x01(\x0c\x12\x11\n\tencrypted\x18\x05 \x01(\x08\x12\x12\n\ncompressed\x18\x06 \x01(\x08\"a\n\x1a\x43MsgClientPeerChunkRequest\x12\x0e\n\x06\x61pp_id\x18\x01 \x01(\r\x12\x10\n\x08\x64\x65pot_id\x18\x02 \x01(\r\x12\x0b\n\x03sha\x18\x03 \x01(\x0c\x12\x14\n\x0c\x61\x63\x63\x65ss_token\x18\x04 \x01(\x04\"\x97\x01\n\x1b\x43MsgClientPeerChunkResponse\x12\x0e\n\x06result\x18\x01 \x01(\r\x12\x0e\n\x06\x61pp_id\x18\x02 \x01(\r\x12\x10\n\x08\x64\x65pot_id\x18\x03 \x01(\r\x12\x0b\n\x03sha\x18\x04 \x01(\x0c\x12\x11\n\tencrypted\x18\x05 \x01(\x08\x12\x12\n\ncompressed\x18\x06 \x01(\x08\x12\x12\n\nchunk_data\x18\x07 \x01(\x0c\x42\x05H\x01\x90\x01\x00')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'steammessages_clientlanp2p_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'H\001\220\001\000'
  _CMSGCLIENTLANP2PREQUESTCHUNKS._serialized_start=63
  _CMSGCLIENTLANP2PREQUESTCHUNKS._serialized_end=198
  _CMSGCLIENTLANP2PREQUESTCHUNKS_CHUNKKEY._serialized_start=157
  _CMSGCLIENTLANP2PREQUESTCHUNKS_CHUNKKEY._serialized_end=198
  _CMSGCLIENTLANP2PREQUESTCHUNKSRESPONSE._serialized_start=201
  _CMSGCLIENTLANP2PREQUESTCHUNKSRESPONSE._serialized_end=434
  _CMSGCLIENTLANP2PREQUESTCHUNKSRESPONSE_CHUNKDATA._serialized_start=317
  _CMSGCLIENTLANP2PREQUESTCHUNKSRESPONSE_CHUNKDATA._serialized_end=434
  _CMSGCLIENTPEERCHUNKREQUEST._serialized_start=436
  _CMSGCLIENTPEERCHUNKREQUEST._serialized_end=533
  _CMSGCLIENTPEERCHUNKRESPONSE._serialized_start=536
  _CMSGCLIENTPEERCHUNKRESPONSE._serialized_end=687
# @@protoc_insertion_point(module_scope)
