# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: webuimessages_steaminput.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import steam.protobufs.steammessages_base_pb2 as steammessages__base__pb2
import steam.protobufs.webuimessages_base_pb2 as webuimessages__base__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1ewebuimessages_steaminput.proto\x1a\x18steammessages_base.proto\x1a\x18webuimessages_base.proto\"\x85\x07\n<CSteamInputService_ControllerButtonStateChanged_Notification\x12\x18\n\x10\x63ontroller_index\x18\x01 \x01(\r\x12\x0f\n\x07\x64pad_up\x18\x02 \x01(\x08\x12\x11\n\tdpad_down\x18\x03 \x01(\x08\x12\x11\n\tdpad_left\x18\x04 \x01(\x08\x12\x12\n\ndpad_right\x18\x05 \x01(\x08\x12\x14\n\x0c\x62utton_south\x18\x06 \x01(\x08\x12\x13\n\x0b\x62utton_east\x18\x07 \x01(\x08\x12\x13\n\x0b\x62utton_west\x18\x08 \x01(\x08\x12\x14\n\x0c\x62utton_north\x18\t \x01(\x08\x12\x18\n\x10\x62utton_back_view\x18\n \x01(\x08\x12\x1c\n\x14\x62utton_start_options\x18\x0b \x01(\x08\x12\x14\n\x0c\x62utton_steam\x18\x0c \x01(\x08\x12\x1b\n\x13\x62utton_quick_access\x18\r \x01(\x08\x12\x1b\n\x13\x62utton_mute_capture\x18\x0e \x01(\x08\x12\x18\n\x10left_stick_click\x18\x0f \x01(\x08\x12\x18\n\x10left_stick_touch\x18\x10 \x01(\x08\x12\x1a\n\x12left_stick_deflect\x18\x11 \x01(\x08\x12\x19\n\x11right_stick_click\x18\x12 \x01(\x08\x12\x19\n\x11right_stick_touch\x18\x13 \x01(\x08\x12\x1b\n\x13right_stick_deflect\x18\x14 \x01(\x08\x12\x1d\n\x15\x63\x65nter_trackpad_touch\x18\x15 \x01(\x08\x12\x1d\n\x15\x63\x65nter_trackpad_click\x18\x16 \x01(\x08\x12\x1b\n\x13left_trackpad_touch\x18\x17 \x01(\x08\x12\x1b\n\x13left_trackpad_click\x18\x18 \x01(\x08\x12\x1c\n\x14right_trackpad_touch\x18\x19 \x01(\x08\x12\x1c\n\x14right_trackpad_click\x18\x1a \x01(\x08\x12\x13\n\x0bleft_bumper\x18\x1b \x01(\x08\x12\x14\n\x0cleft_trigger\x18\x1c \x01(\x08\x12\n\n\x02l4\x18\x1d \x01(\x08\x12\n\n\x02l5\x18\x1e \x01(\x08\x12\x10\n\x08left_aux\x18\x1f \x01(\x08\x12\x14\n\x0cright_bumper\x18  \x01(\x08\x12\x15\n\rright_trigger\x18! \x01(\x08\x12\n\n\x02r4\x18\" \x01(\x08\x12\n\n\x02r5\x18# \x01(\x08\x12\x11\n\tright_aux\x18$ \x01(\x08\")\n\x11\x43ontrollerVector2\x12\t\n\x01x\x18\x01 \x01(\x02\x12\t\n\x01y\x18\x02 \x01(\x02\"4\n\x11\x43ontrollerVector3\x12\t\n\x01x\x18\x01 \x01(\x02\x12\t\n\x01y\x18\x02 \x01(\x02\x12\t\n\x01z\x18\x03 \x01(\x02\"B\n\x14\x43ontrollerQuaternion\x12\t\n\x01w\x18\x01 \x01(\x02\x12\t\n\x01x\x18\x02 \x01(\x02\x12\t\n\x01y\x18\x03 \x01(\x02\x12\t\n\x01z\x18\x04 \x01(\x02\"E\n\x19\x43ontrollerGyroEulerAngles\x12\r\n\x05pitch\x18\x01 \x01(\x02\x12\x0b\n\x03yaw\x18\x02 \x01(\x02\x12\x0c\n\x04roll\x18\x03 \x01(\x02\"\x9e\x03\n9CSteamInputService_ControllerAxesStateChange_Notification\x12\x18\n\x10\x63ontroller_index\x18\x01 \x01(\r\x12)\n\rjoystick_left\x18\x02 \x01(\x0b\x32\x12.ControllerVector2\x12*\n\x0ejoystick_right\x18\x03 \x01(\x0b\x32\x12.ControllerVector2\x12)\n\rtrackpad_left\x18\x04 \x01(\x0b\x32\x12.ControllerVector2\x12*\n\x0etrackpad_right\x18\x05 \x01(\x0b\x32\x12.ControllerVector2\x12+\n\x0ftrackpad_center\x18\x06 \x01(\x0b\x32\x12.ControllerVector2\x12\x1e\n\x16trackpad_pressure_left\x18\x07 \x01(\x02\x12\x1f\n\x17trackpad_pressure_right\x18\x08 \x01(\x02\x12\x14\n\x0ctrigger_left\x18\t \x01(\x02\x12\x15\n\rtrigger_right\x18\n \x01(\x02\"\x8f\x02\n5CSteamInputService_GyroQuaternionChanged_Notification\x12\x18\n\x10\x63ontroller_index\x18\x01 \x01(\r\x12\x11\n\timu_index\x18\x02 \x01(\r\x12\x32\n\x13gyro_raw_quaternion\x18\x03 \x01(\x0b\x32\x15.ControllerQuaternion\x12\x37\n\x18gyro_filtered_quaternion\x18\x04 \x01(\x0b\x32\x15.ControllerQuaternion\x12\x1d\n\x15imu_sensor_delta_time\x18\x05 \x01(\r\x12\x1d\n\x15\x65stimated_packet_rate\x18\x06 \x01(\r\"\xcc\x01\n0CSteamInputService_GyroSpeedChanged_Notification\x12\x18\n\x10\x63ontroller_index\x18\x01 \x01(\r\x12\x11\n\timu_index\x18\x02 \x01(\r\x12\x32\n\x0egyro_raw_speed\x18\x03 \x01(\x0b\x32\x1a.ControllerGyroEulerAngles\x12\x37\n\x13gyro_filtered_speed\x18\x04 \x01(\x0b\x32\x1a.ControllerGyroEulerAngles\"\xc4\x01\n8CSteamInputService_GyroAccelerometerChanged_Notification\x12\x18\n\x10\x63ontroller_index\x18\x01 \x01(\r\x12\x11\n\timu_index\x18\x02 \x01(\r\x12+\n\x0f\x61\x63\x63\x65leromter_1g\x18\x04 \x01(\x0b\x32\x12.ControllerVector3\x12.\n\x12trusted_gravity_1g\x18\x05 \x01(\x0b\x32\x12.ControllerVector3\"\xb1\x01\n/CSteamInputService_GyroCalibration_Notification\x12\x18\n\x10\x63ontroller_index\x18\x01 \x01(\r\x12\x11\n\timu_index\x18\x02 \x01(\r\x12\x1a\n\x12\x61\x63\x63\x65leromter_noise\x18\x03 \x01(\x02\x12\x17\n\x0fgyroscope_noise\x18\x04 \x01(\x02\x12\x1c\n\x14\x63\x61libration_progress\x18\x05 \x01(\x02\"]\n.CSteamInputService_ControllerStateFlow_Request\x12\x18\n\x10\x63ontroller_index\x18\x01 \x01(\r\x12\x11\n\tflow_mode\x18\x02 \x01(\r\"1\n/CSteamInputService_ControllerStateFlow_Response\"h\n\x14\x43\x43ontrollerOriginKey\x12\x17\n\x0f\x63ontroller_type\x18\x01 \x01(\x05\x12\x18\n\x10\x63ontroller_style\x18\x02 \x01(\x05\x12\x0e\n\x06source\x18\x03 \x01(\x05\x12\r\n\x05input\x18\x04 \x01(\x05\"^\n\x1e\x43\x43ontrollerAccessibilityString\x12\"\n\x03key\x18\x01 \x01(\x0b\x32\x15.CControllerOriginKey\x12\x18\n\x10localized_string\x18\x02 \x01(\t\";\n9CSteamInputService_ControllerAccessibilityStrings_Request\"n\n:CSteamInputService_ControllerAccessibilityStrings_Response\x12\x30\n\x07strings\x18\x01 \x03(\x0b\x32\x1f.CControllerAccessibilityString2\xb8\x08\n\x11SteamInputManager\x12k\n\x18NotifyButtonStateChanged\x12=.CSteamInputService_ControllerButtonStateChanged_Notification\x1a\x10.WebUINoResponse\x12\x66\n\x16NotifyAxesStateChanged\x12:.CSteamInputService_ControllerAxesStateChange_Notification\x1a\x10.WebUINoResponse\x12l\n NotifyGyroQuaternionStateChanged\x12\x36.CSteamInputService_GyroQuaternionChanged_Notification\x1a\x10.WebUINoResponse\x12\x62\n\x1bNotifyGyroSpeedStateChanged\x12\x31.CSteamInputService_GyroSpeedChanged_Notification\x1a\x10.WebUINoResponse\x12r\n#NotifyGyroAccelerometerStateChanged\x12\x39.CSteamInputService_GyroAccelerometerChanged_Notification\x1a\x10.WebUINoResponse\x12g\n!NotifyGyroCalibrationStateChanged\x12\x30.CSteamInputService_GyroCalibration_Notification\x1a\x10.WebUINoResponse\x12}\n\x18StartControllerStateFlow\x12/.CSteamInputService_ControllerStateFlow_Request\x1a\x30.CSteamInputService_ControllerStateFlow_Response\x12{\n\x16\x45ndControllerStateFlow\x12/.CSteamInputService_ControllerStateFlow_Request\x1a\x30.CSteamInputService_ControllerStateFlow_Response\x12\x9c\x01\n!GetControllerAccessibilityStrings\x12:.CSteamInputService_ControllerAccessibilityStrings_Request\x1a;.CSteamInputService_ControllerAccessibilityStrings_Response\x1a\x04\x80\x97\"\x02\x42\x05H\x01\x90\x01\x01')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'webuimessages_steaminput_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'H\001\220\001\001'
  _STEAMINPUTMANAGER._options = None
  _STEAMINPUTMANAGER._serialized_options = b'\200\227\"\002'
  _CSTEAMINPUTSERVICE_CONTROLLERBUTTONSTATECHANGED_NOTIFICATION._serialized_start=87
  _CSTEAMINPUTSERVICE_CONTROLLERBUTTONSTATECHANGED_NOTIFICATION._serialized_end=988
  _CONTROLLERVECTOR2._serialized_start=990
  _CONTROLLERVECTOR2._serialized_end=1031
  _CONTROLLERVECTOR3._serialized_start=1033
  _CONTROLLERVECTOR3._serialized_end=1085
  _CONTROLLERQUATERNION._serialized_start=1087
  _CONTROLLERQUATERNION._serialized_end=1153
  _CONTROLLERGYROEULERANGLES._serialized_start=1155
  _CONTROLLERGYROEULERANGLES._serialized_end=1224
  _CSTEAMINPUTSERVICE_CONTROLLERAXESSTATECHANGE_NOTIFICATION._serialized_start=1227
  _CSTEAMINPUTSERVICE_CONTROLLERAXESSTATECHANGE_NOTIFICATION._serialized_end=1641
  _CSTEAMINPUTSERVICE_GYROQUATERNIONCHANGED_NOTIFICATION._serialized_start=1644
  _CSTEAMINPUTSERVICE_GYROQUATERNIONCHANGED_NOTIFICATION._serialized_end=1915
  _CSTEAMINPUTSERVICE_GYROSPEEDCHANGED_NOTIFICATION._serialized_start=1918
  _CSTEAMINPUTSERVICE_GYROSPEEDCHANGED_NOTIFICATION._serialized_end=2122
  _CSTEAMINPUTSERVICE_GYROACCELEROMETERCHANGED_NOTIFICATION._serialized_start=2125
  _CSTEAMINPUTSERVICE_GYROACCELEROMETERCHANGED_NOTIFICATION._serialized_end=2321
  _CSTEAMINPUTSERVICE_GYROCALIBRATION_NOTIFICATION._serialized_start=2324
  _CSTEAMINPUTSERVICE_GYROCALIBRATION_NOTIFICATION._serialized_end=2501
  _CSTEAMINPUTSERVICE_CONTROLLERSTATEFLOW_REQUEST._serialized_start=2503
  _CSTEAMINPUTSERVICE_CONTROLLERSTATEFLOW_REQUEST._serialized_end=2596
  _CSTEAMINPUTSERVICE_CONTROLLERSTATEFLOW_RESPONSE._serialized_start=2598
  _CSTEAMINPUTSERVICE_CONTROLLERSTATEFLOW_RESPONSE._serialized_end=2647
  _CCONTROLLERORIGINKEY._serialized_start=2649
  _CCONTROLLERORIGINKEY._serialized_end=2753
  _CCONTROLLERACCESSIBILITYSTRING._serialized_start=2755
  _CCONTROLLERACCESSIBILITYSTRING._serialized_end=2849
  _CSTEAMINPUTSERVICE_CONTROLLERACCESSIBILITYSTRINGS_REQUEST._serialized_start=2851
  _CSTEAMINPUTSERVICE_CONTROLLERACCESSIBILITYSTRINGS_REQUEST._serialized_end=2910
  _CSTEAMINPUTSERVICE_CONTROLLERACCESSIBILITYSTRINGS_RESPONSE._serialized_start=2912
  _CSTEAMINPUTSERVICE_CONTROLLERACCESSIBILITYSTRINGS_RESPONSE._serialized_end=3022
  _STEAMINPUTMANAGER._serialized_start=3025
  _STEAMINPUTMANAGER._serialized_end=4105
_builder.BuildServices(DESCRIPTOR, 'webuimessages_steaminput_pb2', globals())
# @@protoc_insertion_point(module_scope)
