# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: webuimessages_hardwareupdate.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import steam.protobufs.enums_pb2 as enums__pb2
import steam.protobufs.steammessages_base_pb2 as steammessages__base__pb2
import steam.protobufs.webuimessages_base_pb2 as webuimessages__base__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"webuimessages_hardwareupdate.proto\x1a\x0b\x65nums.proto\x1a\x18steammessages_base.proto\x1a\x18webuimessages_base.proto\"\"\n CHardwareUpdate_GetState_Request\"_\n!CHardwareUpdate_GetState_Response\x12\x1c\n\x14is_updater_supported\x18\x01 \x01(\x08\x12\x1c\n\x14has_seen_controllers\x18\x02 \x01(\x08\"+\n)CHardwareUpdate_StateChanged_Notification\")\n\'CHardwareUpdate_CheckForUpdates_Request\"\x7f\n\x1b\x43MsgAvailableHardwareUpdate\x12\r\n\x05\x65type\x18\x01 \x01(\r\x12\x13\n\x0bhardware_id\x18\x02 \x01(\r\x12\x15\n\rserial_number\x18\x03 \x01(\t\x12\x12\n\ncurrent_ts\x18\x04 \x01(\t\x12\x11\n\tupdate_ts\x18\x05 \x01(\t\"Y\n(CHardwareUpdate_CheckForUpdates_Response\x12-\n\x07updates\x18\x01 \x03(\x0b\x32\x1c.CMsgAvailableHardwareUpdate\"7\n\x1e\x43HardwareUpdate_Update_Request\x12\x15\n\rserial_number\x18\x01 \x01(\t\"!\n\x1f\x43HardwareUpdate_Update_Response\"?\n+CHardwareUpdate_UpdateProgress_Notification\x12\x10\n\x08progress\x18\x01 \x01(\x05\"1\n/CHardwareUpdate_UpdateStateChanged_Notification2\xaa\x04\n\x0eHardwareUpdate\x12Q\n\x08GetState\x12!.CHardwareUpdate_GetState_Request\x1a\".CHardwareUpdate_GetState_Response\x12R\n\x12NotifyStateChanged\x12*.CHardwareUpdate_StateChanged_Notification\x1a\x10.WebUINoResponse\x12\x66\n\x0f\x43heckForUpdates\x12(.CHardwareUpdate_CheckForUpdates_Request\x1a).CHardwareUpdate_CheckForUpdates_Response\x12K\n\x06Update\x12\x1f.CHardwareUpdate_Update_Request\x1a .CHardwareUpdate_Update_Response\x12V\n\x14NotifyUpdateProgress\x12,.CHardwareUpdate_UpdateProgress_Notification\x1a\x10.WebUINoResponse\x12^\n\x18NotifyUpdateStateChanged\x12\x30.CHardwareUpdate_UpdateStateChanged_Notification\x1a\x10.WebUINoResponse\x1a\x04\x80\x97\"\x01\x42\x05H\x01\x90\x01\x01')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'webuimessages_hardwareupdate_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'H\001\220\001\001'
  _HARDWAREUPDATE._options = None
  _HARDWAREUPDATE._serialized_options = b'\200\227\"\001'
  _CHARDWAREUPDATE_GETSTATE_REQUEST._serialized_start=103
  _CHARDWAREUPDATE_GETSTATE_REQUEST._serialized_end=137
  _CHARDWAREUPDATE_GETSTATE_RESPONSE._serialized_start=139
  _CHARDWAREUPDATE_GETSTATE_RESPONSE._serialized_end=234
  _CHARDWAREUPDATE_STATECHANGED_NOTIFICATION._serialized_start=236
  _CHARDWAREUPDATE_STATECHANGED_NOTIFICATION._serialized_end=279
  _CHARDWAREUPDATE_CHECKFORUPDATES_REQUEST._serialized_start=281
  _CHARDWAREUPDATE_CHECKFORUPDATES_REQUEST._serialized_end=322
  _CMSGAVAILABLEHARDWAREUPDATE._serialized_start=324
  _CMSGAVAILABLEHARDWAREUPDATE._serialized_end=451
  _CHARDWAREUPDATE_CHECKFORUPDATES_RESPONSE._serialized_start=453
  _CHARDWAREUPDATE_CHECKFORUPDATES_RESPONSE._serialized_end=542
  _CHARDWAREUPDATE_UPDATE_REQUEST._serialized_start=544
  _CHARDWAREUPDATE_UPDATE_REQUEST._serialized_end=599
  _CHARDWAREUPDATE_UPDATE_RESPONSE._serialized_start=601
  _CHARDWAREUPDATE_UPDATE_RESPONSE._serialized_end=634
  _CHARDWAREUPDATE_UPDATEPROGRESS_NOTIFICATION._serialized_start=636
  _CHARDWAREUPDATE_UPDATEPROGRESS_NOTIFICATION._serialized_end=699
  _CHARDWAREUPDATE_UPDATESTATECHANGED_NOTIFICATION._serialized_start=701
  _CHARDWAREUPDATE_UPDATESTATECHANGED_NOTIFICATION._serialized_end=750
  _HARDWAREUPDATE._serialized_start=753
  _HARDWAREUPDATE._serialized_end=1307
_builder.BuildServices(DESCRIPTOR, 'webuimessages_hardwareupdate_pb2', globals())
# @@protoc_insertion_point(module_scope)
