# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: webuimessages_base.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import steam.protobufs.enums_pb2 as enums__pb2
import steam.protobufs.steammessages_base_pb2 as steammessages__base__pb2
from google.protobuf import descriptor_pb2 as google_dot_protobuf_dot_descriptor__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18webuimessages_base.proto\x1a\x0b\x65nums.proto\x1a\x18steammessages_base.proto\x1a google/protobuf/descriptor.proto\"\x11\n\x0fWebUINoResponse*\xa0\x01\n\x14\x45\x43lientExecutionSite\x12!\n\x1dk_EClientExecutionSiteInvalid\x10\x00\x12!\n\x1dk_EClientExecutionSiteSteamUI\x10\x01\x12#\n\x1fk_EClientExecutionSiteClientdll\x10\x02\x12\x1d\n\x19k_EClientExecutionSiteAny\x10\x03:}\n\x1cwebui_service_execution_site\x12\x1f.google.protobuf.ServiceOptions\x18\xf0\xa2\x04 \x01(\x0e\x32\x15.EClientExecutionSite:\x1dk_EClientExecutionSiteSteamUI:{\n\x1bwebui_method_execution_site\x12\x1e.google.protobuf.MethodOptions\x18\xf0\xa2\x04 \x01(\x0e\x32\x15.EClientExecutionSite:\x1dk_EClientExecutionSiteInvalidB\x05H\x01\x90\x01\x01')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'webuimessages_base_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:
  google_dot_protobuf_dot_descriptor__pb2.ServiceOptions.RegisterExtension(webui_service_execution_site)
  google_dot_protobuf_dot_descriptor__pb2.MethodOptions.RegisterExtension(webui_method_execution_site)

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'H\001\220\001\001'
  _ECLIENTEXECUTIONSITE._serialized_start=121
  _ECLIENTEXECUTIONSITE._serialized_end=281
  _WEBUINORESPONSE._serialized_start=101
  _WEBUINORESPONSE._serialized_end=118
# @@protoc_insertion_point(module_scope)
