# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: steammessages_parental_objects.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import steam.protobufs.enums_pb2 as enums__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$steammessages_parental_objects.proto\x1a\x0b\x65nums.proto\"0\n\x0bParentalApp\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x12\n\nis_allowed\x18\x02 \x01(\x08\"R\n\x13ParentalPlaytimeDay\x12\x1c\n\x14\x61llowed_time_windows\x18\x01 \x01(\x04\x12\x1d\n\x15\x61llowed_daily_minutes\x18\x02 \x01(\r\"p\n\x1cParentalPlaytimeRestrictions\x12#\n\x1b\x61pply_playtime_restrictions\x18\x02 \x01(\x08\x12+\n\rplaytime_days\x18\x0f \x03(\x0b\x32\x14.ParentalPlaytimeDay\"j\n%ParentalTemporaryPlaytimeRestrictions\x12*\n\x0crestrictions\x18\x01 \x01(\x0b\x32\x14.ParentalPlaytimeDay\x12\x15\n\rrtime_expires\x18\x02 \x01(\r\"\x9d\x05\n\x10ParentalSettings\x12\x0f\n\x07steamid\x18\x01 \x01(\x06\x12\x17\n\x0f\x61pplist_base_id\x18\x02 \x01(\r\x12 \n\x18\x61pplist_base_description\x18\x03 \x01(\t\x12\"\n\x0c\x61pplist_base\x18\x04 \x03(\x0b\x32\x0c.ParentalApp\x12$\n\x0e\x61pplist_custom\x18\x05 \x03(\x0b\x32\x0c.ParentalApp\x12\x18\n\x10passwordhashtype\x18\x06 \x01(\r\x12\x0c\n\x04salt\x18\x07 \x01(\x0c\x12\x14\n\x0cpasswordhash\x18\x08 \x01(\x0c\x12\x12\n\nis_enabled\x18\t \x01(\x08\x12\x18\n\x10\x65nabled_features\x18\n \x01(\r\x12\x16\n\x0erecovery_email\x18\x0b \x01(\t\x12\x1c\n\x14is_site_license_lock\x18\x0c \x01(\x08\x12\"\n\x1atemporary_enabled_features\x18\r \x01(\r\x12*\n\"rtime_temporary_feature_expiration\x18\x0e \x01(\r\x12<\n\x15playtime_restrictions\x18\x0f \x01(\x0b\x32\x1d.ParentalPlaytimeRestrictions\x12O\n\x1ftemporary_playtime_restrictions\x18\x10 \x01(\x0b\x32&.ParentalTemporaryPlaytimeRestrictions\x12*\n\"excluded_store_content_descriptors\x18\x11 \x03(\r\x12.\n&excluded_community_content_descriptors\x18\x12 \x03(\r\x12\x16\n\x0eutility_appids\x18\x13 \x03(\r\"\xc3\x01\n\x16ParentalFeatureRequest\x12\x11\n\trequestid\x18\x01 \x01(\x06\x12\x16\n\x0e\x66\x61mily_groupid\x18\x02 \x01(\x06\x12\x0f\n\x07steamid\x18\x03 \x01(\x06\x12\x10\n\x08\x66\x65\x61tures\x18\x04 \x01(\r\x12\x16\n\x0etime_requested\x18\x05 \x01(\r\x12\x10\n\x08\x61pproved\x18\x06 \x01(\x08\x12\x19\n\x11steamid_responder\x18\x07 \x01(\x06\x12\x16\n\x0etime_responded\x18\x08 \x01(\r\"\xcc\x02\n\x17ParentalPlaytimeRequest\x12\x11\n\trequestid\x18\x01 \x01(\x06\x12\x16\n\x0e\x66\x61mily_groupid\x18\x02 \x01(\x06\x12\x0f\n\x07steamid\x18\x03 \x01(\x06\x12;\n\x1d\x63urrent_playtime_restrictions\x18\x04 \x01(\x0b\x32\x14.ParentalPlaytimeDay\x12\x14\n\x0ctime_expires\x18\x05 \x01(\r\x12\x16\n\x0etime_requested\x18\x06 \x01(\r\x12\x10\n\x08\x61pproved\x18\x07 \x01(\x08\x12\x19\n\x11steamid_responder\x18\x08 \x01(\x06\x12\x16\n\x0etime_responded\x18\t \x01(\r\x12\x45\n\x15restrictions_approved\x18\n \x01(\x0b\x32&.ParentalTemporaryPlaytimeRestrictionsB\x02H\x01')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'steammessages_parental_objects_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'H\001'
  _PARENTALAPP._serialized_start=53
  _PARENTALAPP._serialized_end=101
  _PARENTALPLAYTIMEDAY._serialized_start=103
  _PARENTALPLAYTIMEDAY._serialized_end=185
  _PARENTALPLAYTIMERESTRICTIONS._serialized_start=187
  _PARENTALPLAYTIMERESTRICTIONS._serialized_end=299
  _PARENTALTEMPORARYPLAYTIMERESTRICTIONS._serialized_start=301
  _PARENTALTEMPORARYPLAYTIMERESTRICTIONS._serialized_end=407
  _PARENTALSETTINGS._serialized_start=410
  _PARENTALSETTINGS._serialized_end=1079
  _PARENTALFEATUREREQUEST._serialized_start=1082
  _PARENTALFEATUREREQUEST._serialized_end=1277
  _PARENTALPLAYTIMEREQUEST._serialized_start=1280
  _PARENTALPLAYTIMEREQUEST._serialized_end=1612
# @@protoc_insertion_point(module_scope)
