# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: steammessages_partnerapps.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import steam.protobufs.steammessages_base_pb2 as steammessages__base__pb2
import steam.protobufs.steammessages_unified_base_pb2 as steammessages__unified__base__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1fsteammessages_partnerapps.proto\x1a\x18steammessages_base.proto\x1a steammessages_unified_base.proto\"J\n\'CPartnerApps_RequestUploadToken_Request\x12\x10\n\x08\x66ilename\x18\x01 \x01(\t\x12\r\n\x05\x61ppid\x18\x02 \x01(\r\"f\n(CPartnerApps_RequestUploadToken_Response\x12\x14\n\x0cupload_token\x18\x01 \x01(\x04\x12\x10\n\x08location\x18\x02 \x01(\t\x12\x12\n\nrouting_id\x18\x03 \x01(\x04\"]\n!CPartnerApps_FinishUpload_Request\x12\x14\n\x0cupload_token\x18\x01 \x01(\x04\x12\x12\n\nrouting_id\x18\x02 \x01(\x04\x12\x0e\n\x06\x61pp_id\x18\x03 \x01(\r\"H\n(CPartnerApps_FinishUploadKVSign_Response\x12\x1c\n\x14signed_installscript\x18\x01 \x01(\t\"\xa2\x01\n*CPartnerApps_FinishUploadLegacyDRM_Request\x12\x14\n\x0cupload_token\x18\x01 \x01(\x04\x12\x12\n\nrouting_id\x18\x02 \x01(\x04\x12\x0e\n\x06\x61pp_id\x18\x03 \x01(\r\x12\r\n\x05\x66lags\x18\x04 \x01(\r\x12\x11\n\ttool_name\x18\x05 \x01(\t\x12\x18\n\tuse_cloud\x18\x06 \x01(\x08:\x05\x66\x61lse\">\n+CPartnerApps_FinishUploadLegacyDRM_Response\x12\x0f\n\x07\x66ile_id\x18\x01 \x01(\t\"$\n\"CPartnerApps_FinishUpload_Response\"\x89\x01\n&CPartnerApps_FinishUploadDepot_Request\x12\x14\n\x0cupload_token\x18\x01 \x01(\x04\x12\x12\n\nrouting_id\x18\x02 \x01(\x04\x12\x0e\n\x06\x61pp_id\x18\x03 \x01(\r\x12\x10\n\x08\x64\x65pot_id\x18\x04 \x01(\r\x12\x13\n\x0b\x62uild_flags\x18\x05 \x01(\r\"C\n\'CPartnerApps_FinishUploadDepot_Response\x12\x18\n\x10\x62uild_routing_id\x18\x01 \x01(\x04\"T\n(CPartnerApps_GetDepotBuildResult_Request\x12\x14\n\x0cupload_token\x18\x01 \x01(\x04\x12\x12\n\nrouting_id\x18\x02 \x01(\x04\"S\n)CPartnerApps_GetDepotBuildResult_Response\x12\x13\n\x0bmanifest_id\x18\x01 \x01(\x04\x12\x11\n\terror_msg\x18\x02 \x01(\t\"5\n#CPartnerApps_FindDRMUploads_Request\x12\x0e\n\x06\x61pp_id\x18\x01 \x01(\x05\"\xb4\x01\n\x1e\x43PartnerApps_ExistingDRMUpload\x12\x0f\n\x07\x66ile_id\x18\x01 \x01(\t\x12\x0e\n\x06\x61pp_id\x18\x02 \x01(\r\x12\x10\n\x08\x61\x63tor_id\x18\x03 \x01(\x05\x12\x15\n\rsupplied_name\x18\x05 \x01(\t\x12\r\n\x05\x66lags\x18\x06 \x01(\r\x12\x10\n\x08mod_type\x18\x07 \x01(\t\x12\x11\n\ttimestamp\x18\x08 \x01(\x07\x12\x14\n\x0corig_file_id\x18\t \x01(\t\"X\n$CPartnerApps_FindDRMUploads_Response\x12\x30\n\x07uploads\x18\x01 \x03(\x0b\x32\x1f.CPartnerApps_ExistingDRMUpload\"@\n\x1d\x43PartnerApps_Download_Request\x12\x0f\n\x07\x66ile_id\x18\x01 \x01(\t\x12\x0e\n\x06\x61pp_id\x18\x02 \x01(\x05\"F\n\x1e\x43PartnerApps_Download_Response\x12\x14\n\x0c\x64ownload_url\x18\x01 \x01(\t\x12\x0e\n\x06\x61pp_id\x18\x02 \x01(\x05\x32\x8d\t\n\x0bPartnerApps\x12o\n\x18RequestKVSignUploadToken\x12(.CPartnerApps_RequestUploadToken_Request\x1a).CPartnerApps_RequestUploadToken_Response\x12l\n\x15RequestDRMUploadToken\x12(.CPartnerApps_RequestUploadToken_Request\x1a).CPartnerApps_RequestUploadToken_Response\x12l\n\x15RequestCEGUploadToken\x12(.CPartnerApps_RequestUploadToken_Request\x1a).CPartnerApps_RequestUploadToken_Response\x12n\n\x17RequestDepotUploadToken\x12(.CPartnerApps_RequestUploadToken_Request\x1a).CPartnerApps_RequestUploadToken_Response\x12\x63\n\x12\x46inishUploadKVSign\x12\".CPartnerApps_FinishUpload_Request\x1a).CPartnerApps_FinishUploadKVSign_Response\x12r\n\x15\x46inishUploadDRMUpload\x12+.CPartnerApps_FinishUploadLegacyDRM_Request\x1a,.CPartnerApps_FinishUploadLegacyDRM_Response\x12`\n\x15\x46inishUploadCEGUpload\x12\".CPartnerApps_FinishUpload_Request\x1a#.CPartnerApps_FinishUpload_Response\x12l\n\x17\x46inishUploadDepotUpload\x12\'.CPartnerApps_FinishUploadDepot_Request\x1a(.CPartnerApps_FinishUploadDepot_Response\x12l\n\x13GetDepotBuildResult\x12).CPartnerApps_GetDepotBuildResult_Request\x1a*.CPartnerApps_GetDepotBuildResult_Response\x12]\n\x0e\x46indDRMUploads\x12$.CPartnerApps_FindDRMUploads_Request\x1a%.CPartnerApps_FindDRMUploads_Response\x12K\n\x08\x44ownload\x12\x1e.CPartnerApps_Download_Request\x1a\x1f.CPartnerApps_Download_ResponseB\x03\x90\x01\x01')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'steammessages_partnerapps_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\220\001\001'
  _CPARTNERAPPS_REQUESTUPLOADTOKEN_REQUEST._serialized_start=95
  _CPARTNERAPPS_REQUESTUPLOADTOKEN_REQUEST._serialized_end=169
  _CPARTNERAPPS_REQUESTUPLOADTOKEN_RESPONSE._serialized_start=171
  _CPARTNERAPPS_REQUESTUPLOADTOKEN_RESPONSE._serialized_end=273
  _CPARTNERAPPS_FINISHUPLOAD_REQUEST._serialized_start=275
  _CPARTNERAPPS_FINISHUPLOAD_REQUEST._serialized_end=368
  _CPARTNERAPPS_FINISHUPLOADKVSIGN_RESPONSE._serialized_start=370
  _CPARTNERAPPS_FINISHUPLOADKVSIGN_RESPONSE._serialized_end=442
  _CPARTNERAPPS_FINISHUPLOADLEGACYDRM_REQUEST._serialized_start=445
  _CPARTNERAPPS_FINISHUPLOADLEGACYDRM_REQUEST._serialized_end=607
  _CPARTNERAPPS_FINISHUPLOADLEGACYDRM_RESPONSE._serialized_start=609
  _CPARTNERAPPS_FINISHUPLOADLEGACYDRM_RESPONSE._serialized_end=671
  _CPARTNERAPPS_FINISHUPLOAD_RESPONSE._serialized_start=673
  _CPARTNERAPPS_FINISHUPLOAD_RESPONSE._serialized_end=709
  _CPARTNERAPPS_FINISHUPLOADDEPOT_REQUEST._serialized_start=712
  _CPARTNERAPPS_FINISHUPLOADDEPOT_REQUEST._serialized_end=849
  _CPARTNERAPPS_FINISHUPLOADDEPOT_RESPONSE._serialized_start=851
  _CPARTNERAPPS_FINISHUPLOADDEPOT_RESPONSE._serialized_end=918
  _CPARTNERAPPS_GETDEPOTBUILDRESULT_REQUEST._serialized_start=920
  _CPARTNERAPPS_GETDEPOTBUILDRESULT_REQUEST._serialized_end=1004
  _CPARTNERAPPS_GETDEPOTBUILDRESULT_RESPONSE._serialized_start=1006
  _CPARTNERAPPS_GETDEPOTBUILDRESULT_RESPONSE._serialized_end=1089
  _CPARTNERAPPS_FINDDRMUPLOADS_REQUEST._serialized_start=1091
  _CPARTNERAPPS_FINDDRMUPLOADS_REQUEST._serialized_end=1144
  _CPARTNERAPPS_EXISTINGDRMUPLOAD._serialized_start=1147
  _CPARTNERAPPS_EXISTINGDRMUPLOAD._serialized_end=1327
  _CPARTNERAPPS_FINDDRMUPLOADS_RESPONSE._serialized_start=1329
  _CPARTNERAPPS_FINDDRMUPLOADS_RESPONSE._serialized_end=1417
  _CPARTNERAPPS_DOWNLOAD_REQUEST._serialized_start=1419
  _CPARTNERAPPS_DOWNLOAD_REQUEST._serialized_end=1483
  _CPARTNERAPPS_DOWNLOAD_RESPONSE._serialized_start=1485
  _CPARTNERAPPS_DOWNLOAD_RESPONSE._serialized_end=1555
  _PARTNERAPPS._serialized_start=1558
  _PARTNERAPPS._serialized_end=2723
_builder.BuildServices(DESCRIPTOR, 'steammessages_partnerapps_pb2', globals())
# @@protoc_insertion_point(module_scope)
