# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: steammessages_steamtv.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import steam.protobufs.steammessages_base_pb2 as steammessages__base__pb2
import steam.protobufs.steammessages_unified_base_pb2 as steammessages__unified__base__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1bsteammessages_steamtv.proto\x1a\x18steammessages_base.proto\x1a steammessages_unified_base.proto\">\n\'CSteamTV_CreateBroadcastChannel_Request\x12\x13\n\x0bunique_name\x18\x01 \x01(\t\"H\n(CSteamTV_CreateBroadcastChannel_Response\x12\x1c\n\x14\x62roadcast_channel_id\x18\x01 \x01(\x06\"=\n&CSteamTV_GetBroadcastChannelID_Request\x12\x13\n\x0bunique_name\x18\x01 \x01(\t\"m\n\'CSteamTV_GetBroadcastChannelID_Response\x12\x1c\n\x14\x62roadcast_channel_id\x18\x01 \x01(\x06\x12\x13\n\x0bunique_name\x18\x02 \x01(\t\x12\x0f\n\x07steamid\x18\x03 \x01(\x06\"\xd4\x01\n+CSteamTV_SetBroadcastChannelProfile_Request\x12\x1c\n\x14\x62roadcast_channel_id\x18\x01 \x01(\x06\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x10\n\x08language\x18\x03 \x01(\t\x12\x10\n\x08headline\x18\x04 \x01(\t\x12\x0f\n\x07summary\x18\x05 \x01(\t\x12\x13\n\x0b\x61vatar_hash\x18\x06 \x01(\t\x12\x10\n\x08schedule\x18\x07 \x01(\t\x12\r\n\x05rules\x18\x08 \x01(\t\x12\x0e\n\x06panels\x18\t \x01(\t\".\n,CSteamTV_SetBroadcastChannelProfile_Response\"K\n+CSteamTV_GetBroadcastChannelProfile_Request\x12\x1c\n\x14\x62roadcast_channel_id\x18\x01 \x01(\x06\"\xe4\x01\n,CSteamTV_GetBroadcastChannelProfile_Response\x12\x13\n\x0bunique_name\x18\x01 \x01(\t\x12\x15\n\rowner_steamid\x18\x02 \x01(\x06\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x10\n\x08language\x18\x04 \x01(\t\x12\x10\n\x08headline\x18\x05 \x01(\t\x12\x0f\n\x07summary\x18\x06 \x01(\t\x12\x10\n\x08schedule\x18\x07 \x01(\t\x12\r\n\x05rules\x18\x08 \x01(\t\x12\x0e\n\x06panels\x18\t \x01(\t\x12\x14\n\x0cis_partnered\x18\n \x01(\x08\"\x9b\x02\n)CSteamTV_SetBroadcastChannelImage_Request\x12\x1c\n\x14\x62roadcast_channel_id\x18\x01 \x01(\x06\x12\x44\n\nimage_type\x18\x02 \x01(\x0e\x32\x14.EBroadcastImageType:\x1ak_EBroadcastImageType_None\x12\x13\n\x0bimage_index\x18\x03 \x01(\r\x12\x13\n\x0bimage_width\x18\x04 \x01(\r\x12\x14\n\x0cimage_height\x18\x05 \x01(\r\x12\x11\n\tfile_size\x18\x06 \x01(\r\x12\x16\n\x0e\x66ile_extension\x18\x07 \x01(\t\x12\x11\n\tfile_hash\x18\x08 \x01(\t\x12\x0c\n\x04undo\x18\t \x01(\x08\"H\n*CSteamTV_SetBroadcastChannelImage_Response\x12\x1a\n\x12replace_image_hash\x18\x01 \x01(\t\"u\n*CSteamTV_GetBroadcastChannelImages_Request\x12\x1c\n\x14\x62roadcast_channel_id\x18\x01 \x01(\x06\x12)\n\x0bimage_types\x18\x02 \x03(\x0e\x32\x14.EBroadcastImageType\"\xeb\x01\n+CSteamTV_GetBroadcastChannelImages_Response\x12\x43\n\x06images\x18\x01 \x03(\x0b\x32\x33.CSteamTV_GetBroadcastChannelImages_Response.Images\x1aw\n\x06Images\x12\x44\n\nimage_type\x18\x01 \x01(\x0e\x32\x14.EBroadcastImageType:\x1ak_EBroadcastImageType_None\x12\x12\n\nimage_path\x18\x02 \x01(\t\x12\x13\n\x0bimage_index\x18\x03 \x01(\r\"\x94\x02\n/CSteamTV_SetBroadcastChannelLinkRegions_Request\x12\x1c\n\x14\x62roadcast_channel_id\x18\x01 \x01(\x06\x12\x45\n\x05links\x18\x02 \x03(\x0b\x32\x36.CSteamTV_SetBroadcastChannelLinkRegions_Request.Links\x1a|\n\x05Links\x12\x12\n\nlink_index\x18\x01 \x01(\r\x12\x0b\n\x03url\x18\x02 \x01(\t\x12\x18\n\x10link_description\x18\x03 \x01(\t\x12\x0c\n\x04left\x18\x04 \x01(\r\x12\x0b\n\x03top\x18\x05 \x01(\r\x12\r\n\x05width\x18\x06 \x01(\r\x12\x0e\n\x06height\x18\x07 \x01(\r\"2\n0CSteamTV_SetBroadcastChannelLinkRegions_Response\"I\n)CSteamTV_GetBroadcastChannelLinks_Request\x12\x1c\n\x14\x62roadcast_channel_id\x18\x01 \x01(\x06\"\xec\x01\n*CSteamTV_GetBroadcastChannelLinks_Response\x12@\n\x05links\x18\x01 \x03(\x0b\x32\x31.CSteamTV_GetBroadcastChannelLinks_Response.Links\x1a|\n\x05Links\x12\x12\n\nlink_index\x18\x01 \x01(\r\x12\x0b\n\x03url\x18\x02 \x01(\t\x12\x18\n\x10link_description\x18\x03 \x01(\t\x12\x0c\n\x04left\x18\x04 \x01(\r\x12\x0b\n\x03top\x18\x05 \x01(\r\x12\r\n\x05width\x18\x06 \x01(\r\x12\x0e\n\x06height\x18\x07 \x01(\r\"P\n0CSteamTV_GetBroadcastChannelBroadcasters_Request\x12\x1c\n\x14\x62roadcast_channel_id\x18\x01 \x01(\x06\"\xcb\x01\n1CSteamTV_GetBroadcastChannelBroadcasters_Response\x12T\n\x0c\x62roadcasters\x18\x01 \x03(\x0b\x32>.CSteamTV_GetBroadcastChannelBroadcasters_Response.Broadcaster\x1a@\n\x0b\x42roadcaster\x12\x0f\n\x07steamid\x18\x01 \x01(\x06\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x12\n\nrtmp_token\x18\x03 \x01(\t\"&\n$CSteamTV_GetFollowedChannels_Request\"\x98\x03\n\x18GetBroadcastChannelEntry\x12\x1c\n\x14\x62roadcast_channel_id\x18\x01 \x01(\x06\x12\x13\n\x0bunique_name\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\r\n\x05\x61ppid\x18\x04 \x01(\r\x12\x0f\n\x07viewers\x18\x05 \x01(\x04\x12\r\n\x05views\x18\x06 \x01(\x04\x12\x15\n\rthumbnail_url\x18\x07 \x01(\t\x12\x11\n\tfollowers\x18\x08 \x01(\x04\x12\x10\n\x08headline\x18\t \x01(\t\x12\x12\n\navatar_url\x18\n \x01(\t\x12\x1b\n\x13\x62roadcaster_steamid\x18\x0b \x01(\x06\x12\x13\n\x0bsubscribers\x18\x0c \x01(\x04\x12\x16\n\x0e\x62\x61\x63kground_url\x18\r \x01(\t\x12\x13\n\x0bis_featured\x18\x0e \x01(\x08\x12\x13\n\x0bis_disabled\x18\x0f \x01(\x08\x12\x0f\n\x07is_live\x18\x10 \x01(\x08\x12\x10\n\x08language\x18\x11 \x01(\t\x12\x0f\n\x07reports\x18\x12 \x01(\r\x12\x14\n\x0cis_partnered\x18\x13 \x01(\x08\"S\n%CSteamTV_GetFollowedChannels_Response\x12*\n\x07results\x18\x01 \x03(\x0b\x32\x19.GetBroadcastChannelEntry\"(\n&CSteamTV_GetSubscribedChannels_Request\"U\n\'CSteamTV_GetSubscribedChannels_Response\x12*\n\x07results\x18\x01 \x03(\x0b\x32\x19.GetBroadcastChannelEntry\"J\n*CSteamTV_GetBroadcastChannelStatus_Request\x12\x1c\n\x14\x62roadcast_channel_id\x18\x01 \x01(\x06\"\x91\x02\n+CSteamTV_GetBroadcastChannelStatus_Response\x12\x0f\n\x07is_live\x18\x01 \x01(\x08\x12\x13\n\x0bis_disabled\x18\x02 \x01(\x08\x12\r\n\x05\x61ppid\x18\x03 \x01(\r\x12\x0f\n\x07viewers\x18\x04 \x01(\x04\x12\r\n\x05views\x18\x05 \x01(\x04\x12\x1b\n\x13\x62roadcaster_steamid\x18\x06 \x01(\x06\x12\x15\n\rthumbnail_url\x18\x07 \x01(\t\x12\x11\n\tfollowers\x18\x08 \x01(\x04\x12\x13\n\x0bsubscribers\x18\t \x01(\x04\x12\x13\n\x0bunique_name\x18\n \x01(\t\x12\x1c\n\x14\x62roadcast_session_id\x18\x0b \x01(\x04\"U\n\'CSteamTV_FollowBroadcastChannel_Request\x12\x1c\n\x14\x62roadcast_channel_id\x18\x01 \x01(\x06\x12\x0c\n\x04undo\x18\x02 \x01(\x08\"?\n(CSteamTV_FollowBroadcastChannel_Response\x12\x13\n\x0bis_followed\x18\x01 \x01(\x08\"J\n*CSteamTV_SubscribeBroadcastChannel_Request\x12\x1c\n\x14\x62roadcast_channel_id\x18\x01 \x01(\x06\"D\n+CSteamTV_SubscribeBroadcastChannel_Response\x12\x15\n\ris_subscribed\x18\x01 \x01(\x08\"I\n)CSteamTV_GetBroadcastChannelClips_Request\x12\x1c\n\x14\x62roadcast_channel_id\x18\x01 \x01(\x06\"\xea\x01\n\x1a\x43SteamTV_BroadcastClipInfo\x12\x19\n\x11\x62roadcast_clip_id\x18\x01 \x01(\x04\x12\x12\n\nchannel_id\x18\x02 \x01(\x04\x12\x0e\n\x06\x61pp_id\x18\x03 \x01(\r\x12\x1b\n\x13\x62roadcaster_steamid\x18\x04 \x01(\x06\x12\x17\n\x0f\x63reator_steamid\x18\x05 \x01(\x06\x12\x19\n\x11video_description\x18\x06 \x01(\t\x12\x11\n\tlive_time\x18\x07 \x01(\r\x12\x11\n\tlength_ms\x18\x08 \x01(\r\x12\x16\n\x0ethumbnail_path\x18\t \x01(\t\"p\n*CSteamTV_GetBroadcastChannelClips_Response\x12*\n\x05\x63lips\x18\x01 \x03(\x0b\x32\x1b.CSteamTV_BroadcastClipInfo\x12\x16\n\x0ethumbnail_host\x18\x02 \x01(\t\"W\n\'CSteamTV_ReportBroadcastChannel_Request\x12\x1c\n\x14\x62roadcast_channel_id\x18\x01 \x01(\x06\x12\x0e\n\x06reason\x18\x02 \x01(\t\"*\n(CSteamTV_ReportBroadcastChannel_Response\"O\n/CSteamTV_GetBroadcastChannelInteraction_Request\x12\x1c\n\x14\x62roadcast_channel_id\x18\x01 \x01(\x06\"^\n0CSteamTV_GetBroadcastChannelInteraction_Response\x12\x13\n\x0bis_followed\x18\x01 \x01(\x08\x12\x15\n\ris_subscribed\x18\x02 \x01(\x08\"\x7f\n\x19\x43SteamTV_GetGames_Request\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x44\n\talgorithm\x18\x02 \x01(\x0e\x32\x13.EGetGamesAlgorithm:\x1ck_EGetGamesAlgorithm_Default\x12\r\n\x05\x63ount\x18\x03 \x01(\r\"\xb5\x01\n\rCSteamTV_Game\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\r\n\x05image\x18\x03 \x01(\t\x12\x0f\n\x07viewers\x18\x04 \x01(\x04\x12+\n\x08\x63hannels\x18\x05 \x03(\x0b\x32\x19.GetBroadcastChannelEntry\x12\x14\n\x0crelease_date\x18\x06 \x01(\t\x12\x11\n\tdeveloper\x18\x07 \x01(\t\x12\x11\n\tpublisher\x18\x08 \x01(\t\"=\n\x1a\x43SteamTV_GetGames_Response\x12\x1f\n\x07results\x18\x01 \x03(\x0b\x32\x0e.CSteamTV_Game\"\x88\x01\n\x1c\x43SteamTV_GetChannels_Request\x12J\n\talgorithm\x18\x01 \x01(\x0e\x32\x16.EGetChannelsAlgorithm:\x1fk_EGetChannelsAlgorithm_Default\x12\r\n\x05\x63ount\x18\x02 \x01(\r\x12\r\n\x05\x61ppid\x18\x03 \x01(\r\"K\n\x1d\x43SteamTV_GetChannels_Response\x12*\n\x07results\x18\x01 \x03(\x0b\x32\x19.GetBroadcastChannelEntry\"\x87\x01\n\x1b\x43SteamTV_AddChatBan_Request\x12\x1c\n\x14\x62roadcast_channel_id\x18\x01 \x01(\x06\x12\x17\n\x0f\x63hatter_steamid\x18\x02 \x01(\x06\x12\x10\n\x08\x64uration\x18\x03 \x01(\r\x12\x11\n\tpermanent\x18\x04 \x01(\x08\x12\x0c\n\x04undo\x18\x05 \x01(\x08\"\x1e\n\x1c\x43SteamTV_AddChatBan_Response\"<\n\x1c\x43SteamTV_GetChatBans_Request\x12\x1c\n\x14\x62roadcast_channel_id\x18\x01 \x01(\x06\"z\n\x10\x43SteamTV_ChatBan\x12\x16\n\x0eissuer_steamid\x18\x01 \x01(\x06\x12\x17\n\x0f\x63hatter_steamid\x18\x02 \x01(\x06\x12\x14\n\x0ctime_expires\x18\x03 \x01(\t\x12\x11\n\tpermanent\x18\x04 \x01(\x08\x12\x0c\n\x04name\x18\x05 \x01(\t\"C\n\x1d\x43SteamTV_GetChatBans_Response\x12\"\n\x07results\x18\x01 \x03(\x0b\x32\x11.CSteamTV_ChatBan\"j\n!CSteamTV_AddChatModerator_Request\x12\x1c\n\x14\x62roadcast_channel_id\x18\x01 \x01(\x06\x12\x19\n\x11moderator_steamid\x18\x02 \x01(\x06\x12\x0c\n\x04undo\x18\x03 \x01(\x08\"$\n\"CSteamTV_AddChatModerator_Response\"B\n\"CSteamTV_GetChatModerators_Request\x12\x1c\n\x14\x62roadcast_channel_id\x18\x01 \x01(\x06\"7\n\x16\x43SteamTV_ChatModerator\x12\x0f\n\x07steamid\x18\x01 \x01(\x06\x12\x0c\n\x04name\x18\x02 \x01(\t\"O\n#CSteamTV_GetChatModerators_Response\x12(\n\x07results\x18\x01 \x03(\x0b\x32\x17.CSteamTV_ChatModerator\"W\n\x1b\x43SteamTV_AddWordBan_Request\x12\x1c\n\x14\x62roadcast_channel_id\x18\x01 \x01(\x06\x12\x0c\n\x04word\x18\x02 \x01(\t\x12\x0c\n\x04undo\x18\x03 \x01(\x08\"\x1e\n\x1c\x43SteamTV_AddWordBan_Response\"<\n\x1c\x43SteamTV_GetWordBans_Request\x12\x1c\n\x14\x62roadcast_channel_id\x18\x01 \x01(\x06\"0\n\x1d\x43SteamTV_GetWordBans_Response\x12\x0f\n\x07results\x18\x01 \x03(\t\"9\n\x19\x43SteamTV_JoinChat_Request\x12\x1c\n\x14\x62roadcast_channel_id\x18\x01 \x01(\x06\"a\n\x1a\x43SteamTV_JoinChat_Response\x12\x0f\n\x07\x63hat_id\x18\x01 \x01(\x06\x12\x19\n\x11view_url_template\x18\x02 \x01(\t\x12\x17\n\x0f\x66lair_group_ids\x18\x03 \x03(\x04\"\'\n\x17\x43SteamTV_Search_Request\x12\x0c\n\x04term\x18\x01 \x01(\t\"F\n\x18\x43SteamTV_Search_Response\x12*\n\x07results\x18\x01 \x03(\x0b\x32\x19.GetBroadcastChannelEntry\")\n\'CSteamTV_GetSteamTVUserSettings_Request\"g\n(CSteamTV_GetSteamTVUserSettings_Response\x12\x19\n\x11stream_live_email\x18\x01 \x01(\x08\x12 \n\x18stream_live_notification\x18\x02 \x01(\x08\"f\n\'CSteamTV_SetSteamTVUserSettings_Request\x12\x19\n\x11stream_live_email\x18\x01 \x01(\x08\x12 \n\x18stream_live_notification\x18\x02 \x01(\x08\"*\n(CSteamTV_SetSteamTVUserSettings_Response\")\n\'CSteamTV_GetMyBroadcastChannels_Request\"V\n(CSteamTV_GetMyBroadcastChannels_Response\x12*\n\x07results\x18\x01 \x03(\x0b\x32\x19.GetBroadcastChannelEntry\"&\n$CSteamTV_GetHomePageContents_Request\"S\n\"CSteamTV_HomePageTemplate_Takeover\x12-\n\nbroadcasts\x18\x01 \x03(\x0b\x32\x19.GetBroadcastChannelEntry\"s\n$CSteamTV_HomePageTemplate_SingleGame\x12-\n\nbroadcasts\x18\x01 \x03(\x0b\x32\x19.GetBroadcastChannelEntry\x12\r\n\x05\x61ppid\x18\x02 \x01(\r\x12\r\n\x05title\x18\x03 \x01(\t\"_\n\rGameListEntry\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x11\n\tgame_name\x18\x02 \x01(\t\x12,\n\tbroadcast\x18\x03 \x01(\x0b\x32\x19.GetBroadcastChannelEntry\"T\n\"CSteamTV_HomePageTemplate_GameList\x12\x1f\n\x07\x65ntries\x18\x01 \x03(\x0b\x32\x0e.GameListEntry\x12\r\n\x05title\x18\x02 \x01(\t\"f\n&CSteamTV_HomePageTemplate_QuickExplore\x12-\n\nbroadcasts\x18\x01 \x03(\x0b\x32\x19.GetBroadcastChannelEntry\x12\r\n\x05title\x18\x02 \x01(\t\"f\n&CSteamTV_HomePageTemplate_ConveyorBelt\x12-\n\nbroadcasts\x18\x01 \x03(\x0b\x32\x19.GetBroadcastChannelEntry\x12\r\n\x05title\x18\x02 \x01(\t\"z\n$CSteamTV_HomePageTemplate_WatchParty\x12,\n\tbroadcast\x18\x01 \x01(\x0b\x32\x19.GetBroadcastChannelEntry\x12\r\n\x05title\x18\x02 \x01(\t\x12\x15\n\rchat_group_id\x18\x03 \x01(\x04\"b\n#CSteamTV_HomePageTemplate_Developer\x12,\n\tbroadcast\x18\x01 \x01(\x0b\x32\x19.GetBroadcastChannelEntry\x12\r\n\x05title\x18\x02 \x01(\t\"0\n\x1f\x43SteamTV_HomePageTemplate_Event\x12\r\n\x05title\x18\x01 \x01(\t\"\xc2\x04\n\x1b\x43SteamTV_HomePageContentRow\x12R\n\rtemplate_type\x18\x01 \x01(\x0e\x32\x18.ESteamTVContentTemplate:!k_ESteamTVContentTemplate_Invalid\x12\x35\n\x08takeover\x18\x02 \x01(\x0b\x32#.CSteamTV_HomePageTemplate_Takeover\x12:\n\x0bsingle_game\x18\x03 \x01(\x0b\x32%.CSteamTV_HomePageTemplate_SingleGame\x12\x36\n\tgame_list\x18\x04 \x01(\x0b\x32#.CSteamTV_HomePageTemplate_GameList\x12>\n\rquick_explore\x18\x05 \x01(\x0b\x32\'.CSteamTV_HomePageTemplate_QuickExplore\x12>\n\rconveyor_belt\x18\x06 \x01(\x0b\x32\'.CSteamTV_HomePageTemplate_ConveyorBelt\x12:\n\x0bwatch_party\x18\x07 \x01(\x0b\x32%.CSteamTV_HomePageTemplate_WatchParty\x12\x37\n\tdeveloper\x18\x08 \x01(\x0b\x32$.CSteamTV_HomePageTemplate_Developer\x12/\n\x05\x65vent\x18\t \x01(\x0b\x32 .CSteamTV_HomePageTemplate_Event\"S\n%CSteamTV_GetHomePageContents_Response\x12*\n\x04rows\x18\x01 \x03(\x0b\x32\x1c.CSteamTV_HomePageContentRow\"M\n!CSteamTV_AppCheer_SingleCheerType\x12\x12\n\ncheer_type\x18\x01 \x01(\r\x12\x14\n\x0c\x63heer_amount\x18\x02 \x01(\r\"x\n\x19\x43SteamTV_AppCheer_Request\x12\x0e\n\x06\x61pp_id\x18\x01 \x01(\r\x12\x17\n\x0f\x63heer_target_id\x18\x02 \x01(\x06\x12\x32\n\x06\x63heers\x18\x03 \x03(\x0b\x32\".CSteamTV_AppCheer_SingleCheerType\":\n\x1a\x43SteamTV_AppCheer_Response\x12\x1c\n\x14\x61ggregation_delay_ms\x18\x01 \x01(\r*\x8a\x02\n\x13\x45\x42roadcastImageType\x12\x1e\n\x1ak_EBroadcastImageType_None\x10\x00\x12!\n\x1dk_EBroadcastImageType_Offline\x10\x01\x12!\n\x1dk_EBroadcastImageType_Standby\x10\x02\x12 \n\x1ck_EBroadcastImageType_Avatar\x10\x03\x12!\n\x1dk_EBroadcastImageType_Summary\x10\x04\x12$\n k_EBroadcastImageType_Background\x10\x05\x12\"\n\x1ek_EBroadcastImageType_Emoticon\x10\x06*\x80\x01\n\x12\x45GetGamesAlgorithm\x12 \n\x1ck_EGetGamesAlgorithm_Default\x10\x01\x12#\n\x1fk_EGetGamesAlgorithm_MostPlayed\x10\x02\x12#\n\x1fk_EGetGamesAlgorithm_PopularNew\x10\x03*\xd5\x01\n\x15\x45GetChannelsAlgorithm\x12#\n\x1fk_EGetChannelsAlgorithm_Default\x10\x01\x12#\n\x1fk_EGetChannelsAlgorithm_Friends\x10\x02\x12$\n k_EGetChannelsAlgorithm_Featured\x10\x03\x12%\n!k_EGetChannelsAlgorithm_Developer\x10\x04\x12%\n!k_EGetChannelsAlgorithm_Following\x10\x05*\x8a\x03\n\x17\x45SteamTVContentTemplate\x12%\n!k_ESteamTVContentTemplate_Invalid\x10\x00\x12&\n\"k_ESteamTVContentTemplate_Takeover\x10\x01\x12(\n$k_ESteamTVContentTemplate_SingleGame\x10\x02\x12&\n\"k_ESteamTVContentTemplate_GameList\x10\x03\x12*\n&k_ESteamTVContentTemplate_QuickExplore\x10\x04\x12*\n&k_ESteamTVContentTemplate_ConveyorBelt\x10\x05\x12(\n$k_ESteamTVContentTemplate_WatchParty\x10\x06\x12\'\n#k_ESteamTVContentTemplate_Developer\x10\x07\x12#\n\x1fk_ESteamTVContentTemplate_Event\x10\x08\x32\xea\x19\n\x07SteamTV\x12m\n\x16\x43reateBroadcastChannel\x12(.CSteamTV_CreateBroadcastChannel_Request\x1a).CSteamTV_CreateBroadcastChannel_Response\x12j\n\x15GetBroadcastChannelID\x12\'.CSteamTV_GetBroadcastChannelID_Request\x1a(.CSteamTV_GetBroadcastChannelID_Response\x12y\n\x1aSetBroadcastChannelProfile\x12,.CSteamTV_SetBroadcastChannelProfile_Request\x1a-.CSteamTV_SetBroadcastChannelProfile_Response\x12y\n\x1aGetBroadcastChannelProfile\x12,.CSteamTV_GetBroadcastChannelProfile_Request\x1a-.CSteamTV_GetBroadcastChannelProfile_Response\x12s\n\x18SetBroadcastChannelImage\x12*.CSteamTV_SetBroadcastChannelImage_Request\x1a+.CSteamTV_SetBroadcastChannelImage_Response\x12v\n\x19GetBroadcastChannelImages\x12+.CSteamTV_GetBroadcastChannelImages_Request\x1a,.CSteamTV_GetBroadcastChannelImages_Response\x12\x85\x01\n\x1eSetBroadcastChannelLinkRegions\x12\x30.CSteamTV_SetBroadcastChannelLinkRegions_Request\x1a\x31.CSteamTV_SetBroadcastChannelLinkRegions_Response\x12s\n\x18GetBroadcastChannelLinks\x12*.CSteamTV_GetBroadcastChannelLinks_Request\x1a+.CSteamTV_GetBroadcastChannelLinks_Response\x12\x88\x01\n\x1fGetBroadcastChannelBroadcasters\x12\x31.CSteamTV_GetBroadcastChannelBroadcasters_Request\x1a\x32.CSteamTV_GetBroadcastChannelBroadcasters_Response\x12\x64\n\x13GetFollowedChannels\x12%.CSteamTV_GetFollowedChannels_Request\x1a&.CSteamTV_GetFollowedChannels_Response\x12j\n\x15GetSubscribedChannels\x12\'.CSteamTV_GetSubscribedChannels_Request\x1a(.CSteamTV_GetSubscribedChannels_Response\x12v\n\x19GetBroadcastChannelStatus\x12+.CSteamTV_GetBroadcastChannelStatus_Request\x1a,.CSteamTV_GetBroadcastChannelStatus_Response\x12m\n\x16\x46ollowBroadcastChannel\x12(.CSteamTV_FollowBroadcastChannel_Request\x1a).CSteamTV_FollowBroadcastChannel_Response\x12v\n\x19SubscribeBroadcastChannel\x12+.CSteamTV_SubscribeBroadcastChannel_Request\x1a,.CSteamTV_SubscribeBroadcastChannel_Response\x12s\n\x18GetBroadcastChannelClips\x12*.CSteamTV_GetBroadcastChannelClips_Request\x1a+.CSteamTV_GetBroadcastChannelClips_Response\x12m\n\x16ReportBroadcastChannel\x12(.CSteamTV_ReportBroadcastChannel_Request\x1a).CSteamTV_ReportBroadcastChannel_Response\x12\x85\x01\n\x1eGetBroadcastChannelInteraction\x12\x30.CSteamTV_GetBroadcastChannelInteraction_Request\x1a\x31.CSteamTV_GetBroadcastChannelInteraction_Response\x12\x43\n\x08GetGames\x12\x1a.CSteamTV_GetGames_Request\x1a\x1b.CSteamTV_GetGames_Response\x12L\n\x0bGetChannels\x12\x1d.CSteamTV_GetChannels_Request\x1a\x1e.CSteamTV_GetChannels_Response\x12I\n\nAddChatBan\x12\x1c.CSteamTV_AddChatBan_Request\x1a\x1d.CSteamTV_AddChatBan_Response\x12L\n\x0bGetChatBans\x12\x1d.CSteamTV_GetChatBans_Request\x1a\x1e.CSteamTV_GetChatBans_Response\x12[\n\x10\x41\x64\x64\x43hatModerator\x12\".CSteamTV_AddChatModerator_Request\x1a#.CSteamTV_AddChatModerator_Response\x12^\n\x11GetChatModerators\x12#.CSteamTV_GetChatModerators_Request\x1a$.CSteamTV_GetChatModerators_Response\x12I\n\nAddWordBan\x12\x1c.CSteamTV_AddWordBan_Request\x1a\x1d.CSteamTV_AddWordBan_Response\x12L\n\x0bGetWordBans\x12\x1d.CSteamTV_GetWordBans_Request\x1a\x1e.CSteamTV_GetWordBans_Response\x12\x43\n\x08JoinChat\x12\x1a.CSteamTV_JoinChat_Request\x1a\x1b.CSteamTV_JoinChat_Response\x12=\n\x06Search\x12\x18.CSteamTV_Search_Request\x1a\x19.CSteamTV_Search_Response\x12m\n\x16GetSteamTVUserSettings\x12(.CSteamTV_GetSteamTVUserSettings_Request\x1a).CSteamTV_GetSteamTVUserSettings_Response\x12m\n\x16SetSteamTVUserSettings\x12(.CSteamTV_SetSteamTVUserSettings_Request\x1a).CSteamTV_SetSteamTVUserSettings_Response\x12m\n\x16GetMyBroadcastChannels\x12(.CSteamTV_GetMyBroadcastChannels_Request\x1a).CSteamTV_GetMyBroadcastChannels_Response\x12\x64\n\x13GetHomePageContents\x12%.CSteamTV_GetHomePageContents_Request\x1a&.CSteamTV_GetHomePageContents_Response\x12\x43\n\x08\x41ppCheer\x12\x1a.CSteamTV_AppCheer_Request\x1a\x1b.CSteamTV_AppCheer_ResponseB\x03\x90\x01\x01')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'steammessages_steamtv_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\220\001\001'
  _EBROADCASTIMAGETYPE._serialized_start=8810
  _EBROADCASTIMAGETYPE._serialized_end=9076
  _EGETGAMESALGORITHM._serialized_start=9079
  _EGETGAMESALGORITHM._serialized_end=9207
  _EGETCHANNELSALGORITHM._serialized_start=9210
  _EGETCHANNELSALGORITHM._serialized_end=9423
  _ESTEAMTVCONTENTTEMPLATE._serialized_start=9426
  _ESTEAMTVCONTENTTEMPLATE._serialized_end=9820
  _CSTEAMTV_CREATEBROADCASTCHANNEL_REQUEST._serialized_start=91
  _CSTEAMTV_CREATEBROADCASTCHANNEL_REQUEST._serialized_end=153
  _CSTEAMTV_CREATEBROADCASTCHANNEL_RESPONSE._serialized_start=155
  _CSTEAMTV_CREATEBROADCASTCHANNEL_RESPONSE._serialized_end=227
  _CSTEAMTV_GETBROADCASTCHANNELID_REQUEST._serialized_start=229
  _CSTEAMTV_GETBROADCASTCHANNELID_REQUEST._serialized_end=290
  _CSTEAMTV_GETBROADCASTCHANNELID_RESPONSE._serialized_start=292
  _CSTEAMTV_GETBROADCASTCHANNELID_RESPONSE._serialized_end=401
  _CSTEAMTV_SETBROADCASTCHANNELPROFILE_REQUEST._serialized_start=404
  _CSTEAMTV_SETBROADCASTCHANNELPROFILE_REQUEST._serialized_end=616
  _CSTEAMTV_SETBROADCASTCHANNELPROFILE_RESPONSE._serialized_start=618
  _CSTEAMTV_SETBROADCASTCHANNELPROFILE_RESPONSE._serialized_end=664
  _CSTEAMTV_GETBROADCASTCHANNELPROFILE_REQUEST._serialized_start=666
  _CSTEAMTV_GETBROADCASTCHANNELPROFILE_REQUEST._serialized_end=741
  _CSTEAMTV_GETBROADCASTCHANNELPROFILE_RESPONSE._serialized_start=744
  _CSTEAMTV_GETBROADCASTCHANNELPROFILE_RESPONSE._serialized_end=972
  _CSTEAMTV_SETBROADCASTCHANNELIMAGE_REQUEST._serialized_start=975
  _CSTEAMTV_SETBROADCASTCHANNELIMAGE_REQUEST._serialized_end=1258
  _CSTEAMTV_SETBROADCASTCHANNELIMAGE_RESPONSE._serialized_start=1260
  _CSTEAMTV_SETBROADCASTCHANNELIMAGE_RESPONSE._serialized_end=1332
  _CSTEAMTV_GETBROADCASTCHANNELIMAGES_REQUEST._serialized_start=1334
  _CSTEAMTV_GETBROADCASTCHANNELIMAGES_REQUEST._serialized_end=1451
  _CSTEAMTV_GETBROADCASTCHANNELIMAGES_RESPONSE._serialized_start=1454
  _CSTEAMTV_GETBROADCASTCHANNELIMAGES_RESPONSE._serialized_end=1689
  _CSTEAMTV_GETBROADCASTCHANNELIMAGES_RESPONSE_IMAGES._serialized_start=1570
  _CSTEAMTV_GETBROADCASTCHANNELIMAGES_RESPONSE_IMAGES._serialized_end=1689
  _CSTEAMTV_SETBROADCASTCHANNELLINKREGIONS_REQUEST._serialized_start=1692
  _CSTEAMTV_SETBROADCASTCHANNELLINKREGIONS_REQUEST._serialized_end=1968
  _CSTEAMTV_SETBROADCASTCHANNELLINKREGIONS_REQUEST_LINKS._serialized_start=1844
  _CSTEAMTV_SETBROADCASTCHANNELLINKREGIONS_REQUEST_LINKS._serialized_end=1968
  _CSTEAMTV_SETBROADCASTCHANNELLINKREGIONS_RESPONSE._serialized_start=1970
  _CSTEAMTV_SETBROADCASTCHANNELLINKREGIONS_RESPONSE._serialized_end=2020
  _CSTEAMTV_GETBROADCASTCHANNELLINKS_REQUEST._serialized_start=2022
  _CSTEAMTV_GETBROADCASTCHANNELLINKS_REQUEST._serialized_end=2095
  _CSTEAMTV_GETBROADCASTCHANNELLINKS_RESPONSE._serialized_start=2098
  _CSTEAMTV_GETBROADCASTCHANNELLINKS_RESPONSE._serialized_end=2334
  _CSTEAMTV_GETBROADCASTCHANNELLINKS_RESPONSE_LINKS._serialized_start=1844
  _CSTEAMTV_GETBROADCASTCHANNELLINKS_RESPONSE_LINKS._serialized_end=1968
  _CSTEAMTV_GETBROADCASTCHANNELBROADCASTERS_REQUEST._serialized_start=2336
  _CSTEAMTV_GETBROADCASTCHANNELBROADCASTERS_REQUEST._serialized_end=2416
  _CSTEAMTV_GETBROADCASTCHANNELBROADCASTERS_RESPONSE._serialized_start=2419
  _CSTEAMTV_GETBROADCASTCHANNELBROADCASTERS_RESPONSE._serialized_end=2622
  _CSTEAMTV_GETBROADCASTCHANNELBROADCASTERS_RESPONSE_BROADCASTER._serialized_start=2558
  _CSTEAMTV_GETBROADCASTCHANNELBROADCASTERS_RESPONSE_BROADCASTER._serialized_end=2622
  _CSTEAMTV_GETFOLLOWEDCHANNELS_REQUEST._serialized_start=2624
  _CSTEAMTV_GETFOLLOWEDCHANNELS_REQUEST._serialized_end=2662
  _GETBROADCASTCHANNELENTRY._serialized_start=2665
  _GETBROADCASTCHANNELENTRY._serialized_end=3073
  _CSTEAMTV_GETFOLLOWEDCHANNELS_RESPONSE._serialized_start=3075
  _CSTEAMTV_GETFOLLOWEDCHANNELS_RESPONSE._serialized_end=3158
  _CSTEAMTV_GETSUBSCRIBEDCHANNELS_REQUEST._serialized_start=3160
  _CSTEAMTV_GETSUBSCRIBEDCHANNELS_REQUEST._serialized_end=3200
  _CSTEAMTV_GETSUBSCRIBEDCHANNELS_RESPONSE._serialized_start=3202
  _CSTEAMTV_GETSUBSCRIBEDCHANNELS_RESPONSE._serialized_end=3287
  _CSTEAMTV_GETBROADCASTCHANNELSTATUS_REQUEST._serialized_start=3289
  _CSTEAMTV_GETBROADCASTCHANNELSTATUS_REQUEST._serialized_end=3363
  _CSTEAMTV_GETBROADCASTCHANNELSTATUS_RESPONSE._serialized_start=3366
  _CSTEAMTV_GETBROADCASTCHANNELSTATUS_RESPONSE._serialized_end=3639
  _CSTEAMTV_FOLLOWBROADCASTCHANNEL_REQUEST._serialized_start=3641
  _CSTEAMTV_FOLLOWBROADCASTCHANNEL_REQUEST._serialized_end=3726
  _CSTEAMTV_FOLLOWBROADCASTCHANNEL_RESPONSE._serialized_start=3728
  _CSTEAMTV_FOLLOWBROADCASTCHANNEL_RESPONSE._serialized_end=3791
  _CSTEAMTV_SUBSCRIBEBROADCASTCHANNEL_REQUEST._serialized_start=3793
  _CSTEAMTV_SUBSCRIBEBROADCASTCHANNEL_REQUEST._serialized_end=3867
  _CSTEAMTV_SUBSCRIBEBROADCASTCHANNEL_RESPONSE._serialized_start=3869
  _CSTEAMTV_SUBSCRIBEBROADCASTCHANNEL_RESPONSE._serialized_end=3937
  _CSTEAMTV_GETBROADCASTCHANNELCLIPS_REQUEST._serialized_start=3939
  _CSTEAMTV_GETBROADCASTCHANNELCLIPS_REQUEST._serialized_end=4012
  _CSTEAMTV_BROADCASTCLIPINFO._serialized_start=4015
  _CSTEAMTV_BROADCASTCLIPINFO._serialized_end=4249
  _CSTEAMTV_GETBROADCASTCHANNELCLIPS_RESPONSE._serialized_start=4251
  _CSTEAMTV_GETBROADCASTCHANNELCLIPS_RESPONSE._serialized_end=4363
  _CSTEAMTV_REPORTBROADCASTCHANNEL_REQUEST._serialized_start=4365
  _CSTEAMTV_REPORTBROADCASTCHANNEL_REQUEST._serialized_end=4452
  _CSTEAMTV_REPORTBROADCASTCHANNEL_RESPONSE._serialized_start=4454
  _CSTEAMTV_REPORTBROADCASTCHANNEL_RESPONSE._serialized_end=4496
  _CSTEAMTV_GETBROADCASTCHANNELINTERACTION_REQUEST._serialized_start=4498
  _CSTEAMTV_GETBROADCASTCHANNELINTERACTION_REQUEST._serialized_end=4577
  _CSTEAMTV_GETBROADCASTCHANNELINTERACTION_RESPONSE._serialized_start=4579
  _CSTEAMTV_GETBROADCASTCHANNELINTERACTION_RESPONSE._serialized_end=4673
  _CSTEAMTV_GETGAMES_REQUEST._serialized_start=4675
  _CSTEAMTV_GETGAMES_REQUEST._serialized_end=4802
  _CSTEAMTV_GAME._serialized_start=4805
  _CSTEAMTV_GAME._serialized_end=4986
  _CSTEAMTV_GETGAMES_RESPONSE._serialized_start=4988
  _CSTEAMTV_GETGAMES_RESPONSE._serialized_end=5049
  _CSTEAMTV_GETCHANNELS_REQUEST._serialized_start=5052
  _CSTEAMTV_GETCHANNELS_REQUEST._serialized_end=5188
  _CSTEAMTV_GETCHANNELS_RESPONSE._serialized_start=5190
  _CSTEAMTV_GETCHANNELS_RESPONSE._serialized_end=5265
  _CSTEAMTV_ADDCHATBAN_REQUEST._serialized_start=5268
  _CSTEAMTV_ADDCHATBAN_REQUEST._serialized_end=5403
  _CSTEAMTV_ADDCHATBAN_RESPONSE._serialized_start=5405
  _CSTEAMTV_ADDCHATBAN_RESPONSE._serialized_end=5435
  _CSTEAMTV_GETCHATBANS_REQUEST._serialized_start=5437
  _CSTEAMTV_GETCHATBANS_REQUEST._serialized_end=5497
  _CSTEAMTV_CHATBAN._serialized_start=5499
  _CSTEAMTV_CHATBAN._serialized_end=5621
  _CSTEAMTV_GETCHATBANS_RESPONSE._serialized_start=5623
  _CSTEAMTV_GETCHATBANS_RESPONSE._serialized_end=5690
  _CSTEAMTV_ADDCHATMODERATOR_REQUEST._serialized_start=5692
  _CSTEAMTV_ADDCHATMODERATOR_REQUEST._serialized_end=5798
  _CSTEAMTV_ADDCHATMODERATOR_RESPONSE._serialized_start=5800
  _CSTEAMTV_ADDCHATMODERATOR_RESPONSE._serialized_end=5836
  _CSTEAMTV_GETCHATMODERATORS_REQUEST._serialized_start=5838
  _CSTEAMTV_GETCHATMODERATORS_REQUEST._serialized_end=5904
  _CSTEAMTV_CHATMODERATOR._serialized_start=5906
  _CSTEAMTV_CHATMODERATOR._serialized_end=5961
  _CSTEAMTV_GETCHATMODERATORS_RESPONSE._serialized_start=5963
  _CSTEAMTV_GETCHATMODERATORS_RESPONSE._serialized_end=6042
  _CSTEAMTV_ADDWORDBAN_REQUEST._serialized_start=6044
  _CSTEAMTV_ADDWORDBAN_REQUEST._serialized_end=6131
  _CSTEAMTV_ADDWORDBAN_RESPONSE._serialized_start=6133
  _CSTEAMTV_ADDWORDBAN_RESPONSE._serialized_end=6163
  _CSTEAMTV_GETWORDBANS_REQUEST._serialized_start=6165
  _CSTEAMTV_GETWORDBANS_REQUEST._serialized_end=6225
  _CSTEAMTV_GETWORDBANS_RESPONSE._serialized_start=6227
  _CSTEAMTV_GETWORDBANS_RESPONSE._serialized_end=6275
  _CSTEAMTV_JOINCHAT_REQUEST._serialized_start=6277
  _CSTEAMTV_JOINCHAT_REQUEST._serialized_end=6334
  _CSTEAMTV_JOINCHAT_RESPONSE._serialized_start=6336
  _CSTEAMTV_JOINCHAT_RESPONSE._serialized_end=6433
  _CSTEAMTV_SEARCH_REQUEST._serialized_start=6435
  _CSTEAMTV_SEARCH_REQUEST._serialized_end=6474
  _CSTEAMTV_SEARCH_RESPONSE._serialized_start=6476
  _CSTEAMTV_SEARCH_RESPONSE._serialized_end=6546
  _CSTEAMTV_GETSTEAMTVUSERSETTINGS_REQUEST._serialized_start=6548
  _CSTEAMTV_GETSTEAMTVUSERSETTINGS_REQUEST._serialized_end=6589
  _CSTEAMTV_GETSTEAMTVUSERSETTINGS_RESPONSE._serialized_start=6591
  _CSTEAMTV_GETSTEAMTVUSERSETTINGS_RESPONSE._serialized_end=6694
  _CSTEAMTV_SETSTEAMTVUSERSETTINGS_REQUEST._serialized_start=6696
  _CSTEAMTV_SETSTEAMTVUSERSETTINGS_REQUEST._serialized_end=6798
  _CSTEAMTV_SETSTEAMTVUSERSETTINGS_RESPONSE._serialized_start=6800
  _CSTEAMTV_SETSTEAMTVUSERSETTINGS_RESPONSE._serialized_end=6842
  _CSTEAMTV_GETMYBROADCASTCHANNELS_REQUEST._serialized_start=6844
  _CSTEAMTV_GETMYBROADCASTCHANNELS_REQUEST._serialized_end=6885
  _CSTEAMTV_GETMYBROADCASTCHANNELS_RESPONSE._serialized_start=6887
  _CSTEAMTV_GETMYBROADCASTCHANNELS_RESPONSE._serialized_end=6973
  _CSTEAMTV_GETHOMEPAGECONTENTS_REQUEST._serialized_start=6975
  _CSTEAMTV_GETHOMEPAGECONTENTS_REQUEST._serialized_end=7013
  _CSTEAMTV_HOMEPAGETEMPLATE_TAKEOVER._serialized_start=7015
  _CSTEAMTV_HOMEPAGETEMPLATE_TAKEOVER._serialized_end=7098
  _CSTEAMTV_HOMEPAGETEMPLATE_SINGLEGAME._serialized_start=7100
  _CSTEAMTV_HOMEPAGETEMPLATE_SINGLEGAME._serialized_end=7215
  _GAMELISTENTRY._serialized_start=7217
  _GAMELISTENTRY._serialized_end=7312
  _CSTEAMTV_HOMEPAGETEMPLATE_GAMELIST._serialized_start=7314
  _CSTEAMTV_HOMEPAGETEMPLATE_GAMELIST._serialized_end=7398
  _CSTEAMTV_HOMEPAGETEMPLATE_QUICKEXPLORE._serialized_start=7400
  _CSTEAMTV_HOMEPAGETEMPLATE_QUICKEXPLORE._serialized_end=7502
  _CSTEAMTV_HOMEPAGETEMPLATE_CONVEYORBELT._serialized_start=7504
  _CSTEAMTV_HOMEPAGETEMPLATE_CONVEYORBELT._serialized_end=7606
  _CSTEAMTV_HOMEPAGETEMPLATE_WATCHPARTY._serialized_start=7608
  _CSTEAMTV_HOMEPAGETEMPLATE_WATCHPARTY._serialized_end=7730
  _CSTEAMTV_HOMEPAGETEMPLATE_DEVELOPER._serialized_start=7732
  _CSTEAMTV_HOMEPAGETEMPLATE_DEVELOPER._serialized_end=7830
  _CSTEAMTV_HOMEPAGETEMPLATE_EVENT._serialized_start=7832
  _CSTEAMTV_HOMEPAGETEMPLATE_EVENT._serialized_end=7880
  _CSTEAMTV_HOMEPAGECONTENTROW._serialized_start=7883
  _CSTEAMTV_HOMEPAGECONTENTROW._serialized_end=8461
  _CSTEAMTV_GETHOMEPAGECONTENTS_RESPONSE._serialized_start=8463
  _CSTEAMTV_GETHOMEPAGECONTENTS_RESPONSE._serialized_end=8546
  _CSTEAMTV_APPCHEER_SINGLECHEERTYPE._serialized_start=8548
  _CSTEAMTV_APPCHEER_SINGLECHEERTYPE._serialized_end=8625
  _CSTEAMTV_APPCHEER_REQUEST._serialized_start=8627
  _CSTEAMTV_APPCHEER_REQUEST._serialized_end=8747
  _CSTEAMTV_APPCHEER_RESPONSE._serialized_start=8749
  _CSTEAMTV_APPCHEER_RESPONSE._serialized_end=8807
  _STEAMTV._serialized_start=9823
  _STEAMTV._serialized_end=13129
_builder.BuildServices(DESCRIPTOR, 'steammessages_steamtv_pb2', globals())
# @@protoc_insertion_point(module_scope)
