# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: steammessages_useraccount.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import steam.protobufs.steammessages_base_pb2 as steammessages__base__pb2
import steam.protobufs.steammessages_unified_base_pb2 as steammessages__unified__base__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1fsteammessages_useraccount.proto\x1a\x18steammessages_base.proto\x1a steammessages_unified_base.proto\"P\n8CUserAccount_GetAvailableValveDiscountPromotions_Request\x12\x14\n\x0c\x63ountry_code\x18\x01 \x01(\t\"\x85\x04\n9CUserAccount_GetAvailableValveDiscountPromotions_Response\x12l\n\npromotions\x18\x01 \x03(\x0b\x32X.CUserAccount_GetAvailableValveDiscountPromotions_Response.ValveDiscountPromotionDetails\x1a\xd9\x02\n\x1dValveDiscountPromotionDetails\x12\x13\n\x0bpromotionid\x18\x01 \x01(\r\x12\x1d\n\x15promotion_description\x18\x02 \x01(\t\x12\x1b\n\x13minimum_cart_amount\x18\x03 \x01(\x03\x12\'\n\x1fminimum_cart_amount_for_display\x18\x04 \x01(\x03\x12\x17\n\x0f\x64iscount_amount\x18\x05 \x01(\x03\x12\x15\n\rcurrency_code\x18\x06 \x01(\x05\x12\x1b\n\x13\x61vailable_use_count\x18\x07 \x01(\x05\x12!\n\x19promotional_discount_type\x18\x08 \x01(\x05\x12\x19\n\x11loyalty_reward_id\x18\t \x01(\x05\x12\x1c\n\x14localized_name_token\x18\n \x01(\t\x12\x15\n\rmax_use_count\x18\x0b \x01(\x05\"\x8a\x01\n+CUserAccount_GetClientWalletDetails_Request\x12\x1e\n\x16include_balance_in_usd\x18\x01 \x01(\x08\x12\x18\n\rwallet_region\x18\x02 \x01(\x05:\x01\x31\x12!\n\x19include_formatted_balance\x18\x03 \x01(\x08\"\xb5\x04\n&CUserAccount_GetWalletDetails_Response\x12\x12\n\nhas_wallet\x18\x01 \x01(\x08\x12\x19\n\x11user_country_code\x18\x02 \x01(\t\x12\x1b\n\x13wallet_country_code\x18\x03 \x01(\t\x12\x14\n\x0cwallet_state\x18\x04 \x01(\t\x12\x0f\n\x07\x62\x61lance\x18\x05 \x01(\x03\x12\x17\n\x0f\x64\x65layed_balance\x18\x06 \x01(\x03\x12\x15\n\rcurrency_code\x18\x07 \x01(\x05\x12\x1c\n\x14time_most_recent_txn\x18\x08 \x01(\r\x12\x19\n\x11most_recent_txnid\x18\t \x01(\x04\x12\x16\n\x0e\x62\x61lance_in_usd\x18\n \x01(\x03\x12\x1e\n\x16\x64\x65layed_balance_in_usd\x18\x0b \x01(\x03\x12#\n\x1bhas_wallet_in_other_regions\x18\x0c \x01(\x08\x12\x15\n\rother_regions\x18\r \x03(\x05\x12\x19\n\x11\x66ormatted_balance\x18\x0e \x01(\t\x12!\n\x19\x66ormatted_delayed_balance\x18\x0f \x01(\t\x12*\n\"delayed_balance_available_min_time\x18\x10 \x01(\x05\x12*\n\"delayed_balance_available_max_time\x18\x11 \x01(\x05\x12%\n\x1d\x64\x65layed_balance_newest_source\x18\x12 \x01(\x05\"+\n)CUserAccount_GetAccountLinkStatus_Request\"}\n*CUserAccount_GetAccountLinkStatus_Response\x12\x0c\n\x04pwid\x18\x01 \x01(\r\x12\x1d\n\x15identity_verification\x18\x02 \x01(\r\x12\"\n\x1aperformed_age_verification\x18\x03 \x01(\x08\"9\n(CUserAccount_CancelLicenseForApp_Request\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\"+\n)CUserAccount_CancelLicenseForApp_Response\"6\n#CUserAccount_GetUserCountry_Request\x12\x0f\n\x07steamid\x18\x01 \x01(\x06\"7\n$CUserAccount_GetUserCountry_Response\x12\x0f\n\x07\x63ountry\x18\x01 \x01(\t\"r\n,CUserAccount_CreateFriendInviteToken_Request\x12\x14\n\x0cinvite_limit\x18\x01 \x01(\r\x12\x17\n\x0finvite_duration\x18\x02 \x01(\r\x12\x13\n\x0binvite_note\x18\x03 \x01(\t\"\x99\x01\n-CUserAccount_CreateFriendInviteToken_Response\x12\x14\n\x0cinvite_token\x18\x01 \x01(\t\x12\x14\n\x0cinvite_limit\x18\x02 \x01(\x04\x12\x17\n\x0finvite_duration\x18\x03 \x01(\x04\x12\x14\n\x0ctime_created\x18\x04 \x01(\x07\x12\r\n\x05valid\x18\x05 \x01(\x08\",\n*CUserAccount_GetFriendInviteTokens_Request\"m\n+CUserAccount_GetFriendInviteTokens_Response\x12>\n\x06tokens\x18\x01 \x03(\x0b\x32..CUserAccount_CreateFriendInviteToken_Response\"S\n*CUserAccount_ViewFriendInviteToken_Request\x12\x0f\n\x07steamid\x18\x01 \x01(\x06\x12\x14\n\x0cinvite_token\x18\x02 \x01(\t\"f\n+CUserAccount_ViewFriendInviteToken_Response\x12\r\n\x05valid\x18\x01 \x01(\x08\x12\x0f\n\x07steamid\x18\x02 \x01(\x04\x12\x17\n\x0finvite_duration\x18\x03 \x01(\x04\"U\n,CUserAccount_RedeemFriendInviteToken_Request\x12\x0f\n\x07steamid\x18\x01 \x01(\x06\x12\x14\n\x0cinvite_token\x18\x02 \x01(\t\"/\n-CUserAccount_RedeemFriendInviteToken_Response\"D\n,CUserAccount_RevokeFriendInviteToken_Request\x12\x14\n\x0cinvite_token\x18\x01 \x01(\t\"/\n-CUserAccount_RevokeFriendInviteToken_Response\">\n\'CUserAccount_RegisterCompatTool_Request\x12\x13\n\x0b\x63ompat_tool\x18\x01 \x01(\r\"*\n(CUserAccount_RegisterCompatTool_Response\"w\n.CEmbeddedClient_AuthorizeCurrentDevice_Request\x12\x0f\n\x07steamid\x18\x01 \x01(\x06\x12\r\n\x05\x61ppid\x18\x02 \x01(\r\x12\x13\n\x0b\x64\x65vice_info\x18\x03 \x01(\t\x12\x10\n\x08\x64\x65viceid\x18\x04 \x01(\r\"`\n\x15\x43\x45mbeddedClient_Token\x12\x0f\n\x07steamid\x18\x01 \x01(\x06\x12\x14\n\x0c\x63lient_token\x18\x02 \x01(\x0c\x12\x0e\n\x06\x65xpiry\x18\x03 \x01(\r\x12\x10\n\x08\x64\x65viceid\x18\x04 \x01(\r\"a\n(CEmbeddedClient_AuthorizeDevice_Response\x12\x0e\n\x06result\x18\x01 \x01(\r\x12%\n\x05token\x18\x02 \x01(\x0b\x32\x16.CEmbeddedClient_Token2\x9c\n\n\x0bUserAccount\x12\x9c\x01\n#GetAvailableValveDiscountPromotions\x12\x39.CUserAccount_GetAvailableValveDiscountPromotions_Request\x1a:.CUserAccount_GetAvailableValveDiscountPromotions_Response\x12o\n\x16GetClientWalletDetails\x12,.CUserAccount_GetClientWalletDetails_Request\x1a\'.CUserAccount_GetWalletDetails_Response\x12o\n\x14GetAccountLinkStatus\x12*.CUserAccount_GetAccountLinkStatus_Request\x1a+.CUserAccount_GetAccountLinkStatus_Response\x12l\n\x13\x43\x61ncelLicenseForApp\x12).CUserAccount_CancelLicenseForApp_Request\x1a*.CUserAccount_CancelLicenseForApp_Response\x12]\n\x0eGetUserCountry\x12$.CUserAccount_GetUserCountry_Request\x1a%.CUserAccount_GetUserCountry_Response\x12x\n\x17\x43reateFriendInviteToken\x12-.CUserAccount_CreateFriendInviteToken_Request\x1a..CUserAccount_CreateFriendInviteToken_Response\x12r\n\x15GetFriendInviteTokens\x12+.CUserAccount_GetFriendInviteTokens_Request\x1a,.CUserAccount_GetFriendInviteTokens_Response\x12r\n\x15ViewFriendInviteToken\x12+.CUserAccount_ViewFriendInviteToken_Request\x1a,.CUserAccount_ViewFriendInviteToken_Response\x12x\n\x17RedeemFriendInviteToken\x12-.CUserAccount_RedeemFriendInviteToken_Request\x1a..CUserAccount_RedeemFriendInviteToken_Response\x12x\n\x17RevokeFriendInviteToken\x12-.CUserAccount_RevokeFriendInviteToken_Request\x1a..CUserAccount_RevokeFriendInviteToken_Response\x12i\n\x12RegisterCompatTool\x12(.CUserAccount_RegisterCompatTool_Request\x1a).CUserAccount_RegisterCompatTool_Response2\x86\x01\n\x0e\x45mbeddedClient\x12t\n\x16\x41uthorizeCurrentDevice\x12/.CEmbeddedClient_AuthorizeCurrentDevice_Request\x1a).CEmbeddedClient_AuthorizeDevice_ResponseB\x03\x90\x01\x01')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'steammessages_useraccount_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\220\001\001'
  _CUSERACCOUNT_GETAVAILABLEVALVEDISCOUNTPROMOTIONS_REQUEST._serialized_start=95
  _CUSERACCOUNT_GETAVAILABLEVALVEDISCOUNTPROMOTIONS_REQUEST._serialized_end=175
  _CUSERACCOUNT_GETAVAILABLEVALVEDISCOUNTPROMOTIONS_RESPONSE._serialized_start=178
  _CUSERACCOUNT_GETAVAILABLEVALVEDISCOUNTPROMOTIONS_RESPONSE._serialized_end=695
  _CUSERACCOUNT_GETAVAILABLEVALVEDISCOUNTPROMOTIONS_RESPONSE_VALVEDISCOUNTPROMOTIONDETAILS._serialized_start=350
  _CUSERACCOUNT_GETAVAILABLEVALVEDISCOUNTPROMOTIONS_RESPONSE_VALVEDISCOUNTPROMOTIONDETAILS._serialized_end=695
  _CUSERACCOUNT_GETCLIENTWALLETDETAILS_REQUEST._serialized_start=698
  _CUSERACCOUNT_GETCLIENTWALLETDETAILS_REQUEST._serialized_end=836
  _CUSERACCOUNT_GETWALLETDETAILS_RESPONSE._serialized_start=839
  _CUSERACCOUNT_GETWALLETDETAILS_RESPONSE._serialized_end=1404
  _CUSERACCOUNT_GETACCOUNTLINKSTATUS_REQUEST._serialized_start=1406
  _CUSERACCOUNT_GETACCOUNTLINKSTATUS_REQUEST._serialized_end=1449
  _CUSERACCOUNT_GETACCOUNTLINKSTATUS_RESPONSE._serialized_start=1451
  _CUSERACCOUNT_GETACCOUNTLINKSTATUS_RESPONSE._serialized_end=1576
  _CUSERACCOUNT_CANCELLICENSEFORAPP_REQUEST._serialized_start=1578
  _CUSERACCOUNT_CANCELLICENSEFORAPP_REQUEST._serialized_end=1635
  _CUSERACCOUNT_CANCELLICENSEFORAPP_RESPONSE._serialized_start=1637
  _CUSERACCOUNT_CANCELLICENSEFORAPP_RESPONSE._serialized_end=1680
  _CUSERACCOUNT_GETUSERCOUNTRY_REQUEST._serialized_start=1682
  _CUSERACCOUNT_GETUSERCOUNTRY_REQUEST._serialized_end=1736
  _CUSERACCOUNT_GETUSERCOUNTRY_RESPONSE._serialized_start=1738
  _CUSERACCOUNT_GETUSERCOUNTRY_RESPONSE._serialized_end=1793
  _CUSERACCOUNT_CREATEFRIENDINVITETOKEN_REQUEST._serialized_start=1795
  _CUSERACCOUNT_CREATEFRIENDINVITETOKEN_REQUEST._serialized_end=1909
  _CUSERACCOUNT_CREATEFRIENDINVITETOKEN_RESPONSE._serialized_start=1912
  _CUSERACCOUNT_CREATEFRIENDINVITETOKEN_RESPONSE._serialized_end=2065
  _CUSERACCOUNT_GETFRIENDINVITETOKENS_REQUEST._serialized_start=2067
  _CUSERACCOUNT_GETFRIENDINVITETOKENS_REQUEST._serialized_end=2111
  _CUSERACCOUNT_GETFRIENDINVITETOKENS_RESPONSE._serialized_start=2113
  _CUSERACCOUNT_GETFRIENDINVITETOKENS_RESPONSE._serialized_end=2222
  _CUSERACCOUNT_VIEWFRIENDINVITETOKEN_REQUEST._serialized_start=2224
  _CUSERACCOUNT_VIEWFRIENDINVITETOKEN_REQUEST._serialized_end=2307
  _CUSERACCOUNT_VIEWFRIENDINVITETOKEN_RESPONSE._serialized_start=2309
  _CUSERACCOUNT_VIEWFRIENDINVITETOKEN_RESPONSE._serialized_end=2411
  _CUSERACCOUNT_REDEEMFRIENDINVITETOKEN_REQUEST._serialized_start=2413
  _CUSERACCOUNT_REDEEMFRIENDINVITETOKEN_REQUEST._serialized_end=2498
  _CUSERACCOUNT_REDEEMFRIENDINVITETOKEN_RESPONSE._serialized_start=2500
  _CUSERACCOUNT_REDEEMFRIENDINVITETOKEN_RESPONSE._serialized_end=2547
  _CUSERACCOUNT_REVOKEFRIENDINVITETOKEN_REQUEST._serialized_start=2549
  _CUSERACCOUNT_REVOKEFRIENDINVITETOKEN_REQUEST._serialized_end=2617
  _CUSERACCOUNT_REVOKEFRIENDINVITETOKEN_RESPONSE._serialized_start=2619
  _CUSERACCOUNT_REVOKEFRIENDINVITETOKEN_RESPONSE._serialized_end=2666
  _CUSERACCOUNT_REGISTERCOMPATTOOL_REQUEST._serialized_start=2668
  _CUSERACCOUNT_REGISTERCOMPATTOOL_REQUEST._serialized_end=2730
  _CUSERACCOUNT_REGISTERCOMPATTOOL_RESPONSE._serialized_start=2732
  _CUSERACCOUNT_REGISTERCOMPATTOOL_RESPONSE._serialized_end=2774
  _CEMBEDDEDCLIENT_AUTHORIZECURRENTDEVICE_REQUEST._serialized_start=2776
  _CEMBEDDEDCLIENT_AUTHORIZECURRENTDEVICE_REQUEST._serialized_end=2895
  _CEMBEDDEDCLIENT_TOKEN._serialized_start=2897
  _CEMBEDDEDCLIENT_TOKEN._serialized_end=2993
  _CEMBEDDEDCLIENT_AUTHORIZEDEVICE_RESPONSE._serialized_start=2995
  _CEMBEDDEDCLIENT_AUTHORIZEDEVICE_RESPONSE._serialized_end=3092
  _USERACCOUNT._serialized_start=3095
  _USERACCOUNT._serialized_end=4403
  _EMBEDDEDCLIENT._serialized_start=4406
  _EMBEDDEDCLIENT._serialized_end=4540
_builder.BuildServices(DESCRIPTOR, 'steammessages_useraccount_pb2', globals())
# @@protoc_insertion_point(module_scope)
