# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: steammessages_twofactor.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import steam.protobufs.steammessages_base_pb2 as steammessages__base__pb2
import steam.protobufs.steammessages_unified_base_pb2 as steammessages__unified__base__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1dsteammessages_twofactor.proto\x1a\x18steammessages_base.proto\x1a steammessages_unified_base.proto\".\n\x17\x43TwoFactor_Time_Request\x12\x13\n\x0bsender_time\x18\x01 \x01(\x04\"\xa5\x02\n\x18\x43TwoFactor_Time_Response\x12\x13\n\x0bserver_time\x18\x01 \x01(\x04\x12\x1e\n\x16skew_tolerance_seconds\x18\x02 \x01(\x04\x12\x17\n\x0flarge_time_jink\x18\x03 \x01(\x04\x12\x1f\n\x17probe_frequency_seconds\x18\x04 \x01(\r\x12-\n%adjusted_time_probe_frequency_seconds\x18\x05 \x01(\r\x12$\n\x1chint_probe_frequency_seconds\x18\x06 \x01(\r\x12\x14\n\x0csync_timeout\x18\x07 \x01(\r\x12\x19\n\x11try_again_seconds\x18\x08 \x01(\r\x12\x14\n\x0cmax_attempts\x18\t \x01(\r\"{\n\x19\x43TwoFactor_Status_Request\x12\x0f\n\x07steamid\x18\x01 \x01(\x06\x12M\n\x07include\x18\x02 \x01(\x0e\x32\x1a.ETwoFactorStatusFieldFlag: k_ETwoFactorStatusFieldFlag_None\"\xa6\x01\n\x15\x43TwoFactor_UsageEvent\x12\x0c\n\x04time\x18\x01 \x01(\r\x12G\n\nusage_type\x18\x02 \x01(\x0e\x32\x14.ETwoFactorUsageType:\x1dk_ETwoFactorUsageType_Unknown\x12\x19\n\x11\x63onfirmation_type\x18\x03 \x01(\x05\x12\x1b\n\x13\x63onfirmation_action\x18\x04 \x01(\x05\"\xd6\x03\n\x1a\x43TwoFactor_Status_Response\x12\r\n\x05state\x18\x01 \x01(\r\x12\x1b\n\x13inactivation_reason\x18\x02 \x01(\r\x12\x1a\n\x12\x61uthenticator_type\x18\x03 \x01(\r\x12\x1d\n\x15\x61uthenticator_allowed\x18\x04 \x01(\x08\x12\x19\n\x11steamguard_scheme\x18\x05 \x01(\r\x12\x11\n\ttoken_gid\x18\x06 \x01(\t\x12\x17\n\x0f\x65mail_validated\x18\x07 \x01(\x08\x12\x19\n\x11\x64\x65vice_identifier\x18\x08 \x01(\t\x12\x14\n\x0ctime_created\x18\t \x01(\r\x12%\n\x1drevocation_attempts_remaining\x18\n \x01(\r\x12\x18\n\x10\x63lassified_agent\x18\x0b \x01(\t\x12$\n\x1c\x61llow_external_authenticator\x18\x0c \x01(\x08\x12\x18\n\x10time_transferred\x18\r \x01(\r\x12\x0f\n\x07version\x18\x0e \x01(\r\x12\x1f\n\x17last_seen_auth_token_id\x18\x0f \x01(\x06\x12&\n\x06usages\x18\x10 \x03(\x0b\x32\x16.CTwoFactor_UsageEvent\"\xca\x01\n#CTwoFactor_AddAuthenticator_Request\x12\x0f\n\x07steamid\x18\x01 \x01(\x06\x12\x1a\n\x12\x61uthenticator_time\x18\x02 \x01(\x04\x12\x15\n\rserial_number\x18\x03 \x01(\x06\x12\x1a\n\x12\x61uthenticator_type\x18\x04 \x01(\r\x12\x19\n\x11\x64\x65vice_identifier\x18\x05 \x01(\t\x12\x14\n\x0chttp_headers\x18\x07 \x03(\t\x12\x12\n\x07version\x18\x08 \x01(\r:\x01\x31\"\xa4\x02\n$CTwoFactor_AddAuthenticator_Response\x12\x15\n\rshared_secret\x18\x01 \x01(\x0c\x12\x15\n\rserial_number\x18\x02 \x01(\x06\x12\x17\n\x0frevocation_code\x18\x03 \x01(\t\x12\x0b\n\x03uri\x18\x04 \x01(\t\x12\x13\n\x0bserver_time\x18\x05 \x01(\x04\x12\x14\n\x0c\x61\x63\x63ount_name\x18\x06 \x01(\t\x12\x11\n\ttoken_gid\x18\x07 \x01(\t\x12\x17\n\x0fidentity_secret\x18\x08 \x01(\x0c\x12\x10\n\x08secret_1\x18\t \x01(\x0c\x12\x0e\n\x06status\x18\n \x01(\x05\x12\x19\n\x11phone_number_hint\x18\x0b \x01(\t\x12\x14\n\x0c\x63onfirm_type\x18\x0c \x01(\x05\"\xc0\x01\n+CTwoFactor_FinalizeAddAuthenticator_Request\x12\x0f\n\x07steamid\x18\x01 \x01(\x06\x12\x1a\n\x12\x61uthenticator_code\x18\x02 \x01(\t\x12\x1a\n\x12\x61uthenticator_time\x18\x03 \x01(\x04\x12\x17\n\x0f\x61\x63tivation_code\x18\x04 \x01(\t\x12\x14\n\x0chttp_headers\x18\x05 \x03(\t\x12\x19\n\x11validate_sms_code\x18\x06 \x01(\x08\"d\n,CTwoFactor_FinalizeAddAuthenticator_Response\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x13\n\x0bserver_time\x18\x03 \x01(\x04\x12\x0e\n\x06status\x18\x04 \x01(\x05\"\\\n%CTwoFactor_UpdateTokenVersion_Request\x12\x0f\n\x07steamid\x18\x01 \x01(\x06\x12\x0f\n\x07version\x18\x02 \x01(\r\x12\x11\n\tsignature\x18\x03 \x01(\x0c\"(\n&CTwoFactor_UpdateTokenVersion_Response\"\x9e\x01\n&CTwoFactor_RemoveAuthenticator_Request\x12\x17\n\x0frevocation_code\x18\x02 \x01(\t\x12\x19\n\x11revocation_reason\x18\x05 \x01(\r\x12\x19\n\x11steamguard_scheme\x18\x06 \x01(\r\x12%\n\x1dremove_all_steamguard_cookies\x18\x07 \x01(\x08\"v\n\'CTwoFactor_RemoveAuthenticator_Response\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x13\n\x0bserver_time\x18\x03 \x01(\x04\x12%\n\x1drevocation_attempts_remaining\x18\x05 \x01(\r\"9\n7CTwoFactor_RemoveAuthenticatorViaChallengeStart_Request\"K\n8CTwoFactor_RemoveAuthenticatorViaChallengeStart_Response\x12\x0f\n\x07success\x18\x01 \x01(\x08\"~\n:CTwoFactor_RemoveAuthenticatorViaChallengeContinue_Request\x12\x10\n\x08sms_code\x18\x01 \x01(\t\x12\x1a\n\x12generate_new_token\x18\x02 \x01(\x08\x12\x12\n\x07version\x18\x03 \x01(\r:\x01\x31\"\xb5\x02\n:CRemoveAuthenticatorViaChallengeContinue_Replacement_Token\x12\x15\n\rshared_secret\x18\x01 \x01(\x0c\x12\x15\n\rserial_number\x18\x02 \x01(\x06\x12\x17\n\x0frevocation_code\x18\x03 \x01(\t\x12\x0b\n\x03uri\x18\x04 \x01(\t\x12\x13\n\x0bserver_time\x18\x05 \x01(\x04\x12\x14\n\x0c\x61\x63\x63ount_name\x18\x06 \x01(\t\x12\x11\n\ttoken_gid\x18\x07 \x01(\t\x12\x17\n\x0fidentity_secret\x18\x08 \x01(\x0c\x12\x10\n\x08secret_1\x18\t \x01(\x0c\x12\x0e\n\x06status\x18\n \x01(\x05\x12\x19\n\x11steamguard_scheme\x18\x0b \x01(\r\x12\x0f\n\x07steamid\x18\x0c \x01(\x06\"\xa6\x01\n;CTwoFactor_RemoveAuthenticatorViaChallengeContinue_Response\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12V\n\x11replacement_token\x18\x02 \x01(\x0b\x32;.CRemoveAuthenticatorViaChallengeContinue_Replacement_Token*l\n\x19\x45TwoFactorStatusFieldFlag\x12$\n k_ETwoFactorStatusFieldFlag_None\x10\x00\x12)\n%k_ETwoFactorStatusFieldFlag_LastUsage\x10\x01*\xa7\x01\n\x13\x45TwoFactorUsageType\x12!\n\x1dk_ETwoFactorUsageType_Unknown\x10\x00\x12\x1e\n\x1ak_ETwoFactorUsageType_None\x10\x01\x12,\n(k_ETwoFactorUsageType_MobileConfirmation\x10\x02\x12\x1f\n\x1bk_ETwoFactorUsageType_Login\x10\x03\x32\x85\x07\n\tTwoFactor\x12@\n\tQueryTime\x12\x18.CTwoFactor_Time_Request\x1a\x19.CTwoFactor_Time_Response\x12\x46\n\x0bQueryStatus\x12\x1a.CTwoFactor_Status_Request\x1a\x1b.CTwoFactor_Status_Response\x12_\n\x10\x41\x64\x64\x41uthenticator\x12$.CTwoFactor_AddAuthenticator_Request\x1a%.CTwoFactor_AddAuthenticator_Response\x12w\n\x18\x46inalizeAddAuthenticator\x12,.CTwoFactor_FinalizeAddAuthenticator_Request\x1a-.CTwoFactor_FinalizeAddAuthenticator_Response\x12\x65\n\x12UpdateTokenVersion\x12&.CTwoFactor_UpdateTokenVersion_Request\x1a\'.CTwoFactor_UpdateTokenVersion_Response\x12h\n\x13RemoveAuthenticator\x12\'.CTwoFactor_RemoveAuthenticator_Request\x1a(.CTwoFactor_RemoveAuthenticator_Response\x12\x9b\x01\n$RemoveAuthenticatorViaChallengeStart\x12\x38.CTwoFactor_RemoveAuthenticatorViaChallengeStart_Request\x1a\x39.CTwoFactor_RemoveAuthenticatorViaChallengeStart_Response\x12\xa4\x01\n\'RemoveAuthenticatorViaChallengeContinue\x12;.CTwoFactor_RemoveAuthenticatorViaChallengeContinue_Request\x1a<.CTwoFactor_RemoveAuthenticatorViaChallengeContinue_ResponseB\x03\x90\x01\x01')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'steammessages_twofactor_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\220\001\001'
  _ETWOFACTORSTATUSFIELDFLAG._serialized_start=3163
  _ETWOFACTORSTATUSFIELDFLAG._serialized_end=3271
  _ETWOFACTORUSAGETYPE._serialized_start=3274
  _ETWOFACTORUSAGETYPE._serialized_end=3441
  _CTWOFACTOR_TIME_REQUEST._serialized_start=93
  _CTWOFACTOR_TIME_REQUEST._serialized_end=139
  _CTWOFACTOR_TIME_RESPONSE._serialized_start=142
  _CTWOFACTOR_TIME_RESPONSE._serialized_end=435
  _CTWOFACTOR_STATUS_REQUEST._serialized_start=437
  _CTWOFACTOR_STATUS_REQUEST._serialized_end=560
  _CTWOFACTOR_USAGEEVENT._serialized_start=563
  _CTWOFACTOR_USAGEEVENT._serialized_end=729
  _CTWOFACTOR_STATUS_RESPONSE._serialized_start=732
  _CTWOFACTOR_STATUS_RESPONSE._serialized_end=1202
  _CTWOFACTOR_ADDAUTHENTICATOR_REQUEST._serialized_start=1205
  _CTWOFACTOR_ADDAUTHENTICATOR_REQUEST._serialized_end=1407
  _CTWOFACTOR_ADDAUTHENTICATOR_RESPONSE._serialized_start=1410
  _CTWOFACTOR_ADDAUTHENTICATOR_RESPONSE._serialized_end=1702
  _CTWOFACTOR_FINALIZEADDAUTHENTICATOR_REQUEST._serialized_start=1705
  _CTWOFACTOR_FINALIZEADDAUTHENTICATOR_REQUEST._serialized_end=1897
  _CTWOFACTOR_FINALIZEADDAUTHENTICATOR_RESPONSE._serialized_start=1899
  _CTWOFACTOR_FINALIZEADDAUTHENTICATOR_RESPONSE._serialized_end=1999
  _CTWOFACTOR_UPDATETOKENVERSION_REQUEST._serialized_start=2001
  _CTWOFACTOR_UPDATETOKENVERSION_REQUEST._serialized_end=2093
  _CTWOFACTOR_UPDATETOKENVERSION_RESPONSE._serialized_start=2095
  _CTWOFACTOR_UPDATETOKENVERSION_RESPONSE._serialized_end=2135
  _CTWOFACTOR_REMOVEAUTHENTICATOR_REQUEST._serialized_start=2138
  _CTWOFACTOR_REMOVEAUTHENTICATOR_REQUEST._serialized_end=2296
  _CTWOFACTOR_REMOVEAUTHENTICATOR_RESPONSE._serialized_start=2298
  _CTWOFACTOR_REMOVEAUTHENTICATOR_RESPONSE._serialized_end=2416
  _CTWOFACTOR_REMOVEAUTHENTICATORVIACHALLENGESTART_REQUEST._serialized_start=2418
  _CTWOFACTOR_REMOVEAUTHENTICATORVIACHALLENGESTART_REQUEST._serialized_end=2475
  _CTWOFACTOR_REMOVEAUTHENTICATORVIACHALLENGESTART_RESPONSE._serialized_start=2477
  _CTWOFACTOR_REMOVEAUTHENTICATORVIACHALLENGESTART_RESPONSE._serialized_end=2552
  _CTWOFACTOR_REMOVEAUTHENTICATORVIACHALLENGECONTINUE_REQUEST._serialized_start=2554
  _CTWOFACTOR_REMOVEAUTHENTICATORVIACHALLENGECONTINUE_REQUEST._serialized_end=2680
  _CREMOVEAUTHENTICATORVIACHALLENGECONTINUE_REPLACEMENT_TOKEN._serialized_start=2683
  _CREMOVEAUTHENTICATORVIACHALLENGECONTINUE_REPLACEMENT_TOKEN._serialized_end=2992
  _CTWOFACTOR_REMOVEAUTHENTICATORVIACHALLENGECONTINUE_RESPONSE._serialized_start=2995
  _CTWOFACTOR_REMOVEAUTHENTICATORVIACHALLENGECONTINUE_RESPONSE._serialized_end=3161
  _TWOFACTOR._serialized_start=3444
  _TWOFACTOR._serialized_end=4345
_builder.BuildServices(DESCRIPTOR, 'steammessages_twofactor_pb2', globals())
# @@protoc_insertion_point(module_scope)
