# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: steammessages_clientnotificationtypes.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n+steammessages_clientnotificationtypes.proto\"4\n#CClientNotificationCloudSyncFailure\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\"5\n$CClientNotificationCloudSyncConflict\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\"b\n\x1d\x43\x43lientNotificationScreenshot\x12\x19\n\x11screenshot_handle\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x11\n\tlocal_url\x18\x03 \x01(\t\"H\n$CClientNotificationDownloadCompleted\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x11\n\tdlc_appid\x18\x02 \x01(\r\"2\n\x1f\x43\x43lientNotificationFriendInvite\x12\x0f\n\x07steamid\x18\x01 \x01(\x06\"A\n%CClientNotificationFriendInviteRollup\x12\x18\n\x10new_invite_count\x18\x01 \x01(\r\"E\n\x1f\x43\x43lientNotificationFriendInGame\x12\x0f\n\x07steamid\x18\x01 \x01(\x06\x12\x11\n\tgame_name\x18\x02 \x01(\t\"2\n\x1f\x43\x43lientNotificationFriendOnline\x12\x0f\n\x07steamid\x18\x01 \x01(\x06\"\x8a\x02\n\x1e\x43\x43lientNotificationAchievement\x12\x16\n\x0e\x61\x63hievement_id\x18\x01 \x01(\t\x12\r\n\x05\x61ppid\x18\x02 \x01(\r\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12\x11\n\timage_url\x18\x05 \x01(\t\x12\x10\n\x08\x61\x63hieved\x18\x06 \x01(\x08\x12\x16\n\x0ertime_unlocked\x18\x07 \x01(\r\x12\x14\n\x0cmin_progress\x18\x08 \x01(\x02\x12\x18\n\x10\x63urrent_progress\x18\t \x01(\x02\x12\x14\n\x0cmax_progress\x18\n \x01(\x02\x12\x1b\n\x13global_achieved_pct\x18\x0b \x01(\x02\"6\n\x1d\x43\x43lientNotificationLowBattery\x12\x15\n\rpct_remaining\x18\x01 \x01(\x02\"x\n\x1f\x43\x43lientNotificationSystemUpdate\x12U\n\x04type\x18\x01 \x01(\x0e\x32\x1e.ESystemUpdateNotificationType:\'k_ESystemUpdateNotificationType_Invalid\"\x9e\x01\n CClientNotificationFriendMessage\x12\x0b\n\x03tag\x18\x01 \x01(\t\x12\x0f\n\x07steamid\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\x12\x0c\n\x04\x62ody\x18\x04 \x01(\t\x12\x0c\n\x04icon\x18\x05 \x01(\t\x12\x16\n\x0enotificationid\x18\x06 \x01(\r\x12\x19\n\x11response_steamurl\x18\x07 \x01(\t\"\xc6\x01\n#CClientNotificationGroupChatMessage\x12\x0b\n\x03tag\x18\x01 \x01(\t\x12\x16\n\x0esteamid_sender\x18\x02 \x01(\t\x12\x15\n\rchat_group_id\x18\x03 \x01(\t\x12\x0f\n\x07\x63hat_id\x18\x04 \x01(\t\x12\r\n\x05title\x18\x05 \x01(\t\x12\x0c\n\x04\x62ody\x18\x06 \x01(\t\x12\x0f\n\x07rawbody\x18\x07 \x01(\t\x12\x0c\n\x04icon\x18\x08 \x01(\t\x12\x16\n\x0enotificationid\x18\t \x01(\r\"i\n:CClientNotificationFamilySharingDeviceAuthorizationChanged\x12\x17\n\x0f\x61\x63\x63ountid_owner\x18\x01 \x01(\r\x12\x12\n\nauthorized\x18\x02 \x01(\x08\"p\n+CClientNotificationFamilySharingStopPlaying\x12\x17\n\x0f\x61\x63\x63ountid_owner\x18\x01 \x01(\r\x12\x19\n\x11seconds_remaining\x18\x02 \x01(\r\x12\r\n\x05\x61ppid\x18\x03 \x01(\r\"K\n0CClientNotificationFamilySharingLibraryAvailable\x12\x17\n\x0f\x61\x63\x63ountid_owner\x18\x01 \x01(\r\"7\n$CClientNotificationIncomingVoiceChat\x12\x0f\n\x07steamid\x18\x01 \x01(\x06\"*\n(CClientNotificationClaimSteamDeckRewards\"6\n\x1f\x43\x43lientNotificationGiftReceived\x12\x13\n\x0bsender_name\x18\x01 \x01(\t\"Y\n#CClientNotificationItemAnnouncement\x12\x16\n\x0enew_item_count\x18\x01 \x01(\r\x12\x1a\n\x12new_backpack_items\x18\x02 \x01(\x08\"*\n(CClientNotificationHardwareSurveyPending\"7\n\x1f\x43\x43lientNotificationLowDiskSpace\x12\x14\n\x0c\x66older_index\x18\x01 \x01(\r\"W\n%CClientNotificationBatteryTemperature\x12\x13\n\x0btemperature\x18\x01 \x01(\r\x12\x19\n\x11notification_type\x18\x02 \x01(\t\",\n*CClientNotificationDockUnsupportedFirmware\"H\n$CClientNotificationPeerContentUpload\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x11\n\tpeer_name\x18\x02 \x01(\t\"N\n2CClientNotificationCannotReadControllerGuideButton\x12\x18\n\x10\x63ontroller_index\x18\x01 \x01(\x05\"(\n&CClientNotificationOverlaySplashScreen\"L\n,CClientNotificationBroadcastAvailableToWatch\x12\x1c\n\x14\x62roadcast_permission\x18\x01 \x01(\x05\"\x87\x01\n&CClientNotificationTimedTrialRemaining\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x0c\n\x04icon\x18\x02 \x01(\t\x12\x0f\n\x07offline\x18\x03 \x01(\x08\x12\x17\n\x0f\x61llowed_seconds\x18\x04 \x01(\r\x12\x16\n\x0eplayed_seconds\x18\x05 \x01(\r\"!\n\x1f\x43\x43lientNotificationLoginRefresh\"!\n\x1f\x43\x43lientNotificationTimerExpired\"b\n-CClientNotificationSteamInputActionSetChanged\x12\x18\n\x10\x63ontroller_index\x18\x01 \x01(\x05\x12\x17\n\x0f\x61\x63tion_set_name\x18\x02 \x01(\t\"O\n)CClientNotificationRemoteClientConnection\x12\x0f\n\x07machine\x18\x01 \x01(\t\x12\x11\n\tconnected\x18\x02 \x01(\x08\"P\n*CClientNotificationRemoteClientStartStream\x12\x0f\n\x07machine\x18\x01 \x01(\t\x12\x11\n\tgame_name\x18\x02 \x01(\t\"d\n,CClientNotificationStreamingClientConnection\x12\x10\n\x08hostname\x18\x01 \x01(\t\x12\x0f\n\x07machine\x18\x02 \x01(\t\x12\x11\n\tconnected\x18\x03 \x01(\x08\"N\n\"CClientNotificationPlaytimeWarning\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x1a\n\x12playtime_remaining\x18\x02 \x01(\r\"\x84\x01\n%CClientNotificationGameRecordingError\x12\x0f\n\x07game_id\x18\x01 \x01(\x06\x12J\n\nerror_type\x18\x02 \x01(\x0e\x32\x18.EGameRecordingErrorType:\x1ck_EGameRecordingErrorGeneral\"8\n%CClientNotificationGameRecordingStart\x12\x0f\n\x07game_id\x18\x01 \x01(\x06\"_\n$CClientNotificationGameRecordingStop\x12\x0f\n\x07game_id\x18\x01 \x01(\x06\x12\x0f\n\x07\x63lip_id\x18\x02 \x01(\t\x12\x15\n\rduration_secs\x18\x03 \x01(\x02\"B\n/CClientNotificationGameRecordingUserMarkerAdded\x12\x0f\n\x07game_id\x18\x01 \x01(\x06\"f\n+CClientNotificationGameRecordingInstantClip\x12\x0f\n\x07game_id\x18\x01 \x01(\x06\x12\x0f\n\x07\x63lip_id\x18\x02 \x01(\t\x12\x15\n\rduration_secs\x18\x03 \x01(\x02*\xca\x16\n\x17\x45\x43lientNotificationType\x12%\n!k_EClientNotificationType_Invalid\x10\x00\x12/\n+k_EClientNotificationType_DownloadCompleted\x10\x01\x12*\n&k_EClientNotificationType_FriendInvite\x10\x02\x12*\n&k_EClientNotificationType_FriendInGame\x10\x03\x12*\n&k_EClientNotificationType_FriendOnline\x10\x04\x12)\n%k_EClientNotificationType_Achievement\x10\x05\x12(\n$k_EClientNotificationType_LowBattery\x10\x06\x12*\n&k_EClientNotificationType_SystemUpdate\x10\x07\x12+\n\'k_EClientNotificationType_FriendMessage\x10\x08\x12.\n*k_EClientNotificationType_GroupChatMessage\x10\t\x12\x30\n,k_EClientNotificationType_FriendInviteRollup\x10\n\x12\x36\n2k_EClientNotificationType_FamilySharingStopPlaying\x10\x0c\x12(\n$k_EClientNotificationType_Screenshot\x10\x0e\x12.\n*k_EClientNotificationType_CloudSyncFailure\x10\x0f\x12/\n+k_EClientNotificationType_CloudSyncConflict\x10\x10\x12/\n+k_EClientNotificationType_IncomingVoiceChat\x10\x11\x12\x33\n/k_EClientNotificationType_ClaimSteamDeckRewards\x10\x12\x12*\n&k_EClientNotificationType_GiftReceived\x10\x13\x12.\n*k_EClientNotificationType_ItemAnnouncement\x10\x14\x12,\n(k_EClientNotificationType_HardwareSurvey\x10\x15\x12*\n&k_EClientNotificationType_LowDiskSpace\x10\x16\x12\x30\n,k_EClientNotificationType_BatteryTemperature\x10\x17\x12\x35\n1k_EClientNotificationType_DockUnsupportedFirmware\x10\x18\x12/\n+k_EClientNotificationType_PeerContentUpload\x10\x19\x12=\n9k_EClientNotificationType_CannotReadControllerGuideButton\x10\x1a\x12%\n!k_EClientNotificationType_Comment\x10\x1b\x12&\n\"k_EClientNotificationType_Wishlist\x10\x1c\x12(\n$k_EClientNotificationType_TradeOffer\x10\x1d\x12\'\n#k_EClientNotificationType_AsyncGame\x10\x1e\x12%\n!k_EClientNotificationType_General\x10\x1f\x12)\n%k_EClientNotificationType_HelpRequest\x10 \x12\x31\n-k_EClientNotificationType_OverlaySplashScreen\x10!\x12\x37\n3k_EClientNotificationType_BroadcastAvailableToWatch\x10\"\x12\x31\n-k_EClientNotificationType_TimedTrialRemaining\x10#\x12*\n&k_EClientNotificationType_LoginRefresh\x10$\x12\'\n#k_EClientNotificationType_MajorSale\x10%\x12*\n&k_EClientNotificationType_TimerExpired\x10&\x12*\n&k_EClientNotificationType_ModeratorMsg\x10\'\x12\x38\n4k_EClientNotificationType_SteamInputActionSetChanged\x10(\x12\x34\n0k_EClientNotificationType_RemoteClientConnection\x10)\x12\x35\n1k_EClientNotificationType_RemoteClientStartStream\x10*\x12\x37\n3k_EClientNotificationType_StreamingClientConnection\x10+\x12*\n&k_EClientNotificationType_FamilyInvite\x10,\x12-\n)k_EClientNotificationType_PlaytimeWarning\x10-\x12\x33\n/k_EClientNotificationType_FamilyPurchaseRequest\x10.\x12;\n7k_EClientNotificationType_FamilyPurchaseRequestResponse\x10/\x12\x34\n0k_EClientNotificationType_ParentalFeatureRequest\x10\x30\x12\x35\n1k_EClientNotificationType_ParentalPlaytimeRequest\x10\x31\x12\x30\n,k_EClientNotificationType_GameRecordingError\x10\x32\x12\x35\n1k_EClientNotificationType_ParentalFeatureResponse\x10\x33\x12\x36\n2k_EClientNotificationType_ParentalPlaytimeResponse\x10\x34\x12\x30\n,k_EClientNotificationType_RequestedGameAdded\x10\x35\x12,\n(k_EClientNotificationType_ClipDownloaded\x10\x36\x12\x30\n,k_EClientNotificationType_GameRecordingStart\x10\x37\x12/\n+k_EClientNotificationType_GameRecordingStop\x10\x38\x12:\n6k_EClientNotificationType_GameRecordingUserMarkerAdded\x10\x39\x12\x36\n2k_EClientNotificationType_GameRecordingInstantClip\x10:\x12,\n(k_EClientNotificationType_PlaytestInvite\x10;\x12+\n\'k_EClientNotificationType_TradeReversal\x10<*\xad\x01\n\x1d\x45SystemUpdateNotificationType\x12+\n\'k_ESystemUpdateNotificationType_Invalid\x10\x00\x12-\n)k_ESystemUpdateNotificationType_Available\x10\x01\x12\x30\n,k_ESystemUpdateNotificationType_NeedsRestart\x10\x02*b\n\x17\x45GameRecordingErrorType\x12 \n\x1ck_EGameRecordingErrorGeneral\x10\x01\x12%\n!k_EGameRecordingErrorLowDiskSpace\x10\x02\x42\x05H\x01\x90\x01\x01')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'steammessages_clientnotificationtypes_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'H\001\220\001\001'
  _ECLIENTNOTIFICATIONTYPE._serialized_start=3553
  _ECLIENTNOTIFICATIONTYPE._serialized_end=6443
  _ESYSTEMUPDATENOTIFICATIONTYPE._serialized_start=6446
  _ESYSTEMUPDATENOTIFICATIONTYPE._serialized_end=6619
  _EGAMERECORDINGERRORTYPE._serialized_start=6621
  _EGAMERECORDINGERRORTYPE._serialized_end=6719
  _CCLIENTNOTIFICATIONCLOUDSYNCFAILURE._serialized_start=47
  _CCLIENTNOTIFICATIONCLOUDSYNCFAILURE._serialized_end=99
  _CCLIENTNOTIFICATIONCLOUDSYNCCONFLICT._serialized_start=101
  _CCLIENTNOTIFICATIONCLOUDSYNCCONFLICT._serialized_end=154
  _CCLIENTNOTIFICATIONSCREENSHOT._serialized_start=156
  _CCLIENTNOTIFICATIONSCREENSHOT._serialized_end=254
  _CCLIENTNOTIFICATIONDOWNLOADCOMPLETED._serialized_start=256
  _CCLIENTNOTIFICATIONDOWNLOADCOMPLETED._serialized_end=328
  _CCLIENTNOTIFICATIONFRIENDINVITE._serialized_start=330
  _CCLIENTNOTIFICATIONFRIENDINVITE._serialized_end=380
  _CCLIENTNOTIFICATIONFRIENDINVITEROLLUP._serialized_start=382
  _CCLIENTNOTIFICATIONFRIENDINVITEROLLUP._serialized_end=447
  _CCLIENTNOTIFICATIONFRIENDINGAME._serialized_start=449
  _CCLIENTNOTIFICATIONFRIENDINGAME._serialized_end=518
  _CCLIENTNOTIFICATIONFRIENDONLINE._serialized_start=520
  _CCLIENTNOTIFICATIONFRIENDONLINE._serialized_end=570
  _CCLIENTNOTIFICATIONACHIEVEMENT._serialized_start=573
  _CCLIENTNOTIFICATIONACHIEVEMENT._serialized_end=839
  _CCLIENTNOTIFICATIONLOWBATTERY._serialized_start=841
  _CCLIENTNOTIFICATIONLOWBATTERY._serialized_end=895
  _CCLIENTNOTIFICATIONSYSTEMUPDATE._serialized_start=897
  _CCLIENTNOTIFICATIONSYSTEMUPDATE._serialized_end=1017
  _CCLIENTNOTIFICATIONFRIENDMESSAGE._serialized_start=1020
  _CCLIENTNOTIFICATIONFRIENDMESSAGE._serialized_end=1178
  _CCLIENTNOTIFICATIONGROUPCHATMESSAGE._serialized_start=1181
  _CCLIENTNOTIFICATIONGROUPCHATMESSAGE._serialized_end=1379
  _CCLIENTNOTIFICATIONFAMILYSHARINGDEVICEAUTHORIZATIONCHANGED._serialized_start=1381
  _CCLIENTNOTIFICATIONFAMILYSHARINGDEVICEAUTHORIZATIONCHANGED._serialized_end=1486
  _CCLIENTNOTIFICATIONFAMILYSHARINGSTOPPLAYING._serialized_start=1488
  _CCLIENTNOTIFICATIONFAMILYSHARINGSTOPPLAYING._serialized_end=1600
  _CCLIENTNOTIFICATIONFAMILYSHARINGLIBRARYAVAILABLE._serialized_start=1602
  _CCLIENTNOTIFICATIONFAMILYSHARINGLIBRARYAVAILABLE._serialized_end=1677
  _CCLIENTNOTIFICATIONINCOMINGVOICECHAT._serialized_start=1679
  _CCLIENTNOTIFICATIONINCOMINGVOICECHAT._serialized_end=1734
  _CCLIENTNOTIFICATIONCLAIMSTEAMDECKREWARDS._serialized_start=1736
  _CCLIENTNOTIFICATIONCLAIMSTEAMDECKREWARDS._serialized_end=1778
  _CCLIENTNOTIFICATIONGIFTRECEIVED._serialized_start=1780
  _CCLIENTNOTIFICATIONGIFTRECEIVED._serialized_end=1834
  _CCLIENTNOTIFICATIONITEMANNOUNCEMENT._serialized_start=1836
  _CCLIENTNOTIFICATIONITEMANNOUNCEMENT._serialized_end=1925
  _CCLIENTNOTIFICATIONHARDWARESURVEYPENDING._serialized_start=1927
  _CCLIENTNOTIFICATIONHARDWARESURVEYPENDING._serialized_end=1969
  _CCLIENTNOTIFICATIONLOWDISKSPACE._serialized_start=1971
  _CCLIENTNOTIFICATIONLOWDISKSPACE._serialized_end=2026
  _CCLIENTNOTIFICATIONBATTERYTEMPERATURE._serialized_start=2028
  _CCLIENTNOTIFICATIONBATTERYTEMPERATURE._serialized_end=2115
  _CCLIENTNOTIFICATIONDOCKUNSUPPORTEDFIRMWARE._serialized_start=2117
  _CCLIENTNOTIFICATIONDOCKUNSUPPORTEDFIRMWARE._serialized_end=2161
  _CCLIENTNOTIFICATIONPEERCONTENTUPLOAD._serialized_start=2163
  _CCLIENTNOTIFICATIONPEERCONTENTUPLOAD._serialized_end=2235
  _CCLIENTNOTIFICATIONCANNOTREADCONTROLLERGUIDEBUTTON._serialized_start=2237
  _CCLIENTNOTIFICATIONCANNOTREADCONTROLLERGUIDEBUTTON._serialized_end=2315
  _CCLIENTNOTIFICATIONOVERLAYSPLASHSCREEN._serialized_start=2317
  _CCLIENTNOTIFICATIONOVERLAYSPLASHSCREEN._serialized_end=2357
  _CCLIENTNOTIFICATIONBROADCASTAVAILABLETOWATCH._serialized_start=2359
  _CCLIENTNOTIFICATIONBROADCASTAVAILABLETOWATCH._serialized_end=2435
  _CCLIENTNOTIFICATIONTIMEDTRIALREMAINING._serialized_start=2438
  _CCLIENTNOTIFICATIONTIMEDTRIALREMAINING._serialized_end=2573
  _CCLIENTNOTIFICATIONLOGINREFRESH._serialized_start=2575
  _CCLIENTNOTIFICATIONLOGINREFRESH._serialized_end=2608
  _CCLIENTNOTIFICATIONTIMEREXPIRED._serialized_start=2610
  _CCLIENTNOTIFICATIONTIMEREXPIRED._serialized_end=2643
  _CCLIENTNOTIFICATIONSTEAMINPUTACTIONSETCHANGED._serialized_start=2645
  _CCLIENTNOTIFICATIONSTEAMINPUTACTIONSETCHANGED._serialized_end=2743
  _CCLIENTNOTIFICATIONREMOTECLIENTCONNECTION._serialized_start=2745
  _CCLIENTNOTIFICATIONREMOTECLIENTCONNECTION._serialized_end=2824
  _CCLIENTNOTIFICATIONREMOTECLIENTSTARTSTREAM._serialized_start=2826
  _CCLIENTNOTIFICATIONREMOTECLIENTSTARTSTREAM._serialized_end=2906
  _CCLIENTNOTIFICATIONSTREAMINGCLIENTCONNECTION._serialized_start=2908
  _CCLIENTNOTIFICATIONSTREAMINGCLIENTCONNECTION._serialized_end=3008
  _CCLIENTNOTIFICATIONPLAYTIMEWARNING._serialized_start=3010
  _CCLIENTNOTIFICATIONPLAYTIMEWARNING._serialized_end=3088
  _CCLIENTNOTIFICATIONGAMERECORDINGERROR._serialized_start=3091
  _CCLIENTNOTIFICATIONGAMERECORDINGERROR._serialized_end=3223
  _CCLIENTNOTIFICATIONGAMERECORDINGSTART._serialized_start=3225
  _CCLIENTNOTIFICATIONGAMERECORDINGSTART._serialized_end=3281
  _CCLIENTNOTIFICATIONGAMERECORDINGSTOP._serialized_start=3283
  _CCLIENTNOTIFICATIONGAMERECORDINGSTOP._serialized_end=3378
  _CCLIENTNOTIFICATIONGAMERECORDINGUSERMARKERADDED._serialized_start=3380
  _CCLIENTNOTIFICATIONGAMERECORDINGUSERMARKERADDED._serialized_end=3446
  _CCLIENTNOTIFICATIONGAMERECORDINGINSTANTCLIP._serialized_start=3448
  _CCLIENTNOTIFICATIONGAMERECORDINGINSTANTCLIP._serialized_end=3550
# @@protoc_insertion_point(module_scope)
