# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: steammessages_gamenetworking.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import steam.protobufs.steammessages_base_pb2 as steammessages__base__pb2
import steam.protobufs.steammessages_unified_base_pb2 as steammessages__unified__base__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"steammessages_gamenetworking.proto\x1a\x18steammessages_base.proto\x1a steammessages_unified_base.proto\"P\n&CGameNetworking_AllocateFakeIP_Request\x12\x0e\n\x06\x61pp_id\x18\x01 \x01(\r\x12\x16\n\x0enum_fake_ports\x18\x02 \x01(\r\"N\n\'CGameNetworking_AllocateFakeIP_Response\x12\x0f\n\x07\x66\x61ke_ip\x18\x01 \x01(\x07\x12\x12\n\nfake_ports\x18\x02 \x03(\r\"a\n*CGameNetworking_ReleaseFakeIP_Notification\x12\x0e\n\x06\x61pp_id\x18\x01 \x01(\r\x12\x0f\n\x07\x66\x61ke_ip\x18\x02 \x01(\x07\x12\x12\n\nfake_ports\x18\x03 \x03(\r2\xc6\x01\n\x0eGameNetworking\x12\x63\n\x0e\x41llocateFakeIP\x12\'.CGameNetworking_AllocateFakeIP_Request\x1a(.CGameNetworking_AllocateFakeIP_Response\x12O\n\x13NotifyReleaseFakeIP\x12+.CGameNetworking_ReleaseFakeIP_Notification\x1a\x0b.NoResponseB\x03\x90\x01\x01')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'steammessages_gamenetworking_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\220\001\001'
  _CGAMENETWORKING_ALLOCATEFAKEIP_REQUEST._serialized_start=98
  _CGAMENETWORKING_ALLOCATEFAKEIP_REQUEST._serialized_end=178
  _CGAMENETWORKING_ALLOCATEFAKEIP_RESPONSE._serialized_start=180
  _CGAMENETWORKING_ALLOCATEFAKEIP_RESPONSE._serialized_end=258
  _CGAMENETWORKING_RELEASEFAKEIP_NOTIFICATION._serialized_start=260
  _CGAMENETWORKING_RELEASEFAKEIP_NOTIFICATION._serialized_end=357
  _GAMENETWORKING._serialized_start=360
  _GAMENETWORKING._serialized_end=558
_builder.BuildServices(DESCRIPTOR, 'steammessages_gamenetworking_pb2', globals())
# @@protoc_insertion_point(module_scope)
