# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: steammessages_timedtrial.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import steam.protobufs.steammessages_base_pb2 as steammessages__base__pb2
import steam.protobufs.steammessages_unified_base_pb2 as steammessages__unified__base__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1esteammessages_timedtrial.proto\x1a\x18steammessages_base.proto\x1a steammessages_unified_base.proto\"5\n$CTimedTrial_GetTimeRemaining_Request\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\"\x84\x01\n%CTimedTrial_GetTimeRemaining_Response\x12\x16\n\x0eseconds_played\x18\x01 \x01(\r\x12\x17\n\x0fseconds_allowed\x18\x02 \x01(\r\x12\x11\n\tpackageid\x18\x03 \x01(\r\x12\x17\n\x0fmastersub_appid\x18\x04 \x01(\r\"K\n\"CTimedTrial_RecordPlaytime_Request\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x16\n\x0eseconds_played\x18\x02 \x01(\r\"V\n#CTimedTrial_RecordPlaytime_Response\x12\x16\n\x0eseconds_played\x18\x01 \x01(\r\x12\x17\n\x0fseconds_allowed\x18\x02 \x01(\r\"2\n!CTimedTrial_ResetPlaytime_Request\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\"U\n\"CTimedTrial_ResetPlaytime_Response\x12\x16\n\x0eseconds_played\x18\x01 \x01(\r\x12\x17\n\x0fseconds_allowed\x18\x02 \x01(\r2\xa6\x02\n\nTimedTrial\x12\x61\n\x10GetTimeRemaining\x12%.CTimedTrial_GetTimeRemaining_Request\x1a&.CTimedTrial_GetTimeRemaining_Response\x12[\n\x0eRecordPlaytime\x12#.CTimedTrial_RecordPlaytime_Request\x1a$.CTimedTrial_RecordPlaytime_Response\x12X\n\rResetPlaytime\x12\".CTimedTrial_ResetPlaytime_Request\x1a#.CTimedTrial_ResetPlaytime_ResponseB\x03\x90\x01\x01')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'steammessages_timedtrial_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\220\001\001'
  _CTIMEDTRIAL_GETTIMEREMAINING_REQUEST._serialized_start=94
  _CTIMEDTRIAL_GETTIMEREMAINING_REQUEST._serialized_end=147
  _CTIMEDTRIAL_GETTIMEREMAINING_RESPONSE._serialized_start=150
  _CTIMEDTRIAL_GETTIMEREMAINING_RESPONSE._serialized_end=282
  _CTIMEDTRIAL_RECORDPLAYTIME_REQUEST._serialized_start=284
  _CTIMEDTRIAL_RECORDPLAYTIME_REQUEST._serialized_end=359
  _CTIMEDTRIAL_RECORDPLAYTIME_RESPONSE._serialized_start=361
  _CTIMEDTRIAL_RECORDPLAYTIME_RESPONSE._serialized_end=447
  _CTIMEDTRIAL_RESETPLAYTIME_REQUEST._serialized_start=449
  _CTIMEDTRIAL_RESETPLAYTIME_REQUEST._serialized_end=499
  _CTIMEDTRIAL_RESETPLAYTIME_RESPONSE._serialized_start=501
  _CTIMEDTRIAL_RESETPLAYTIME_RESPONSE._serialized_end=586
  _TIMEDTRIAL._serialized_start=589
  _TIMEDTRIAL._serialized_end=883
_builder.BuildServices(DESCRIPTOR, 'steammessages_timedtrial_pb2', globals())
# @@protoc_insertion_point(module_scope)
