# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: steamnetworkingsockets_messages.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import steam.protobufs.steamnetworkingsockets_messages_certs_pb2 as steamnetworkingsockets__messages__certs__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%steamnetworkingsockets_messages.proto\x1a+steamnetworkingsockets_messages_certs.proto\"\x80\x02\n!CMsgSteamDatagramSessionCryptInfo\x12\x46\n\x08key_type\x18\x01 \x01(\x0e\x32+.CMsgSteamDatagramSessionCryptInfo.EKeyType:\x07INVALID\x12\x10\n\x08key_data\x18\x02 \x01(\x0c\x12\r\n\x05nonce\x18\x03 \x01(\x06\x12\x18\n\x10protocol_version\x18\x04 \x01(\r\x12/\n\x07\x63iphers\x18\x05 \x03(\x0e\x32\x1e.ESteamNetworkingSocketsCipher\"\'\n\x08\x45KeyType\x12\x0b\n\x07INVALID\x10\x00\x12\x0e\n\nCURVE25519\x10\x01\"J\n\'CMsgSteamDatagramSessionCryptInfoSigned\x12\x0c\n\x04info\x18\x01 \x01(\x0c\x12\x11\n\tsignature\x18\x02 \x01(\x0c\"=\n\x1b\x43MsgSteamDatagramDiagnostic\x12\x10\n\x08severity\x18\x01 \x01(\r\x12\x0c\n\x04text\x18\x02 \x01(\t\"\x8b\x02\n\'CMsgSteamDatagramLinkInstantaneousStats\x12\x1f\n\x17out_packets_per_sec_x10\x18\x01 \x01(\r\x12\x19\n\x11out_bytes_per_sec\x18\x02 \x01(\r\x12\x1e\n\x16in_packets_per_sec_x10\x18\x03 \x01(\r\x12\x18\n\x10in_bytes_per_sec\x18\x04 \x01(\r\x12\x0f\n\x07ping_ms\x18\x05 \x01(\r\x12\x1b\n\x13packets_dropped_pct\x18\x06 \x01(\r\x12\"\n\x1apackets_weird_sequence_pct\x18\x07 \x01(\r\x12\x18\n\x10peak_jitter_usec\x18\x08 \x01(\r\"\xed\n\n\"CMsgSteamDatagramLinkLifetimeStats\x12\x19\n\x11\x63onnected_seconds\x18\x02 \x01(\r\x12\x14\n\x0cpackets_sent\x18\x03 \x01(\x04\x12\x0f\n\x07kb_sent\x18\x04 \x01(\x04\x12\x14\n\x0cpackets_recv\x18\x05 \x01(\x04\x12\x0f\n\x07kb_recv\x18\x06 \x01(\x04\x12\x1e\n\x16packets_recv_sequenced\x18\x07 \x01(\x04\x12\x1c\n\x14packets_recv_dropped\x18\x08 \x01(\x04\x12!\n\x19packets_recv_out_of_order\x18\t \x01(\x04\x12+\n#packets_recv_out_of_order_corrected\x18\x0f \x01(\x04\x12\x1e\n\x16packets_recv_duplicate\x18\n \x01(\x04\x12\x1a\n\x12packets_recv_lurch\x18\x0b \x01(\x04\x12(\n multipath_packets_recv_sequenced\x18\x0c \x03(\x04\x12$\n\x1cmultipath_packets_recv_later\x18\r \x03(\x04\x12\x1e\n\x16multipath_send_enabled\x18\x0e \x01(\r\x12\x1d\n\x15quality_histogram_100\x18\x15 \x01(\r\x12\x1c\n\x14quality_histogram_99\x18\x16 \x01(\r\x12\x1c\n\x14quality_histogram_97\x18\x17 \x01(\r\x12\x1c\n\x14quality_histogram_95\x18\x18 \x01(\r\x12\x1c\n\x14quality_histogram_90\x18\x19 \x01(\r\x12\x1c\n\x14quality_histogram_75\x18\x1a \x01(\r\x12\x1c\n\x14quality_histogram_50\x18\x1b \x01(\r\x12\x1b\n\x13quality_histogram_1\x18\x1c \x01(\r\x12\x1e\n\x16quality_histogram_dead\x18\x1d \x01(\r\x12\x19\n\x11quality_ntile_2nd\x18\x1e \x01(\r\x12\x19\n\x11quality_ntile_5th\x18\x1f \x01(\r\x12\x1a\n\x12quality_ntile_25th\x18  \x01(\r\x12\x1a\n\x12quality_ntile_50th\x18! \x01(\r\x12\x19\n\x11ping_histogram_25\x18) \x01(\r\x12\x19\n\x11ping_histogram_50\x18* \x01(\r\x12\x19\n\x11ping_histogram_75\x18+ \x01(\r\x12\x1a\n\x12ping_histogram_100\x18, \x01(\r\x12\x1a\n\x12ping_histogram_125\x18- \x01(\r\x12\x1a\n\x12ping_histogram_150\x18. \x01(\r\x12\x1a\n\x12ping_histogram_200\x18/ \x01(\r\x12\x1a\n\x12ping_histogram_300\x18\x30 \x01(\r\x12\x1a\n\x12ping_histogram_max\x18\x31 \x01(\r\x12\x16\n\x0eping_ntile_5th\x18\x32 \x01(\r\x12\x17\n\x0fping_ntile_50th\x18\x33 \x01(\r\x12\x17\n\x0fping_ntile_75th\x18\x34 \x01(\r\x12\x17\n\x0fping_ntile_95th\x18\x35 \x01(\r\x12\x17\n\x0fping_ntile_98th\x18\x36 \x01(\r\x12#\n\x1bjitter_histogram_negligible\x18= \x01(\r\x12\x1a\n\x12jitter_histogram_1\x18> \x01(\r\x12\x1a\n\x12jitter_histogram_2\x18? \x01(\r\x12\x1a\n\x12jitter_histogram_5\x18@ \x01(\r\x12\x1b\n\x13jitter_histogram_10\x18\x41 \x01(\r\x12\x1b\n\x13jitter_histogram_20\x18\x42 \x01(\r\"\x9c\x01\n\"CMsgSteamDatagramConnectionQuality\x12?\n\rinstantaneous\x18\x01 \x01(\x0b\x32(.CMsgSteamDatagramLinkInstantaneousStats\x12\x35\n\x08lifetime\x18\x02 \x01(\x0b\x32#.CMsgSteamDatagramLinkLifetimeStats\"%\n\x10\x43MsgICECandidate\x12\x11\n\tcandidate\x18\x03 \x01(\t\"~\n\x11\x43MsgICERendezvous\x12%\n\x04\x61uth\x18\x02 \x01(\x0b\x32\x17.CMsgICERendezvous.Auth\x12(\n\radd_candidate\x18\x01 \x01(\x0b\x32\x11.CMsgICECandidate\x1a\x18\n\x04\x41uth\x12\x10\n\x08pwd_frag\x18\x01 \x01(\t\"\xa3\t\n CMsgSteamNetworkingP2PRendezvous\x12\x15\n\rfrom_identity\x18\x08 \x01(\t\x12\x1a\n\x12\x66rom_connection_id\x18\t \x01(\x07\x12\x13\n\x0bto_identity\x18\n \x01(\t\x12\x18\n\x10to_connection_id\x18\x01 \x01(\x07\x12\x12\n\nsdr_routes\x18\x02 \x01(\x0c\x12 \n\x18\x61\x63k_peer_routes_revision\x18\x03 \x01(\r\x12\x13\n\x0bice_enabled\x18\x07 \x01(\x08\x12\x1c\n\x14hosted_server_ticket\x18\x0e \x01(\x0c\x12I\n\x0f\x63onnect_request\x18\x04 \x01(\x0b\x32\x30.CMsgSteamNetworkingP2PRendezvous.ConnectRequest\x12?\n\nconnect_ok\x18\x05 \x01(\x0b\x32+.CMsgSteamNetworkingP2PRendezvous.ConnectOK\x12M\n\x11\x63onnection_closed\x18\x06 \x01(\x0b\x32\x32.CMsgSteamNetworkingP2PRendezvous.ConnectionClosed\x12\x18\n\x10\x61\x63k_reliable_msg\x18\x0b \x01(\r\x12\x1a\n\x12\x66irst_reliable_msg\x18\x0c \x01(\r\x12L\n\x11reliable_messages\x18\r \x03(\x0b\x32\x31.CMsgSteamNetworkingP2PRendezvous.ReliableMessage\x12R\n\x14\x61pplication_messages\x18\x0f \x03(\x0b\x32\x34.CMsgSteamNetworkingP2PRendezvous.ApplicationMessage\x1a\xc5\x01\n\x0e\x43onnectRequest\x12\x37\n\x05\x63rypt\x18\x06 \x01(\x0b\x32(.CMsgSteamDatagramSessionCryptInfoSigned\x12\x31\n\x04\x63\x65rt\x18\x07 \x01(\x0b\x32#.CMsgSteamDatagramCertificateSigned\x12\x17\n\x0fto_virtual_port\x18\t \x01(\r\x12\x19\n\x11\x66rom_virtual_port\x18\n \x01(\r\x12\x13\n\x0b\x66rom_fakeip\x18\x0b \x01(\t\x1aw\n\tConnectOK\x12\x37\n\x05\x63rypt\x18\x05 \x01(\x0b\x32(.CMsgSteamDatagramSessionCryptInfoSigned\x12\x31\n\x04\x63\x65rt\x18\x06 \x01(\x0b\x32#.CMsgSteamDatagramCertificateSigned\x1a\x36\n\x10\x43onnectionClosed\x12\r\n\x05\x64\x65\x62ug\x18\x05 \x01(\t\x12\x13\n\x0breason_code\x18\x06 \x01(\r\x1a\x32\n\x0fReliableMessage\x12\x1f\n\x03ice\x18\x01 \x01(\x0b\x32\x12.CMsgICERendezvous\x1aT\n\x12\x41pplicationMessage\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\x0c\x12\x0f\n\x07msg_num\x18\x02 \x01(\x04\x12\r\n\x05\x66lags\x18\x03 \x01(\r\x12\x10\n\x08lane_idx\x18\x04 \x01(\r\"\xa6\x03\n$CMsgSteamNetworkingICESessionSummary\x12\x1b\n\x13\x66\x61ilure_reason_code\x18\x07 \x01(\r\x12\x1d\n\x15local_candidate_types\x18\x01 \x01(\r\x12\x1e\n\x16remote_candidate_types\x18\x02 \x01(\r\x12\x1a\n\x12initial_route_kind\x18\x03 \x01(\r\x12\x14\n\x0cinitial_ping\x18\x04 \x01(\r\x12\x15\n\rinitial_score\x18\x06 \x01(\r\x12\x16\n\x0enegotiation_ms\x18\x05 \x01(\r\x12\x17\n\x0f\x62\x65st_route_kind\x18\x10 \x01(\r\x12\x11\n\tbest_ping\x18\x11 \x01(\r\x12\x12\n\nbest_score\x18\x12 \x01(\r\x12\x11\n\tbest_time\x18\x13 \x01(\r\x12\x18\n\x10selected_seconds\x18\x0c \x01(\r\x12\x15\n\ruser_settings\x18\r \x01(\r\x12\x16\n\x0eice_enable_var\x18\x0e \x01(\r\x12%\n\x1dlocal_candidate_types_allowed\x18\x0f \x01(\r*\xa7\x01\n\x1d\x45SteamNetworkingSocketsCipher\x12+\n\'k_ESteamNetworkingSocketsCipher_INVALID\x10\x00\x12(\n$k_ESteamNetworkingSocketsCipher_NULL\x10\x01\x12/\n+k_ESteamNetworkingSocketsCipher_AES_256_GCM\x10\x02\x42\x05H\x01\x90\x01\x00')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'steamnetworkingsockets_messages_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'H\001\220\001\000'
  _ESTEAMNETWORKINGSOCKETSCIPHER._serialized_start=4088
  _ESTEAMNETWORKINGSOCKETSCIPHER._serialized_end=4255
  _CMSGSTEAMDATAGRAMSESSIONCRYPTINFO._serialized_start=87
  _CMSGSTEAMDATAGRAMSESSIONCRYPTINFO._serialized_end=343
  _CMSGSTEAMDATAGRAMSESSIONCRYPTINFO_EKEYTYPE._serialized_start=304
  _CMSGSTEAMDATAGRAMSESSIONCRYPTINFO_EKEYTYPE._serialized_end=343
  _CMSGSTEAMDATAGRAMSESSIONCRYPTINFOSIGNED._serialized_start=345
  _CMSGSTEAMDATAGRAMSESSIONCRYPTINFOSIGNED._serialized_end=419
  _CMSGSTEAMDATAGRAMDIAGNOSTIC._serialized_start=421
  _CMSGSTEAMDATAGRAMDIAGNOSTIC._serialized_end=482
  _CMSGSTEAMDATAGRAMLINKINSTANTANEOUSSTATS._serialized_start=485
  _CMSGSTEAMDATAGRAMLINKINSTANTANEOUSSTATS._serialized_end=752
  _CMSGSTEAMDATAGRAMLINKLIFETIMESTATS._serialized_start=755
  _CMSGSTEAMDATAGRAMLINKLIFETIMESTATS._serialized_end=2144
  _CMSGSTEAMDATAGRAMCONNECTIONQUALITY._serialized_start=2147
  _CMSGSTEAMDATAGRAMCONNECTIONQUALITY._serialized_end=2303
  _CMSGICECANDIDATE._serialized_start=2305
  _CMSGICECANDIDATE._serialized_end=2342
  _CMSGICERENDEZVOUS._serialized_start=2344
  _CMSGICERENDEZVOUS._serialized_end=2470
  _CMSGICERENDEZVOUS_AUTH._serialized_start=2446
  _CMSGICERENDEZVOUS_AUTH._serialized_end=2470
  _CMSGSTEAMNETWORKINGP2PRENDEZVOUS._serialized_start=2473
  _CMSGSTEAMNETWORKINGP2PRENDEZVOUS._serialized_end=3660
  _CMSGSTEAMNETWORKINGP2PRENDEZVOUS_CONNECTREQUEST._serialized_start=3148
  _CMSGSTEAMNETWORKINGP2PRENDEZVOUS_CONNECTREQUEST._serialized_end=3345
  _CMSGSTEAMNETWORKINGP2PRENDEZVOUS_CONNECTOK._serialized_start=3347
  _CMSGSTEAMNETWORKINGP2PRENDEZVOUS_CONNECTOK._serialized_end=3466
  _CMSGSTEAMNETWORKINGP2PRENDEZVOUS_CONNECTIONCLOSED._serialized_start=3468
  _CMSGSTEAMNETWORKINGP2PRENDEZVOUS_CONNECTIONCLOSED._serialized_end=3522
  _CMSGSTEAMNETWORKINGP2PRENDEZVOUS_RELIABLEMESSAGE._serialized_start=3524
  _CMSGSTEAMNETWORKINGP2PRENDEZVOUS_RELIABLEMESSAGE._serialized_end=3574
  _CMSGSTEAMNETWORKINGP2PRENDEZVOUS_APPLICATIONMESSAGE._serialized_start=3576
  _CMSGSTEAMNETWORKINGP2PRENDEZVOUS_APPLICATIONMESSAGE._serialized_end=3660
  _CMSGSTEAMNETWORKINGICESESSIONSUMMARY._serialized_start=3663
  _CMSGSTEAMNETWORKINGICESESSIONSUMMARY._serialized_end=4085
# @@protoc_insertion_point(module_scope)
