# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: steammessages_shader.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import steam.protobufs.steammessages_base_pb2 as steammessages__base__pb2
import steam.protobufs.steammessages_unified_base_pb2 as steammessages__unified__base__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1asteammessages_shader.proto\x1a\x18steammessages_base.proto\x1a steammessages_unified_base.proto\"+\n)CShader_GetShaderReportingCadence_Request\"j\n*CShader_GetShaderReportingCadence_Response\x12\x1f\n\x17rereport_time_threshold\x18\x01 \x01(\x04\x12\x1b\n\x13percent_to_rereport\x18\x02 \x01(\r\"\xc9\x01\n\x1e\x43Shader_RegisterShader_Request\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x10\n\x08gpu_desc\x18\x02 \x01(\t\x12\x13\n\x0b\x64river_desc\x18\x03 \x01(\t\x12\x37\n\x07shaders\x18\x04 \x03(\x0b\x32&.CShader_RegisterShader_Request.Shader\x1a\x38\n\x06Shader\x12\x15\n\rcache_key_sha\x18\x01 \x01(\x0c\x12\x17\n\x0fshader_code_sha\x18\x02 \x01(\x0c\"<\n\x1f\x43Shader_RegisterShader_Response\x12\x19\n\x11requested_codeids\x18\x01 \x03(\r\"\xa0\x01\n\x1a\x43Shader_SendShader_Request\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x37\n\x07shaders\x18\x02 \x03(\x0b\x32&.CShader_SendShader_Request.ShaderCode\x1a:\n\nShaderCode\x12\x17\n\x0fshader_code_sha\x18\x01 \x01(\x0c\x12\x13\n\x0bshader_code\x18\x02 \x01(\x0c\"\x1d\n\x1b\x43Shader_SendShader_Response\"Y\n!CShader_GetBucketManifest_Request\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x10\n\x08gpu_desc\x18\x02 \x01(\t\x12\x13\n\x0b\x64river_desc\x18\x03 \x01(\t\"]\n\"CShader_GetBucketManifest_Response\x12\x12\n\nmanifestid\x18\x01 \x01(\x04\x12\x11\n\tdepotsize\x18\x02 \x01(\x04\x12\x10\n\x08\x62ucketid\x18\x03 \x01(\x04\"G\n\x1e\x43Shader_GetStaleBucket_Request\x12\x10\n\x08gpu_desc\x18\x01 \x01(\t\x12\x13\n\x0b\x64river_desc\x18\x02 \x01(\t\"\x9b\x01\n\x1f\x43Shader_GetStaleBucket_Response\x12\x10\n\x08\x62ucketid\x18\x01 \x01(\x04\x12\r\n\x05\x61ppid\x18\x02 \x01(\r\x12\x12\n\nmanifestid\x18\x03 \x01(\x04\x12\x10\n\x08gpu_desc\x18\x04 \x01(\t\x12\x13\n\x0b\x64river_desc\x18\x05 \x01(\t\x12\x1c\n\x14\x64\x65pot_encryption_key\x18\x06 \x01(\x0c\"\xb7\x01\n#CShader_ReportExternalBuild_Request\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x10\n\x08gpu_desc\x18\x02 \x01(\t\x12\x13\n\x0b\x64river_desc\x18\x03 \x01(\t\x12\x12\n\nmanifestid\x18\x04 \x01(\x04\x12\x17\n\x0fsource_gpu_desc\x18\x05 \x01(\t\x12\x1a\n\x12source_driver_desc\x18\x06 \x01(\t\x12\x11\n\tdepotsize\x18\x07 \x01(\x04\"&\n$CShader_ReportExternalBuild_Response2\xb3\x04\n\x06Shader\x12t\n\x19GetShaderReportingCadence\x12*.CShader_GetShaderReportingCadence_Request\x1a+.CShader_GetShaderReportingCadence_Response\x12S\n\x0eRegisterShader\x12\x1f.CShader_RegisterShader_Request\x1a .CShader_RegisterShader_Response\x12G\n\nSendShader\x12\x1b.CShader_SendShader_Request\x1a\x1c.CShader_SendShader_Response\x12\\\n\x11GetBucketManifest\x12\".CShader_GetBucketManifest_Request\x1a#.CShader_GetBucketManifest_Response\x12S\n\x0eGetStaleBucket\x12\x1f.CShader_GetStaleBucket_Request\x1a .CShader_GetStaleBucket_Response\x12\x62\n\x13ReportExternalBuild\x12$.CShader_ReportExternalBuild_Request\x1a%.CShader_ReportExternalBuild_ResponseB\x03\x90\x01\x01')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'steammessages_shader_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\220\001\001'
  _CSHADER_GETSHADERREPORTINGCADENCE_REQUEST._serialized_start=90
  _CSHADER_GETSHADERREPORTINGCADENCE_REQUEST._serialized_end=133
  _CSHADER_GETSHADERREPORTINGCADENCE_RESPONSE._serialized_start=135
  _CSHADER_GETSHADERREPORTINGCADENCE_RESPONSE._serialized_end=241
  _CSHADER_REGISTERSHADER_REQUEST._serialized_start=244
  _CSHADER_REGISTERSHADER_REQUEST._serialized_end=445
  _CSHADER_REGISTERSHADER_REQUEST_SHADER._serialized_start=389
  _CSHADER_REGISTERSHADER_REQUEST_SHADER._serialized_end=445
  _CSHADER_REGISTERSHADER_RESPONSE._serialized_start=447
  _CSHADER_REGISTERSHADER_RESPONSE._serialized_end=507
  _CSHADER_SENDSHADER_REQUEST._serialized_start=510
  _CSHADER_SENDSHADER_REQUEST._serialized_end=670
  _CSHADER_SENDSHADER_REQUEST_SHADERCODE._serialized_start=612
  _CSHADER_SENDSHADER_REQUEST_SHADERCODE._serialized_end=670
  _CSHADER_SENDSHADER_RESPONSE._serialized_start=672
  _CSHADER_SENDSHADER_RESPONSE._serialized_end=701
  _CSHADER_GETBUCKETMANIFEST_REQUEST._serialized_start=703
  _CSHADER_GETBUCKETMANIFEST_REQUEST._serialized_end=792
  _CSHADER_GETBUCKETMANIFEST_RESPONSE._serialized_start=794
  _CSHADER_GETBUCKETMANIFEST_RESPONSE._serialized_end=887
  _CSHADER_GETSTALEBUCKET_REQUEST._serialized_start=889
  _CSHADER_GETSTALEBUCKET_REQUEST._serialized_end=960
  _CSHADER_GETSTALEBUCKET_RESPONSE._serialized_start=963
  _CSHADER_GETSTALEBUCKET_RESPONSE._serialized_end=1118
  _CSHADER_REPORTEXTERNALBUILD_REQUEST._serialized_start=1121
  _CSHADER_REPORTEXTERNALBUILD_REQUEST._serialized_end=1304
  _CSHADER_REPORTEXTERNALBUILD_RESPONSE._serialized_start=1306
  _CSHADER_REPORTEXTERNALBUILD_RESPONSE._serialized_end=1344
  _SHADER._serialized_start=1347
  _SHADER._serialized_end=1910
_builder.BuildServices(DESCRIPTOR, 'steammessages_shader_pb2', globals())
# @@protoc_insertion_point(module_scope)
