# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: htmlmessages.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import steam.protobufs.enums_pb2 as enums__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x12htmlmessages.proto\x1a\x0b\x65nums.proto\"^\n\tCMsgKeyUp\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\x12\x0f\n\x07keyCode\x18\x02 \x01(\r\x12\x11\n\tmodifiers\x18\x03 \x01(\r\x12\x15\n\rnativeKeyCode\x18\x04 \x01(\r\"w\n\x0b\x43MsgKeyDown\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\x12\x0f\n\x07keyCode\x18\x02 \x01(\r\x12\x11\n\tmodifiers\x18\x03 \x01(\r\x12\x15\n\ris_system_key\x18\x04 \x01(\x08\x12\x15\n\rnativeKeyCode\x18\x05 \x01(\r\"q\n\x0b\x43MsgKeyChar\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\x12\x0f\n\x07unichar\x18\x02 \x01(\r\x12\x11\n\tmodifiers\x18\x03 \x01(\r\x12\x0f\n\x07keyCode\x18\x04 \x01(\r\x12\x15\n\rnativeKeyCode\x18\x05 \x01(\r\"P\n\rCMsgMouseDown\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\x12\x14\n\x0cmouse_button\x18\x02 \x01(\r\x12\x11\n\tmodifiers\x18\x03 \x01(\r\"z\n\x0b\x43MsgMouseUp\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\x12\x14\n\x0cmouse_button\x18\x02 \x01(\r\x12\x11\n\tmodifiers\x18\x03 \x01(\r\x12\x14\n\x0cis_off_panel\x18\x04 \x01(\x08\x12\t\n\x01x\x18\x05 \x01(\x05\x12\t\n\x01y\x18\x06 \x01(\x05\"T\n\x11\x43MsgMouseDblClick\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\x12\x14\n\x0cmouse_button\x18\x02 \x01(\r\x12\x11\n\tmodifiers\x18\x03 \x01(\r\"[\n\x0e\x43MsgMouseWheel\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\x12\x0e\n\x06\x64\x65ltax\x18\x02 \x01(\x05\x12\x0e\n\x06\x64\x65ltay\x18\x03 \x01(\x05\x12\x11\n\tmodifiers\x18\x04 \x01(\r\"P\n\rCMsgMouseMove\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\x12\t\n\x01x\x18\x02 \x01(\x05\x12\t\n\x01y\x18\x03 \x01(\x05\x12\x11\n\tmodifiers\x18\x04 \x01(\r\"(\n\x0e\x43MsgMouseLeave\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\"\xdd\x03\n\x11\x43MsgBrowserCreate\x12\x12\n\nrequest_id\x18\x01 \x01(\r\x12\x11\n\tuseragent\x18\x03 \x01(\t\x12\x10\n\x08user_css\x18\x05 \x01(\t\x12\x18\n\x10native_dropdowns\x18\x06 \x01(\x08\x12\x13\n\x0b\x64pi_scaling\x18\x07 \x01(\x02\x12\x17\n\toffscreen\x18\x08 \x01(\x08:\x04true\x12\x18\n\rinitial_width\x18\t \x01(\r:\x01\x30\x12\x19\n\x0einitial_height\x18\n \x01(\r:\x01\x30\x12\x13\n\x0bwindow_icon\x18\x0b \x01(\t\x12\x19\n\nborderless\x18\x0c \x01(\x08:\x05\x66\x61lse\x12\x15\n\rvroverlay_key\x18\r \x01(\t\x12\x17\n\x0c\x62rowser_type\x18\x0e \x01(\r:\x01\x30\x12 \n\x0binitial_top\x18\x0f \x01(\x05:\x0b-2147483648\x12!\n\x0cinitial_left\x18\x10 \x01(\x05:\x0b-2147483648\x12(\n\x19only_allow_trusted_popups\x18\x11 \x01(\x08:\x05\x66\x61lse\x12\x13\n\x0binitial_url\x18\x12 \x01(\t\x12\x13\n\x0bhwnd_parent\x18\x13 \x01(\x06\x12\x19\n\x0e\x63reation_flags\x18\x14 \x01(\r:\x01\x30\"G\n\x19\x43MsgBrowserCreateResponse\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\x12\x12\n\nrequest_id\x18\x02 \x01(\r\"+\n\x11\x43MsgBrowserRemove\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\"\x98\x02\n\x1e\x43MsgSetLocalFileRequestMapping\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\x12\x13\n\x0brequest_url\x18\x02 \x01(\t\x12\x1a\n\x12\x64\x65\x66\x61ult_local_path\x18\x03 \x01(\t\x12?\n\x06routes\x18\x04 \x03(\x0b\x32/.CMsgSetLocalFileRequestMapping.AdditionalRoute\x1al\n\x0f\x41\x64\x64itionalRoute\x12\x14\n\x0crelative_url\x18\x01 \x01(\t\x12\x12\n\nlocal_path\x18\x02 \x01(\t\x12\x1a\n\x12\x61llowed_extensions\x18\x03 \x01(\t\x12\x13\n\x0burl_rewrite\x18\x04 \x01(\x08\"\xb9\x01\n\x17\x43MsgBrowserErrorStrings\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\x12\r\n\x05title\x18\x02 \x01(\t\x12\x0e\n\x06header\x18\x03 \x01(\t\x12\x12\n\ncache_miss\x18\x04 \x01(\t\x12\x0f\n\x07\x62\x61\x64_url\x18\x05 \x01(\t\x12\x1a\n\x12\x63onnection_problem\x18\x06 \x01(\t\x12\x15\n\rproxy_problem\x18\x07 \x01(\t\x12\x0f\n\x07unknown\x18\x08 \x01(\t\":\n\x12\x43MsgBrowserSetName\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\x12\x0c\n\x04name\x18\x02 \x01(\t\"H\n\x0f\x43MsgBrowserSize\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\x12\r\n\x05width\x18\x02 \x01(\x01\x12\x0e\n\x06height\x18\x03 \x01(\x01\"N\n\x15\x43MsgBrowserSetMinSize\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\x12\r\n\x05width\x18\x02 \x01(\x01\x12\x0e\n\x06height\x18\x03 \x01(\x01\"e\n\x13\x43MsgBrowserPosition\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\x12\t\n\x01x\x18\x02 \x01(\x01\x12\t\n\x01y\x18\x03 \x01(\x01\x12\x0f\n\x07x_local\x18\x04 \x01(\x01\x12\x0f\n\x07y_local\x18\x05 \x01(\x01\"\xe8\x01\n\x12\x43MsgBrowserResized\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\x12\t\n\x01x\x18\x02 \x01(\x01\x12\t\n\x01y\x18\x03 \x01(\x01\x12\r\n\x05width\x18\x04 \x01(\x01\x12\x0e\n\x06height\x18\x05 \x01(\x01\x12\x12\n\nfullscreen\x18\x06 \x01(\x08\x12\x16\n\x0e\x64pi_horizontal\x18\x07 \x01(\x01\x12\x14\n\x0c\x64pi_vertical\x18\x08 \x01(\x01\x12\x14\n\x0c\x64isplay_name\x18\t \x01(\t\x12\x15\n\rdisplay_width\x18\n \x01(\r\x12\x16\n\x0e\x64isplay_height\x18\x0b \x01(\r\"k\n\x0b\x43MsgPostURL\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\x12\x0b\n\x03url\x18\x02 \x01(\t\x12\x0c\n\x04post\x18\x03 \x01(\t\x12\x12\n\npageserial\x18\x04 \x01(\r\x12\x15\n\rreplace_entry\x18\x05 \x01(\x08\"t\n\rCMsgAddHeader\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\x12\x0b\n\x03key\x18\x02 \x01(\t\x12\r\n\x05value\x18\x03 \x01(\t\x12\x1a\n\x12only_send_to_steam\x18\x04 \x01(\x08\x12\x13\n\x0bsend_in_xhr\x18\x05 \x01(\x08\"&\n\x0c\x43MsgStopLoad\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\"$\n\nCMsgReload\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\"\'\n\rCMsgGoForward\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\"$\n\nCMsgGoBack\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\"7\n\rCMsgWasHidden\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\x12\x0e\n\x06hidden\x18\x02 \x01(\x08\"B\n\x17\x43MsgSetWindowVisibility\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\x12\x0f\n\x07visible\x18\x02 \x01(\x08\"*\n\x10\x43MsgClearHistory\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\"2\n\x18\x43MsgClearAllBrowsingData\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\"\"\n\x08\x43MsgCopy\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\"#\n\tCMsgPaste\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\"?\n\x15\x43MsgExecuteJavaScript\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\x12\x0e\n\x06script\x18\x02 \x01(\t\"5\n\x0c\x43MsgSetFocus\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\x12\r\n\x05\x66ocus\x18\x02 \x01(\x08\"5\n\x1b\x43MsgHorizontalScrollBarSize\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\"\x93\x01\n#CMsgHorizontalScrollBarSizeResponse\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\x12\x12\n\nscroll_max\x18\x06 \x01(\r\x12\x0e\n\x06scroll\x18\x07 \x01(\r\x12\x0c\n\x04zoom\x18\x08 \x01(\x02\x12\x0f\n\x07visible\x18\t \x01(\x08\x12\x11\n\tpage_size\x18\n \x01(\r\"3\n\x19\x43MsgVerticalScrollBarSize\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\"\x91\x01\n!CMsgVerticalScrollBarSizeResponse\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\x12\x12\n\nscroll_max\x18\x06 \x01(\r\x12\x0e\n\x06scroll\x18\x07 \x01(\r\x12\x0c\n\x04zoom\x18\x08 \x01(\x02\x12\x0f\n\x07visible\x18\t \x01(\x08\x12\x11\n\tpage_size\x18\n \x01(\r\"X\n\x08\x43MsgFind\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\x12\x0c\n\x04\x66ind\x18\x02 \x01(\t\x12\x0e\n\x06infind\x18\x03 \x01(\x08\x12\x16\n\x07reverse\x18\x04 \x01(\x08:\x05\x66\x61lse\"&\n\x0c\x43MsgStopFind\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\"A\n\x17\x43MsgSetHorizontalScroll\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\x12\x0e\n\x06scroll\x18\x02 \x01(\r\"?\n\x15\x43MsgSetVerticalScroll\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\x12\x0e\n\x06scroll\x18\x02 \x01(\r\"8\n\x10\x43MsgSetZoomLevel\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\x12\x0c\n\x04zoom\x18\x02 \x01(\x01\"(\n\x0e\x43MsgViewSource\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\"X\n\x10\x43MsgBrowserReady\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\x12\x16\n\x0evr_overlay_key\x18\x02 \x01(\t\x12\x14\n\x0chwnd_browser\x18\x03 \x01(\x06\"\x87\x01\n\x0e\x43MsgURLChanged\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\x12\x0b\n\x03url\x18\x02 \x01(\t\x12\x10\n\x08postData\x18\x03 \x01(\t\x12\x13\n\x0b\x62IsRedirect\x18\x04 \x01(\x08\x12\x11\n\tpagetitle\x18\x05 \x01(\t\x12\x16\n\x0e\x62NewNavigation\x18\x06 \x01(\x08\"\x1c\n\rCHistoryEntry\x12\x0b\n\x03url\x18\x01 \x01(\t\"\\\n\x12\x43MsgHistoryChanged\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\x12\r\n\x05index\x18\x02 \x01(\r\x12\x1f\n\x07\x65ntries\x18\x03 \x03(\x0b\x32\x0e.CHistoryEntry\"c\n\rCMsgLoadError\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\x12\x12\n\nerror_code\x18\x02 \x01(\x05\x12\x0b\n\x03url\x18\x03 \x01(\t\x12\x19\n\x11\x65rror_description\x18\x04 \x01(\t\")\n\x0b\x43HTMLHeader\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\"\xbc\x01\n\x15\x43HTMLPageSecurityInfo\x12\x18\n\tbIsSecure\x18\x01 \x01(\x08:\x05\x66\x61lse\x12\x1c\n\rbHasCertError\x18\x02 \x01(\x08:\x05\x66\x61lse\x12\x12\n\nissuerName\x18\x03 \x01(\t\x12\x10\n\x08\x63\x65rtName\x18\x04 \x01(\t\x12\x15\n\ncertExpiry\x18\x05 \x01(\x05:\x01\x30\x12\x14\n\tnCertBits\x18\x06 \x01(\x05:\x01\x30\x12\x18\n\tbIsEVCert\x18\x07 \x01(\x08:\x05\x66\x61lse\"M\n\x13\x43MsgFinishedRequest\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\x12\x0b\n\x03url\x18\x02 \x01(\t\x12\x11\n\tpageTitle\x18\x03 \x01(\t\"j\n\x11\x43MsgLoadedRequest\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\x12\x0b\n\x03url\x18\x02 \x01(\t\x12\x11\n\tpageTitle\x18\x03 \x01(\t\x12\x1d\n\x07headers\x18\x05 \x03(\x0b\x32\x0c.CHTMLHeader\"=\n\x15\x43MsgFavIconURLChanged\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\x12\x0c\n\x04urls\x18\x02 \x03(\t\"f\n\x10\x43MsgPageSecurity\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\x12\x0b\n\x03url\x18\x02 \x01(\t\x12-\n\rsecurity_info\x18\x03 \x01(\x0b\x32\x16.CHTMLPageSecurityInfo\"n\n\x10\x43MsgStartRequest\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\x12\x0b\n\x03url\x18\x02 \x01(\t\x12\x0e\n\x06target\x18\x03 \x01(\t\x12\x10\n\x08postData\x18\x04 \x01(\t\x12\x13\n\x0b\x62IsRedirect\x18\x05 \x01(\x08\"B\n\x18\x43MsgStartRequestResponse\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\x12\x0e\n\x06\x62\x41llow\x18\x02 \x01(\x08\"\'\n\rCMsgShowPopup\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\"\'\n\rCMsgHidePopup\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\"Y\n\rCMsgSizePopup\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\x12\t\n\x01x\x18\x02 \x01(\x05\x12\t\n\x01y\x18\x03 \x01(\x05\x12\x0c\n\x04wide\x18\x04 \x01(\r\x12\x0c\n\x04tall\x18\x05 \x01(\r\"J\n\x0e\x43MsgOpenNewTab\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\x12\x0b\n\x03url\x18\x02 \x01(\t\x12\x13\n\x0b\x62\x46oreground\x18\x03 \x01(\x08\"\x84\x02\n\x13\x43MsgPopupHTMLWindow\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\x12\x0b\n\x03url\x18\x02 \x01(\t\x12\x16\n\x01x\x18\x03 \x01(\x05:\x0b-2147483648\x12\x16\n\x01y\x18\x04 \x01(\x05:\x0b-2147483648\x12\x0c\n\x04wide\x18\x05 \x01(\r\x12\x0c\n\x04tall\x18\x06 \x01(\r\x12\x13\n\x0bpopup_index\x18\x07 \x01(\r\x12\x17\n\x0ftrusted_creator\x18\x08 \x01(\x08\x12\x0c\n\x04name\x18\t \x01(\t\x12\x0c\n\x04hwnd\x18\n \x01(\x04\x12\x1a\n\x12parent_popup_index\x18\x0b \x01(\r\x12\x16\n\x0e\x63reation_flags\x18\x0c \x01(\r\"E\n\x1b\x43MsgPopupHTMLWindowResponse\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\x12\x0e\n\x06\x62\x41llow\x18\x02 \x01(\x08\"9\n\x10\x43MsgSetHTMLTitle\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\x12\r\n\x05title\x18\x02 \x01(\t\":\n\x13\x43MsgLoadingResource\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\x12\x0b\n\x03url\x18\x02 \x01(\t\"6\n\x0e\x43MsgStatusText\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\x12\x0c\n\x04text\x18\x02 \x01(\t\"\x8c\x01\n\rCMsgSetCursor\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\x12\x0e\n\x06\x63ursor\x18\x02 \x01(\r\x12\x13\n\x0b\x63ustom_data\x18\x03 \x01(\x0c\x12\x0c\n\x04wide\x18\x04 \x01(\r\x12\x0c\n\x04tall\x18\x05 \x01(\r\x12\x10\n\x08xhotspot\x18\x06 \x01(\r\x12\x10\n\x08yhotspot\x18\x07 \x01(\r\"\x9b\x02\n\x12\x43MsgFileLoadDialog\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\x12\x1d\n\x15owning_browser_handle\x18\x02 \x01(\r\x12\r\n\x05title\x18\x03 \x01(\t\x12\x13\n\x0binitialFile\x18\x04 \x01(\t\x12\x14\n\x0c\x61\x63\x63\x65pt_types\x18\x05 \x03(\t\x12\x0f\n\x07is_save\x18\x06 \x01(\x08\x12\x18\n\x10\x63hoose_directory\x18\x07 \x01(\x08\x12+\n\x07\x66ilters\x18\x08 \x03(\x0b\x32\x1a.CMsgFileLoadDialog.Filter\x1a<\n\x06\x46ilter\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x10\n\x08patterns\x18\x02 \x03(\t\x12\x12\n\nis_default\x18\x03 \x01(\x08\"t\n\x1a\x43MsgFileLoadDialogResponse\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\x12\x1d\n\x15owning_browser_handle\x18\x02 \x01(\r\x12\x10\n\x08\x62success\x18\x03 \x01(\x08\x12\r\n\x05\x66iles\x18\x04 \x03(\t\"+\n\x16\x43MsgRequestProcessInfo\x12\x11\n\trequestid\x18\x01 \x01(\x04\"\xeb\n\n\x1b\x43MsgProcessInfoNotification\x12\x11\n\trequestid\x18\x01 \x01(\x04\x12\x43\n\ngpu_status\x18\x02 \x01(\x0e\x32\x12.EBrowserGPUStatus:\x1bk_EBrowserGPUStatus_Invalid\x12J\n\tcanvas_2d\x18\x03 \x01(\x0e\x32\x16.EBrowserFeatureStatus:\x1fk_EBrowserFeatureStatus_Invalid\x12Y\n\x18\x63\x61nvas_oop_rasterization\x18\x04 \x01(\x0e\x32\x16.EBrowserFeatureStatus:\x1fk_EBrowserFeatureStatus_Invalid\x12\x64\n#direct_rendering_display_compositor\x18\x05 \x01(\x0e\x32\x16.EBrowserFeatureStatus:\x1fk_EBrowserFeatureStatus_Invalid\x12P\n\x0fgpu_compositing\x18\x06 \x01(\x0e\x32\x16.EBrowserFeatureStatus:\x1fk_EBrowserFeatureStatus_Invalid\x12X\n\x17multiple_raster_threads\x18\x07 \x01(\x0e\x32\x16.EBrowserFeatureStatus:\x1fk_EBrowserFeatureStatus_Invalid\x12G\n\x06opengl\x18\x08 \x01(\x0e\x32\x16.EBrowserFeatureStatus:\x1fk_EBrowserFeatureStatus_Invalid\x12N\n\rrasterization\x18\t \x01(\x0e\x32\x16.EBrowserFeatureStatus:\x1fk_EBrowserFeatureStatus_Invalid\x12I\n\x08raw_draw\x18\n \x01(\x0e\x32\x16.EBrowserFeatureStatus:\x1fk_EBrowserFeatureStatus_Invalid\x12N\n\rskia_graphite\x18\x0b \x01(\x0e\x32\x16.EBrowserFeatureStatus:\x1fk_EBrowserFeatureStatus_Invalid\x12M\n\x0cvideo_decode\x18\r \x01(\x0e\x32\x16.EBrowserFeatureStatus:\x1fk_EBrowserFeatureStatus_Invalid\x12M\n\x0cvideo_encode\x18\x0e \x01(\x0e\x32\x16.EBrowserFeatureStatus:\x1fk_EBrowserFeatureStatus_Invalid\x12G\n\x06vulkan\x18\x0f \x01(\x0e\x32\x16.EBrowserFeatureStatus:\x1fk_EBrowserFeatureStatus_Invalid\x12\x46\n\x05webgl\x18\x10 \x01(\x0e\x32\x16.EBrowserFeatureStatus:\x1fk_EBrowserFeatureStatus_Invalid\x12G\n\x06webgl2\x18\x11 \x01(\x0e\x32\x16.EBrowserFeatureStatus:\x1fk_EBrowserFeatureStatus_Invalid\x12G\n\x06webgpu\x18\x12 \x01(\x0e\x32\x16.EBrowserFeatureStatus:\x1fk_EBrowserFeatureStatus_Invalid\x12\x46\n\x05webnn\x18\x13 \x01(\x0e\x32\x16.EBrowserFeatureStatus:\x1fk_EBrowserFeatureStatus_Invalid\"7\n\x0f\x43MsgShowToolTip\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\x12\x0c\n\x04text\x18\x02 \x01(\t\"9\n\x11\x43MsgUpdateToolTip\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\x12\x0c\n\x04text\x18\x02 \x01(\t\")\n\x0f\x43MsgHideToolTip\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\"Q\n\x11\x43MsgSearchResults\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\x12\x13\n\x0b\x61\x63tiveMatch\x18\x02 \x01(\x05\x12\x0f\n\x07results\x18\x03 \x01(\x05\"#\n\tCMsgClose\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\"\x8a\x01\n\x19\x43MsgSetSharedPaintBuffers\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\x12\x0c\n\x04wide\x18\x02 \x01(\r\x12\x0c\n\x04tall\x18\x03 \x01(\r\x12\x12\n\nsource_pid\x18\x04 \x01(\x04\x12\x15\n\rsource_handle\x18\x05 \x01(\x04\x12\x0e\n\x06handle\x18\x06 \x01(\x04\"3\n\x19\x43MsgAckSharedPaintBuffers\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\"\xbb\x01\n\x0e\x43MsgNeedsPaint\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\x12\x0f\n\x07scrollx\x18\n \x01(\r\x12\x0f\n\x07scrolly\x18\x0b \x01(\r\x12\x11\n\tpagescale\x18\x0c \x01(\x02\x12\x12\n\npageserial\x18\x0f \x01(\r\x12\x14\n\x0c\x61vg_frame_ms\x18\x14 \x01(\r\x12\x1b\n\x13stddev_sum_frame_ms\x18\x15 \x01(\x02\x12\x15\n\rlong_frame_ms\x18\x16 \x01(\r\"\xaf\x01\n\x13\x43MsgComboNeedsPaint\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\x12\x0c\n\x04rgba\x18\x02 \x01(\x04\x12\x18\n\rcombobox_wide\x18\x03 \x01(\r:\x01\x30\x12\x18\n\rcombobox_tall\x18\x04 \x01(\r:\x01\x30\x12\x1f\n\x14shared_memory_handle\x18\x05 \x01(\x04:\x01\x30\x12\x1d\n\x12shared_memory_size\x18\x07 \x01(\x04:\x01\x30\"\xb3\x01\n\x1b\x43MsgNeedsSharedTexturePaint\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\x12\x14\n\x0cshare_handle\x18\x02 \x01(\r\x12\r\n\x05width\x18\x03 \x01(\r\x12\x0e\n\x06height\x18\x04 \x01(\r\x12\x0f\n\x07scrollx\x18\x05 \x01(\r\x12\x0f\n\x07scrolly\x18\x06 \x01(\r\x12\x11\n\tpagescale\x18\x07 \x01(\x02\x12\x12\n\npageserial\x18\x08 \x01(\r\"%\n\x0b\x43MsgGetZoom\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\";\n\x13\x43MsgGetZoomResponse\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\x12\x0c\n\x04zoom\x18\x02 \x01(\x02\"B\n\x12\x43MsgLinkAtPosition\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\x12\t\n\x01x\x18\x02 \x01(\r\x12\t\n\x01y\x18\x03 \x01(\r\"z\n\x1a\x43MsgLinkAtPositionResponse\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\x12\t\n\x01x\x18\x02 \x01(\r\x12\t\n\x01y\x18\x03 \x01(\r\x12\x0b\n\x03url\x18\x04 \x01(\t\x12\x11\n\tblivelink\x18\x05 \x01(\x08\x12\x0e\n\x06\x62input\x18\x06 \x01(\x08\"K\n\x1b\x43MsgZoomToElementAtPosition\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\x12\t\n\x01x\x18\x02 \x01(\r\x12\t\n\x01y\x18\x03 \x01(\r\"^\n#CMsgZoomToElementAtPositionResponse\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\x12\r\n\x05scale\x18\x02 \x01(\x02\x12\x10\n\x08\x64uration\x18\x03 \x01(\x02\"S\n\x14\x43MsgScalePageToValue\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\x12\r\n\x05scale\x18\x02 \x01(\x02\x12\t\n\x01x\x18\x03 \x01(\x02\x12\t\n\x01y\x18\x04 \x01(\x02\"W\n\x1b\x43MsgForcePopupsToDirectHWND\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\x12 \n\x18\x66orce_direct_hwnd_popups\x18\x02 \x01(\x08\"D\n\x1c\x43MsgScalePageToValueResponse\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\x12\x0c\n\x04zoom\x18\x02 \x01(\x02\"j\n\x12\x43MsgSavePageToJPEG\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\x12\x0b\n\x03url\x18\x02 \x01(\t\x12\x10\n\x08\x66ilename\x18\x03 \x01(\t\x12\r\n\x05width\x18\x04 \x01(\r\x12\x0e\n\x06height\x18\x05 \x01(\r\"S\n\x1a\x43MsgSavePageToJPEGResponse\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\x12\x0b\n\x03url\x18\x02 \x01(\t\x12\x10\n\x08\x66ilename\x18\x03 \x01(\t\"6\n\x0b\x43MsgJSAlert\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\x12\x0f\n\x07message\x18\x02 \x01(\t\"8\n\rCMsgJSConfirm\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\x12\x0f\n\x07message\x18\x02 \x01(\t\">\n\x14\x43MsgJSDialogResponse\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\x12\x0e\n\x06result\x18\x02 \x01(\x08\"V\n\x17\x43MsgCanGoBackAndForward\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\x12\x0f\n\x07\x62goback\x18\x02 \x01(\x08\x12\x12\n\nbgoforward\x18\x03 \x01(\x08\"I\n\x10\x43MsgOpenSteamURL\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\x12\x0b\n\x03url\x18\x02 \x01(\t\x12\x10\n\x08referrer\x18\x03 \x01(\t\"\x8c\x01\n\rCMsgSetCookie\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\x12\x0c\n\x04path\x18\x03 \x01(\t\x12\x0c\n\x04host\x18\x04 \x01(\t\x12\x0f\n\x07\x65xpires\x18\x05 \x01(\r\x12\x0e\n\x06secure\x18\x06 \x01(\x08\x12\x10\n\x08httponly\x18\x07 \x01(\x08\x12\x10\n\x08samesite\x18\x08 \x01(\x05\"J\n\x16\x43MsgSetTargetFrameRate\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\x12\x18\n\x10nTargetFrameRate\x18\x02 \x01(\r\"*\n\x10\x43MsgPauseRepaint\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\")\n\x0f\x43MsgFullRepaint\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\"/\n\x15\x43MsgRequestFullScreen\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\",\n\x12\x43MsgExitFullScreen\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\"4\n\x1a\x43MsgToggleFindInPageDialog\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\"0\n\x16\x43MsgSetPIDShuttingDown\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\"9\n\x1f\x43MsgDisableBackgroundThrottling\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\"0\n\x16\x43MsgAckPIDShuttingDown\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\";\n\x14\x43MsgGetCookiesForURL\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\x12\x0b\n\x03url\x18\x02 \x01(\t\"D\n\x07\x43\x43ookie\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\x12\x0e\n\x06\x64omain\x18\x03 \x01(\t\x12\x0c\n\x04path\x18\x04 \x01(\t\"^\n\x1c\x43MsgGetCookiesForURLResponse\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\x12\x0b\n\x03url\x18\x02 \x01(\t\x12\x19\n\x07\x63ookies\x18\x03 \x03(\x0b\x32\x08.CCookie\"\xc0\x01\n\x10\x43MsgNodeHasFocus\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\x12\x0e\n\x06\x62Input\x18\x02 \x01(\x08\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x16\n\x0e\x65lementtagname\x18\x04 \x01(\t\x12\x18\n\x10searchbuttontext\x18\x05 \x01(\t\x12\x1a\n\x12\x62HasMultipleInputs\x18\x06 \x01(\x08\x12\x12\n\ninput_type\x18\x07 \x01(\t\x12\x14\n\x0c\x62IsMainFrame\x18\x08 \x01(\x08\"2\n\x18\x43MsgZoomToFocusedElement\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\"-\n\x13\x43MsgFocusedNodeText\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\"D\n\x1b\x43MsgFocusedNodeTextResponse\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\x12\r\n\x05value\x18\x02 \x01(\t\"\x1f\n\x0b\x43MsgBuildID\x12\x10\n\x08\x62uild_id\x18\x01 \x01(\x04\"*\n\x10\x43MsgOpenDevTools\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\"+\n\x11\x43MsgCloseDevTools\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\"=\n\x0e\x43MsgUnlockH264\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\x12\x13\n\x0bunlock_code\x18\x02 \x01(\t\"g\n\x1c\x43MsgScreenInformationChanged\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\x12\x16\n\x0eoverride_width\x18\x02 \x01(\x01\x12\x17\n\x0foverride_height\x18\x03 \x01(\x01\"-\n\x13\x43MsgClearAllCookies\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\"<\n\rCMsgScreenDPI\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\x12\x13\n\x0b\x64pi_scaling\x18\x02 \x01(\x02\"*\n\x10\x43MsgAckScreenDPI\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\")\n\x16\x43MsgAuthedSteamDomains\x12\x0f\n\x07\x64omains\x18\x01 \x03(\t\"%\n\x13\x43MsgSteamAuthNeeded\x12\x0e\n\x06\x66iller\x18\x01 \x01(\x08\"*\n\x17\x43MsgSteamAuthCookiesSet\x12\x0f\n\x07success\x18\x01 \x01(\x08\"\x8a\x01\n\x14\x43MsgJSRegisterMethod\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\x12\x0c\n\x04name\x18\x02 \x01(\t\x12L\n\x0bmethod_type\x18\x03 \x01(\x0e\x32\x16.EJSRegisterMethodType:\x1fk_EJSRegisterMethodType_Invalid\"\xe4\x02\n\x0b\x43MsgJSValue\x12\x12\n\nbool_value\x18\x01 \x01(\x08\x12\x11\n\tint_value\x18\x02 \x01(\x05\x12\x12\n\nuint_value\x18\x03 \x01(\r\x12\x14\n\x0c\x64ouble_value\x18\x04 \x01(\x01\x12\x14\n\x0cstring_value\x18\x05 \x01(\t\x12\x17\n\x0f\x66unction_handle\x18\x06 \x01(\x04\x12\x13\n\x0b\x62ytes_value\x18\x0c \x01(\x0c\x12\x10\n\x08is_array\x18\x08 \x01(\x08\x12\"\n\x0c\x61rray_values\x18\t \x03(\x0b\x32\x0c.CMsgJSValue\x12\x11\n\tis_object\x18\n \x01(\x08\x12\x38\n\x11object_properties\x18\x0b \x03(\x0b\x32\x1d.CMsgJSValue.JSObjectProperty\x1a=\n\x10JSObjectProperty\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x1b\n\x05value\x18\x02 \x01(\x0b\x32\x0c.CMsgJSValue\"x\n\x10\x43MsgJSMethodCall\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\x12\x1d\n\x15owning_browser_handle\x18\x02 \x01(\r\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x1f\n\targuments\x18\x04 \x03(\x0b\x32\x0c.CMsgJSValue\"\x88\x01\n\x15\x43MsgJSExecuteCallback\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\x12\x1d\n\x15owning_browser_handle\x18\x02 \x01(\r\x12\x17\n\x0f\x66unction_handle\x18\x03 \x01(\x04\x12\x1f\n\targuments\x18\x04 \x03(\x0b\x32\x0c.CMsgJSValue\"\x9c\x01\n\x14\x43MsgJSExecutePromise\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\x12\x1d\n\x15owning_browser_handle\x18\x02 \x01(\r\x12\x16\n\x0epromise_handle\x18\x03 \x01(\x04\x12\x15\n\rreject_reason\x18\x04 \x01(\t\x12\x1e\n\x08\x61rgument\x18\x05 \x01(\x0b\x32\x0c.CMsgJSValue\"g\n\x15\x43MsgJSReleaseCallback\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\x12\x1d\n\x15owning_browser_handle\x18\x02 \x01(\r\x12\x17\n\x0f\x66unction_handle\x18\x03 \x01(\x04\"`\n\x14\x43MsgJSRaiseException\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\x12\x1d\n\x15owning_browser_handle\x18\x02 \x01(\r\x12\x11\n\texception\x18\x03 \x01(\t\"[\n\x14\x43MsgLoadLocalization\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\x12\x19\n\x11localization_path\x18\x02 \x01(\t\x12\x10\n\x08language\x18\x03 \x01(\t\"2\n\x18\x43MsgNotifyUserActivation\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\"/\n\x1e\x43MsgSetNetFakeLocalSystemState\x12\r\n\x05state\x18\x01 \x01(\r\"\xe0\x01\n\x1b\x43MsgDraggableRegionsChanged\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\x12:\n\x05rects\x18\x02 \x03(\x0b\x32+.CMsgDraggableRegionsChanged.DraggableRects\x1am\n\x0e\x44raggableRects\x12\t\n\x01x\x18\x01 \x01(\x05\x12\t\n\x01y\x18\x02 \x01(\x05\x12\r\n\x05width\x18\x03 \x01(\x05\x12\x0e\n\x06height\x18\x04 \x01(\x05\x12\x11\n\tdraggable\x18\x05 \x01(\x08\x12\x13\n\x0btransparent\x18\x06 \x01(\x08\"N\n\x15\x43MsgResizeGripChanged\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\x12\r\n\x05width\x18\x02 \x01(\x05\x12\x0e\n\x06height\x18\x03 \x01(\x05\"\xb2\x01\n\x15\x43MsgSetWindowPosition\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\x12\t\n\x01x\x18\x02 \x01(\x01\x12\t\n\x01y\x18\x03 \x01(\x01\x12\r\n\x05width\x18\x04 \x01(\x01\x12\x0e\n\x06height\x18\x05 \x01(\x01\x12\x11\n\tmin_width\x18\x06 \x01(\x01\x12\x12\n\nmin_height\x18\x07 \x01(\x01\x12\x11\n\tmax_width\x18\x08 \x01(\x01\x12\x12\n\nmax_height\x18\t \x01(\x01\"(\n\x0e\x43MsgShowWindow\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\"(\n\x0e\x43MsgHideWindow\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\"0\n\x16\x43MsgBringWindowToFront\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\"1\n\x17\x43MsgSetForegroundWindow\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\"3\n\x19\x43MsgMaximizeRestoreWindow\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\",\n\x12\x43MsgMinimizeWindow\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\"\xe8\x02\n\x1a\x43MsgShowBrowserContextMenu\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\x12\x43\n\x0f\x63ustom_commands\x18\x02 \x03(\x0b\x32*.CMsgShowBrowserContextMenu.ContextCommand\x12\x12\n\ntype_flags\x18\x03 \x01(\r\x12\x10\n\x08page_url\x18\x04 \x01(\t\x12\x0f\n\x07\x63oord_x\x18\x05 \x01(\x05\x12\x0f\n\x07\x63oord_y\x18\x06 \x01(\x05\x12\x10\n\x08link_url\x18\x07 \x01(\t\x12\x1b\n\x13unfiltered_link_url\x18\x08 \x01(\t\x12\x16\n\x0eselection_text\x18\t \x01(\t\x12\x17\n\x0fmisspelled_word\x18\n \x01(\t\x12\x18\n\x10\x65\x64it_state_flags\x18\x0b \x01(\r\x1a+\n\x0e\x43ontextCommand\x12\n\n\x02id\x18\x01 \x01(\x05\x12\r\n\x05label\x18\x02 \x01(\t\"J\n\x1c\x43MsgHandleContextMenuCommand\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\x12\x12\n\ncommand_id\x18\x02 \x01(\x05\"\xa4\x01\n\x10\x43MsgTouchGesture\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\x12\n\n\x02id\x18\x02 \x01(\x05\x12\x0f\n\x07gesture\x18\x03 \x01(\r\x12\t\n\x01x\x18\x04 \x01(\x01\x12\t\n\x01y\x18\x05 \x01(\x01\x12\r\n\x05width\x18\x06 \x01(\x01\x12\x0e\n\x06height\x18\x07 \x01(\x01\x12\x11\n\ttap_count\x18\x08 \x01(\r\x12\x13\n\x0bpinch_scale\x18\t \x01(\x01\"H\n\x1c\x43MsgSetTouchGesturesToCancel\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\x12\x10\n\x08gestures\x18\x02 \x03(\r\"=\n\x15\x43MsgImeSetComposition\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\x12\x0c\n\x04text\x18\x02 \x01(\t\"9\n\x11\x43MsgImeCommitText\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\x12\x0c\n\x04text\x18\x02 \x01(\t\"2\n\x18\x43MsgImeCancelComposition\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\"N\n\x1e\x43MsgImeCompositionRangeChanged\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\x12\t\n\x01x\x18\x02 \x01(\x01\x12\t\n\x01y\x18\x03 \x01(\x01\"B\n\x12\x43MsgInspectElement\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\x12\t\n\x01x\x18\x02 \x01(\r\x12\t\n\x01y\x18\x03 \x01(\r\"8\n\rCMsgDisableF5\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\x12\x0f\n\x07\x64isable\x18\x02 \x01(\x08\"8\n\x11\x43MsgStartDownload\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\x12\x0b\n\x03url\x18\x02 \x01(\t\"L\n\x1a\x43MsgSetWindowStackingOrder\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\x12\x16\n\x0e\x65stackingorder\x18\x02 \x01(\r\"z\n)CMsgBrowserViewPostMessageToParentRequest\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\x12\x0f\n\x07message\x18\x02 \x01(\t\x12\x0c\n\x04\x61rgs\x18\x03 \x01(\t\x12\x16\n\x0erequesting_url\x18\x04 \x01(\t\"9\n\x12\x43MsgBlockedRequest\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\x12\x0b\n\x03url\x18\x02 \x01(\t\"B\n\x17\x43MsgBrowserFocusChanged\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\x12\x0f\n\x07\x66ocused\x18\x02 \x01(\x08\"@\n\x18\x43MsgSetProtocolBlockList\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\x12\x0c\n\x04list\x18\x02 \x01(\t\"J\n\x1e\x43MsgSetForceDeviceScaleFactors\x12\x11\n\tdpi_scale\x18\x01 \x01(\x01\x12\x15\n\rbrowser_scale\x18\x02 \x01(\x01\" \n\rCMsgSetUIMode\x12\x0f\n\x07ui_mode\x18\x01 \x01(\x05\"/\n\x14\x43MsgSetSteamBetaName\x12\x17\n\x0fsteam_beta_name\x18\x01 \x01(\t\"\"\n\x0e\x43MsgSetSteamID\x12\x10\n\x08steam_id\x18\x01 \x01(\x04\"*\n\x10\x43MsgPopupCreated\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\"F\n\x1b\x43MsgSetVRKeyboardVisibility\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\x12\x0f\n\x07visible\x18\x02 \x01(\x08\"\x16\n\x14\x43MsgRestartJSContext\"\xb7\x01\n\x1c\x43MsgSetAccessibilitySettings\x12\x1e\n\x16reduced_motion_enabled\x18\x01 \x01(\x08\x12\\\n\x12preferred_contrast\x18\x02 \x01(\x0e\x32\x1b.EAccessibilityContrastMode:#k_EBrowserContrastMode_NoPreference\x12\x19\n\x11minimum_font_size\x18\x03 \x01(\r*\xad\x01\n\x15\x45JSRegisterMethodType\x12#\n\x1fk_EJSRegisterMethodType_Invalid\x10\x00\x12$\n k_EJSRegisterMethodType_Function\x10\x01\x12$\n k_EJSRegisterMethodType_Callback\x10\x02\x12#\n\x1fk_EJSRegisterMethodType_Promise\x10\x03*\x87\x01\n\x1a\x45\x41\x63\x63\x65ssibilityContrastMode\x12\'\n#k_EBrowserContrastMode_NoPreference\x10\x00\x12\x1f\n\x1bk_EBrowserContrastMode_More\x10\x01\x12\x1f\n\x1bk_EBrowserContrastMode_Less\x10\x02\x42\x05H\x01\x90\x01\x00')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'htmlmessages_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'H\001\220\001\000'
  _EJSREGISTERMETHODTYPE._serialized_start=16188
  _EJSREGISTERMETHODTYPE._serialized_end=16361
  _EACCESSIBILITYCONTRASTMODE._serialized_start=16364
  _EACCESSIBILITYCONTRASTMODE._serialized_end=16499
  _CMSGKEYUP._serialized_start=35
  _CMSGKEYUP._serialized_end=129
  _CMSGKEYDOWN._serialized_start=131
  _CMSGKEYDOWN._serialized_end=250
  _CMSGKEYCHAR._serialized_start=252
  _CMSGKEYCHAR._serialized_end=365
  _CMSGMOUSEDOWN._serialized_start=367
  _CMSGMOUSEDOWN._serialized_end=447
  _CMSGMOUSEUP._serialized_start=449
  _CMSGMOUSEUP._serialized_end=571
  _CMSGMOUSEDBLCLICK._serialized_start=573
  _CMSGMOUSEDBLCLICK._serialized_end=657
  _CMSGMOUSEWHEEL._serialized_start=659
  _CMSGMOUSEWHEEL._serialized_end=750
  _CMSGMOUSEMOVE._serialized_start=752
  _CMSGMOUSEMOVE._serialized_end=832
  _CMSGMOUSELEAVE._serialized_start=834
  _CMSGMOUSELEAVE._serialized_end=874
  _CMSGBROWSERCREATE._serialized_start=877
  _CMSGBROWSERCREATE._serialized_end=1354
  _CMSGBROWSERCREATERESPONSE._serialized_start=1356
  _CMSGBROWSERCREATERESPONSE._serialized_end=1427
  _CMSGBROWSERREMOVE._serialized_start=1429
  _CMSGBROWSERREMOVE._serialized_end=1472
  _CMSGSETLOCALFILEREQUESTMAPPING._serialized_start=1475
  _CMSGSETLOCALFILEREQUESTMAPPING._serialized_end=1755
  _CMSGSETLOCALFILEREQUESTMAPPING_ADDITIONALROUTE._serialized_start=1647
  _CMSGSETLOCALFILEREQUESTMAPPING_ADDITIONALROUTE._serialized_end=1755
  _CMSGBROWSERERRORSTRINGS._serialized_start=1758
  _CMSGBROWSERERRORSTRINGS._serialized_end=1943
  _CMSGBROWSERSETNAME._serialized_start=1945
  _CMSGBROWSERSETNAME._serialized_end=2003
  _CMSGBROWSERSIZE._serialized_start=2005
  _CMSGBROWSERSIZE._serialized_end=2077
  _CMSGBROWSERSETMINSIZE._serialized_start=2079
  _CMSGBROWSERSETMINSIZE._serialized_end=2157
  _CMSGBROWSERPOSITION._serialized_start=2159
  _CMSGBROWSERPOSITION._serialized_end=2260
  _CMSGBROWSERRESIZED._serialized_start=2263
  _CMSGBROWSERRESIZED._serialized_end=2495
  _CMSGPOSTURL._serialized_start=2497
  _CMSGPOSTURL._serialized_end=2604
  _CMSGADDHEADER._serialized_start=2606
  _CMSGADDHEADER._serialized_end=2722
  _CMSGSTOPLOAD._serialized_start=2724
  _CMSGSTOPLOAD._serialized_end=2762
  _CMSGRELOAD._serialized_start=2764
  _CMSGRELOAD._serialized_end=2800
  _CMSGGOFORWARD._serialized_start=2802
  _CMSGGOFORWARD._serialized_end=2841
  _CMSGGOBACK._serialized_start=2843
  _CMSGGOBACK._serialized_end=2879
  _CMSGWASHIDDEN._serialized_start=2881
  _CMSGWASHIDDEN._serialized_end=2936
  _CMSGSETWINDOWVISIBILITY._serialized_start=2938
  _CMSGSETWINDOWVISIBILITY._serialized_end=3004
  _CMSGCLEARHISTORY._serialized_start=3006
  _CMSGCLEARHISTORY._serialized_end=3048
  _CMSGCLEARALLBROWSINGDATA._serialized_start=3050
  _CMSGCLEARALLBROWSINGDATA._serialized_end=3100
  _CMSGCOPY._serialized_start=3102
  _CMSGCOPY._serialized_end=3136
  _CMSGPASTE._serialized_start=3138
  _CMSGPASTE._serialized_end=3173
  _CMSGEXECUTEJAVASCRIPT._serialized_start=3175
  _CMSGEXECUTEJAVASCRIPT._serialized_end=3238
  _CMSGSETFOCUS._serialized_start=3240
  _CMSGSETFOCUS._serialized_end=3293
  _CMSGHORIZONTALSCROLLBARSIZE._serialized_start=3295
  _CMSGHORIZONTALSCROLLBARSIZE._serialized_end=3348
  _CMSGHORIZONTALSCROLLBARSIZERESPONSE._serialized_start=3351
  _CMSGHORIZONTALSCROLLBARSIZERESPONSE._serialized_end=3498
  _CMSGVERTICALSCROLLBARSIZE._serialized_start=3500
  _CMSGVERTICALSCROLLBARSIZE._serialized_end=3551
  _CMSGVERTICALSCROLLBARSIZERESPONSE._serialized_start=3554
  _CMSGVERTICALSCROLLBARSIZERESPONSE._serialized_end=3699
  _CMSGFIND._serialized_start=3701
  _CMSGFIND._serialized_end=3789
  _CMSGSTOPFIND._serialized_start=3791
  _CMSGSTOPFIND._serialized_end=3829
  _CMSGSETHORIZONTALSCROLL._serialized_start=3831
  _CMSGSETHORIZONTALSCROLL._serialized_end=3896
  _CMSGSETVERTICALSCROLL._serialized_start=3898
  _CMSGSETVERTICALSCROLL._serialized_end=3961
  _CMSGSETZOOMLEVEL._serialized_start=3963
  _CMSGSETZOOMLEVEL._serialized_end=4019
  _CMSGVIEWSOURCE._serialized_start=4021
  _CMSGVIEWSOURCE._serialized_end=4061
  _CMSGBROWSERREADY._serialized_start=4063
  _CMSGBROWSERREADY._serialized_end=4151
  _CMSGURLCHANGED._serialized_start=4154
  _CMSGURLCHANGED._serialized_end=4289
  _CHISTORYENTRY._serialized_start=4291
  _CHISTORYENTRY._serialized_end=4319
  _CMSGHISTORYCHANGED._serialized_start=4321
  _CMSGHISTORYCHANGED._serialized_end=4413
  _CMSGLOADERROR._serialized_start=4415
  _CMSGLOADERROR._serialized_end=4514
  _CHTMLHEADER._serialized_start=4516
  _CHTMLHEADER._serialized_end=4557
  _CHTMLPAGESECURITYINFO._serialized_start=4560
  _CHTMLPAGESECURITYINFO._serialized_end=4748
  _CMSGFINISHEDREQUEST._serialized_start=4750
  _CMSGFINISHEDREQUEST._serialized_end=4827
  _CMSGLOADEDREQUEST._serialized_start=4829
  _CMSGLOADEDREQUEST._serialized_end=4935
  _CMSGFAVICONURLCHANGED._serialized_start=4937
  _CMSGFAVICONURLCHANGED._serialized_end=4998
  _CMSGPAGESECURITY._serialized_start=5000
  _CMSGPAGESECURITY._serialized_end=5102
  _CMSGSTARTREQUEST._serialized_start=5104
  _CMSGSTARTREQUEST._serialized_end=5214
  _CMSGSTARTREQUESTRESPONSE._serialized_start=5216
  _CMSGSTARTREQUESTRESPONSE._serialized_end=5282
  _CMSGSHOWPOPUP._serialized_start=5284
  _CMSGSHOWPOPUP._serialized_end=5323
  _CMSGHIDEPOPUP._serialized_start=5325
  _CMSGHIDEPOPUP._serialized_end=5364
  _CMSGSIZEPOPUP._serialized_start=5366
  _CMSGSIZEPOPUP._serialized_end=5455
  _CMSGOPENNEWTAB._serialized_start=5457
  _CMSGOPENNEWTAB._serialized_end=5531
  _CMSGPOPUPHTMLWINDOW._serialized_start=5534
  _CMSGPOPUPHTMLWINDOW._serialized_end=5794
  _CMSGPOPUPHTMLWINDOWRESPONSE._serialized_start=5796
  _CMSGPOPUPHTMLWINDOWRESPONSE._serialized_end=5865
  _CMSGSETHTMLTITLE._serialized_start=5867
  _CMSGSETHTMLTITLE._serialized_end=5924
  _CMSGLOADINGRESOURCE._serialized_start=5926
  _CMSGLOADINGRESOURCE._serialized_end=5984
  _CMSGSTATUSTEXT._serialized_start=5986
  _CMSGSTATUSTEXT._serialized_end=6040
  _CMSGSETCURSOR._serialized_start=6043
  _CMSGSETCURSOR._serialized_end=6183
  _CMSGFILELOADDIALOG._serialized_start=6186
  _CMSGFILELOADDIALOG._serialized_end=6469
  _CMSGFILELOADDIALOG_FILTER._serialized_start=6409
  _CMSGFILELOADDIALOG_FILTER._serialized_end=6469
  _CMSGFILELOADDIALOGRESPONSE._serialized_start=6471
  _CMSGFILELOADDIALOGRESPONSE._serialized_end=6587
  _CMSGREQUESTPROCESSINFO._serialized_start=6589
  _CMSGREQUESTPROCESSINFO._serialized_end=6632
  _CMSGPROCESSINFONOTIFICATION._serialized_start=6635
  _CMSGPROCESSINFONOTIFICATION._serialized_end=8022
  _CMSGSHOWTOOLTIP._serialized_start=8024
  _CMSGSHOWTOOLTIP._serialized_end=8079
  _CMSGUPDATETOOLTIP._serialized_start=8081
  _CMSGUPDATETOOLTIP._serialized_end=8138
  _CMSGHIDETOOLTIP._serialized_start=8140
  _CMSGHIDETOOLTIP._serialized_end=8181
  _CMSGSEARCHRESULTS._serialized_start=8183
  _CMSGSEARCHRESULTS._serialized_end=8264
  _CMSGCLOSE._serialized_start=8266
  _CMSGCLOSE._serialized_end=8301
  _CMSGSETSHAREDPAINTBUFFERS._serialized_start=8304
  _CMSGSETSHAREDPAINTBUFFERS._serialized_end=8442
  _CMSGACKSHAREDPAINTBUFFERS._serialized_start=8444
  _CMSGACKSHAREDPAINTBUFFERS._serialized_end=8495
  _CMSGNEEDSPAINT._serialized_start=8498
  _CMSGNEEDSPAINT._serialized_end=8685
  _CMSGCOMBONEEDSPAINT._serialized_start=8688
  _CMSGCOMBONEEDSPAINT._serialized_end=8863
  _CMSGNEEDSSHAREDTEXTUREPAINT._serialized_start=8866
  _CMSGNEEDSSHAREDTEXTUREPAINT._serialized_end=9045
  _CMSGGETZOOM._serialized_start=9047
  _CMSGGETZOOM._serialized_end=9084
  _CMSGGETZOOMRESPONSE._serialized_start=9086
  _CMSGGETZOOMRESPONSE._serialized_end=9145
  _CMSGLINKATPOSITION._serialized_start=9147
  _CMSGLINKATPOSITION._serialized_end=9213
  _CMSGLINKATPOSITIONRESPONSE._serialized_start=9215
  _CMSGLINKATPOSITIONRESPONSE._serialized_end=9337
  _CMSGZOOMTOELEMENTATPOSITION._serialized_start=9339
  _CMSGZOOMTOELEMENTATPOSITION._serialized_end=9414
  _CMSGZOOMTOELEMENTATPOSITIONRESPONSE._serialized_start=9416
  _CMSGZOOMTOELEMENTATPOSITIONRESPONSE._serialized_end=9510
  _CMSGSCALEPAGETOVALUE._serialized_start=9512
  _CMSGSCALEPAGETOVALUE._serialized_end=9595
  _CMSGFORCEPOPUPSTODIRECTHWND._serialized_start=9597
  _CMSGFORCEPOPUPSTODIRECTHWND._serialized_end=9684
  _CMSGSCALEPAGETOVALUERESPONSE._serialized_start=9686
  _CMSGSCALEPAGETOVALUERESPONSE._serialized_end=9754
  _CMSGSAVEPAGETOJPEG._serialized_start=9756
  _CMSGSAVEPAGETOJPEG._serialized_end=9862
  _CMSGSAVEPAGETOJPEGRESPONSE._serialized_start=9864
  _CMSGSAVEPAGETOJPEGRESPONSE._serialized_end=9947
  _CMSGJSALERT._serialized_start=9949
  _CMSGJSALERT._serialized_end=10003
  _CMSGJSCONFIRM._serialized_start=10005
  _CMSGJSCONFIRM._serialized_end=10061
  _CMSGJSDIALOGRESPONSE._serialized_start=10063
  _CMSGJSDIALOGRESPONSE._serialized_end=10125
  _CMSGCANGOBACKANDFORWARD._serialized_start=10127
  _CMSGCANGOBACKANDFORWARD._serialized_end=10213
  _CMSGOPENSTEAMURL._serialized_start=10215
  _CMSGOPENSTEAMURL._serialized_end=10288
  _CMSGSETCOOKIE._serialized_start=10291
  _CMSGSETCOOKIE._serialized_end=10431
  _CMSGSETTARGETFRAMERATE._serialized_start=10433
  _CMSGSETTARGETFRAMERATE._serialized_end=10507
  _CMSGPAUSEREPAINT._serialized_start=10509
  _CMSGPAUSEREPAINT._serialized_end=10551
  _CMSGFULLREPAINT._serialized_start=10553
  _CMSGFULLREPAINT._serialized_end=10594
  _CMSGREQUESTFULLSCREEN._serialized_start=10596
  _CMSGREQUESTFULLSCREEN._serialized_end=10643
  _CMSGEXITFULLSCREEN._serialized_start=10645
  _CMSGEXITFULLSCREEN._serialized_end=10689
  _CMSGTOGGLEFINDINPAGEDIALOG._serialized_start=10691
  _CMSGTOGGLEFINDINPAGEDIALOG._serialized_end=10743
  _CMSGSETPIDSHUTTINGDOWN._serialized_start=10745
  _CMSGSETPIDSHUTTINGDOWN._serialized_end=10793
  _CMSGDISABLEBACKGROUNDTHROTTLING._serialized_start=10795
  _CMSGDISABLEBACKGROUNDTHROTTLING._serialized_end=10852
  _CMSGACKPIDSHUTTINGDOWN._serialized_start=10854
  _CMSGACKPIDSHUTTINGDOWN._serialized_end=10902
  _CMSGGETCOOKIESFORURL._serialized_start=10904
  _CMSGGETCOOKIESFORURL._serialized_end=10963
  _CCOOKIE._serialized_start=10965
  _CCOOKIE._serialized_end=11033
  _CMSGGETCOOKIESFORURLRESPONSE._serialized_start=11035
  _CMSGGETCOOKIESFORURLRESPONSE._serialized_end=11129
  _CMSGNODEHASFOCUS._serialized_start=11132
  _CMSGNODEHASFOCUS._serialized_end=11324
  _CMSGZOOMTOFOCUSEDELEMENT._serialized_start=11326
  _CMSGZOOMTOFOCUSEDELEMENT._serialized_end=11376
  _CMSGFOCUSEDNODETEXT._serialized_start=11378
  _CMSGFOCUSEDNODETEXT._serialized_end=11423
  _CMSGFOCUSEDNODETEXTRESPONSE._serialized_start=11425
  _CMSGFOCUSEDNODETEXTRESPONSE._serialized_end=11493
  _CMSGBUILDID._serialized_start=11495
  _CMSGBUILDID._serialized_end=11526
  _CMSGOPENDEVTOOLS._serialized_start=11528
  _CMSGOPENDEVTOOLS._serialized_end=11570
  _CMSGCLOSEDEVTOOLS._serialized_start=11572
  _CMSGCLOSEDEVTOOLS._serialized_end=11615
  _CMSGUNLOCKH264._serialized_start=11617
  _CMSGUNLOCKH264._serialized_end=11678
  _CMSGSCREENINFORMATIONCHANGED._serialized_start=11680
  _CMSGSCREENINFORMATIONCHANGED._serialized_end=11783
  _CMSGCLEARALLCOOKIES._serialized_start=11785
  _CMSGCLEARALLCOOKIES._serialized_end=11830
  _CMSGSCREENDPI._serialized_start=11832
  _CMSGSCREENDPI._serialized_end=11892
  _CMSGACKSCREENDPI._serialized_start=11894
  _CMSGACKSCREENDPI._serialized_end=11936
  _CMSGAUTHEDSTEAMDOMAINS._serialized_start=11938
  _CMSGAUTHEDSTEAMDOMAINS._serialized_end=11979
  _CMSGSTEAMAUTHNEEDED._serialized_start=11981
  _CMSGSTEAMAUTHNEEDED._serialized_end=12018
  _CMSGSTEAMAUTHCOOKIESSET._serialized_start=12020
  _CMSGSTEAMAUTHCOOKIESSET._serialized_end=12062
  _CMSGJSREGISTERMETHOD._serialized_start=12065
  _CMSGJSREGISTERMETHOD._serialized_end=12203
  _CMSGJSVALUE._serialized_start=12206
  _CMSGJSVALUE._serialized_end=12562
  _CMSGJSVALUE_JSOBJECTPROPERTY._serialized_start=12501
  _CMSGJSVALUE_JSOBJECTPROPERTY._serialized_end=12562
  _CMSGJSMETHODCALL._serialized_start=12564
  _CMSGJSMETHODCALL._serialized_end=12684
  _CMSGJSEXECUTECALLBACK._serialized_start=12687
  _CMSGJSEXECUTECALLBACK._serialized_end=12823
  _CMSGJSEXECUTEPROMISE._serialized_start=12826
  _CMSGJSEXECUTEPROMISE._serialized_end=12982
  _CMSGJSRELEASECALLBACK._serialized_start=12984
  _CMSGJSRELEASECALLBACK._serialized_end=13087
  _CMSGJSRAISEEXCEPTION._serialized_start=13089
  _CMSGJSRAISEEXCEPTION._serialized_end=13185
  _CMSGLOADLOCALIZATION._serialized_start=13187
  _CMSGLOADLOCALIZATION._serialized_end=13278
  _CMSGNOTIFYUSERACTIVATION._serialized_start=13280
  _CMSGNOTIFYUSERACTIVATION._serialized_end=13330
  _CMSGSETNETFAKELOCALSYSTEMSTATE._serialized_start=13332
  _CMSGSETNETFAKELOCALSYSTEMSTATE._serialized_end=13379
  _CMSGDRAGGABLEREGIONSCHANGED._serialized_start=13382
  _CMSGDRAGGABLEREGIONSCHANGED._serialized_end=13606
  _CMSGDRAGGABLEREGIONSCHANGED_DRAGGABLERECTS._serialized_start=13497
  _CMSGDRAGGABLEREGIONSCHANGED_DRAGGABLERECTS._serialized_end=13606
  _CMSGRESIZEGRIPCHANGED._serialized_start=13608
  _CMSGRESIZEGRIPCHANGED._serialized_end=13686
  _CMSGSETWINDOWPOSITION._serialized_start=13689
  _CMSGSETWINDOWPOSITION._serialized_end=13867
  _CMSGSHOWWINDOW._serialized_start=13869
  _CMSGSHOWWINDOW._serialized_end=13909
  _CMSGHIDEWINDOW._serialized_start=13911
  _CMSGHIDEWINDOW._serialized_end=13951
  _CMSGBRINGWINDOWTOFRONT._serialized_start=13953
  _CMSGBRINGWINDOWTOFRONT._serialized_end=14001
  _CMSGSETFOREGROUNDWINDOW._serialized_start=14003
  _CMSGSETFOREGROUNDWINDOW._serialized_end=14052
  _CMSGMAXIMIZERESTOREWINDOW._serialized_start=14054
  _CMSGMAXIMIZERESTOREWINDOW._serialized_end=14105
  _CMSGMINIMIZEWINDOW._serialized_start=14107
  _CMSGMINIMIZEWINDOW._serialized_end=14151
  _CMSGSHOWBROWSERCONTEXTMENU._serialized_start=14154
  _CMSGSHOWBROWSERCONTEXTMENU._serialized_end=14514
  _CMSGSHOWBROWSERCONTEXTMENU_CONTEXTCOMMAND._serialized_start=14471
  _CMSGSHOWBROWSERCONTEXTMENU_CONTEXTCOMMAND._serialized_end=14514
  _CMSGHANDLECONTEXTMENUCOMMAND._serialized_start=14516
  _CMSGHANDLECONTEXTMENUCOMMAND._serialized_end=14590
  _CMSGTOUCHGESTURE._serialized_start=14593
  _CMSGTOUCHGESTURE._serialized_end=14757
  _CMSGSETTOUCHGESTURESTOCANCEL._serialized_start=14759
  _CMSGSETTOUCHGESTURESTOCANCEL._serialized_end=14831
  _CMSGIMESETCOMPOSITION._serialized_start=14833
  _CMSGIMESETCOMPOSITION._serialized_end=14894
  _CMSGIMECOMMITTEXT._serialized_start=14896
  _CMSGIMECOMMITTEXT._serialized_end=14953
  _CMSGIMECANCELCOMPOSITION._serialized_start=14955
  _CMSGIMECANCELCOMPOSITION._serialized_end=15005
  _CMSGIMECOMPOSITIONRANGECHANGED._serialized_start=15007
  _CMSGIMECOMPOSITIONRANGECHANGED._serialized_end=15085
  _CMSGINSPECTELEMENT._serialized_start=15087
  _CMSGINSPECTELEMENT._serialized_end=15153
  _CMSGDISABLEF5._serialized_start=15155
  _CMSGDISABLEF5._serialized_end=15211
  _CMSGSTARTDOWNLOAD._serialized_start=15213
  _CMSGSTARTDOWNLOAD._serialized_end=15269
  _CMSGSETWINDOWSTACKINGORDER._serialized_start=15271
  _CMSGSETWINDOWSTACKINGORDER._serialized_end=15347
  _CMSGBROWSERVIEWPOSTMESSAGETOPARENTREQUEST._serialized_start=15349
  _CMSGBROWSERVIEWPOSTMESSAGETOPARENTREQUEST._serialized_end=15471
  _CMSGBLOCKEDREQUEST._serialized_start=15473
  _CMSGBLOCKEDREQUEST._serialized_end=15530
  _CMSGBROWSERFOCUSCHANGED._serialized_start=15532
  _CMSGBROWSERFOCUSCHANGED._serialized_end=15598
  _CMSGSETPROTOCOLBLOCKLIST._serialized_start=15600
  _CMSGSETPROTOCOLBLOCKLIST._serialized_end=15664
  _CMSGSETFORCEDEVICESCALEFACTORS._serialized_start=15666
  _CMSGSETFORCEDEVICESCALEFACTORS._serialized_end=15740
  _CMSGSETUIMODE._serialized_start=15742
  _CMSGSETUIMODE._serialized_end=15774
  _CMSGSETSTEAMBETANAME._serialized_start=15776
  _CMSGSETSTEAMBETANAME._serialized_end=15823
  _CMSGSETSTEAMID._serialized_start=15825
  _CMSGSETSTEAMID._serialized_end=15859
  _CMSGPOPUPCREATED._serialized_start=15861
  _CMSGPOPUPCREATED._serialized_end=15903
  _CMSGSETVRKEYBOARDVISIBILITY._serialized_start=15905
  _CMSGSETVRKEYBOARDVISIBILITY._serialized_end=15975
  _CMSGRESTARTJSCONTEXT._serialized_start=15977
  _CMSGRESTARTJSCONTEXT._serialized_end=15999
  _CMSGSETACCESSIBILITYSETTINGS._serialized_start=16002
  _CMSGSETACCESSIBILITYSETTINGS._serialized_end=16185
# @@protoc_insertion_point(module_scope)
