# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: steammessages_gamenotifications.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import steam.protobufs.steammessages_base_pb2 as steammessages__base__pb2
import steam.protobufs.steammessages_unified_base_pb2 as steammessages__unified__base__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%steammessages_gamenotifications.proto\x1a\x18steammessages_base.proto\x1a steammessages_unified_base.proto\"9\n\x1b\x43GameNotifications_Variable\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\"y\n CGameNotifications_LocalizedText\x12\r\n\x05token\x18\x01 \x01(\t\x12/\n\tvariables\x18\x02 \x03(\x0b\x32\x1c.CGameNotifications_Variable\x12\x15\n\rrendered_text\x18\x03 \x01(\t\"\xa5\x01\n\x1d\x43GameNotifications_UserStatus\x12\x0f\n\x07steamid\x18\x01 \x01(\x06\x12\r\n\x05state\x18\x02 \x01(\t\x12\x30\n\x05title\x18\x03 \x01(\x0b\x32!.CGameNotifications_LocalizedText\x12\x32\n\x07message\x18\x04 \x01(\x0b\x32!.CGameNotifications_LocalizedText\"\xbc\x01\n(CGameNotifications_CreateSession_Request\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x0f\n\x07\x63ontext\x18\x02 \x01(\x04\x12\x30\n\x05title\x18\x03 \x01(\x0b\x32!.CGameNotifications_LocalizedText\x12-\n\x05users\x18\x04 \x03(\x0b\x32\x1e.CGameNotifications_UserStatus\x12\x0f\n\x07steamid\x18\x05 \x01(\x06\">\n)CGameNotifications_CreateSession_Response\x12\x11\n\tsessionid\x18\x01 \x01(\x04\"]\n(CGameNotifications_DeleteSession_Request\x12\x11\n\tsessionid\x18\x01 \x01(\x04\x12\r\n\x05\x61ppid\x18\x02 \x01(\r\x12\x0f\n\x07steamid\x18\x03 \x01(\x06\"+\n)CGameNotifications_DeleteSession_Response\"\xbe\x01\n(CGameNotifications_UpdateSession_Request\x12\x11\n\tsessionid\x18\x01 \x01(\x04\x12\r\n\x05\x61ppid\x18\x02 \x01(\r\x12\x30\n\x05title\x18\x03 \x01(\x0b\x32!.CGameNotifications_LocalizedText\x12-\n\x05users\x18\x04 \x03(\x0b\x32\x1e.CGameNotifications_UserStatus\x12\x0f\n\x07steamid\x18\x06 \x01(\x06\"+\n)CGameNotifications_UpdateSession_Response\"\x95\x01\n,CGameNotifications_EnumerateSessions_Request\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12!\n\x19include_all_user_messages\x18\x03 \x01(\x08\x12!\n\x19include_auth_user_message\x18\x04 \x01(\x08\x12\x10\n\x08language\x18\x05 \x01(\t\"\xe2\x01\n\x1a\x43GameNotifications_Session\x12\x11\n\tsessionid\x18\x01 \x01(\x04\x12\r\n\x05\x61ppid\x18\x02 \x01(\x04\x12\x0f\n\x07\x63ontext\x18\x03 \x01(\x04\x12\x30\n\x05title\x18\x04 \x01(\x0b\x32!.CGameNotifications_LocalizedText\x12\x14\n\x0ctime_created\x18\x05 \x01(\r\x12\x14\n\x0ctime_updated\x18\x06 \x01(\r\x12\x33\n\x0buser_status\x18\x07 \x03(\x0b\x32\x1e.CGameNotifications_UserStatus\"^\n-CGameNotifications_EnumerateSessions_Response\x12-\n\x08sessions\x18\x01 \x03(\x0b\x32\x1b.CGameNotifications_Session\"\xeb\x01\n,CGameNotifications_GetSessionDetails_Request\x12P\n\x08sessions\x18\x01 \x03(\x0b\x32>.CGameNotifications_GetSessionDetails_Request.RequestedSession\x12\r\n\x05\x61ppid\x18\x02 \x01(\r\x12\x10\n\x08language\x18\x03 \x01(\t\x1aH\n\x10RequestedSession\x12\x11\n\tsessionid\x18\x01 \x01(\x04\x12!\n\x19include_auth_user_message\x18\x03 \x01(\x08\"^\n-CGameNotifications_GetSessionDetails_Response\x12-\n\x08sessions\x18\x01 \x03(\x0b\x32\x1b.CGameNotifications_Session\"F\n\x18GameNotificationSettings\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x1b\n\x13\x61llow_notifications\x18\x02 \x01(\x08\"v\n5CGameNotifications_UpdateNotificationSettings_Request\x12=\n\x1agame_notification_settings\x18\x01 \x03(\x0b\x32\x19.GameNotificationSettings\"8\n6CGameNotifications_UpdateNotificationSettings_Response\"Z\n8CGameNotifications_OnNotificationsRequested_Notification\x12\x0f\n\x07steamid\x18\x01 \x01(\x06\x12\r\n\x05\x61ppid\x18\x02 \x01(\r\"\xa9\x01\n3CGameNotifications_OnUserStatusChanged_Notification\x12\x0f\n\x07steamid\x18\x01 \x01(\x06\x12\x11\n\tsessionid\x18\x02 \x01(\x04\x12\r\n\x05\x61ppid\x18\x03 \x01(\r\x12.\n\x06status\x18\x04 \x01(\x0b\x32\x1e.CGameNotifications_UserStatus\x12\x0f\n\x07removed\x18\x05 \x01(\x08\x32\xcf\x05\n\x11GameNotifications\x12j\n\x11UserCreateSession\x12).CGameNotifications_CreateSession_Request\x1a*.CGameNotifications_CreateSession_Response\x12j\n\x11UserDeleteSession\x12).CGameNotifications_DeleteSession_Request\x1a*.CGameNotifications_DeleteSession_Response\x12j\n\x11UserUpdateSession\x12).CGameNotifications_UpdateSession_Request\x1a*.CGameNotifications_UpdateSession_Response\x12r\n\x11\x45numerateSessions\x12-.CGameNotifications_EnumerateSessions_Request\x1a..CGameNotifications_EnumerateSessions_Response\x12r\n\x11GetSessionDetails\x12-.CGameNotifications_GetSessionDetails_Request\x1a..CGameNotifications_GetSessionDetails_Response\x12\x8d\x01\n\x1aUpdateNotificationSettings\x12\x36.CGameNotifications_UpdateNotificationSettings_Request\x1a\x37.CGameNotifications_UpdateNotificationSettings_Response2\xdd\x01\n\x17GameNotificationsClient\x12\x62\n\x18OnNotificationsRequested\x12\x39.CGameNotifications_OnNotificationsRequested_Notification\x1a\x0b.NoResponse\x12X\n\x13OnUserStatusChanged\x12\x34.CGameNotifications_OnUserStatusChanged_Notification\x1a\x0b.NoResponse\x1a\x04\xc0\xb5\x18\x02\x42\x03\x90\x01\x01')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'steammessages_gamenotifications_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\220\001\001'
  _GAMENOTIFICATIONSCLIENT._options = None
  _GAMENOTIFICATIONSCLIENT._serialized_options = b'\300\265\030\002'
  _CGAMENOTIFICATIONS_VARIABLE._serialized_start=101
  _CGAMENOTIFICATIONS_VARIABLE._serialized_end=158
  _CGAMENOTIFICATIONS_LOCALIZEDTEXT._serialized_start=160
  _CGAMENOTIFICATIONS_LOCALIZEDTEXT._serialized_end=281
  _CGAMENOTIFICATIONS_USERSTATUS._serialized_start=284
  _CGAMENOTIFICATIONS_USERSTATUS._serialized_end=449
  _CGAMENOTIFICATIONS_CREATESESSION_REQUEST._serialized_start=452
  _CGAMENOTIFICATIONS_CREATESESSION_REQUEST._serialized_end=640
  _CGAMENOTIFICATIONS_CREATESESSION_RESPONSE._serialized_start=642
  _CGAMENOTIFICATIONS_CREATESESSION_RESPONSE._serialized_end=704
  _CGAMENOTIFICATIONS_DELETESESSION_REQUEST._serialized_start=706
  _CGAMENOTIFICATIONS_DELETESESSION_REQUEST._serialized_end=799
  _CGAMENOTIFICATIONS_DELETESESSION_RESPONSE._serialized_start=801
  _CGAMENOTIFICATIONS_DELETESESSION_RESPONSE._serialized_end=844
  _CGAMENOTIFICATIONS_UPDATESESSION_REQUEST._serialized_start=847
  _CGAMENOTIFICATIONS_UPDATESESSION_REQUEST._serialized_end=1037
  _CGAMENOTIFICATIONS_UPDATESESSION_RESPONSE._serialized_start=1039
  _CGAMENOTIFICATIONS_UPDATESESSION_RESPONSE._serialized_end=1082
  _CGAMENOTIFICATIONS_ENUMERATESESSIONS_REQUEST._serialized_start=1085
  _CGAMENOTIFICATIONS_ENUMERATESESSIONS_REQUEST._serialized_end=1234
  _CGAMENOTIFICATIONS_SESSION._serialized_start=1237
  _CGAMENOTIFICATIONS_SESSION._serialized_end=1463
  _CGAMENOTIFICATIONS_ENUMERATESESSIONS_RESPONSE._serialized_start=1465
  _CGAMENOTIFICATIONS_ENUMERATESESSIONS_RESPONSE._serialized_end=1559
  _CGAMENOTIFICATIONS_GETSESSIONDETAILS_REQUEST._serialized_start=1562
  _CGAMENOTIFICATIONS_GETSESSIONDETAILS_REQUEST._serialized_end=1797
  _CGAMENOTIFICATIONS_GETSESSIONDETAILS_REQUEST_REQUESTEDSESSION._serialized_start=1725
  _CGAMENOTIFICATIONS_GETSESSIONDETAILS_REQUEST_REQUESTEDSESSION._serialized_end=1797
  _CGAMENOTIFICATIONS_GETSESSIONDETAILS_RESPONSE._serialized_start=1799
  _CGAMENOTIFICATIONS_GETSESSIONDETAILS_RESPONSE._serialized_end=1893
  _GAMENOTIFICATIONSETTINGS._serialized_start=1895
  _GAMENOTIFICATIONSETTINGS._serialized_end=1965
  _CGAMENOTIFICATIONS_UPDATENOTIFICATIONSETTINGS_REQUEST._serialized_start=1967
  _CGAMENOTIFICATIONS_UPDATENOTIFICATIONSETTINGS_REQUEST._serialized_end=2085
  _CGAMENOTIFICATIONS_UPDATENOTIFICATIONSETTINGS_RESPONSE._serialized_start=2087
  _CGAMENOTIFICATIONS_UPDATENOTIFICATIONSETTINGS_RESPONSE._serialized_end=2143
  _CGAMENOTIFICATIONS_ONNOTIFICATIONSREQUESTED_NOTIFICATION._serialized_start=2145
  _CGAMENOTIFICATIONS_ONNOTIFICATIONSREQUESTED_NOTIFICATION._serialized_end=2235
  _CGAMENOTIFICATIONS_ONUSERSTATUSCHANGED_NOTIFICATION._serialized_start=2238
  _CGAMENOTIFICATIONS_ONUSERSTATUSCHANGED_NOTIFICATION._serialized_end=2407
  _GAMENOTIFICATIONS._serialized_start=2410
  _GAMENOTIFICATIONS._serialized_end=3129
  _GAMENOTIFICATIONSCLIENT._serialized_start=3132
  _GAMENOTIFICATIONSCLIENT._serialized_end=3353
_builder.BuildServices(DESCRIPTOR, 'steammessages_gamenotifications_pb2', globals())
# @@protoc_insertion_point(module_scope)
