# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: steammessages_credentials.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import steam.protobufs.steammessages_base_pb2 as steammessages__base__pb2
import steam.protobufs.steammessages_unified_base_pb2 as steammessages__unified__base__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1fsteammessages_credentials.proto\x1a\x18steammessages_base.proto\x1a steammessages_unified_base.proto\"\xa2\x01\n)CCredentials_GetSteamGuardDetails_Request\x12\x11\n\twebcookie\x18\x02 \x01(\t\x12 \n\x18timestamp_minimum_wanted\x18\x03 \x01(\x07\x12\x1c\n\x14\x64\x65precated_ipaddress\x18\x04 \x01(\x05\x12\"\n\nip_address\x18\x05 \x01(\x0b\x32\x0e.CMsgIPAddress\"\xff\x05\n*CCredentials_GetSteamGuardDetails_Response\x12\x1d\n\x15is_steamguard_enabled\x18\x01 \x01(\x08\x12$\n\x1ctimestamp_steamguard_enabled\x18\x02 \x01(\x07\x12*\n\"deprecated_machine_name_userchosen\x18\x04 \x01(\t\x12\x37\n/deprecated_timestamp_machine_steamguard_enabled\x18\x05 \x01(\x07\x12\x43\n;deprecated_authentication_exists_from_geoloc_before_mintime\x18\x06 \x01(\x08\x12\x1d\n\x15\x64\x65precated_machine_id\x18\x07 \x01(\x04\x12M\n\x0csession_data\x18\x08 \x03(\x0b\x32\x37.CCredentials_GetSteamGuardDetails_Response.SessionData\x12\x1c\n\x14is_twofactor_enabled\x18\t \x01(\x08\x12#\n\x1btimestamp_twofactor_enabled\x18\n \x01(\x07\x12\x19\n\x11is_phone_verified\x18\x0b \x01(\x08\x1a\x95\x02\n\x0bSessionData\x12\x12\n\nmachine_id\x18\x01 \x01(\x04\x12\x1f\n\x17machine_name_userchosen\x18\x02 \x01(\t\x12,\n$timestamp_machine_steamguard_enabled\x18\x03 \x01(\x07\x12\x38\n0authentication_exists_from_geoloc_before_mintime\x18\x04 \x01(\x08\x12\x39\n1authentication_exists_from_same_ip_before_mintime\x18\x06 \x01(\x08\x12\x13\n\x0bpublic_ipv4\x18\x07 \x01(\r\x12\x19\n\x11public_ip_address\x18\x08 \x01(\t\";\n)CCredentials_ValidateEmailAddress_Request\x12\x0e\n\x06stoken\x18\x01 \x01(\t\"C\n*CCredentials_ValidateEmailAddress_Response\x12\x15\n\rwas_validated\x18\x01 \x01(\x08\"_\n-CCredentials_SteamGuardPhishingReport_Request\x12\x14\n\x0cparam_string\x18\x01 \x01(\t\x12\x18\n\x10ipaddress_actual\x18\x02 \x01(\t\"\xb3\x02\n.CCredentials_SteamGuardPhishingReport_Response\x12\x1e\n\x16ipaddress_loginattempt\x18\x01 \x01(\t\x12 \n\x18\x63ountryname_loginattempt\x18\x02 \x01(\t\x12\x1e\n\x16statename_loginattempt\x18\x03 \x01(\t\x12\x1d\n\x15\x63ityname_loginattempt\x18\x04 \x01(\t\x12\x18\n\x10ipaddress_actual\x18\x05 \x01(\t\x12\x1a\n\x12\x63ountryname_actual\x18\x06 \x01(\t\x12\x18\n\x10statename_actual\x18\x07 \x01(\t\x12\x17\n\x0f\x63ityname_actual\x18\x08 \x01(\t\x12\x17\n\x0fsteamguard_code\x18\t \x01(\t\"J\n-CCredentials_LastCredentialChangeTime_Request\x12\x19\n\x11user_changes_only\x18\x01 \x01(\x08\"\xa4\x01\n.CCredentials_LastCredentialChangeTime_Response\x12&\n\x1etimestamp_last_password_change\x18\x01 \x01(\x07\x12#\n\x1btimestamp_last_email_change\x18\x02 \x01(\x07\x12%\n\x1dtimestamp_last_password_reset\x18\x03 \x01(\x07\"+\n)CCredentials_GetAccountAuthSecret_Request\"O\n*CCredentials_GetAccountAuthSecret_Response\x12\x11\n\tsecret_id\x18\x01 \x01(\x05\x12\x0e\n\x06secret\x18\x02 \x01(\x0c\x32\xe1\x04\n\x0b\x43redentials\x12o\n\x14GetSteamGuardDetails\x12*.CCredentials_GetSteamGuardDetails_Request\x1a+.CCredentials_GetSteamGuardDetails_Response\x12o\n\x14ValidateEmailAddress\x12*.CCredentials_ValidateEmailAddress_Request\x1a+.CCredentials_ValidateEmailAddress_Response\x12{\n\x18SteamGuardPhishingReport\x12..CCredentials_SteamGuardPhishingReport_Request\x1a/.CCredentials_SteamGuardPhishingReport_Response\x12\x81\x01\n\x1eGetCredentialChangeTimeDetails\x12..CCredentials_LastCredentialChangeTime_Request\x1a/.CCredentials_LastCredentialChangeTime_Response\x12o\n\x14GetAccountAuthSecret\x12*.CCredentials_GetAccountAuthSecret_Request\x1a+.CCredentials_GetAccountAuthSecret_ResponseB\x03\x90\x01\x01')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'steammessages_credentials_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\220\001\001'
  _CCREDENTIALS_GETSTEAMGUARDDETAILS_REQUEST._serialized_start=96
  _CCREDENTIALS_GETSTEAMGUARDDETAILS_REQUEST._serialized_end=258
  _CCREDENTIALS_GETSTEAMGUARDDETAILS_RESPONSE._serialized_start=261
  _CCREDENTIALS_GETSTEAMGUARDDETAILS_RESPONSE._serialized_end=1028
  _CCREDENTIALS_GETSTEAMGUARDDETAILS_RESPONSE_SESSIONDATA._serialized_start=751
  _CCREDENTIALS_GETSTEAMGUARDDETAILS_RESPONSE_SESSIONDATA._serialized_end=1028
  _CCREDENTIALS_VALIDATEEMAILADDRESS_REQUEST._serialized_start=1030
  _CCREDENTIALS_VALIDATEEMAILADDRESS_REQUEST._serialized_end=1089
  _CCREDENTIALS_VALIDATEEMAILADDRESS_RESPONSE._serialized_start=1091
  _CCREDENTIALS_VALIDATEEMAILADDRESS_RESPONSE._serialized_end=1158
  _CCREDENTIALS_STEAMGUARDPHISHINGREPORT_REQUEST._serialized_start=1160
  _CCREDENTIALS_STEAMGUARDPHISHINGREPORT_REQUEST._serialized_end=1255
  _CCREDENTIALS_STEAMGUARDPHISHINGREPORT_RESPONSE._serialized_start=1258
  _CCREDENTIALS_STEAMGUARDPHISHINGREPORT_RESPONSE._serialized_end=1565
  _CCREDENTIALS_LASTCREDENTIALCHANGETIME_REQUEST._serialized_start=1567
  _CCREDENTIALS_LASTCREDENTIALCHANGETIME_REQUEST._serialized_end=1641
  _CCREDENTIALS_LASTCREDENTIALCHANGETIME_RESPONSE._serialized_start=1644
  _CCREDENTIALS_LASTCREDENTIALCHANGETIME_RESPONSE._serialized_end=1808
  _CCREDENTIALS_GETACCOUNTAUTHSECRET_REQUEST._serialized_start=1810
  _CCREDENTIALS_GETACCOUNTAUTHSECRET_REQUEST._serialized_end=1853
  _CCREDENTIALS_GETACCOUNTAUTHSECRET_RESPONSE._serialized_start=1855
  _CCREDENTIALS_GETACCOUNTAUTHSECRET_RESPONSE._serialized_end=1934
  _CREDENTIALS._serialized_start=1937
  _CREDENTIALS._serialized_end=2546
_builder.BuildServices(DESCRIPTOR, 'steammessages_credentials_pb2', globals())
# @@protoc_insertion_point(module_scope)
