# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: webuimessages_transportvalidation.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import steam.protobufs.steammessages_base_pb2 as steammessages__base__pb2
import steam.protobufs.webuimessages_base_pb2 as webuimessages__base__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'webuimessages_transportvalidation.proto\x1a\x18steammessages_base.proto\x1a\x18webuimessages_base.proto\"E\n+CTransportValidation_AppendToString_Request\x12\x16\n\x0e\x61ppend_strings\x18\x01 \x03(\t\"E\n,CTransportValidation_AppendToString_Response\x12\x15\n\rcombined_text\x18\x01 \x01(\t\"<\n,CTransportValidation_NotifyText_Notification\x12\x0c\n\x04text\x18\x01 \x01(\t\"@\n.CTransportValidation_NotifyNumber_Notification\x12\x0e\n\x06number\x18\x01 \x01(\x05\"2\n0CTransportValidation_GetLastNotifyNumber_Request\"O\n1CTransportValidation_GetLastNotifyNumber_Response\x12\x1a\n\x12last_notify_number\x18\x01 \x01(\x05\"D\n3CTransportValidation_TriggerSyntheticEvents_Request\x12\r\n\x05\x63ount\x18\x01 \x01(\x05\"6\n4CTransportValidation_TriggerSyntheticEvents_Response\"J\n6CTransportValidation_NotifySyntheticEvent_Notification\x12\x10\n\x08sequence\x18\x01 \x01(\x05\"1\n/CTransportValidation_TriggerDataRequest_Request\"@\n0CTransportValidation_TriggerDataRequest_Response\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\x05\"*\n(CTransportValidation_DataRequest_Request\"9\n)CTransportValidation_DataRequest_Response\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\x05\":\n\'CTransportValidation_AddNumbers_Request\x12\x0f\n\x07numbers\x18\x01 \x03(\x05\"?\n(CTransportValidation_AddNumbers_Response\x12\x13\n\x0b\x61\x63\x63umulated\x18\x01 \x01(\x05\"G\n.CTransportValidation_CountOrderedBytes_Request\x12\x15\n\rordered_bytes\x18\x01 \x01(\x0c\"E\n/CTransportValidation_CountOrderedBytes_Response\x12\x12\n\nbyte_count\x18\x01 \x01(\x05\"P\n*CTransportValidation_ThreadedCount_Request\x12\x11\n\tstart_num\x18\x01 \x01(\x05\x12\x0f\n\x07\x65nd_num\x18\x02 \x01(\x05\"-\n+CTransportValidation_ThreadedCount_Response\"<\n-CTransportValidation_NotifyCount_Notification\x12\x0b\n\x03num\x18\x01 \x01(\x05\"1\n/CTransportValidation_RequestInvalidBool_Request\"a\n0CTransportValidation_RequestInvalidBool_Response\x12\x0e\n\x06\x62\x65\x66ore\x18\x01 \x01(\x05\x12\x0e\n\x06output\x18\x02 \x01(\x08\x12\r\n\x05\x61\x66ter\x18\x03 \x01(\x05\"B\n-CTransportValidation_GetLargeResponse_Request\x12\x11\n\tdata_size\x18\x01 \x01(\r\">\n.CTransportValidation_GetLargeResponse_Response\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\x0c\"J\n5CTransportValidation_RequestLargeNotification_Request\x12\x11\n\tdata_size\x18\x01 \x01(\r\"8\n6CTransportValidation_RequestLargeNotification_Response\"=\n-CTransportValidation_NotifyLarge_Notification\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\x0c\"@\n-CTransportValidationClient_AddNumbers_Request\x12\x0f\n\x07numbers\x18\x01 \x03(\x05\"E\n.CTransportValidationClient_AddNumbers_Response\x12\x13\n\x0b\x61\x63\x63umulated\x18\x01 \x01(\x05\x32\xe5\x0c\n\x13TransportValidation\x12m\n\x0e\x41ppendToString\x12,.CTransportValidation_AppendToString_Request\x1a-.CTransportValidation_AppendToString_Response\x12\x61\n\nAddNumbers\x12(.CTransportValidation_AddNumbers_Request\x1a).CTransportValidation_AddNumbers_Response\x12g\n\x10\x41\x64\x64NumbersStatic\x12(.CTransportValidation_AddNumbers_Request\x1a).CTransportValidation_AddNumbers_Response\x12M\n\nNotifyText\x12-.CTransportValidation_NotifyText_Notification\x1a\x10.WebUINoResponse\x12Q\n\x0cNotifyNumber\x12/.CTransportValidation_NotifyNumber_Notification\x1a\x10.WebUINoResponse\x12|\n\x13GetLastNotifyNumber\x12\x31.CTransportValidation_GetLastNotifyNumber_Request\x1a\x32.CTransportValidation_GetLastNotifyNumber_Response\x12\x61\n\x14NotifySyntheticEvent\x12\x37.CTransportValidation_NotifySyntheticEvent_Notification\x1a\x10.WebUINoResponse\x12\x85\x01\n\x16TriggerSyntheticEvents\x12\x34.CTransportValidation_TriggerSyntheticEvents_Request\x1a\x35.CTransportValidation_TriggerSyntheticEvents_Response\x12v\n\x11\x43ountOrderedBytes\x12/.CTransportValidation_CountOrderedBytes_Request\x1a\x30.CTransportValidation_CountOrderedBytes_Response\x12j\n\rThreadedCount\x12+.CTransportValidation_ThreadedCount_Request\x1a,.CTransportValidation_ThreadedCount_Response\x12O\n\x0bNotifyCount\x12..CTransportValidation_NotifyCount_Notification\x1a\x10.WebUINoResponse\x12y\n\x12RequestInvalidBool\x12\x30.CTransportValidation_RequestInvalidBool_Request\x1a\x31.CTransportValidation_RequestInvalidBool_Response\x12s\n\x10GetLargeResponse\x12..CTransportValidation_GetLargeResponse_Request\x1a/.CTransportValidation_GetLargeResponse_Response\x12\x8b\x01\n\x18RequestLargeNotification\x12\x36.CTransportValidation_RequestLargeNotification_Request\x1a\x37.CTransportValidation_RequestLargeNotification_Response\x12O\n\x0bNotifyLarge\x12..CTransportValidation_NotifyLarge_Notification\x1a\x10.WebUINoResponse\x1a\x04\x80\x97\"\x01\x32\x90\x01\n\x19TransportValidationClient\x12m\n\nAddNumbers\x12..CTransportValidationClient_AddNumbers_Request\x1a/.CTransportValidationClient_AddNumbers_Response\x1a\x04\x80\x97\"\x02\x42\x05H\x01\x90\x01\x01')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'webuimessages_transportvalidation_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'H\001\220\001\001'
  _TRANSPORTVALIDATION._options = None
  _TRANSPORTVALIDATION._serialized_options = b'\200\227\"\001'
  _TRANSPORTVALIDATIONCLIENT._options = None
  _TRANSPORTVALIDATIONCLIENT._serialized_options = b'\200\227\"\002'
  _CTRANSPORTVALIDATION_APPENDTOSTRING_REQUEST._serialized_start=95
  _CTRANSPORTVALIDATION_APPENDTOSTRING_REQUEST._serialized_end=164
  _CTRANSPORTVALIDATION_APPENDTOSTRING_RESPONSE._serialized_start=166
  _CTRANSPORTVALIDATION_APPENDTOSTRING_RESPONSE._serialized_end=235
  _CTRANSPORTVALIDATION_NOTIFYTEXT_NOTIFICATION._serialized_start=237
  _CTRANSPORTVALIDATION_NOTIFYTEXT_NOTIFICATION._serialized_end=297
  _CTRANSPORTVALIDATION_NOTIFYNUMBER_NOTIFICATION._serialized_start=299
  _CTRANSPORTVALIDATION_NOTIFYNUMBER_NOTIFICATION._serialized_end=363
  _CTRANSPORTVALIDATION_GETLASTNOTIFYNUMBER_REQUEST._serialized_start=365
  _CTRANSPORTVALIDATION_GETLASTNOTIFYNUMBER_REQUEST._serialized_end=415
  _CTRANSPORTVALIDATION_GETLASTNOTIFYNUMBER_RESPONSE._serialized_start=417
  _CTRANSPORTVALIDATION_GETLASTNOTIFYNUMBER_RESPONSE._serialized_end=496
  _CTRANSPORTVALIDATION_TRIGGERSYNTHETICEVENTS_REQUEST._serialized_start=498
  _CTRANSPORTVALIDATION_TRIGGERSYNTHETICEVENTS_REQUEST._serialized_end=566
  _CTRANSPORTVALIDATION_TRIGGERSYNTHETICEVENTS_RESPONSE._serialized_start=568
  _CTRANSPORTVALIDATION_TRIGGERSYNTHETICEVENTS_RESPONSE._serialized_end=622
  _CTRANSPORTVALIDATION_NOTIFYSYNTHETICEVENT_NOTIFICATION._serialized_start=624
  _CTRANSPORTVALIDATION_NOTIFYSYNTHETICEVENT_NOTIFICATION._serialized_end=698
  _CTRANSPORTVALIDATION_TRIGGERDATAREQUEST_REQUEST._serialized_start=700
  _CTRANSPORTVALIDATION_TRIGGERDATAREQUEST_REQUEST._serialized_end=749
  _CTRANSPORTVALIDATION_TRIGGERDATAREQUEST_RESPONSE._serialized_start=751
  _CTRANSPORTVALIDATION_TRIGGERDATAREQUEST_RESPONSE._serialized_end=815
  _CTRANSPORTVALIDATION_DATAREQUEST_REQUEST._serialized_start=817
  _CTRANSPORTVALIDATION_DATAREQUEST_REQUEST._serialized_end=859
  _CTRANSPORTVALIDATION_DATAREQUEST_RESPONSE._serialized_start=861
  _CTRANSPORTVALIDATION_DATAREQUEST_RESPONSE._serialized_end=918
  _CTRANSPORTVALIDATION_ADDNUMBERS_REQUEST._serialized_start=920
  _CTRANSPORTVALIDATION_ADDNUMBERS_REQUEST._serialized_end=978
  _CTRANSPORTVALIDATION_ADDNUMBERS_RESPONSE._serialized_start=980
  _CTRANSPORTVALIDATION_ADDNUMBERS_RESPONSE._serialized_end=1043
  _CTRANSPORTVALIDATION_COUNTORDEREDBYTES_REQUEST._serialized_start=1045
  _CTRANSPORTVALIDATION_COUNTORDEREDBYTES_REQUEST._serialized_end=1116
  _CTRANSPORTVALIDATION_COUNTORDEREDBYTES_RESPONSE._serialized_start=1118
  _CTRANSPORTVALIDATION_COUNTORDEREDBYTES_RESPONSE._serialized_end=1187
  _CTRANSPORTVALIDATION_THREADEDCOUNT_REQUEST._serialized_start=1189
  _CTRANSPORTVALIDATION_THREADEDCOUNT_REQUEST._serialized_end=1269
  _CTRANSPORTVALIDATION_THREADEDCOUNT_RESPONSE._serialized_start=1271
  _CTRANSPORTVALIDATION_THREADEDCOUNT_RESPONSE._serialized_end=1316
  _CTRANSPORTVALIDATION_NOTIFYCOUNT_NOTIFICATION._serialized_start=1318
  _CTRANSPORTVALIDATION_NOTIFYCOUNT_NOTIFICATION._serialized_end=1378
  _CTRANSPORTVALIDATION_REQUESTINVALIDBOOL_REQUEST._serialized_start=1380
  _CTRANSPORTVALIDATION_REQUESTINVALIDBOOL_REQUEST._serialized_end=1429
  _CTRANSPORTVALIDATION_REQUESTINVALIDBOOL_RESPONSE._serialized_start=1431
  _CTRANSPORTVALIDATION_REQUESTINVALIDBOOL_RESPONSE._serialized_end=1528
  _CTRANSPORTVALIDATION_GETLARGERESPONSE_REQUEST._serialized_start=1530
  _CTRANSPORTVALIDATION_GETLARGERESPONSE_REQUEST._serialized_end=1596
  _CTRANSPORTVALIDATION_GETLARGERESPONSE_RESPONSE._serialized_start=1598
  _CTRANSPORTVALIDATION_GETLARGERESPONSE_RESPONSE._serialized_end=1660
  _CTRANSPORTVALIDATION_REQUESTLARGENOTIFICATION_REQUEST._serialized_start=1662
  _CTRANSPORTVALIDATION_REQUESTLARGENOTIFICATION_REQUEST._serialized_end=1736
  _CTRANSPORTVALIDATION_REQUESTLARGENOTIFICATION_RESPONSE._serialized_start=1738
  _CTRANSPORTVALIDATION_REQUESTLARGENOTIFICATION_RESPONSE._serialized_end=1794
  _CTRANSPORTVALIDATION_NOTIFYLARGE_NOTIFICATION._serialized_start=1796
  _CTRANSPORTVALIDATION_NOTIFYLARGE_NOTIFICATION._serialized_end=1857
  _CTRANSPORTVALIDATIONCLIENT_ADDNUMBERS_REQUEST._serialized_start=1859
  _CTRANSPORTVALIDATIONCLIENT_ADDNUMBERS_REQUEST._serialized_end=1923
  _CTRANSPORTVALIDATIONCLIENT_ADDNUMBERS_RESPONSE._serialized_start=1925
  _CTRANSPORTVALIDATIONCLIENT_ADDNUMBERS_RESPONSE._serialized_end=1994
  _TRANSPORTVALIDATION._serialized_start=1997
  _TRANSPORTVALIDATION._serialized_end=3634
  _TRANSPORTVALIDATIONCLIENT._serialized_start=3637
  _TRANSPORTVALIDATIONCLIENT._serialized_end=3781
_builder.BuildServices(DESCRIPTOR, 'webuimessages_transportvalidation_pb2', globals())
# @@protoc_insertion_point(module_scope)
