# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: webuimessages_sharedjscontext.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import steam.protobufs.enums_pb2 as enums__pb2
import steam.protobufs.steammessages_base_pb2 as steammessages__base__pb2
import steam.protobufs.webuimessages_base_pb2 as webuimessages__base__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#webuimessages_sharedjscontext.proto\x1a\x0b\x65nums.proto\x1a\x18steammessages_base.proto\x1a\x18webuimessages_base.proto\"3\n1CSharedJSContext_GetDesiredSteamUIWindows_Request\"\xd2\x01\n\x18\x43MsgSteamUIBrowserWindow\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x0b\n\x03pid\x18\x02 \x01(\x05\x12\x12\n\nbrowser_id\x18\x03 \x01(\x05\x12\x13\n\x0bwindow_type\x18\x04 \x01(\x05\x12\t\n\x01x\x18\x05 \x01(\x05\x12\t\n\x01y\x18\x06 \x01(\x05\x12\r\n\x05\x61ppid\x18\x07 \x01(\x04\x12\x1c\n\x14parent_window_handle\x18\x08 \x01(\x04\x12\x10\n\x08\x61pp_name\x18\t \x01(\t\x12\x1f\n\x17gamepadui_via_gamescope\x18\n \x01(\x08\"`\n2CSharedJSContext_GetDesiredSteamUIWindows_Response\x12*\n\x07windows\x18\x01 \x03(\x0b\x32\x19.CMsgSteamUIBrowserWindow2\x9d\x01\n\x0fSharedJSContext\x12\x83\x01\n\x18GetDesiredSteamUIWindows\x12\x32.CSharedJSContext_GetDesiredSteamUIWindows_Request\x1a\x33.CSharedJSContext_GetDesiredSteamUIWindows_Response\x1a\x04\x80\x97\"\x01\x42\x05H\x01\x90\x01\x01')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'webuimessages_sharedjscontext_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'H\001\220\001\001'
  _SHAREDJSCONTEXT._options = None
  _SHAREDJSCONTEXT._serialized_options = b'\200\227\"\001'
  _CSHAREDJSCONTEXT_GETDESIREDSTEAMUIWINDOWS_REQUEST._serialized_start=104
  _CSHAREDJSCONTEXT_GETDESIREDSTEAMUIWINDOWS_REQUEST._serialized_end=155
  _CMSGSTEAMUIBROWSERWINDOW._serialized_start=158
  _CMSGSTEAMUIBROWSERWINDOW._serialized_end=368
  _CSHAREDJSCONTEXT_GETDESIREDSTEAMUIWINDOWS_RESPONSE._serialized_start=370
  _CSHAREDJSCONTEXT_GETDESIREDSTEAMUIWINDOWS_RESPONSE._serialized_end=466
  _SHAREDJSCONTEXT._serialized_start=469
  _SHAREDJSCONTEXT._serialized_end=626
_builder.BuildServices(DESCRIPTOR, 'webuimessages_sharedjscontext_pb2', globals())
# @@protoc_insertion_point(module_scope)
