# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: steammessages_appoverview.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import steam.protobufs.enums_pb2 as enums__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1fsteammessages_appoverview.proto\x1a\x0b\x65nums.proto\"\xf9\x02\n\x1a\x43\x41ppOverview_PerClientData\x12\x13\n\x08\x63lientid\x18\x01 \x01(\x04:\x01\x30\x12\x13\n\x0b\x63lient_name\x18\x02 \x01(\t\x12@\n\x0e\x64isplay_status\x18\x03 \x01(\x0e\x32\x0f.EDisplayStatus:\x17k_EDisplayStatusInvalid\x12\x19\n\x11status_percentage\x18\x04 \x01(\r\x12\x13\n\x0b\x61\x63tive_beta\x18\x05 \x01(\t\x12\x11\n\tinstalled\x18\x06 \x01(\x08\x12!\n\x19streaming_to_local_client\x18\t \x01(\x08\x12(\n is_available_on_current_platform\x18\n \x01(\x08\x12\x1a\n\x12is_invalid_os_type\x18\x0b \x01(\x08\x12\x15\n\rplaytime_left\x18\x0c \x01(\r\x12,\n$update_available_but_disabled_by_app\x18\x0e \x01(\x08\"\xc5\x0c\n\x0c\x43\x41ppOverview\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x14\n\x0c\x64isplay_name\x18\x02 \x01(\t\x12\x1c\n\x14visible_in_game_list\x18\x04 \x01(\x08\x12\x15\n\rsubscribed_to\x18\x05 \x01(\x08\x12\x0f\n\x07sort_as\x18\x06 \x01(\t\x12\x33\n\x08\x61pp_type\x18\x07 \x01(\x0e\x32\x0e.EProtoAppType:\x11k_EAppTypeInvalid\x12\x11\n\tmru_index\x18\r \x01(\r\x12\"\n\x17rt_recent_activity_time\x18\x0e \x01(\r:\x01\x30\x12#\n\x18minutes_playtime_forever\x18\x10 \x01(\r:\x01\x30\x12*\n\x1fminutes_playtime_last_two_weeks\x18\x11 \x01(\r:\x01\x30\x12\x1e\n\x13rt_last_time_played\x18\x12 \x01(\r:\x01\x30\x12\x11\n\tstore_tag\x18\x13 \x03(\r\x12\x16\n\x0estore_category\x18\x17 \x03(\r\x12#\n\x18rt_original_release_date\x18\x19 \x01(\r:\x01\x30\x12 \n\x15rt_steam_release_date\x18\x1a \x01(\r:\x01\x30\x12\x11\n\ticon_hash\x18\x1b \x01(\t\x12^\n\x17xbox_controller_support\x18\x1f \x01(\x0e\x32\x1b.EAppControllerSupportLevel: k_EAppControllerSupportLevelNone\x12\x14\n\x0cvr_supported\x18  \x01(\x08\x12\x18\n\x10metacritic_score\x18$ \x01(\r\x12\x14\n\x0csize_on_disk\x18% \x01(\x04\x12\x17\n\x0fthird_party_mod\x18& \x01(\x08\x12\x11\n\ticon_data\x18\' \x01(\t\x12\x18\n\x10icon_data_format\x18( \x01(\t\x12\x0e\n\x06gameid\x18) \x01(\t\x12 \n\x18library_capsule_filename\x18* \x01(\t\x12\x34\n\x0fper_client_data\x18+ \x03(\x0b\x32\x1b.CAppOverview_PerClientData\x12\"\n\x17most_available_clientid\x18, \x01(\x04:\x01\x30\x12\x1c\n\x11selected_clientid\x18- \x01(\x04:\x01\x30\x12\x1c\n\x14rt_store_asset_mtime\x18. \x01(\r\x12\x1d\n\x15rt_custom_image_mtime\x18/ \x01(\r\x12\x1e\n\x16optional_parent_app_id\x18\x30 \x01(\r\x12\x18\n\x10owner_account_id\x18\x31 \x01(\r\x12\"\n\x17review_score_with_bombs\x18\x35 \x01(\r:\x01\x30\x12\'\n\x1creview_percentage_with_bombs\x18\x36 \x01(\r:\x01\x30\x12%\n\x1areview_score_without_bombs\x18\x37 \x01(\r:\x01\x30\x12*\n\x1freview_percentage_without_bombs\x18\x38 \x01(\r:\x01\x30\x12\x12\n\nlibrary_id\x18\x39 \x01(\t\x12\x0f\n\x07vr_only\x18: \x01(\x08\x12\x17\n\x0fmastersub_appid\x18; \x01(\r\x12#\n\x1bmastersub_includedwith_logo\x18< \x01(\t\x12\x1e\n\x16site_license_site_name\x18> \x01(\t\x12\x1f\n\x17shortcut_override_appid\x18? \x01(\r\x12#\n\x1brt_last_time_locally_played\x18\x41 \x01(\r\x12\x19\n\x11rt_purchased_time\x18\x42 \x01(\r\x12\x17\n\x0fheader_filename\x18\x43 \x01(\t\x12\x1b\n\x13local_cache_version\x18\x44 \x01(\r\x12\x1b\n\x10number_of_copies\x18H \x01(\r:\x01\x31\x12*\n\x1fsteam_hw_compat_category_packed\x18I \x01(\r:\x01\x30\x12\x18\n\x10\x61lbum_cover_hash\x18J \x01(\t\x12\"\n\x16\x64isplay_name_elanguage\x18K \x01(\x05:\x02-1\x12\x1a\n\x12has_custom_sort_as\x18L \x01(\x08\"\x7f\n\x13\x43\x41ppOverview_Change\x12#\n\x0c\x61pp_overview\x18\x01 \x03(\x0b\x32\r.CAppOverview\x12\x15\n\rremoved_appid\x18\x02 \x03(\r\x12\x13\n\x0b\x66ull_update\x18\x03 \x01(\x08\x12\x17\n\x0fupdate_complete\x18\x04 \x01(\x08*\xcc\n\n\x0e\x45\x44isplayStatus\x12\x1b\n\x17k_EDisplayStatusInvalid\x10\x00\x12\x1d\n\x19k_EDisplayStatusLaunching\x10\x01\x12 \n\x1ck_EDisplayStatusUninstalling\x10\x02\x12\x1e\n\x1ak_EDisplayStatusInstalling\x10\x03\x12\x1b\n\x17k_EDisplayStatusRunning\x10\x04\x12\x1e\n\x1ak_EDisplayStatusValidating\x10\x05\x12\x1c\n\x18k_EDisplayStatusUpdating\x10\x06\x12\x1f\n\x1bk_EDisplayStatusDownloading\x10\x07\x12!\n\x1dk_EDisplayStatusSynchronizing\x10\x08\x12\"\n\x1ek_EDisplayStatusReadyToInstall\x10\t\x12\"\n\x1ek_EDisplayStatusReadyToPreload\x10\n\x12!\n\x1dk_EDisplayStatusReadyToLaunch\x10\x0b\x12$\n k_EDisplayStatusRegionRestricted\x10\x0c\x12\x1f\n\x1bk_EDisplayStatusPresaleOnly\x10\r\x12#\n\x1fk_EDisplayStatusInvalidPlatform\x10\x0e\x12#\n\x1fk_EDisplayStatusPreloadComplete\x10\x10\x12\"\n\x1ek_EDisplayStatusBorrowerLocked\x10\x11\x12 \n\x1ck_EDisplayStatusUpdatePaused\x10\x12\x12 \n\x1ck_EDisplayStatusUpdateQueued\x10\x13\x12\"\n\x1ek_EDisplayStatusUpdateRequired\x10\x14\x12\"\n\x1ek_EDisplayStatusUpdateDisabled\x10\x15\x12\"\n\x1ek_EDisplayStatusDownloadPaused\x10\x16\x12\"\n\x1ek_EDisplayStatusDownloadQueued\x10\x17\x12$\n k_EDisplayStatusDownloadRequired\x10\x18\x12$\n k_EDisplayStatusDownloadDisabled\x10\x19\x12\"\n\x1ek_EDisplayStatusLicensePending\x10\x1a\x12\"\n\x1ek_EDisplayStatusLicenseExpired\x10\x1b\x12 \n\x1ck_EDisplayStatusAvailForFree\x10\x1c\x12!\n\x1dk_EDisplayStatusAvailToBorrow\x10\x1d\x12\"\n\x1ek_EDisplayStatusAvailGuestPass\x10\x1e\x12\x1c\n\x18k_EDisplayStatusPurchase\x10\x1f\x12\x1f\n\x1bk_EDisplayStatusUnavailable\x10 \x12!\n\x1dk_EDisplayStatusNotLaunchable\x10!\x12\x1e\n\x1ak_EDisplayStatusCloudError\x10\"\x12\"\n\x1ek_EDisplayStatusCloudOutOfDate\x10#\x12\x1f\n\x1bk_EDisplayStatusTerminating\x10$\x12\x1f\n\x1bk_EDisplayStatusOwnerLocked\x10%\x12\"\n\x1ek_EDisplayStatusDownloadFailed\x10&\x12 \n\x1ck_EDisplayStatusUpdateFailed\x10\'*\xf7\x02\n\x0f\x45\x41ppCloudStatus\x12\x1c\n\x18k_EAppCloudStatusInvalid\x10\x00\x12\x1d\n\x19k_EAppCloudStatusDisabled\x10\x01\x12\x1c\n\x18k_EAppCloudStatusUnknown\x10\x02\x12!\n\x1dk_EAppCloudStatusSynchronized\x10\x03\x12\x1d\n\x19k_EAppCloudStatusChecking\x10\x04\x12\x1e\n\x1ak_EAppCloudStatusOutOfSync\x10\x05\x12\x1e\n\x1ak_EAppCloudStatusUploading\x10\x06\x12 \n\x1ck_EAppCloudStatusDownloading\x10\x07\x12\x1f\n\x1bk_EAppCloudStatusSyncFailed\x10\x08\x12\x1d\n\x19k_EAppCloudStatusConflict\x10\t\x12%\n!k_EAppCloudStatusPendingElsewhere\x10\n*\x91\x01\n\x1a\x45\x41ppControllerSupportLevel\x12$\n k_EAppControllerSupportLevelNone\x10\x00\x12\'\n#k_EAppControllerSupportLevelPartial\x10\x01\x12$\n k_EAppControllerSupportLevelFull\x10\x02*\xfd\x01\n#EAppGamepadGyroTrackpadSupportLevel\x12\x39\n,k_EAppGamepadGyroTrackpadSupportLevelUnknown\x10\xff\xff\xff\xff\xff\xff\xff\xff\xff\x01\x12\x32\n.k_EAppGamepadGyroTrackpadSupportLevelNoGamepad\x10\x00\x12\x30\n,k_EAppGamepadGyroTrackpadSupportLevelGamepad\x10\x01\x12\x35\n1k_EAppGamepadGyroTrackpadSupportLevelSimultaneous\x10\x02*\xa1\x01\n\x0e\x45\x41ppHDRSupport\x12\x19\n\x15k_EHDRSupport_Unknown\x10\x00\x12\x15\n\x11k_EHDRSupport_SDR\x10\x01\x12\x15\n\x11k_EHDRSupport_HDR\x10\x02\x12\x1c\n\x18k_EHDRSupport_HDR_Broken\x10\x03\x12(\n$k_EHDRSupport_HDR_RequiresUserAction\x10\x04\x42\x05H\x01\x90\x01\x01')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'steammessages_appoverview_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'H\001\220\001\001'
  _EDISPLAYSTATUS._serialized_start=2166
  _EDISPLAYSTATUS._serialized_end=3522
  _EAPPCLOUDSTATUS._serialized_start=3525
  _EAPPCLOUDSTATUS._serialized_end=3900
  _EAPPCONTROLLERSUPPORTLEVEL._serialized_start=3903
  _EAPPCONTROLLERSUPPORTLEVEL._serialized_end=4048
  _EAPPGAMEPADGYROTRACKPADSUPPORTLEVEL._serialized_start=4051
  _EAPPGAMEPADGYROTRACKPADSUPPORTLEVEL._serialized_end=4304
  _EAPPHDRSUPPORT._serialized_start=4307
  _EAPPHDRSUPPORT._serialized_end=4468
  _CAPPOVERVIEW_PERCLIENTDATA._serialized_start=49
  _CAPPOVERVIEW_PERCLIENTDATA._serialized_end=426
  _CAPPOVERVIEW._serialized_start=429
  _CAPPOVERVIEW._serialized_end=2034
  _CAPPOVERVIEW_CHANGE._serialized_start=2036
  _CAPPOVERVIEW_CHANGE._serialized_end=2163
# @@protoc_insertion_point(module_scope)
