# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: steammessages_auth.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import steam.protobufs.steammessages_base_pb2 as steammessages__base__pb2
import steam.protobufs.steammessages_unified_base_pb2 as steammessages__unified__base__pb2
import steam.protobufs.enums_pb2 as enums__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18steammessages_auth.proto\x1a\x18steammessages_base.proto\x1a steammessages_unified_base.proto\x1a\x0b\x65nums.proto\"G\n/CAuthentication_GetPasswordRSAPublicKey_Request\x12\x14\n\x0c\x61\x63\x63ount_name\x18\x01 \x01(\t\"s\n0CAuthentication_GetPasswordRSAPublicKey_Response\x12\x15\n\rpublickey_mod\x18\x01 \x01(\t\x12\x15\n\rpublickey_exp\x18\x02 \x01(\t\x12\x11\n\ttimestamp\x18\x03 \x01(\x04\"\xa9\x02\n\x1d\x43\x41uthentication_DeviceDetails\x12\x1c\n\x14\x64\x65vice_friendly_name\x18\x01 \x01(\t\x12P\n\rplatform_type\x18\x02 \x01(\x0e\x32\x17.EAuthTokenPlatformType: k_EAuthTokenPlatformType_Unknown\x12\x0f\n\x07os_type\x18\x03 \x01(\x05\x12\x1a\n\x12gaming_device_type\x18\x04 \x01(\r\x12\x14\n\x0c\x63lient_count\x18\x05 \x01(\r\x12\x12\n\nmachine_id\x18\x06 \x01(\x0c\x12\x41\n\x08\x61pp_type\x18\x07 \x01(\x0e\x32\x12.EAuthTokenAppType:\x1bk_EAuthTokenAppType_Unknown\"\xf4\x01\n-CAuthentication_BeginAuthSessionViaQR_Request\x12\x1c\n\x14\x64\x65vice_friendly_name\x18\x01 \x01(\t\x12P\n\rplatform_type\x18\x02 \x01(\x0e\x32\x17.EAuthTokenPlatformType: k_EAuthTokenPlatformType_Unknown\x12\x36\n\x0e\x64\x65vice_details\x18\x03 \x01(\x0b\x32\x1e.CAuthentication_DeviceDetails\x12\x1b\n\nwebsite_id\x18\x04 \x01(\t:\x07Unknown\"\x95\x01\n#CAuthentication_AllowedConfirmation\x12R\n\x11\x63onfirmation_type\x18\x01 \x01(\x0e\x32\x16.EAuthSessionGuardType:\x1fk_EAuthSessionGuardType_Unknown\x12\x1a\n\x12\x61ssociated_message\x18\x02 \x01(\t\"\xd6\x01\n.CAuthentication_BeginAuthSessionViaQR_Response\x12\x11\n\tclient_id\x18\x01 \x01(\x04\x12\x15\n\rchallenge_url\x18\x02 \x01(\t\x12\x12\n\nrequest_id\x18\x03 \x01(\x0c\x12\x10\n\x08interval\x18\x04 \x01(\x02\x12\x43\n\x15\x61llowed_confirmations\x18\x05 \x03(\x0b\x32$.CAuthentication_AllowedConfirmation\x12\x0f\n\x07version\x18\x06 \x01(\x05\"\xee\x03\n6CAuthentication_BeginAuthSessionViaCredentials_Request\x12\x1c\n\x14\x64\x65vice_friendly_name\x18\x01 \x01(\t\x12\x14\n\x0c\x61\x63\x63ount_name\x18\x02 \x01(\t\x12\x1a\n\x12\x65ncrypted_password\x18\x03 \x01(\t\x12\x1c\n\x14\x65ncryption_timestamp\x18\x04 \x01(\x04\x12\x16\n\x0eremember_login\x18\x05 \x01(\x08\x12P\n\rplatform_type\x18\x06 \x01(\x0e\x32\x17.EAuthTokenPlatformType: k_EAuthTokenPlatformType_Unknown\x12K\n\x0bpersistence\x18\x07 \x01(\x0e\x32\x14.ESessionPersistence: k_ESessionPersistence_Persistent\x12\x1b\n\nwebsite_id\x18\x08 \x01(\t:\x07Unknown\x12\x36\n\x0e\x64\x65vice_details\x18\t \x01(\x0b\x32\x1e.CAuthentication_DeviceDetails\x12\x12\n\nguard_data\x18\n \x01(\t\x12\x10\n\x08language\x18\x0b \x01(\r\x12\x14\n\tqos_level\x18\x0c \x01(\x05:\x01\x32\"\x9b\x02\n7CAuthentication_BeginAuthSessionViaCredentials_Response\x12\x11\n\tclient_id\x18\x01 \x01(\x04\x12\x12\n\nrequest_id\x18\x02 \x01(\x0c\x12\x10\n\x08interval\x18\x03 \x01(\x02\x12\x43\n\x15\x61llowed_confirmations\x18\x04 \x03(\x0b\x32$.CAuthentication_AllowedConfirmation\x12\x0f\n\x07steamid\x18\x05 \x01(\x04\x12\x12\n\nweak_token\x18\x06 \x01(\t\x12\x1d\n\x15\x61greement_session_url\x18\x07 \x01(\t\x12\x1e\n\x16\x65xtended_error_message\x18\x08 \x01(\t\"o\n-CAuthentication_PollAuthSessionStatus_Request\x12\x11\n\tclient_id\x18\x01 \x01(\x04\x12\x12\n\nrequest_id\x18\x02 \x01(\x0c\x12\x17\n\x0ftoken_to_revoke\x18\x03 \x01(\x06\"\xfc\x01\n.CAuthentication_PollAuthSessionStatus_Response\x12\x15\n\rnew_client_id\x18\x01 \x01(\x04\x12\x19\n\x11new_challenge_url\x18\x02 \x01(\t\x12\x15\n\rrefresh_token\x18\x03 \x01(\t\x12\x14\n\x0c\x61\x63\x63\x65ss_token\x18\x04 \x01(\t\x12\x1e\n\x16had_remote_interaction\x18\x05 \x01(\x08\x12\x14\n\x0c\x61\x63\x63ount_name\x18\x06 \x01(\t\x12\x16\n\x0enew_guard_data\x18\x07 \x01(\t\x12\x1d\n\x15\x61greement_session_url\x18\x08 \x01(\t\"?\n*CAuthentication_GetAuthSessionInfo_Request\x12\x11\n\tclient_id\x18\x01 \x01(\x04\"\xc0\x04\n+CAuthentication_GetAuthSessionInfo_Response\x12\n\n\x02ip\x18\x01 \x01(\t\x12\x0e\n\x06geoloc\x18\x02 \x01(\t\x12\x0c\n\x04\x63ity\x18\x03 \x01(\t\x12\r\n\x05state\x18\x04 \x01(\t\x12\x0f\n\x07\x63ountry\x18\x05 \x01(\t\x12P\n\rplatform_type\x18\x06 \x01(\x0e\x32\x17.EAuthTokenPlatformType: k_EAuthTokenPlatformType_Unknown\x12\x1c\n\x14\x64\x65vice_friendly_name\x18\x07 \x01(\t\x12\x0f\n\x07version\x18\x08 \x01(\x05\x12Z\n\rlogin_history\x18\t \x01(\x0e\x32\x1c.EAuthSessionSecurityHistory:%k_EAuthSessionSecurityHistory_Invalid\x12#\n\x1brequestor_location_mismatch\x18\n \x01(\x08\x12\x18\n\x10high_usage_login\x18\x0b \x01(\x08\x12R\n\x15requested_persistence\x18\x0c \x01(\x0e\x32\x14.ESessionPersistence:\x1dk_ESessionPersistence_Invalid\x12\x14\n\x0c\x64\x65vice_trust\x18\r \x01(\x05\x12\x41\n\x08\x61pp_type\x18\x0e \x01(\x0e\x32\x12.EAuthTokenAppType:\x1bk_EAuthTokenAppType_Unknown\"U\n.CAuthentication_GetAuthSessionRiskInfo_Request\x12\x11\n\tclient_id\x18\x01 \x01(\x04\x12\x10\n\x08language\x18\x02 \x01(\r\"\xd3\x01\n/CAuthentication_GetAuthSessionRiskInfo_Response\x12\x1a\n\x12location_confirmer\x18\x01 \x01(\t\x12\x1a\n\x12location_requestor\x18\x02 \x01(\t\x12\x16\n\x0elocation_other\x18\x03 \x01(\t\x12P\n\rplatform_type\x18\x04 \x01(\x0e\x32\x17.EAuthTokenPlatformType: k_EAuthTokenPlatformType_Unknown\"\x98\x02\n2CAuthentication_NotifyRiskQuizResults_Notification\x12\x11\n\tclient_id\x18\x01 \x01(\x04\x12T\n\x07results\x18\x02 \x01(\x0b\x32\x43.CAuthentication_NotifyRiskQuizResults_Notification.RiskQuizResults\x12\x17\n\x0fselected_action\x18\x03 \x01(\t\x12\x19\n\x11\x64id_confirm_login\x18\x04 \x01(\x08\x1a\x45\n\x0fRiskQuizResults\x12\x10\n\x08platform\x18\x01 \x01(\x08\x12\x10\n\x08location\x18\x02 \x01(\x08\x12\x0e\n\x06\x61\x63tion\x18\x03 \x01(\x08\"\xee\x01\n?CAuthentication_UpdateAuthSessionWithMobileConfirmation_Request\x12\x0f\n\x07version\x18\x01 \x01(\x05\x12\x11\n\tclient_id\x18\x02 \x01(\x04\x12\x0f\n\x07steamid\x18\x03 \x01(\x06\x12\x11\n\tsignature\x18\x04 \x01(\x0c\x12\x16\n\x07\x63onfirm\x18\x05 \x01(\x08:\x05\x66\x61lse\x12K\n\x0bpersistence\x18\x06 \x01(\x0e\x32\x14.ESessionPersistence: k_ESessionPersistence_Persistent\"B\n@CAuthentication_UpdateAuthSessionWithMobileConfirmation_Response\"\xbb\x01\n;CAuthentication_UpdateAuthSessionWithSteamGuardCode_Request\x12\x11\n\tclient_id\x18\x01 \x01(\x04\x12\x0f\n\x07steamid\x18\x02 \x01(\x06\x12\x0c\n\x04\x63ode\x18\x03 \x01(\t\x12J\n\tcode_type\x18\x04 \x01(\x0e\x32\x16.EAuthSessionGuardType:\x1fk_EAuthSessionGuardType_Unknown\"]\n<CAuthentication_UpdateAuthSessionWithSteamGuardCode_Response\x12\x1d\n\x15\x61greement_session_url\x18\x07 \x01(\t\"\xa0\x01\n2CAuthentication_AccessToken_GenerateForApp_Request\x12\x15\n\rrefresh_token\x18\x01 \x01(\t\x12\x0f\n\x07steamid\x18\x02 \x01(\x06\x12\x42\n\x0crenewal_type\x18\x03 \x01(\x0e\x32\x12.ETokenRenewalType:\x18k_ETokenRenewalType_None\"b\n3CAuthentication_AccessToken_GenerateForApp_Response\x12\x14\n\x0c\x61\x63\x63\x65ss_token\x18\x01 \x01(\t\x12\x15\n\rrefresh_token\x18\x02 \x01(\t\"P\n.CAuthentication_RefreshToken_Enumerate_Request\x12\x1e\n\x0finclude_revoked\x18\x01 \x01(\x08:\x05\x66\x61lse\"\x8a\x07\n/CAuthentication_RefreshToken_Enumerate_Response\x12`\n\x0erefresh_tokens\x18\x01 \x03(\x0b\x32H.CAuthentication_RefreshToken_Enumerate_Response.RefreshTokenDescription\x12\x18\n\x10requesting_token\x18\x02 \x01(\x06\x1ay\n\x0fTokenUsageEvent\x12\x0c\n\x04time\x18\x01 \x01(\r\x12\x1a\n\x02ip\x18\x02 \x01(\x0b\x32\x0e.CMsgIPAddress\x12\x0e\n\x06locale\x18\x03 \x01(\t\x12\x0f\n\x07\x63ountry\x18\x04 \x01(\t\x12\r\n\x05state\x18\x05 \x01(\t\x12\x0c\n\x04\x63ity\x18\x06 \x01(\t\x1a\xdf\x04\n\x17RefreshTokenDescription\x12\x10\n\x08token_id\x18\x01 \x01(\x06\x12\x19\n\x11token_description\x18\x02 \x01(\t\x12\x14\n\x0ctime_updated\x18\x03 \x01(\r\x12P\n\rplatform_type\x18\x04 \x01(\x0e\x32\x17.EAuthTokenPlatformType: k_EAuthTokenPlatformType_Unknown\x12\x11\n\tlogged_in\x18\x05 \x01(\x08\x12\x13\n\x0bos_platform\x18\x06 \x01(\r\x12\x11\n\tauth_type\x18\x07 \x01(\r\x12\x1a\n\x12gaming_device_type\x18\x08 \x01(\r\x12T\n\nfirst_seen\x18\t \x01(\x0b\x32@.CAuthentication_RefreshToken_Enumerate_Response.TokenUsageEvent\x12S\n\tlast_seen\x18\n \x01(\x0b\x32@.CAuthentication_RefreshToken_Enumerate_Response.TokenUsageEvent\x12\x0f\n\x07os_type\x18\x0b \x01(\x05\x12P\n\x13\x61uthentication_type\x18\x0c \x01(\x0e\x32\x14.EAuthenticationType:\x1dk_EAuthenticationType_Unknown\x12J\n\x15\x65\x66\x66\x65\x63tive_token_state\x18\r \x01(\x0e\x32\x10.EAuthTokenState:\x19k_EAuthTokenState_Invalid\"3\n1CAuthentication_GetAuthSessionsForAccount_Request\"H\n2CAuthentication_GetAuthSessionsForAccount_Response\x12\x12\n\nclient_ids\x18\x01 \x03(\x04\"a\n,CAuthentication_MigrateMobileSession_Request\x12\x0f\n\x07steamid\x18\x01 \x01(\x06\x12\r\n\x05token\x18\x02 \x01(\t\x12\x11\n\tsignature\x18\x03 \x01(\t\"\\\n-CAuthentication_MigrateMobileSession_Response\x12\x15\n\rrefresh_token\x18\x01 \x01(\t\x12\x14\n\x0c\x61\x63\x63\x65ss_token\x18\x02 \x01(\t\"\x82\x01\n$CAuthentication_Token_Revoke_Request\x12\r\n\x05token\x18\x01 \x01(\t\x12K\n\rrevoke_action\x18\x02 \x01(\x0e\x32\x17.EAuthTokenRevokeAction:\x1bk_EAuthTokenRevokePermanent\"\'\n%CAuthentication_Token_Revoke_Response\"\xb0\x01\n+CAuthentication_RefreshToken_Revoke_Request\x12\x10\n\x08token_id\x18\x01 \x01(\x06\x12\x0f\n\x07steamid\x18\x02 \x01(\x06\x12K\n\rrevoke_action\x18\x03 \x01(\x0e\x32\x17.EAuthTokenRevokeAction:\x1bk_EAuthTokenRevokePermanent\x12\x11\n\tsignature\x18\x04 \x01(\x0c\".\n,CAuthentication_RefreshToken_Revoke_Response\"m\n:CAuthenticationSupport_QueryRefreshTokensByAccount_Request\x12\x0f\n\x07steamid\x18\x01 \x01(\x06\x12\x1e\n\x16include_revoked_tokens\x18\x02 \x01(\x08\"\xda\x04\n\x1f\x43SupportRefreshTokenDescription\x12\x10\n\x08token_id\x18\x01 \x01(\x06\x12\x19\n\x11token_description\x18\x02 \x01(\t\x12\x14\n\x0ctime_updated\x18\x03 \x01(\r\x12P\n\rplatform_type\x18\x04 \x01(\x0e\x32\x17.EAuthTokenPlatformType: k_EAuthTokenPlatformType_Unknown\x12@\n\x0btoken_state\x18\x05 \x01(\x0e\x32\x10.EAuthTokenState:\x19k_EAuthTokenState_Invalid\x12\x15\n\rowner_steamid\x18\x06 \x01(\x06\x12\x13\n\x0bos_platform\x18\x07 \x01(\r\x12\x0f\n\x07os_type\x18\x08 \x01(\x05\x12\x11\n\tauth_type\x18\t \x01(\r\x12\x1a\n\x12gaming_device_type\x18\n \x01(\r\x12\x44\n\nfirst_seen\x18\x0b \x01(\x0b\x32\x30.CSupportRefreshTokenDescription.TokenUsageEvent\x12\x43\n\tlast_seen\x18\x0c \x01(\x0b\x32\x30.CSupportRefreshTokenDescription.TokenUsageEvent\x1ai\n\x0fTokenUsageEvent\x12\x0c\n\x04time\x18\x01 \x01(\r\x12\x1a\n\x02ip\x18\x02 \x01(\x0b\x32\x0e.CMsgIPAddress\x12\x0f\n\x07\x63ountry\x18\x03 \x01(\t\x12\r\n\x05state\x18\x04 \x01(\t\x12\x0c\n\x04\x63ity\x18\x05 \x01(\t\"\x91\x01\n;CAuthenticationSupport_QueryRefreshTokensByAccount_Response\x12\x38\n\x0erefresh_tokens\x18\x01 \x03(\x0b\x32 .CSupportRefreshTokenDescription\x12\x18\n\x10last_token_reset\x18\x02 \x01(\x05\"H\n4CAuthenticationSupport_QueryRefreshTokenByID_Request\x12\x10\n\x08token_id\x18\x01 \x01(\x06\"q\n5CAuthenticationSupport_QueryRefreshTokenByID_Response\x12\x38\n\x0erefresh_tokens\x18\x01 \x03(\x0b\x32 .CSupportRefreshTokenDescription\"O\n*CAuthenticationSupport_RevokeToken_Request\x12\x10\n\x08token_id\x18\x01 \x01(\x06\x12\x0f\n\x07steamid\x18\x02 \x01(\x06\"-\n+CAuthenticationSupport_RevokeToken_Response\"B\n.CAuthenticationSupport_GetTokenHistory_Request\x12\x10\n\x08token_id\x18\x01 \x01(\x06\"d\n\x19\x43SupportRefreshTokenAudit\x12\x0e\n\x06\x61\x63tion\x18\x01 \x01(\x05\x12\x0c\n\x04time\x18\x02 \x01(\r\x12\x1a\n\x02ip\x18\x03 \x01(\x0b\x32\x0e.CMsgIPAddress\x12\r\n\x05\x61\x63tor\x18\x04 \x01(\x06\"^\n/CAuthenticationSupport_GetTokenHistory_Response\x12+\n\x07history\x18\x01 \x03(\x0b\x32\x1a.CSupportRefreshTokenAudit\"X\n3CAuthenticationSupport_MarkTokenCompromised_Request\x12\x0f\n\x07steamid\x18\x01 \x01(\x06\x12\x10\n\x08token_id\x18\x02 \x01(\x06\"6\n4CAuthenticationSupport_MarkTokenCompromised_Response\"C\n CCloudGaming_CreateNonce_Request\x12\x10\n\x08platform\x18\x01 \x01(\t\x12\r\n\x05\x61ppid\x18\x02 \x01(\r\"B\n!CCloudGaming_CreateNonce_Response\x12\r\n\x05nonce\x18\x01 \x01(\t\x12\x0e\n\x06\x65xpiry\x18\x02 \x01(\r\"M\n%CCloudGaming_GetTimeRemaining_Request\x12\x10\n\x08platform\x18\x01 \x01(\t\x12\x12\n\nappid_list\x18\x02 \x03(\r\"F\n\x1a\x43\x43loudGaming_TimeRemaining\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x19\n\x11minutes_remaining\x18\x02 \x01(\r\"V\n&CCloudGaming_GetTimeRemaining_Response\x12,\n\x07\x65ntries\x18\x02 \x03(\x0b\x32\x1b.CCloudGaming_TimeRemaining*\xb9\x01\n\x16\x45\x41uthTokenPlatformType\x12$\n k_EAuthTokenPlatformType_Unknown\x10\x00\x12(\n$k_EAuthTokenPlatformType_SteamClient\x10\x01\x12\'\n#k_EAuthTokenPlatformType_WebBrowser\x10\x02\x12&\n\"k_EAuthTokenPlatformType_MobileApp\x10\x03*\x85\x01\n\x11\x45\x41uthTokenAppType\x12\x1f\n\x1bk_EAuthTokenAppType_Unknown\x10\x00\x12\'\n#k_EAuthTokenAppType_Mobile_SteamApp\x10\x01\x12&\n\"k_EAuthTokenAppType_Mobile_ChatApp\x10\x02*\xe5\x02\n\x15\x45\x41uthSessionGuardType\x12#\n\x1fk_EAuthSessionGuardType_Unknown\x10\x00\x12 \n\x1ck_EAuthSessionGuardType_None\x10\x01\x12%\n!k_EAuthSessionGuardType_EmailCode\x10\x02\x12&\n\"k_EAuthSessionGuardType_DeviceCode\x10\x03\x12.\n*k_EAuthSessionGuardType_DeviceConfirmation\x10\x04\x12-\n)k_EAuthSessionGuardType_EmailConfirmation\x10\x05\x12(\n$k_EAuthSessionGuardType_MachineToken\x10\x06\x12-\n)k_EAuthSessionGuardType_LegacyMachineAuth\x10\x07*\xac\x01\n\x1b\x45\x41uthSessionSecurityHistory\x12)\n%k_EAuthSessionSecurityHistory_Invalid\x10\x00\x12\x30\n,k_EAuthSessionSecurityHistory_UsedPreviously\x10\x01\x12\x30\n,k_EAuthSessionSecurityHistory_NoPriorHistory\x10\x02*P\n\x11\x45TokenRenewalType\x12\x1c\n\x18k_ETokenRenewalType_None\x10\x00\x12\x1d\n\x19k_ETokenRenewalType_Allow\x10\x01*\xcd\x01\n\x13\x45\x41uthenticationType\x12!\n\x1dk_EAuthenticationType_Unknown\x10\x00\x12\"\n\x1ek_EAuthenticationType_Password\x10\x01\x12\x1c\n\x18k_EAuthenticationType_QR\x10\x02\x12)\n%k_EAuthenticationType_AccountCreation\x10\x03\x12&\n\"k_EAuthenticationType_GuestAccount\x10\x04*\x88\x02\n\x0f\x45\x41uthTokenState\x12\x1d\n\x19k_EAuthTokenState_Invalid\x10\x00\x12\x19\n\x15k_EAuthTokenState_New\x10\x01\x12\x1f\n\x1bk_EAuthTokenState_Confirmed\x10\x02\x12\x1c\n\x18k_EAuthTokenState_Issued\x10\x03\x12\x1c\n\x18k_EAuthTokenState_Denied\x10\x04\x12\x1f\n\x1bk_EAuthTokenState_LoggedOut\x10\x05\x12\x1e\n\x1ak_EAuthTokenState_Consumed\x10\x06\x12\x1d\n\x19k_EAuthTokenState_Revoked\x10\x63*\xaf\x02\n\x16\x45\x41uthTokenRevokeAction\x12\x1c\n\x18k_EAuthTokenRevokeLogout\x10\x00\x12\x1f\n\x1bk_EAuthTokenRevokePermanent\x10\x01\x12\x1e\n\x1ak_EAuthTokenRevokeReplaced\x10\x02\x12\x1d\n\x19k_EAuthTokenRevokeSupport\x10\x03\x12\x1d\n\x19k_EAuthTokenRevokeConsume\x10\x04\x12)\n%k_EAuthTokenRevokeNonRememberedLogout\x10\x05\x12,\n(k_EAuthTokenRevokeNonRememberedPermanent\x10\x06\x12\x1f\n\x1bk_EAuthTokenRevokeAutomatic\x10\x07\x32\x87\x0f\n\x0e\x41uthentication\x12~\n\x17GetPasswordRSAPublicKey\x12\x30.CAuthentication_GetPasswordRSAPublicKey_Request\x1a\x31.CAuthentication_GetPasswordRSAPublicKey_Response\x12x\n\x15\x42\x65ginAuthSessionViaQR\x12..CAuthentication_BeginAuthSessionViaQR_Request\x1a/.CAuthentication_BeginAuthSessionViaQR_Response\x12\x93\x01\n\x1e\x42\x65ginAuthSessionViaCredentials\x12\x37.CAuthentication_BeginAuthSessionViaCredentials_Request\x1a\x38.CAuthentication_BeginAuthSessionViaCredentials_Response\x12x\n\x15PollAuthSessionStatus\x12..CAuthentication_PollAuthSessionStatus_Request\x1a/.CAuthentication_PollAuthSessionStatus_Response\x12o\n\x12GetAuthSessionInfo\x12+.CAuthentication_GetAuthSessionInfo_Request\x1a,.CAuthentication_GetAuthSessionInfo_Response\x12{\n\x16GetAuthSessionRiskInfo\x12/.CAuthentication_GetAuthSessionRiskInfo_Request\x1a\x30.CAuthentication_GetAuthSessionRiskInfo_Response\x12Y\n\x15NotifyRiskQuizResults\x12\x33.CAuthentication_NotifyRiskQuizResults_Notification\x1a\x0b.NoResponse\x12\xae\x01\n\'UpdateAuthSessionWithMobileConfirmation\x12@.CAuthentication_UpdateAuthSessionWithMobileConfirmation_Request\x1a\x41.CAuthentication_UpdateAuthSessionWithMobileConfirmation_Response\x12\xa2\x01\n#UpdateAuthSessionWithSteamGuardCode\x12<.CAuthentication_UpdateAuthSessionWithSteamGuardCode_Request\x1a=.CAuthentication_UpdateAuthSessionWithSteamGuardCode_Response\x12\x86\x01\n\x19GenerateAccessTokenForApp\x12\x33.CAuthentication_AccessToken_GenerateForApp_Request\x1a\x34.CAuthentication_AccessToken_GenerateForApp_Response\x12t\n\x0f\x45numerateTokens\x12/.CAuthentication_RefreshToken_Enumerate_Request\x1a\x30.CAuthentication_RefreshToken_Enumerate_Response\x12\x84\x01\n\x19GetAuthSessionsForAccount\x12\x32.CAuthentication_GetAuthSessionsForAccount_Request\x1a\x33.CAuthentication_GetAuthSessionsForAccount_Response\x12u\n\x14MigrateMobileSession\x12-.CAuthentication_MigrateMobileSession_Request\x1a..CAuthentication_MigrateMobileSession_Response\x12\\\n\x0bRevokeToken\x12%.CAuthentication_Token_Revoke_Request\x1a&.CAuthentication_Token_Revoke_Response\x12q\n\x12RevokeRefreshToken\x12,.CAuthentication_RefreshToken_Revoke_Request\x1a-.CAuthentication_RefreshToken_Revoke_Response2\xa1\x05\n\x15\x41uthenticationSupport\x12\x98\x01\n\x1bQueryRefreshTokensByAccount\x12;.CAuthenticationSupport_QueryRefreshTokensByAccount_Request\x1a<.CAuthenticationSupport_QueryRefreshTokensByAccount_Response\x12\x86\x01\n\x15QueryRefreshTokenByID\x12\x35.CAuthenticationSupport_QueryRefreshTokenByID_Request\x1a\x36.CAuthenticationSupport_QueryRefreshTokenByID_Response\x12h\n\x0bRevokeToken\x12+.CAuthenticationSupport_RevokeToken_Request\x1a,.CAuthenticationSupport_RevokeToken_Response\x12t\n\x0fGetTokenHistory\x12/.CAuthenticationSupport_GetTokenHistory_Request\x1a\x30.CAuthenticationSupport_GetTokenHistory_Response\x12\x83\x01\n\x14MarkTokenCompromised\x12\x34.CAuthenticationSupport_MarkTokenCompromised_Request\x1a\x35.CAuthenticationSupport_MarkTokenCompromised_Response2\xc8\x01\n\x0b\x43loudGaming\x12T\n\x0b\x43reateNonce\x12!.CCloudGaming_CreateNonce_Request\x1a\".CCloudGaming_CreateNonce_Response\x12\x63\n\x10GetTimeRemaining\x12&.CCloudGaming_GetTimeRemaining_Request\x1a\'.CCloudGaming_GetTimeRemaining_ResponseB\x03\x90\x01\x01')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'steammessages_auth_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\220\001\001'
  _EAUTHTOKENPLATFORMTYPE._serialized_start=8125
  _EAUTHTOKENPLATFORMTYPE._serialized_end=8310
  _EAUTHTOKENAPPTYPE._serialized_start=8313
  _EAUTHTOKENAPPTYPE._serialized_end=8446
  _EAUTHSESSIONGUARDTYPE._serialized_start=8449
  _EAUTHSESSIONGUARDTYPE._serialized_end=8806
  _EAUTHSESSIONSECURITYHISTORY._serialized_start=8809
  _EAUTHSESSIONSECURITYHISTORY._serialized_end=8981
  _ETOKENRENEWALTYPE._serialized_start=8983
  _ETOKENRENEWALTYPE._serialized_end=9063
  _EAUTHENTICATIONTYPE._serialized_start=9066
  _EAUTHENTICATIONTYPE._serialized_end=9271
  _EAUTHTOKENSTATE._serialized_start=9274
  _EAUTHTOKENSTATE._serialized_end=9538
  _EAUTHTOKENREVOKEACTION._serialized_start=9541
  _EAUTHTOKENREVOKEACTION._serialized_end=9844
  _CAUTHENTICATION_GETPASSWORDRSAPUBLICKEY_REQUEST._serialized_start=101
  _CAUTHENTICATION_GETPASSWORDRSAPUBLICKEY_REQUEST._serialized_end=172
  _CAUTHENTICATION_GETPASSWORDRSAPUBLICKEY_RESPONSE._serialized_start=174
  _CAUTHENTICATION_GETPASSWORDRSAPUBLICKEY_RESPONSE._serialized_end=289
  _CAUTHENTICATION_DEVICEDETAILS._serialized_start=292
  _CAUTHENTICATION_DEVICEDETAILS._serialized_end=589
  _CAUTHENTICATION_BEGINAUTHSESSIONVIAQR_REQUEST._serialized_start=592
  _CAUTHENTICATION_BEGINAUTHSESSIONVIAQR_REQUEST._serialized_end=836
  _CAUTHENTICATION_ALLOWEDCONFIRMATION._serialized_start=839
  _CAUTHENTICATION_ALLOWEDCONFIRMATION._serialized_end=988
  _CAUTHENTICATION_BEGINAUTHSESSIONVIAQR_RESPONSE._serialized_start=991
  _CAUTHENTICATION_BEGINAUTHSESSIONVIAQR_RESPONSE._serialized_end=1205
  _CAUTHENTICATION_BEGINAUTHSESSIONVIACREDENTIALS_REQUEST._serialized_start=1208
  _CAUTHENTICATION_BEGINAUTHSESSIONVIACREDENTIALS_REQUEST._serialized_end=1702
  _CAUTHENTICATION_BEGINAUTHSESSIONVIACREDENTIALS_RESPONSE._serialized_start=1705
  _CAUTHENTICATION_BEGINAUTHSESSIONVIACREDENTIALS_RESPONSE._serialized_end=1988
  _CAUTHENTICATION_POLLAUTHSESSIONSTATUS_REQUEST._serialized_start=1990
  _CAUTHENTICATION_POLLAUTHSESSIONSTATUS_REQUEST._serialized_end=2101
  _CAUTHENTICATION_POLLAUTHSESSIONSTATUS_RESPONSE._serialized_start=2104
  _CAUTHENTICATION_POLLAUTHSESSIONSTATUS_RESPONSE._serialized_end=2356
  _CAUTHENTICATION_GETAUTHSESSIONINFO_REQUEST._serialized_start=2358
  _CAUTHENTICATION_GETAUTHSESSIONINFO_REQUEST._serialized_end=2421
  _CAUTHENTICATION_GETAUTHSESSIONINFO_RESPONSE._serialized_start=2424
  _CAUTHENTICATION_GETAUTHSESSIONINFO_RESPONSE._serialized_end=3000
  _CAUTHENTICATION_GETAUTHSESSIONRISKINFO_REQUEST._serialized_start=3002
  _CAUTHENTICATION_GETAUTHSESSIONRISKINFO_REQUEST._serialized_end=3087
  _CAUTHENTICATION_GETAUTHSESSIONRISKINFO_RESPONSE._serialized_start=3090
  _CAUTHENTICATION_GETAUTHSESSIONRISKINFO_RESPONSE._serialized_end=3301
  _CAUTHENTICATION_NOTIFYRISKQUIZRESULTS_NOTIFICATION._serialized_start=3304
  _CAUTHENTICATION_NOTIFYRISKQUIZRESULTS_NOTIFICATION._serialized_end=3584
  _CAUTHENTICATION_NOTIFYRISKQUIZRESULTS_NOTIFICATION_RISKQUIZRESULTS._serialized_start=3515
  _CAUTHENTICATION_NOTIFYRISKQUIZRESULTS_NOTIFICATION_RISKQUIZRESULTS._serialized_end=3584
  _CAUTHENTICATION_UPDATEAUTHSESSIONWITHMOBILECONFIRMATION_REQUEST._serialized_start=3587
  _CAUTHENTICATION_UPDATEAUTHSESSIONWITHMOBILECONFIRMATION_REQUEST._serialized_end=3825
  _CAUTHENTICATION_UPDATEAUTHSESSIONWITHMOBILECONFIRMATION_RESPONSE._serialized_start=3827
  _CAUTHENTICATION_UPDATEAUTHSESSIONWITHMOBILECONFIRMATION_RESPONSE._serialized_end=3893
  _CAUTHENTICATION_UPDATEAUTHSESSIONWITHSTEAMGUARDCODE_REQUEST._serialized_start=3896
  _CAUTHENTICATION_UPDATEAUTHSESSIONWITHSTEAMGUARDCODE_REQUEST._serialized_end=4083
  _CAUTHENTICATION_UPDATEAUTHSESSIONWITHSTEAMGUARDCODE_RESPONSE._serialized_start=4085
  _CAUTHENTICATION_UPDATEAUTHSESSIONWITHSTEAMGUARDCODE_RESPONSE._serialized_end=4178
  _CAUTHENTICATION_ACCESSTOKEN_GENERATEFORAPP_REQUEST._serialized_start=4181
  _CAUTHENTICATION_ACCESSTOKEN_GENERATEFORAPP_REQUEST._serialized_end=4341
  _CAUTHENTICATION_ACCESSTOKEN_GENERATEFORAPP_RESPONSE._serialized_start=4343
  _CAUTHENTICATION_ACCESSTOKEN_GENERATEFORAPP_RESPONSE._serialized_end=4441
  _CAUTHENTICATION_REFRESHTOKEN_ENUMERATE_REQUEST._serialized_start=4443
  _CAUTHENTICATION_REFRESHTOKEN_ENUMERATE_REQUEST._serialized_end=4523
  _CAUTHENTICATION_REFRESHTOKEN_ENUMERATE_RESPONSE._serialized_start=4526
  _CAUTHENTICATION_REFRESHTOKEN_ENUMERATE_RESPONSE._serialized_end=5432
  _CAUTHENTICATION_REFRESHTOKEN_ENUMERATE_RESPONSE_TOKENUSAGEEVENT._serialized_start=4701
  _CAUTHENTICATION_REFRESHTOKEN_ENUMERATE_RESPONSE_TOKENUSAGEEVENT._serialized_end=4822
  _CAUTHENTICATION_REFRESHTOKEN_ENUMERATE_RESPONSE_REFRESHTOKENDESCRIPTION._serialized_start=4825
  _CAUTHENTICATION_REFRESHTOKEN_ENUMERATE_RESPONSE_REFRESHTOKENDESCRIPTION._serialized_end=5432
  _CAUTHENTICATION_GETAUTHSESSIONSFORACCOUNT_REQUEST._serialized_start=5434
  _CAUTHENTICATION_GETAUTHSESSIONSFORACCOUNT_REQUEST._serialized_end=5485
  _CAUTHENTICATION_GETAUTHSESSIONSFORACCOUNT_RESPONSE._serialized_start=5487
  _CAUTHENTICATION_GETAUTHSESSIONSFORACCOUNT_RESPONSE._serialized_end=5559
  _CAUTHENTICATION_MIGRATEMOBILESESSION_REQUEST._serialized_start=5561
  _CAUTHENTICATION_MIGRATEMOBILESESSION_REQUEST._serialized_end=5658
  _CAUTHENTICATION_MIGRATEMOBILESESSION_RESPONSE._serialized_start=5660
  _CAUTHENTICATION_MIGRATEMOBILESESSION_RESPONSE._serialized_end=5752
  _CAUTHENTICATION_TOKEN_REVOKE_REQUEST._serialized_start=5755
  _CAUTHENTICATION_TOKEN_REVOKE_REQUEST._serialized_end=5885
  _CAUTHENTICATION_TOKEN_REVOKE_RESPONSE._serialized_start=5887
  _CAUTHENTICATION_TOKEN_REVOKE_RESPONSE._serialized_end=5926
  _CAUTHENTICATION_REFRESHTOKEN_REVOKE_REQUEST._serialized_start=5929
  _CAUTHENTICATION_REFRESHTOKEN_REVOKE_REQUEST._serialized_end=6105
  _CAUTHENTICATION_REFRESHTOKEN_REVOKE_RESPONSE._serialized_start=6107
  _CAUTHENTICATION_REFRESHTOKEN_REVOKE_RESPONSE._serialized_end=6153
  _CAUTHENTICATIONSUPPORT_QUERYREFRESHTOKENSBYACCOUNT_REQUEST._serialized_start=6155
  _CAUTHENTICATIONSUPPORT_QUERYREFRESHTOKENSBYACCOUNT_REQUEST._serialized_end=6264
  _CSUPPORTREFRESHTOKENDESCRIPTION._serialized_start=6267
  _CSUPPORTREFRESHTOKENDESCRIPTION._serialized_end=6869
  _CSUPPORTREFRESHTOKENDESCRIPTION_TOKENUSAGEEVENT._serialized_start=6764
  _CSUPPORTREFRESHTOKENDESCRIPTION_TOKENUSAGEEVENT._serialized_end=6869
  _CAUTHENTICATIONSUPPORT_QUERYREFRESHTOKENSBYACCOUNT_RESPONSE._serialized_start=6872
  _CAUTHENTICATIONSUPPORT_QUERYREFRESHTOKENSBYACCOUNT_RESPONSE._serialized_end=7017
  _CAUTHENTICATIONSUPPORT_QUERYREFRESHTOKENBYID_REQUEST._serialized_start=7019
  _CAUTHENTICATIONSUPPORT_QUERYREFRESHTOKENBYID_REQUEST._serialized_end=7091
  _CAUTHENTICATIONSUPPORT_QUERYREFRESHTOKENBYID_RESPONSE._serialized_start=7093
  _CAUTHENTICATIONSUPPORT_QUERYREFRESHTOKENBYID_RESPONSE._serialized_end=7206
  _CAUTHENTICATIONSUPPORT_REVOKETOKEN_REQUEST._serialized_start=7208
  _CAUTHENTICATIONSUPPORT_REVOKETOKEN_REQUEST._serialized_end=7287
  _CAUTHENTICATIONSUPPORT_REVOKETOKEN_RESPONSE._serialized_start=7289
  _CAUTHENTICATIONSUPPORT_REVOKETOKEN_RESPONSE._serialized_end=7334
  _CAUTHENTICATIONSUPPORT_GETTOKENHISTORY_REQUEST._serialized_start=7336
  _CAUTHENTICATIONSUPPORT_GETTOKENHISTORY_REQUEST._serialized_end=7402
  _CSUPPORTREFRESHTOKENAUDIT._serialized_start=7404
  _CSUPPORTREFRESHTOKENAUDIT._serialized_end=7504
  _CAUTHENTICATIONSUPPORT_GETTOKENHISTORY_RESPONSE._serialized_start=7506
  _CAUTHENTICATIONSUPPORT_GETTOKENHISTORY_RESPONSE._serialized_end=7600
  _CAUTHENTICATIONSUPPORT_MARKTOKENCOMPROMISED_REQUEST._serialized_start=7602
  _CAUTHENTICATIONSUPPORT_MARKTOKENCOMPROMISED_REQUEST._serialized_end=7690
  _CAUTHENTICATIONSUPPORT_MARKTOKENCOMPROMISED_RESPONSE._serialized_start=7692
  _CAUTHENTICATIONSUPPORT_MARKTOKENCOMPROMISED_RESPONSE._serialized_end=7746
  _CCLOUDGAMING_CREATENONCE_REQUEST._serialized_start=7748
  _CCLOUDGAMING_CREATENONCE_REQUEST._serialized_end=7815
  _CCLOUDGAMING_CREATENONCE_RESPONSE._serialized_start=7817
  _CCLOUDGAMING_CREATENONCE_RESPONSE._serialized_end=7883
  _CCLOUDGAMING_GETTIMEREMAINING_REQUEST._serialized_start=7885
  _CCLOUDGAMING_GETTIMEREMAINING_REQUEST._serialized_end=7962
  _CCLOUDGAMING_TIMEREMAINING._serialized_start=7964
  _CCLOUDGAMING_TIMEREMAINING._serialized_end=8034
  _CCLOUDGAMING_GETTIMEREMAINING_RESPONSE._serialized_start=8036
  _CCLOUDGAMING_GETTIMEREMAINING_RESPONSE._serialized_end=8122
  _AUTHENTICATION._serialized_start=9847
  _AUTHENTICATION._serialized_end=11774
  _AUTHENTICATIONSUPPORT._serialized_start=11777
  _AUTHENTICATIONSUPPORT._serialized_end=12450
  _CLOUDGAMING._serialized_start=12453
  _CLOUDGAMING._serialized_end=12653
_builder.BuildServices(DESCRIPTOR, 'steammessages_auth_pb2', globals())
# @@protoc_insertion_point(module_scope)
