# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: steammessages_unified_base.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import descriptor_pb2 as google_dot_protobuf_dot_descriptor__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n steammessages_unified_base.proto\x1a google/protobuf/descriptor.proto\"\x0c\n\nNoResponse*]\n\x13\x45ProtoExecutionSite\x12 \n\x1ck_EProtoExecutionSiteUnknown\x10\x00\x12$\n k_EProtoExecutionSiteSteamClient\x10\x02*e\n\x11\x45ProtoServiceType\x12$\n k_EProtoServiceTypeSteamMessages\x10\x00\x12*\n&k_EProtoServiceTypeVRGamepadUIMessages\x10\x01:>\n\x13message_description\x12\x1f.google.protobuf.MessageOptions\x18\xb8\x8e\x03 \x01(\t:D\n\x12\x66orce_emit_message\x12\x1f.google.protobuf.MessageOptions\x18\xea\x86\x03 \x01(\x08:\x05\x66\x61lse:4\n\x0b\x64\x65scription\x12\x1d.google.protobuf.FieldOptions\x18\xd0\x86\x03 \x01(\t:>\n\x13service_description\x12\x1f.google.protobuf.ServiceOptions\x18\xd0\x86\x03 \x01(\t:u\n\x16service_execution_site\x12\x1f.google.protobuf.ServiceOptions\x18\xd8\x86\x03 \x01(\x0e\x32\x14.EProtoExecutionSite:\x1ck_EProtoExecutionSiteUnknown:m\n\x0cservice_type\x12\x1f.google.protobuf.ServiceOptions\x18\xe9\x86\x03 \x01(\x0e\x32\x12.EProtoServiceType: k_EProtoServiceTypeSteamMessages:D\n\x12\x66orce_emit_service\x12\x1f.google.protobuf.ServiceOptions\x18\xea\x86\x03 \x01(\x08:\x05\x66\x61lse:<\n\x12method_description\x12\x1e.google.protobuf.MethodOptions\x18\xd0\x86\x03 \x01(\t:8\n\x10\x65num_description\x12\x1c.google.protobuf.EnumOptions\x18\xd0\x86\x03 \x01(\t:C\n\x16\x65num_value_description\x12!.google.protobuf.EnumValueOptions\x18\xd0\x86\x03 \x01(\tB\x05H\x01\x90\x01\x00')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'steammessages_unified_base_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:
  google_dot_protobuf_dot_descriptor__pb2.MessageOptions.RegisterExtension(message_description)
  google_dot_protobuf_dot_descriptor__pb2.MessageOptions.RegisterExtension(force_emit_message)
  google_dot_protobuf_dot_descriptor__pb2.FieldOptions.RegisterExtension(description)
  google_dot_protobuf_dot_descriptor__pb2.ServiceOptions.RegisterExtension(service_description)
  google_dot_protobuf_dot_descriptor__pb2.ServiceOptions.RegisterExtension(service_execution_site)
  google_dot_protobuf_dot_descriptor__pb2.ServiceOptions.RegisterExtension(service_type)
  google_dot_protobuf_dot_descriptor__pb2.ServiceOptions.RegisterExtension(force_emit_service)
  google_dot_protobuf_dot_descriptor__pb2.MethodOptions.RegisterExtension(method_description)
  google_dot_protobuf_dot_descriptor__pb2.EnumOptions.RegisterExtension(enum_description)
  google_dot_protobuf_dot_descriptor__pb2.EnumValueOptions.RegisterExtension(enum_value_description)

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'H\001\220\001\000'
  _EPROTOEXECUTIONSITE._serialized_start=84
  _EPROTOEXECUTIONSITE._serialized_end=177
  _EPROTOSERVICETYPE._serialized_start=179
  _EPROTOSERVICETYPE._serialized_end=280
  _NORESPONSE._serialized_start=70
  _NORESPONSE._serialized_end=82
# @@protoc_insertion_point(module_scope)
