# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: webuimessages_steamengine.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import steam.protobufs.steammessages_base_pb2 as steammessages__base__pb2
import steam.protobufs.webuimessages_base_pb2 as webuimessages__base__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1fwebuimessages_steamengine.proto\x1a\x18steammessages_base.proto\x1a\x18webuimessages_base.proto\"V\n4CSteamEngine_UpdateTextFilterDictionary_Notification\x12\x10\n\x08language\x18\x01 \x02(\t\x12\x0c\n\x04type\x18\x02 \x02(\t\"N\n,CSteamEngine_GetTextFilterDictionary_Request\x12\x10\n\x08language\x18\x01 \x02(\t\x12\x0c\n\x04type\x18\x02 \x02(\t\"C\n-CSteamEngine_GetTextFilterDictionary_Response\x12\x12\n\ndictionary\x18\x01 \x01(\t\"W\n5CSteamEngine_TextFilterDictionaryChanged_Notification\x12\x10\n\x08language\x18\x01 \x02(\t\x12\x0c\n\x04type\x18\x02 \x02(\t\"3\n$CSteamEngine_GetGameIDForPID_Request\x12\x0b\n\x03pid\x18\x01 \x01(\r\"7\n%CSteamEngine_GetGameIDForPID_Response\x12\x0e\n\x06gameid\x18\x01 \x01(\x04\"^\n5CSteamEngine_SetOverlayEscapeKeyHandling_Notification\x12\x0e\n\x06gameid\x18\x01 \x02(\x04\x12\x15\n\rshould_handle\x18\x02 \x02(\x08\"b\n6CSteamEngine_SearchAppDataCacheByStoreKeywords_Request\x12\x13\n\x0bsearch_term\x18\x01 \x01(\t\x12\x13\n\x0bmax_results\x18\x02 \x01(\r\"I\n7CSteamEngine_SearchAppDataCacheByStoreKeywords_Response\x12\x0e\n\x06\x61ppids\x18\x01 \x03(\r2\xc7\x05\n\x0bSteamEngine\x12\x65\n\x1aUpdateTextFilterDictionary\x12\x35.CSteamEngine_UpdateTextFilterDictionary_Notification\x1a\x10.WebUINoResponse\x12x\n\x17GetTextFilterDictionary\x12-.CSteamEngine_GetTextFilterDictionary_Request\x1a..CSteamEngine_GetTextFilterDictionary_Response\x12m\n!NotifyTextFilterDictionaryChanged\x12\x36.CSteamEngine_TextFilterDictionaryChanged_Notification\x1a\x10.WebUINoResponse\x12`\n\x0fGetGameIDForPID\x12%.CSteamEngine_GetGameIDForPID_Request\x1a&.CSteamEngine_GetGameIDForPID_Response\x12g\n\x1bSetOverlayEscapeKeyHandling\x12\x36.CSteamEngine_SetOverlayEscapeKeyHandling_Notification\x1a\x10.WebUINoResponse\x12\x96\x01\n!SearchAppDataCacheByStoreKeywords\x12\x37.CSteamEngine_SearchAppDataCacheByStoreKeywords_Request\x1a\x38.CSteamEngine_SearchAppDataCacheByStoreKeywords_Response\x1a\x04\x80\x97\"\x02\x42\x05H\x01\x90\x01\x01')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'webuimessages_steamengine_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'H\001\220\001\001'
  _STEAMENGINE._options = None
  _STEAMENGINE._serialized_options = b'\200\227\"\002'
  _CSTEAMENGINE_UPDATETEXTFILTERDICTIONARY_NOTIFICATION._serialized_start=87
  _CSTEAMENGINE_UPDATETEXTFILTERDICTIONARY_NOTIFICATION._serialized_end=173
  _CSTEAMENGINE_GETTEXTFILTERDICTIONARY_REQUEST._serialized_start=175
  _CSTEAMENGINE_GETTEXTFILTERDICTIONARY_REQUEST._serialized_end=253
  _CSTEAMENGINE_GETTEXTFILTERDICTIONARY_RESPONSE._serialized_start=255
  _CSTEAMENGINE_GETTEXTFILTERDICTIONARY_RESPONSE._serialized_end=322
  _CSTEAMENGINE_TEXTFILTERDICTIONARYCHANGED_NOTIFICATION._serialized_start=324
  _CSTEAMENGINE_TEXTFILTERDICTIONARYCHANGED_NOTIFICATION._serialized_end=411
  _CSTEAMENGINE_GETGAMEIDFORPID_REQUEST._serialized_start=413
  _CSTEAMENGINE_GETGAMEIDFORPID_REQUEST._serialized_end=464
  _CSTEAMENGINE_GETGAMEIDFORPID_RESPONSE._serialized_start=466
  _CSTEAMENGINE_GETGAMEIDFORPID_RESPONSE._serialized_end=521
  _CSTEAMENGINE_SETOVERLAYESCAPEKEYHANDLING_NOTIFICATION._serialized_start=523
  _CSTEAMENGINE_SETOVERLAYESCAPEKEYHANDLING_NOTIFICATION._serialized_end=617
  _CSTEAMENGINE_SEARCHAPPDATACACHEBYSTOREKEYWORDS_REQUEST._serialized_start=619
  _CSTEAMENGINE_SEARCHAPPDATACACHEBYSTOREKEYWORDS_REQUEST._serialized_end=717
  _CSTEAMENGINE_SEARCHAPPDATACACHEBYSTOREKEYWORDS_RESPONSE._serialized_start=719
  _CSTEAMENGINE_SEARCHAPPDATACACHEBYSTOREKEYWORDS_RESPONSE._serialized_end=792
  _STEAMENGINE._serialized_start=795
  _STEAMENGINE._serialized_end=1506
_builder.BuildServices(DESCRIPTOR, 'webuimessages_steamengine_pb2', globals())
# @@protoc_insertion_point(module_scope)
