# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: webuimessages_transport.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import steam.protobufs.steammessages_base_pb2 as steammessages__base__pb2
import steam.protobufs.webuimessages_base_pb2 as webuimessages__base__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1dwebuimessages_transport.proto\x1a\x18steammessages_base.proto\x1a\x18webuimessages_base.proto\"7\n#CTransportAuth_Authenticate_Request\x12\x10\n\x08\x61uth_key\x18\x01 \x01(\t\"&\n$CTransportAuth_Authenticate_Response\"+\n)CTransportAuth_StartShutdown_Notification2\xc7\x01\n\rTransportAuth\x12[\n\x0c\x41uthenticate\x12$.CTransportAuth_Authenticate_Request\x1a%.CTransportAuth_Authenticate_Response\x12S\n\x13NotifyStartShutdown\x12*.CTransportAuth_StartShutdown_Notification\x1a\x10.WebUINoResponse\x1a\x04\x80\x97\"\x03\x42\x05H\x01\x90\x01\x01')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'webuimessages_transport_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'H\001\220\001\001'
  _TRANSPORTAUTH._options = None
  _TRANSPORTAUTH._serialized_options = b'\200\227\"\003'
  _CTRANSPORTAUTH_AUTHENTICATE_REQUEST._serialized_start=85
  _CTRANSPORTAUTH_AUTHENTICATE_REQUEST._serialized_end=140
  _CTRANSPORTAUTH_AUTHENTICATE_RESPONSE._serialized_start=142
  _CTRANSPORTAUTH_AUTHENTICATE_RESPONSE._serialized_end=180
  _CTRANSPORTAUTH_STARTSHUTDOWN_NOTIFICATION._serialized_start=182
  _CTRANSPORTAUTH_STARTSHUTDOWN_NOTIFICATION._serialized_end=225
  _TRANSPORTAUTH._serialized_start=228
  _TRANSPORTAUTH._serialized_end=427
_builder.BuildServices(DESCRIPTOR, 'webuimessages_transport_pb2', globals())
# @@protoc_insertion_point(module_scope)
