# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: steammessages_broadcast.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import steam.protobufs.steammessages_base_pb2 as steammessages__base__pb2
import steam.protobufs.steammessages_unified_base_pb2 as steammessages__unified__base__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1dsteammessages_broadcast.proto\x1a\x18steammessages_base.proto\x1a steammessages_unified_base.proto\"\xdc\x01\n(CBroadcast_BeginBroadcastSession_Request\x12\x12\n\npermission\x18\x01 \x01(\x05\x12\x0e\n\x06gameid\x18\x02 \x01(\x04\x12\x1a\n\x12\x63lient_instance_id\x18\x03 \x01(\x04\x12\r\n\x05title\x18\x04 \x01(\t\x12\x0e\n\x06\x63\x65llid\x18\x05 \x01(\r\x12\x12\n\nrtmp_token\x18\x06 \x01(\x04\x12\x18\n\x10thumbnail_upload\x18\x07 \x01(\x08\x12\r\n\x05sysid\x18\t \x01(\r\x12\x14\n\x0c\x61llow_webrtc\x18\n \x01(\x08\"\xcb\x01\n)CBroadcast_BeginBroadcastSession_Response\x12\x14\n\x0c\x62roadcast_id\x18\x01 \x01(\x06\x12 \n\x18thumbnail_upload_address\x18\x02 \x01(\t\x12\x1e\n\x16thumbnail_upload_token\x18\x03 \x01(\t\x12\"\n\x1athumbnail_interval_seconds\x18\x04 \x01(\r\x12\"\n\x1aheartbeat_interval_seconds\x18\x05 \x01(\r\">\n&CBroadcast_EndBroadcastSession_Request\x12\x14\n\x0c\x62roadcast_id\x18\x01 \x01(\x06\")\n\'CBroadcast_EndBroadcastSession_Response\"\xcb\x01\n\'CBroadcast_StartBroadcastUpload_Request\x12\x14\n\x0c\x62roadcast_id\x18\x01 \x01(\x06\x12\x0e\n\x06\x63\x65llid\x18\x02 \x01(\r\x12\x0f\n\x07\x61s_rtmp\x18\x03 \x01(\x08\x12\x15\n\rdelay_seconds\x18\x04 \x01(\r\x12\x15\n\nrtmp_token\x18\x05 \x01(\x04:\x01\x30\x12\x19\n\x11upload_ip_address\x18\x06 \x01(\r\x12\x11\n\tis_replay\x18\x07 \x01(\x08\x12\r\n\x05sysid\x18\x08 \x01(\r\"\xa2\x01\n(CBroadcast_StartBroadcastUpload_Response\x12\x14\n\x0cupload_token\x18\x01 \x01(\t\x12\x16\n\x0eupload_address\x18\x02 \x01(\t\x12\x1b\n\x13\x62roadcast_upload_id\x18\x03 \x01(\x06\x12\x15\n\renable_replay\x18\x06 \x01(\x08\x12\x14\n\x0chttp_address\x18\x07 \x01(\t\"g\n1CBroadcast_NotifyBroadcastUploadStop_Notification\x12\x1b\n\x13\x62roadcast_upload_id\x18\x01 \x01(\x06\x12\x15\n\rupload_result\x18\x02 \x01(\r\"\xe6\x01\n!CBroadcast_WatchBroadcast_Request\x12\x0f\n\x07steamid\x18\x01 \x01(\x06\x12\x1d\n\x15\x65xisting_broadcast_id\x18\x02 \x01(\x06\x12\x14\n\x0cviewer_token\x18\x03 \x01(\x06\x12\x13\n\x0b\x63lient_cell\x18\x05 \x01(\r\x12S\n\x0ewatch_location\x18\x06 \x01(\x0e\x32\x18.EBroadcastWatchLocation:!k_EBroadcastWatchLocation_Invalid\x12\x11\n\tis_webrtc\x18\x07 \x01(\x08\"\x9e\x08\n\"CBroadcast_WatchBroadcast_Response\x12[\n\x08response\x18\x01 \x01(\x0e\x32\x32.CBroadcast_WatchBroadcast_Response.EWatchResponse:\x15k_EWatchResponseReady\x12\x0f\n\x07mpd_url\x18\x02 \x01(\t\x12\x14\n\x0c\x62roadcast_id\x18\x03 \x01(\x06\x12\x0e\n\x06gameid\x18\x04 \x01(\x04\x12\r\n\x05title\x18\x05 \x01(\t\x12\x13\n\x0bnum_viewers\x18\x06 \x01(\r\x12\x12\n\npermission\x18\x07 \x01(\x05\x12\x0f\n\x07is_rtmp\x18\x08 \x01(\x08\x12\x15\n\rseconds_delay\x18\t \x01(\x05\x12\x14\n\x0cviewer_token\x18\n \x01(\x06\x12\x1b\n\x13hls_m3u8_master_url\x18\x0b \x01(\t\x12\x1a\n\x12heartbeat_interval\x18\x0c \x01(\x05\x12\x15\n\rthumbnail_url\x18\r \x01(\t\x12\x11\n\tis_webrtc\x18\x0e \x01(\x08\x12\x19\n\x11webrtc_session_id\x18\x0f \x01(\x06\x12\x18\n\x10webrtc_offer_sdp\x18\x10 \x01(\t\x12\x1a\n\x12webrtc_turn_server\x18\x11 \x01(\t\x12\x11\n\tis_replay\x18\x12 \x01(\x08\x12\x10\n\x08\x64uration\x18\x13 \x01(\x05\x12\x1f\n\x17\x63\x64n_auth_url_parameters\x18\x14 \x01(\t\"\xf3\x03\n\x0e\x45WatchResponse\x12\x19\n\x15k_EWatchResponseReady\x10\x01\x12 \n\x1ck_EWatchResponseNotAvailable\x10\x02\x12&\n\"k_EWatchResponseWaitingForApproval\x10\x03\x12#\n\x1fk_EWatchResponseWaitingForStart\x10\x04\x12\"\n\x1ek_EWatchResponseInvalidSession\x10\x05\x12%\n!k_EWatchResponseTooManyBroadcasts\x10\x06\x12\'\n#k_EWatchResponseWaitingForReconnect\x10\x07\x12&\n\"k_EWatchResponseSystemNotSupported\x10\x08\x12\"\n\x1ek_EWatchResponseUserRestricted\x10\t\x12#\n\x1fk_EWatchResponseClientOutOfDate\x10\n\x12%\n!k_EWatchResponsePoorUploadQuality\x10\x0b\x12\'\n#k_EWatchResponseMissingSubscription\x10\x0c\x12\"\n\x1ek_EWatchResponseTooManyViewers\x10\r\"\x81\x01\n*CBroadcast_HeartbeatBroadcast_Notification\x12\x0f\n\x07steamid\x18\x01 \x01(\x06\x12\x14\n\x0c\x62roadcast_id\x18\x02 \x01(\x06\x12\x14\n\x0cviewer_token\x18\x03 \x01(\x06\x12\x16\n\x0erepresentation\x18\x04 \x01(\r\"l\n-CBroadcast_StopWatchingBroadcast_Notification\x12\x0f\n\x07steamid\x18\x01 \x01(\x06\x12\x14\n\x0c\x62roadcast_id\x18\x02 \x01(\x06\x12\x14\n\x0cviewer_token\x18\x03 \x01(\x06\"N\n%CBroadcast_GetBroadcastStatus_Request\x12\x0f\n\x07steamid\x18\x01 \x01(\x06\x12\x14\n\x0c\x62roadcast_id\x18\x02 \x01(\x06\"\xd1\x02\n&CBroadcast_GetBroadcastStatus_Response\x12\x0e\n\x06gameid\x18\x01 \x01(\x04\x12\r\n\x05title\x18\x02 \x01(\t\x12\x13\n\x0bnum_viewers\x18\x03 \x01(\r\x12\x12\n\npermission\x18\x04 \x01(\x05\x12\x0f\n\x07is_rtmp\x18\x05 \x01(\x08\x12\x15\n\rseconds_delay\x18\x06 \x01(\x05\x12\x14\n\x0cis_publisher\x18\x07 \x01(\x08\x12\x15\n\rthumbnail_url\x18\x08 \x01(\t\x12\x17\n\x0fupdate_interval\x18\t \x01(\x05\x12\x14\n\x0cis_uploading\x18\n \x01(\x08\x12\x10\n\x08\x64uration\x18\x0b \x01(\r\x12\x11\n\tis_replay\x18\x0c \x01(\x08\x12\x18\n\x10is_capturing_vod\x18\r \x01(\x08\x12\x1c\n\x14is_store_whitelisted\x18\x0e \x01(\x08\"Q\n(CBroadcast_GetBroadcastThumbnail_Request\x12\x0f\n\x07steamid\x18\x01 \x01(\x06\x12\x14\n\x0c\x62roadcast_id\x18\x02 \x01(\x06\"\x82\x01\n)CBroadcast_GetBroadcastThumbnail_Response\x12\x15\n\rthumbnail_url\x18\x01 \x01(\t\x12\x17\n\x0fupdate_interval\x18\x02 \x01(\x05\x12\x13\n\x0bnum_viewers\x18\x03 \x01(\x05\x12\x10\n\x08\x64uration\x18\x04 \x01(\x05\"R\n$CBroadcast_InviteToBroadcast_Request\x12\x0f\n\x07steamid\x18\x01 \x01(\x06\x12\x19\n\x11\x61pproval_response\x18\x02 \x01(\x08\"8\n%CBroadcast_InviteToBroadcast_Response\x12\x0f\n\x07success\x18\x01 \x01(\x08\"|\n-CBroadcast_SendBroadcastStateToServer_Request\x12\x12\n\npermission\x18\x01 \x01(\x05\x12\x0e\n\x06gameid\x18\x02 \x01(\x04\x12\r\n\x05title\x18\x03 \x01(\t\x12\x18\n\x10game_data_config\x18\x04 \x01(\t\"0\n.CBroadcast_SendBroadcastStateToServer_Response\"O\n7CBroadcast_NotifyBroadcastSessionHeartbeat_Notification\x12\x14\n\x0c\x62roadcast_id\x18\x01 \x01(\x06\"x\n\'CBroadcast_GetBroadcastChatInfo_Request\x12\x0f\n\x07steamid\x18\x01 \x01(\x06\x12\x14\n\x0c\x62roadcast_id\x18\x02 \x01(\x06\x12\x11\n\tclient_ip\x18\x03 \x01(\r\x12\x13\n\x0b\x63lient_cell\x18\x04 \x01(\r\"o\n(CBroadcast_GetBroadcastChatInfo_Response\x12\x0f\n\x07\x63hat_id\x18\x01 \x01(\x06\x12\x19\n\x11view_url_template\x18\x03 \x01(\t\x12\x17\n\x0f\x66lair_group_ids\x18\x04 \x03(\r\"\x86\x01\n\"CBroadcast_PostChatMessage_Request\x12\x0f\n\x07\x63hat_id\x18\x01 \x01(\x06\x12\x0f\n\x07message\x18\x02 \x01(\t\x12\x13\n\x0binstance_id\x18\x03 \x01(\r\x12\x13\n\x08language\x18\x04 \x01(\r:\x01\x30\x12\x14\n\x0c\x63ountry_code\x18\x05 \x01(\t\"{\n#CBroadcast_PostChatMessage_Response\x12\x14\n\x0cpersona_name\x18\x01 \x01(\t\x12\x0f\n\x07in_game\x18\x02 \x01(\x08\x12\x0e\n\x06result\x18\x03 \x01(\x05\x12\x1d\n\x15\x63ooldown_time_seconds\x18\x04 \x01(\x05\"K\n)CBroadcast_UpdateChatMessageFlair_Request\x12\x0f\n\x07\x63hat_id\x18\x01 \x01(\x06\x12\r\n\x05\x66lair\x18\x02 \x01(\t\"\\\n*CBroadcast_UpdateChatMessageFlair_Response\x12\x0e\n\x06result\x18\x01 \x01(\x05\x12\x0f\n\x07\x63hat_id\x18\x02 \x01(\x06\x12\r\n\x05\x66lair\x18\x03 \x01(\t\"`\n(CBroadcast_MuteBroadcastChatUser_Request\x12\x0f\n\x07\x63hat_id\x18\x01 \x01(\x06\x12\x14\n\x0cuser_steamid\x18\x02 \x01(\x06\x12\r\n\x05muted\x18\x03 \x01(\x08\"+\n)CBroadcast_MuteBroadcastChatUser_Response\"N\n%CBroadcast_RemoveUserChatText_Request\x12\x0f\n\x07\x63hat_id\x18\x01 \x01(\x06\x12\x14\n\x0cuser_steamid\x18\x02 \x01(\x06\"(\n&CBroadcast_RemoveUserChatText_Response\"U\n,CBroadcast_GetBroadcastChatUserNames_Request\x12\x0f\n\x07\x63hat_id\x18\x01 \x01(\x06\x12\x14\n\x0cuser_steamid\x18\x02 \x03(\x06\"\xba\x01\n-CBroadcast_GetBroadcastChatUserNames_Response\x12Q\n\rpersona_names\x18\x01 \x03(\x0b\x32:.CBroadcast_GetBroadcastChatUserNames_Response.PersonaName\x1a\x36\n\x0bPersonaName\x12\x16\n\x08steam_id\x18\x01 \x01(\x06\x42\x04\xc0\xb6\x18\x01\x12\x0f\n\x07persona\x18\x02 \x01(\t\"\x99\x01\n!CBroadcast_StartBuildClip_Request\x12\x0f\n\x07steamid\x18\x01 \x01(\x06\x12\x1c\n\x14\x62roadcast_session_id\x18\x02 \x01(\x06\x12\x15\n\rfirst_segment\x18\x03 \x01(\x05\x12\x14\n\x0cnum_segments\x18\x04 \x01(\x05\x12\x18\n\x10\x63lip_description\x18\x05 \x01(\t\"?\n\"CBroadcast_StartBuildClip_Response\x12\x19\n\x11\x62roadcast_clip_id\x18\x01 \x01(\x06\"B\n%CBroadcast_GetBuildClipStatus_Request\x12\x19\n\x11\x62roadcast_clip_id\x18\x01 \x01(\x06\"(\n&CBroadcast_GetBuildClipStatus_Response\"\x7f\n!CBroadcast_SetClipDetails_Request\x12\x19\n\x11\x62roadcast_clip_id\x18\x01 \x01(\x04\x12\x12\n\nstart_time\x18\x02 \x01(\r\x12\x10\n\x08\x65nd_time\x18\x03 \x01(\r\x12\x19\n\x11video_description\x18\x04 \x01(\t\"$\n\"CBroadcast_SetClipDetails_Response\">\n!CBroadcast_GetClipDetails_Request\x12\x19\n\x11\x62roadcast_clip_id\x18\x01 \x01(\x04\"\x95\x02\n\"CBroadcast_GetClipDetails_Response\x12\x19\n\x11\x62roadcast_clip_id\x18\x01 \x01(\x04\x12\x10\n\x08video_id\x18\x02 \x01(\x04\x12\x12\n\nchannel_id\x18\x03 \x01(\x04\x12\x0e\n\x06\x61pp_id\x18\x04 \x01(\r\x12\x1d\n\x15\x61\x63\x63ountid_broadcaster\x18\x05 \x01(\r\x12\x1b\n\x13\x61\x63\x63ountid_clipmaker\x18\x06 \x01(\r\x12\x19\n\x11video_description\x18\x07 \x01(\t\x12\x12\n\nstart_time\x18\x08 \x01(\r\x12\x1b\n\x13length_milliseconds\x18\t \x01(\r\x12\x16\n\x0ethumbnail_path\x18\n \x01(\t\"\x85\x03\n\x1e\x43\x42roadcast_SetRTMPInfo_Request\x12\x1c\n\x14\x62roadcast_permission\x18\x01 \x01(\x05\x12\x14\n\x0cupdate_token\x18\x02 \x01(\x08\x12\x17\n\x0f\x62roadcast_delay\x18\x03 \x01(\x05\x12\x0e\n\x06\x61pp_id\x18\x04 \x01(\r\x12\x17\n\x0frequired_app_id\x18\x05 \x01(\r\x12^\n\x19\x62roadcast_chat_permission\x18\x06 \x01(\x0e\x32\x19.EBroadcastChatPermission: k_EBroadcastChatPermissionPublic\x12\x18\n\x10\x62roadcast_buffer\x18\x07 \x01(\x05\x12\x0f\n\x07steamid\x18\x08 \x01(\x06\x12\x17\n\x0f\x63hat_rate_limit\x18\t \x01(\r\x12\x15\n\renable_replay\x18\n \x01(\x08\x12\x1c\n\x14is_partner_chat_only\x18\x0b \x01(\x08\x12\x14\n\x0cwordban_list\x18\x0c \x01(\t\"!\n\x1f\x43\x42roadcast_SetRTMPInfo_Response\"=\n\x1e\x43\x42roadcast_GetRTMPInfo_Request\x12\n\n\x02ip\x18\x01 \x01(\r\x12\x0f\n\x07steamid\x18\x02 \x01(\x06\"\x97\x03\n\x1f\x43\x42roadcast_GetRTMPInfo_Response\x12\x1c\n\x14\x62roadcast_permission\x18\x01 \x01(\x05\x12\x11\n\trtmp_host\x18\x02 \x01(\t\x12\x12\n\nrtmp_token\x18\x03 \x01(\t\x12\x17\n\x0f\x62roadcast_delay\x18\x04 \x01(\x05\x12\x0e\n\x06\x61pp_id\x18\x05 \x01(\r\x12\x17\n\x0frequired_app_id\x18\x06 \x01(\r\x12^\n\x19\x62roadcast_chat_permission\x18\x07 \x01(\x0e\x32\x19.EBroadcastChatPermission: k_EBroadcastChatPermissionPublic\x12\x18\n\x10\x62roadcast_buffer\x18\x08 \x01(\x05\x12\x0f\n\x07steamid\x18\t \x01(\x06\x12\x17\n\x0f\x63hat_rate_limit\x18\n \x01(\r\x12\x15\n\renable_replay\x18\x0b \x01(\x08\x12\x1c\n\x14is_partner_chat_only\x18\x0c \x01(\x08\x12\x14\n\x0cwordban_list\x18\r \x01(\t\"a\n,CBroadcast_WebRTCHaveTURNServer_Notification\x12\x1c\n\x14\x62roadcast_session_id\x18\x01 \x01(\x06\x12\x13\n\x0bturn_server\x18\x02 \x01(\t\"\x9a\x01\n$CBroadcast_WebRTCStartResult_Request\x12\x19\n\x11webrtc_session_id\x18\x01 \x01(\x06\x12\x0f\n\x07started\x18\x02 \x01(\x08\x12\r\n\x05offer\x18\x03 \x01(\t\x12\x14\n\x0cresolution_x\x18\x04 \x01(\r\x12\x14\n\x0cresolution_y\x18\x05 \x01(\r\x12\x0b\n\x03\x66ps\x18\x06 \x01(\r\"\'\n%CBroadcast_WebRTCStartResult_Response\"=\n CBroadcast_WebRTCStopped_Request\x12\x19\n\x11webrtc_session_id\x18\x01 \x01(\x06\"#\n!CBroadcast_WebRTCStopped_Response\"l\n\"CBroadcast_WebRTCSetAnswer_Request\x12\x1b\n\x13\x62roadcaster_steamid\x18\x01 \x01(\x06\x12\x19\n\x11webrtc_session_id\x18\x02 \x01(\x06\x12\x0e\n\x06\x61nswer\x18\x03 \x01(\t\"%\n#CBroadcast_WebRTCSetAnswer_Response\";\n)CBroadcast_WebRTCLookupTURNServer_Request\x12\x0e\n\x06\x63\x65llid\x18\x01 \x01(\r\"A\n*CBroadcast_WebRTCLookupTURNServer_Response\x12\x13\n\x0bturn_server\x18\x01 \x01(\t\"Z\n\x1b\x43\x42roadcast_WebRTC_Candidate\x12\x0f\n\x07sdp_mid\x18\x01 \x01(\t\x12\x17\n\x0fsdp_mline_index\x18\x02 \x01(\x05\x12\x11\n\tcandidate\x18\x03 \x01(\t\"w\n)CBroadcast_WebRTCAddHostCandidate_Request\x12\x19\n\x11webrtc_session_id\x18\x01 \x01(\x06\x12/\n\tcandidate\x18\x02 \x01(\x0b\x32\x1c.CBroadcast_WebRTC_Candidate\",\n*CBroadcast_WebRTCAddHostCandidate_Response\"\x96\x01\n+CBroadcast_WebRTCAddViewerCandidate_Request\x12\x1b\n\x13\x62roadcaster_steamid\x18\x01 \x01(\x06\x12\x19\n\x11webrtc_session_id\x18\x02 \x01(\x06\x12/\n\tcandidate\x18\x03 \x01(\x0b\x32\x1c.CBroadcast_WebRTC_Candidate\".\n,CBroadcast_WebRTCAddViewerCandidate_Response\"\x82\x01\n*CBroadcast_WebRTCGetHostCandidates_Request\x12\x1b\n\x13\x62roadcaster_steamid\x18\x01 \x01(\x06\x12\x19\n\x11webrtc_session_id\x18\x02 \x01(\x06\x12\x1c\n\x14\x63\x61ndidate_generation\x18\x03 \x01(\r\"}\n+CBroadcast_WebRTCGetHostCandidates_Response\x12\x1c\n\x14\x63\x61ndidate_generation\x18\x01 \x01(\r\x12\x30\n\ncandidates\x18\x02 \x03(\x0b\x32\x1c.CBroadcast_WebRTC_Candidate\"\x93\x01\n*CBroadcast_GetBroadcastUploadStats_Request\x12\x16\n\trow_limit\x18\x01 \x01(\r:\x03\x31\x30\x30\x12\x15\n\nstart_time\x18\x02 \x01(\r:\x01\x30\x12\x11\n\tupload_id\x18\x03 \x01(\x04\x12\x0f\n\x07steamid\x18\x04 \x01(\x06\x12\x12\n\nsession_id\x18\x05 \x01(\x04\"\xd7\x04\n+CBroadcast_GetBroadcastUploadStats_Response\x12N\n\x0cupload_stats\x18\x01 \x03(\x0b\x32\x38.CBroadcast_GetBroadcastUploadStats_Response.UploadStats\x1a\xd7\x03\n\x0bUploadStats\x12\x15\n\rupload_result\x18\x01 \x01(\r\x12\x14\n\x0ctime_stopped\x18\x02 \x01(\r\x12\x18\n\x10seconds_uploaded\x18\x03 \x01(\r\x12\x13\n\x0bmax_viewers\x18\x04 \x01(\r\x12\x14\n\x0cresolution_x\x18\x05 \x01(\r\x12\x14\n\x0cresolution_y\x18\x06 \x01(\r\x12\x15\n\ravg_bandwidth\x18\x07 \x01(\r\x12\x13\n\x0btotal_bytes\x18\x08 \x01(\x04\x12\x0e\n\x06\x61pp_id\x18\t \x01(\r\x12\x1c\n\x14total_unique_viewers\x18\n \x01(\r\x12\x1d\n\x15total_seconds_watched\x18\x0b \x01(\x04\x12\x14\n\x0ctime_started\x18\x0c \x01(\r\x12\x11\n\tupload_id\x18\r \x01(\x04\x12\x15\n\rlocal_address\x18\x0e \x01(\t\x12\x16\n\x0eremote_address\x18\x0f \x01(\t\x12\x19\n\x11\x66rames_per_second\x18\x10 \x01(\r\x12\x1b\n\x13num_representations\x18\x11 \x01(\r\x12\x10\n\x08\x61pp_name\x18\x12 \x01(\t\x12\x11\n\tis_replay\x18\x13 \x01(\x08\x12\x12\n\nsession_id\x18\x14 \x01(\x04\"P\n*CBroadcast_GetBroadcastViewerStats_Request\x12\x11\n\tupload_id\x18\x01 \x01(\x04\x12\x0f\n\x07steamid\x18\x02 \x01(\x06\"\xbc\x02\n+CBroadcast_GetBroadcastViewerStats_Response\x12N\n\x0cviewer_stats\x18\x01 \x03(\x0b\x32\x38.CBroadcast_GetBroadcastViewerStats_Response.ViewerStats\x12P\n\rcountry_stats\x18\x02 \x03(\x0b\x32\x39.CBroadcast_GetBroadcastViewerStats_Response.CountryStats\x1a\x30\n\x0bViewerStats\x12\x0c\n\x04time\x18\x01 \x01(\r\x12\x13\n\x0bnum_viewers\x18\x02 \x01(\r\x1a\x39\n\x0c\x43ountryStats\x12\x14\n\x0c\x63ountry_code\x18\x01 \x01(\t\x12\x13\n\x0bnum_viewers\x18\x02 \x01(\r\"\xf8\x01\n,CBroadcast_BroadcastViewerState_Notification\x12\x0f\n\x07steamid\x18\x01 \x01(\x06\x12\x61\n\x05state\x18\x02 \x01(\x0e\x32:.CBroadcast_BroadcastViewerState_Notification.EViewerState:\x16k_EViewerNeedsApproval\"T\n\x0c\x45ViewerState\x12\x1a\n\x16k_EViewerNeedsApproval\x10\x01\x12\x15\n\x11k_EViewerWatching\x10\x02\x12\x11\n\rk_EViewerLeft\x10\x03\"F\n.CBroadcast_WaitingBroadcastViewer_Notification\x12\x14\n\x0c\x62roadcast_id\x18\x01 \x01(\x06\"\xdc\x01\n.CBroadcast_BroadcastUploadStarted_Notification\x12\x14\n\x0c\x62roadcast_id\x18\x01 \x01(\x06\x12\x14\n\x0cupload_token\x18\x02 \x01(\t\x12\x16\n\x0eupload_address\x18\x03 \x01(\t\x12\x14\n\x0chttp_address\x18\x04 \x01(\t\x12\x1b\n\x13\x62roadcast_upload_id\x18\x05 \x01(\x06\x12\"\n\x1aheartbeat_interval_seconds\x18\x06 \x01(\r\x12\x0f\n\x07is_rtmp\x18\x07 \x01(\x08\"\x95\x01\n+CBroadcast_StopBroadcastUpload_Notification\x12\x14\n\x0c\x62roadcast_id\x18\x01 \x01(\x06\x12\x1a\n\x12\x62roadcast_relay_id\x18\x02 \x01(\x06\x12\x15\n\rupload_result\x18\x03 \x01(\r\x12\x1d\n\x15too_many_poor_uploads\x18\x04 \x01(\x08\"=\n%CBroadcast_SessionClosed_Notification\x12\x14\n\x0c\x62roadcast_id\x18\x01 \x01(\x06\"L\n-CBroadcast_ViewerBroadcastInvite_Notification\x12\x1b\n\x13\x62roadcaster_steamid\x18\x01 \x01(\x06\"T\n\'CBroadcast_BroadcastStatus_Notification\x12\x14\n\x0c\x62roadcast_id\x18\x01 \x01(\x06\x12\x13\n\x0bnum_viewers\x18\x02 \x01(\x05\"\x8e\x01\n,CBroadcast_BroadcastChannelLive_Notification\x12\x1c\n\x14\x62roadcast_channel_id\x18\x01 \x01(\x06\x12\x1e\n\x16\x62roadcast_channel_name\x18\x02 \x01(\t\x12 \n\x18\x62roadcast_channel_avatar\x18\x03 \x01(\t\"\xc1\x01\n,CBroadcast_SendThumbnailToRelay_Notification\x12\x1e\n\x16thumbnail_upload_token\x18\x01 \x01(\t\x12&\n\x1ethumbnail_broadcast_session_id\x18\x02 \x01(\x06\x12\x16\n\x0ethumbnail_data\x18\x03 \x01(\x0c\x12\x17\n\x0fthumbnail_width\x18\x04 \x01(\r\x12\x18\n\x10thumbnail_height\x18\x05 \x01(\r\"L\n,CBroadcast_WebRTCNeedTURNServer_Notification\x12\x1c\n\x14\x62roadcast_session_id\x18\x01 \x01(\x06\"\x8c\x01\n#CBroadcast_WebRTCStart_Notification\x12\x1c\n\x14\x62roadcast_session_id\x18\x01 \x01(\x06\x12\x19\n\x11webrtc_session_id\x18\x02 \x01(\x06\x12\x16\n\x0eviewer_steamid\x18\x03 \x01(\x06\x12\x14\n\x0cviewer_token\x18\x04 \x01(\x06\"r\n\'CBroadcast_WebRTCSetAnswer_Notification\x12\x1c\n\x14\x62roadcast_session_id\x18\x01 \x01(\x06\x12\x19\n\x11webrtc_session_id\x18\x02 \x01(\x06\x12\x0e\n\x06\x61nswer\x18\x03 \x01(\t\"\x9c\x01\n0CBroadcast_WebRTCAddViewerCandidate_Notification\x12\x1c\n\x14\x62roadcast_session_id\x18\x01 \x01(\x06\x12\x19\n\x11webrtc_session_id\x18\x02 \x01(\x06\x12/\n\tcandidate\x18\x03 \x01(\x0b\x32\x1c.CBroadcast_WebRTC_Candidate*\xd5\x05\n\x17\x45\x42roadcastWatchLocation\x12%\n!k_EBroadcastWatchLocation_Invalid\x10\x00\x12)\n%k_EBroadcastWatchLocation_SteamTV_Tab\x10\x01\x12\x30\n,k_EBroadcastWatchLocation_SteamTV_WatchParty\x10\x02\x12&\n\"k_EBroadcastWatchLocation_Chat_Tab\x10\x03\x12-\n)k_EBroadcastWatchLocation_Chat_WatchParty\x10\x04\x12+\n\'k_EBroadcastWatchLocation_CommunityPage\x10\x05\x12*\n&k_EBroadcastWatchLocation_StoreAppPage\x10\x06\x12$\n k_EBroadcastWatchLocation_InGame\x10\x07\x12(\n$k_EBroadcastWatchLocation_BigPicture\x10\x08\x12\'\n#k_EBroadcastWatchLocation_SalesPage\x10\t\x12)\n%k_EBroadcastWatchLocation_CuratorPage\x10\n\x12+\n\'k_EBroadcastWatchLocation_DeveloperPage\x10\x0b\x12*\n&k_EBroadcastWatchLocation_Chat_Friends\x10\x0c\x12)\n%k_EBroadcastWatchLocation_SteamTV_Web\x10\r\x12/\n+k_EBroadcastWatchLocation_DesktopUI_Overlay\x10\x0e\x12-\n)k_EBroadcastWatchLocation_TrailerCarousel\x10\x0f*g\n\x18\x45\x42roadcastChatPermission\x12$\n k_EBroadcastChatPermissionPublic\x10\x00\x12%\n!k_EBroadcastChatPermissionOwnsApp\x10\x01\x32\xb7\x1b\n\tBroadcast\x12n\n\x15\x42\x65ginBroadcastSession\x12).CBroadcast_BeginBroadcastSession_Request\x1a*.CBroadcast_BeginBroadcastSession_Response\x12h\n\x13\x45ndBroadcastSession\x12\'.CBroadcast_EndBroadcastSession_Request\x1a(.CBroadcast_EndBroadcastSession_Response\x12k\n\x14StartBroadcastUpload\x12(.CBroadcast_StartBroadcastUpload_Request\x1a).CBroadcast_StartBroadcastUpload_Response\x12\\\n\x19NotifyBroadcastUploadStop\x12\x32.CBroadcast_NotifyBroadcastUploadStop_Notification\x1a\x0b.NoResponse\x12Y\n\x0eWatchBroadcast\x12\".CBroadcast_WatchBroadcast_Request\x1a#.CBroadcast_WatchBroadcast_Response\x12N\n\x12HeartbeatBroadcast\x12+.CBroadcast_HeartbeatBroadcast_Notification\x1a\x0b.NoResponse\x12T\n\x15StopWatchingBroadcast\x12..CBroadcast_StopWatchingBroadcast_Notification\x1a\x0b.NoResponse\x12\x65\n\x12GetBroadcastStatus\x12&.CBroadcast_GetBroadcastStatus_Request\x1a\'.CBroadcast_GetBroadcastStatus_Response\x12n\n\x15GetBroadcastThumbnail\x12).CBroadcast_GetBroadcastThumbnail_Request\x1a*.CBroadcast_GetBroadcastThumbnail_Response\x12\x62\n\x11InviteToBroadcast\x12%.CBroadcast_InviteToBroadcast_Request\x1a&.CBroadcast_InviteToBroadcast_Response\x12}\n\x1aSendBroadcastStateToServer\x12..CBroadcast_SendBroadcastStateToServer_Request\x1a/.CBroadcast_SendBroadcastStateToServer_Response\x12h\n\x1fNotifyBroadcastSessionHeartbeat\x12\x38.CBroadcast_NotifyBroadcastSessionHeartbeat_Notification\x1a\x0b.NoResponse\x12k\n\x14GetBroadcastChatInfo\x12(.CBroadcast_GetBroadcastChatInfo_Request\x1a).CBroadcast_GetBroadcastChatInfo_Response\x12\\\n\x0fPostChatMessage\x12#.CBroadcast_PostChatMessage_Request\x1a$.CBroadcast_PostChatMessage_Response\x12q\n\x16UpdateChatMessageFlair\x12*.CBroadcast_UpdateChatMessageFlair_Request\x1a+.CBroadcast_UpdateChatMessageFlair_Response\x12n\n\x15MuteBroadcastChatUser\x12).CBroadcast_MuteBroadcastChatUser_Request\x1a*.CBroadcast_MuteBroadcastChatUser_Response\x12\x65\n\x12RemoveUserChatText\x12&.CBroadcast_RemoveUserChatText_Request\x1a\'.CBroadcast_RemoveUserChatText_Response\x12z\n\x19GetBroadcastChatUserNames\x12-.CBroadcast_GetBroadcastChatUserNames_Request\x1a..CBroadcast_GetBroadcastChatUserNames_Response\x12Y\n\x0eStartBuildClip\x12\".CBroadcast_StartBuildClip_Request\x1a#.CBroadcast_StartBuildClip_Response\x12\x65\n\x12GetBuildClipStatus\x12&.CBroadcast_GetBuildClipStatus_Request\x1a\'.CBroadcast_GetBuildClipStatus_Response\x12Y\n\x0eSetClipDetails\x12\".CBroadcast_SetClipDetails_Request\x1a#.CBroadcast_SetClipDetails_Response\x12Y\n\x0eGetClipDetails\x12\".CBroadcast_GetClipDetails_Request\x1a#.CBroadcast_GetClipDetails_Response\x12P\n\x0bSetRTMPInfo\x12\x1f.CBroadcast_SetRTMPInfo_Request\x1a .CBroadcast_SetRTMPInfo_Response\x12P\n\x0bGetRTMPInfo\x12\x1f.CBroadcast_GetRTMPInfo_Request\x1a .CBroadcast_GetRTMPInfo_Response\x12X\n\x1aNotifyWebRTCHaveTURNServer\x12-.CBroadcast_WebRTCHaveTURNServer_Notification\x1a\x0b.NoResponse\x12\x62\n\x11WebRTCStartResult\x12%.CBroadcast_WebRTCStartResult_Request\x1a&.CBroadcast_WebRTCStartResult_Response\x12V\n\rWebRTCStopped\x12!.CBroadcast_WebRTCStopped_Request\x1a\".CBroadcast_WebRTCStopped_Response\x12\\\n\x0fWebRTCSetAnswer\x12#.CBroadcast_WebRTCSetAnswer_Request\x1a$.CBroadcast_WebRTCSetAnswer_Response\x12q\n\x16WebRTCLookupTURNServer\x12*.CBroadcast_WebRTCLookupTURNServer_Request\x1a+.CBroadcast_WebRTCLookupTURNServer_Response\x12q\n\x16WebRTCAddHostCandidate\x12*.CBroadcast_WebRTCAddHostCandidate_Request\x1a+.CBroadcast_WebRTCAddHostCandidate_Response\x12w\n\x18WebRTCAddViewerCandidate\x12,.CBroadcast_WebRTCAddViewerCandidate_Request\x1a-.CBroadcast_WebRTCAddViewerCandidate_Response\x12t\n\x17WebRTCGetHostCandidates\x12+.CBroadcast_WebRTCGetHostCandidates_Request\x1a,.CBroadcast_WebRTCGetHostCandidates_Response\x12t\n\x17GetBroadcastUploadStats\x12+.CBroadcast_GetBroadcastUploadStats_Request\x1a,.CBroadcast_GetBroadcastUploadStats_Response\x12t\n\x17GetBroadcastViewerStats\x12+.CBroadcast_GetBroadcastViewerStats_Request\x1a,.CBroadcast_GetBroadcastViewerStats_Response2\xff\x08\n\x0f\x42roadcastClient\x12X\n\x1aNotifyBroadcastViewerState\x12-.CBroadcast_BroadcastViewerState_Notification\x1a\x0b.NoResponse\x12\\\n\x1cNotifyWaitingBroadcastViewer\x12/.CBroadcast_WaitingBroadcastViewer_Notification\x1a\x0b.NoResponse\x12\\\n\x1cNotifyBroadcastUploadStarted\x12/.CBroadcast_BroadcastUploadStarted_Notification\x1a\x0b.NoResponse\x12V\n\x19NotifyStopBroadcastUpload\x12,.CBroadcast_StopBroadcastUpload_Notification\x1a\x0b.NoResponse\x12J\n\x13NotifySessionClosed\x12&.CBroadcast_SessionClosed_Notification\x1a\x0b.NoResponse\x12Z\n\x1bNotifyViewerBroadcastInvite\x12..CBroadcast_ViewerBroadcastInvite_Notification\x1a\x0b.NoResponse\x12N\n\x15NotifyBroadcastStatus\x12(.CBroadcast_BroadcastStatus_Notification\x1a\x0b.NoResponse\x12X\n\x1aNotifyBroadcastChannelLive\x12-.CBroadcast_BroadcastChannelLive_Notification\x1a\x0b.NoResponse\x12R\n\x14SendThumbnailToRelay\x12-.CBroadcast_SendThumbnailToRelay_Notification\x1a\x0b.NoResponse\x12X\n\x1aNotifyWebRTCNeedTURNServer\x12-.CBroadcast_WebRTCNeedTURNServer_Notification\x1a\x0b.NoResponse\x12\x46\n\x11NotifyWebRTCStart\x12$.CBroadcast_WebRTCStart_Notification\x1a\x0b.NoResponse\x12N\n\x15NotifyWebRTCSetAnswer\x12(.CBroadcast_WebRTCSetAnswer_Notification\x1a\x0b.NoResponse\x12`\n\x1eNotifyWebRTCAddViewerCandidate\x12\x31.CBroadcast_WebRTCAddViewerCandidate_Notification\x1a\x0b.NoResponse\x1a\x04\xc0\xb5\x18\x02\x42\x03\x90\x01\x01')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'steammessages_broadcast_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\220\001\001'
  _CBROADCAST_GETBROADCASTCHATUSERNAMES_RESPONSE_PERSONANAME.fields_by_name['steam_id']._options = None
  _CBROADCAST_GETBROADCASTCHATUSERNAMES_RESPONSE_PERSONANAME.fields_by_name['steam_id']._serialized_options = b'\300\266\030\001'
  _BROADCASTCLIENT._options = None
  _BROADCASTCLIENT._serialized_options = b'\300\265\030\002'
  _EBROADCASTWATCHLOCATION._serialized_start=10933
  _EBROADCASTWATCHLOCATION._serialized_end=11658
  _EBROADCASTCHATPERMISSION._serialized_start=11660
  _EBROADCASTCHATPERMISSION._serialized_end=11763
  _CBROADCAST_BEGINBROADCASTSESSION_REQUEST._serialized_start=94
  _CBROADCAST_BEGINBROADCASTSESSION_REQUEST._serialized_end=314
  _CBROADCAST_BEGINBROADCASTSESSION_RESPONSE._serialized_start=317
  _CBROADCAST_BEGINBROADCASTSESSION_RESPONSE._serialized_end=520
  _CBROADCAST_ENDBROADCASTSESSION_REQUEST._serialized_start=522
  _CBROADCAST_ENDBROADCASTSESSION_REQUEST._serialized_end=584
  _CBROADCAST_ENDBROADCASTSESSION_RESPONSE._serialized_start=586
  _CBROADCAST_ENDBROADCASTSESSION_RESPONSE._serialized_end=627
  _CBROADCAST_STARTBROADCASTUPLOAD_REQUEST._serialized_start=630
  _CBROADCAST_STARTBROADCASTUPLOAD_REQUEST._serialized_end=833
  _CBROADCAST_STARTBROADCASTUPLOAD_RESPONSE._serialized_start=836
  _CBROADCAST_STARTBROADCASTUPLOAD_RESPONSE._serialized_end=998
  _CBROADCAST_NOTIFYBROADCASTUPLOADSTOP_NOTIFICATION._serialized_start=1000
  _CBROADCAST_NOTIFYBROADCASTUPLOADSTOP_NOTIFICATION._serialized_end=1103
  _CBROADCAST_WATCHBROADCAST_REQUEST._serialized_start=1106
  _CBROADCAST_WATCHBROADCAST_REQUEST._serialized_end=1336
  _CBROADCAST_WATCHBROADCAST_RESPONSE._serialized_start=1339
  _CBROADCAST_WATCHBROADCAST_RESPONSE._serialized_end=2393
  _CBROADCAST_WATCHBROADCAST_RESPONSE_EWATCHRESPONSE._serialized_start=1894
  _CBROADCAST_WATCHBROADCAST_RESPONSE_EWATCHRESPONSE._serialized_end=2393
  _CBROADCAST_HEARTBEATBROADCAST_NOTIFICATION._serialized_start=2396
  _CBROADCAST_HEARTBEATBROADCAST_NOTIFICATION._serialized_end=2525
  _CBROADCAST_STOPWATCHINGBROADCAST_NOTIFICATION._serialized_start=2527
  _CBROADCAST_STOPWATCHINGBROADCAST_NOTIFICATION._serialized_end=2635
  _CBROADCAST_GETBROADCASTSTATUS_REQUEST._serialized_start=2637
  _CBROADCAST_GETBROADCASTSTATUS_REQUEST._serialized_end=2715
  _CBROADCAST_GETBROADCASTSTATUS_RESPONSE._serialized_start=2718
  _CBROADCAST_GETBROADCASTSTATUS_RESPONSE._serialized_end=3055
  _CBROADCAST_GETBROADCASTTHUMBNAIL_REQUEST._serialized_start=3057
  _CBROADCAST_GETBROADCASTTHUMBNAIL_REQUEST._serialized_end=3138
  _CBROADCAST_GETBROADCASTTHUMBNAIL_RESPONSE._serialized_start=3141
  _CBROADCAST_GETBROADCASTTHUMBNAIL_RESPONSE._serialized_end=3271
  _CBROADCAST_INVITETOBROADCAST_REQUEST._serialized_start=3273
  _CBROADCAST_INVITETOBROADCAST_REQUEST._serialized_end=3355
  _CBROADCAST_INVITETOBROADCAST_RESPONSE._serialized_start=3357
  _CBROADCAST_INVITETOBROADCAST_RESPONSE._serialized_end=3413
  _CBROADCAST_SENDBROADCASTSTATETOSERVER_REQUEST._serialized_start=3415
  _CBROADCAST_SENDBROADCASTSTATETOSERVER_REQUEST._serialized_end=3539
  _CBROADCAST_SENDBROADCASTSTATETOSERVER_RESPONSE._serialized_start=3541
  _CBROADCAST_SENDBROADCASTSTATETOSERVER_RESPONSE._serialized_end=3589
  _CBROADCAST_NOTIFYBROADCASTSESSIONHEARTBEAT_NOTIFICATION._serialized_start=3591
  _CBROADCAST_NOTIFYBROADCASTSESSIONHEARTBEAT_NOTIFICATION._serialized_end=3670
  _CBROADCAST_GETBROADCASTCHATINFO_REQUEST._serialized_start=3672
  _CBROADCAST_GETBROADCASTCHATINFO_REQUEST._serialized_end=3792
  _CBROADCAST_GETBROADCASTCHATINFO_RESPONSE._serialized_start=3794
  _CBROADCAST_GETBROADCASTCHATINFO_RESPONSE._serialized_end=3905
  _CBROADCAST_POSTCHATMESSAGE_REQUEST._serialized_start=3908
  _CBROADCAST_POSTCHATMESSAGE_REQUEST._serialized_end=4042
  _CBROADCAST_POSTCHATMESSAGE_RESPONSE._serialized_start=4044
  _CBROADCAST_POSTCHATMESSAGE_RESPONSE._serialized_end=4167
  _CBROADCAST_UPDATECHATMESSAGEFLAIR_REQUEST._serialized_start=4169
  _CBROADCAST_UPDATECHATMESSAGEFLAIR_REQUEST._serialized_end=4244
  _CBROADCAST_UPDATECHATMESSAGEFLAIR_RESPONSE._serialized_start=4246
  _CBROADCAST_UPDATECHATMESSAGEFLAIR_RESPONSE._serialized_end=4338
  _CBROADCAST_MUTEBROADCASTCHATUSER_REQUEST._serialized_start=4340
  _CBROADCAST_MUTEBROADCASTCHATUSER_REQUEST._serialized_end=4436
  _CBROADCAST_MUTEBROADCASTCHATUSER_RESPONSE._serialized_start=4438
  _CBROADCAST_MUTEBROADCASTCHATUSER_RESPONSE._serialized_end=4481
  _CBROADCAST_REMOVEUSERCHATTEXT_REQUEST._serialized_start=4483
  _CBROADCAST_REMOVEUSERCHATTEXT_REQUEST._serialized_end=4561
  _CBROADCAST_REMOVEUSERCHATTEXT_RESPONSE._serialized_start=4563
  _CBROADCAST_REMOVEUSERCHATTEXT_RESPONSE._serialized_end=4603
  _CBROADCAST_GETBROADCASTCHATUSERNAMES_REQUEST._serialized_start=4605
  _CBROADCAST_GETBROADCASTCHATUSERNAMES_REQUEST._serialized_end=4690
  _CBROADCAST_GETBROADCASTCHATUSERNAMES_RESPONSE._serialized_start=4693
  _CBROADCAST_GETBROADCASTCHATUSERNAMES_RESPONSE._serialized_end=4879
  _CBROADCAST_GETBROADCASTCHATUSERNAMES_RESPONSE_PERSONANAME._serialized_start=4825
  _CBROADCAST_GETBROADCASTCHATUSERNAMES_RESPONSE_PERSONANAME._serialized_end=4879
  _CBROADCAST_STARTBUILDCLIP_REQUEST._serialized_start=4882
  _CBROADCAST_STARTBUILDCLIP_REQUEST._serialized_end=5035
  _CBROADCAST_STARTBUILDCLIP_RESPONSE._serialized_start=5037
  _CBROADCAST_STARTBUILDCLIP_RESPONSE._serialized_end=5100
  _CBROADCAST_GETBUILDCLIPSTATUS_REQUEST._serialized_start=5102
  _CBROADCAST_GETBUILDCLIPSTATUS_REQUEST._serialized_end=5168
  _CBROADCAST_GETBUILDCLIPSTATUS_RESPONSE._serialized_start=5170
  _CBROADCAST_GETBUILDCLIPSTATUS_RESPONSE._serialized_end=5210
  _CBROADCAST_SETCLIPDETAILS_REQUEST._serialized_start=5212
  _CBROADCAST_SETCLIPDETAILS_REQUEST._serialized_end=5339
  _CBROADCAST_SETCLIPDETAILS_RESPONSE._serialized_start=5341
  _CBROADCAST_SETCLIPDETAILS_RESPONSE._serialized_end=5377
  _CBROADCAST_GETCLIPDETAILS_REQUEST._serialized_start=5379
  _CBROADCAST_GETCLIPDETAILS_REQUEST._serialized_end=5441
  _CBROADCAST_GETCLIPDETAILS_RESPONSE._serialized_start=5444
  _CBROADCAST_GETCLIPDETAILS_RESPONSE._serialized_end=5721
  _CBROADCAST_SETRTMPINFO_REQUEST._serialized_start=5724
  _CBROADCAST_SETRTMPINFO_REQUEST._serialized_end=6113
  _CBROADCAST_SETRTMPINFO_RESPONSE._serialized_start=6115
  _CBROADCAST_SETRTMPINFO_RESPONSE._serialized_end=6148
  _CBROADCAST_GETRTMPINFO_REQUEST._serialized_start=6150
  _CBROADCAST_GETRTMPINFO_REQUEST._serialized_end=6211
  _CBROADCAST_GETRTMPINFO_RESPONSE._serialized_start=6214
  _CBROADCAST_GETRTMPINFO_RESPONSE._serialized_end=6621
  _CBROADCAST_WEBRTCHAVETURNSERVER_NOTIFICATION._serialized_start=6623
  _CBROADCAST_WEBRTCHAVETURNSERVER_NOTIFICATION._serialized_end=6720
  _CBROADCAST_WEBRTCSTARTRESULT_REQUEST._serialized_start=6723
  _CBROADCAST_WEBRTCSTARTRESULT_REQUEST._serialized_end=6877
  _CBROADCAST_WEBRTCSTARTRESULT_RESPONSE._serialized_start=6879
  _CBROADCAST_WEBRTCSTARTRESULT_RESPONSE._serialized_end=6918
  _CBROADCAST_WEBRTCSTOPPED_REQUEST._serialized_start=6920
  _CBROADCAST_WEBRTCSTOPPED_REQUEST._serialized_end=6981
  _CBROADCAST_WEBRTCSTOPPED_RESPONSE._serialized_start=6983
  _CBROADCAST_WEBRTCSTOPPED_RESPONSE._serialized_end=7018
  _CBROADCAST_WEBRTCSETANSWER_REQUEST._serialized_start=7020
  _CBROADCAST_WEBRTCSETANSWER_REQUEST._serialized_end=7128
  _CBROADCAST_WEBRTCSETANSWER_RESPONSE._serialized_start=7130
  _CBROADCAST_WEBRTCSETANSWER_RESPONSE._serialized_end=7167
  _CBROADCAST_WEBRTCLOOKUPTURNSERVER_REQUEST._serialized_start=7169
  _CBROADCAST_WEBRTCLOOKUPTURNSERVER_REQUEST._serialized_end=7228
  _CBROADCAST_WEBRTCLOOKUPTURNSERVER_RESPONSE._serialized_start=7230
  _CBROADCAST_WEBRTCLOOKUPTURNSERVER_RESPONSE._serialized_end=7295
  _CBROADCAST_WEBRTC_CANDIDATE._serialized_start=7297
  _CBROADCAST_WEBRTC_CANDIDATE._serialized_end=7387
  _CBROADCAST_WEBRTCADDHOSTCANDIDATE_REQUEST._serialized_start=7389
  _CBROADCAST_WEBRTCADDHOSTCANDIDATE_REQUEST._serialized_end=7508
  _CBROADCAST_WEBRTCADDHOSTCANDIDATE_RESPONSE._serialized_start=7510
  _CBROADCAST_WEBRTCADDHOSTCANDIDATE_RESPONSE._serialized_end=7554
  _CBROADCAST_WEBRTCADDVIEWERCANDIDATE_REQUEST._serialized_start=7557
  _CBROADCAST_WEBRTCADDVIEWERCANDIDATE_REQUEST._serialized_end=7707
  _CBROADCAST_WEBRTCADDVIEWERCANDIDATE_RESPONSE._serialized_start=7709
  _CBROADCAST_WEBRTCADDVIEWERCANDIDATE_RESPONSE._serialized_end=7755
  _CBROADCAST_WEBRTCGETHOSTCANDIDATES_REQUEST._serialized_start=7758
  _CBROADCAST_WEBRTCGETHOSTCANDIDATES_REQUEST._serialized_end=7888
  _CBROADCAST_WEBRTCGETHOSTCANDIDATES_RESPONSE._serialized_start=7890
  _CBROADCAST_WEBRTCGETHOSTCANDIDATES_RESPONSE._serialized_end=8015
  _CBROADCAST_GETBROADCASTUPLOADSTATS_REQUEST._serialized_start=8018
  _CBROADCAST_GETBROADCASTUPLOADSTATS_REQUEST._serialized_end=8165
  _CBROADCAST_GETBROADCASTUPLOADSTATS_RESPONSE._serialized_start=8168
  _CBROADCAST_GETBROADCASTUPLOADSTATS_RESPONSE._serialized_end=8767
  _CBROADCAST_GETBROADCASTUPLOADSTATS_RESPONSE_UPLOADSTATS._serialized_start=8296
  _CBROADCAST_GETBROADCASTUPLOADSTATS_RESPONSE_UPLOADSTATS._serialized_end=8767
  _CBROADCAST_GETBROADCASTVIEWERSTATS_REQUEST._serialized_start=8769
  _CBROADCAST_GETBROADCASTVIEWERSTATS_REQUEST._serialized_end=8849
  _CBROADCAST_GETBROADCASTVIEWERSTATS_RESPONSE._serialized_start=8852
  _CBROADCAST_GETBROADCASTVIEWERSTATS_RESPONSE._serialized_end=9168
  _CBROADCAST_GETBROADCASTVIEWERSTATS_RESPONSE_VIEWERSTATS._serialized_start=9061
  _CBROADCAST_GETBROADCASTVIEWERSTATS_RESPONSE_VIEWERSTATS._serialized_end=9109
  _CBROADCAST_GETBROADCASTVIEWERSTATS_RESPONSE_COUNTRYSTATS._serialized_start=9111
  _CBROADCAST_GETBROADCASTVIEWERSTATS_RESPONSE_COUNTRYSTATS._serialized_end=9168
  _CBROADCAST_BROADCASTVIEWERSTATE_NOTIFICATION._serialized_start=9171
  _CBROADCAST_BROADCASTVIEWERSTATE_NOTIFICATION._serialized_end=9419
  _CBROADCAST_BROADCASTVIEWERSTATE_NOTIFICATION_EVIEWERSTATE._serialized_start=9335
  _CBROADCAST_BROADCASTVIEWERSTATE_NOTIFICATION_EVIEWERSTATE._serialized_end=9419
  _CBROADCAST_WAITINGBROADCASTVIEWER_NOTIFICATION._serialized_start=9421
  _CBROADCAST_WAITINGBROADCASTVIEWER_NOTIFICATION._serialized_end=9491
  _CBROADCAST_BROADCASTUPLOADSTARTED_NOTIFICATION._serialized_start=9494
  _CBROADCAST_BROADCASTUPLOADSTARTED_NOTIFICATION._serialized_end=9714
  _CBROADCAST_STOPBROADCASTUPLOAD_NOTIFICATION._serialized_start=9717
  _CBROADCAST_STOPBROADCASTUPLOAD_NOTIFICATION._serialized_end=9866
  _CBROADCAST_SESSIONCLOSED_NOTIFICATION._serialized_start=9868
  _CBROADCAST_SESSIONCLOSED_NOTIFICATION._serialized_end=9929
  _CBROADCAST_VIEWERBROADCASTINVITE_NOTIFICATION._serialized_start=9931
  _CBROADCAST_VIEWERBROADCASTINVITE_NOTIFICATION._serialized_end=10007
  _CBROADCAST_BROADCASTSTATUS_NOTIFICATION._serialized_start=10009
  _CBROADCAST_BROADCASTSTATUS_NOTIFICATION._serialized_end=10093
  _CBROADCAST_BROADCASTCHANNELLIVE_NOTIFICATION._serialized_start=10096
  _CBROADCAST_BROADCASTCHANNELLIVE_NOTIFICATION._serialized_end=10238
  _CBROADCAST_SENDTHUMBNAILTORELAY_NOTIFICATION._serialized_start=10241
  _CBROADCAST_SENDTHUMBNAILTORELAY_NOTIFICATION._serialized_end=10434
  _CBROADCAST_WEBRTCNEEDTURNSERVER_NOTIFICATION._serialized_start=10436
  _CBROADCAST_WEBRTCNEEDTURNSERVER_NOTIFICATION._serialized_end=10512
  _CBROADCAST_WEBRTCSTART_NOTIFICATION._serialized_start=10515
  _CBROADCAST_WEBRTCSTART_NOTIFICATION._serialized_end=10655
  _CBROADCAST_WEBRTCSETANSWER_NOTIFICATION._serialized_start=10657
  _CBROADCAST_WEBRTCSETANSWER_NOTIFICATION._serialized_end=10771
  _CBROADCAST_WEBRTCADDVIEWERCANDIDATE_NOTIFICATION._serialized_start=10774
  _CBROADCAST_WEBRTCADDVIEWERCANDIDATE_NOTIFICATION._serialized_end=10930
  _BROADCAST._serialized_start=11766
  _BROADCAST._serialized_end=15277
  _BROADCASTCLIENT._serialized_start=15280
  _BROADCASTCLIENT._serialized_end=16431
_builder.BuildServices(DESCRIPTOR, 'steammessages_broadcast_pb2', globals())
# @@protoc_insertion_point(module_scope)
