# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: steammessages_remoteplay.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1esteammessages_remoteplay.proto\"H\n\x15\x43\x44iscoveryPingRequest\x12\x10\n\x08sequence\x18\x01 \x01(\r\x12\x1d\n\x15packet_size_requested\x18\x02 \x01(\r\"H\n\x16\x43\x44iscoveryPingResponse\x12\x10\n\x08sequence\x18\x01 \x01(\r\x12\x1c\n\x14packet_size_received\x18\x02 \x01(\r\"5\n\x1d\x43StreamingClientHandshakeInfo\x12\x14\n\x0cnetwork_test\x18\x02 \x01(\x05\"C\n\x13\x43\x43lientHandshakeMsg\x12,\n\x04info\x18\x01 \x02(\x0b\x32\x1e.CStreamingClientHandshakeInfo\",\n\x1d\x43StreamingServerHandshakeInfo\x12\x0b\n\x03mtu\x18\x01 \x01(\x05\"C\n\x13\x43ServerHandshakeMsg\x12,\n\x04info\x18\x01 \x02(\x0b\x32\x1e.CStreamingServerHandshakeInfo\"s\n\x19\x43\x41uthenticationRequestMsg\x12\r\n\x05token\x18\x01 \x01(\x0c\x12\x36\n\x07version\x18\x02 \x01(\x0e\x32\x0f.EStreamVersion:\x14k_EStreamVersionNone\x12\x0f\n\x07steamid\x18\x03 \x01(\x04\"\xd4\x01\n\x1a\x43\x41uthenticationResponseMsg\x12K\n\x06result\x18\x01 \x01(\x0e\x32\x30.CAuthenticationResponseMsg.AuthenticationResult:\tSUCCEEDED\x12\x36\n\x07version\x18\x02 \x01(\x0e\x32\x0f.EStreamVersion:\x14k_EStreamVersionNone\"1\n\x14\x41uthenticationResult\x12\r\n\tSUCCEEDED\x10\x00\x12\n\n\x06\x46\x41ILED\x10\x01\"\x0f\n\rCKeepAliveMsg\"\x83\x01\n\x14\x43StartNetworkTestMsg\x12\x0e\n\x06\x66rames\x18\x01 \x01(\r\x12\x11\n\tframerate\x18\x02 \x01(\r\x12\x14\n\x0c\x62itrate_kbps\x18\x03 \x01(\r\x12\x1a\n\x12\x62urst_bitrate_kbps\x18\x04 \x01(\r\x12\x16\n\x0e\x62\x61ndwidth_test\x18\x05 \x01(\x08\"\x89\x01\n\x10\x43StreamVideoMode\x12\r\n\x05width\x18\x01 \x02(\r\x12\x0e\n\x06height\x18\x02 \x02(\r\x12\x14\n\x0crefresh_rate\x18\x03 \x01(\r\x12\x1e\n\x16refresh_rate_numerator\x18\x04 \x01(\r\x12 \n\x18refresh_rate_denominator\x18\x05 \x01(\r\"\xa2\x01\n\x11\x43StreamVideoLimit\x12:\n\x05\x63odec\x18\x01 \x01(\x0e\x32\x12.EStreamVideoCodec:\x17k_EStreamVideoCodecNone\x12\x1f\n\x04mode\x18\x02 \x01(\x0b\x32\x11.CStreamVideoMode\x12\x14\n\x0c\x62itrate_kbps\x18\x03 \x01(\x05\x12\x1a\n\x12\x62urst_bitrate_kbps\x18\x04 \x01(\x05\"\xbc\x04\n\x14\x43StreamingClientCaps\x12\x13\n\x0bsystem_info\x18\x01 \x01(\t\x12\x1a\n\x12system_can_suspend\x18\x02 \x01(\x08\x12#\n\x1bmaximum_decode_bitrate_kbps\x18\x03 \x01(\x05\x12\"\n\x1amaximum_burst_bitrate_kbps\x18\x04 \x01(\x05\x12$\n\x1csupports_video_hevc_OBSOLETE\x18\x05 \x01(\x08\x12\x1b\n\x13\x64isable_steam_store\x18\x06 \x01(\x08\x12\x1d\n\x15\x64isable_client_cursor\x18\x07 \x01(\x08\x12\'\n\x1f\x64isable_intel_hardware_encoding\x18\x08 \x01(\x08\x12%\n\x1d\x64isable_amd_hardware_encoding\x18\t \x01(\x08\x12(\n disable_nvidia_hardware_encoding\x18\n \x01(\x08\x12\x13\n\x0b\x66orm_factor\x18\x0b \x01(\x05\x12\x1e\n\x16has_on_screen_keyboard\x18\x0c \x01(\x08\x12\x31\n\x15supported_colorspaces\x18\r \x03(\x0e\x32\x12.EStreamColorspace\x12\x32\n\x16supported_audio_codecs\x18\x0e \x03(\x0e\x32\x12.EStreamAudioCodec\x12\x32\n\x16supported_video_codecs\x18\x0f \x03(\x0e\x32\x12.EStreamVideoCodec\"\x90\x08\n\x16\x43StreamingClientConfig\x12\x44\n\x07quality\x18\x01 \x01(\x0e\x32\x19.EStreamQualityPreference:\x18k_EStreamQualityBalanced\x12\x1c\n\x14\x64\x65sired_resolution_x\x18\x02 \x01(\r\x12\x1c\n\x14\x64\x65sired_resolution_y\x18\x03 \x01(\r\x12#\n\x1b\x64\x65sired_framerate_numerator\x18\x04 \x01(\r\x12%\n\x1d\x64\x65sired_framerate_denominator\x18\x05 \x01(\r\x12 \n\x14\x64\x65sired_bitrate_kbps\x18\x06 \x01(\x05:\x02-1\x12&\n\x18\x65nable_hardware_decoding\x18\x07 \x01(\x08:\x04true\x12)\n\x1a\x65nable_performance_overlay\x18\x08 \x01(\x08:\x05\x66\x61lse\x12$\n\x16\x65nable_video_streaming\x18\t \x01(\x08:\x04true\x12$\n\x16\x65nable_audio_streaming\x18\n \x01(\x08:\x04true\x12$\n\x16\x65nable_input_streaming\x18\x0b \x01(\x08:\x04true\x12\x19\n\x0e\x61udio_channels\x18\x0c \x01(\x05:\x01\x32\x12 \n\x11\x65nable_video_hevc\x18\r \x01(\x08:\x05\x66\x61lse\x12&\n\x18\x65nable_performance_icons\x18\x0e \x01(\x08:\x04true\x12*\n\x1b\x65nable_microphone_streaming\x18\x0f \x01(\x08:\x05\x66\x61lse\x12!\n\x19\x63ontroller_overlay_hotkey\x18\x10 \x01(\t\x12/\n enable_touch_controller_OBSOLETE\x18\x11 \x01(\x08:\x05\x66\x61lse\x12?\n\tp2p_scope\x18\x13 \x01(\x0e\x32\x10.EStreamP2PScope:\x1ak_EStreamP2PScopeAutomatic\x12(\n\x19\x65nable_audio_uncompressed\x18\x14 \x01(\x08:\x05\x66\x61lse\x12)\n\rdisplay_limit\x18\x15 \x01(\x0b\x32\x12.CStreamVideoLimit\x12)\n\rquality_limit\x18\x16 \x01(\x0b\x32\x12.CStreamVideoLimit\x12)\n\rruntime_limit\x18\x17 \x01(\x0b\x32\x12.CStreamVideoLimit\x12)\n\rdecoder_limit\x18\x18 \x03(\x0b\x32\x12.CStreamVideoLimit\x12$\n\x15\x65nable_unreliable_fec\x18\x19 \x01(\x08:\x05\x66\x61lse\x12\x1f\n\x10\x65nable_video_av1\x18\x1a \x01(\x08:\x05\x66\x61lse\"\xda\x03\n\x16\x43StreamingServerConfig\x12!\n\x19\x63hange_desktop_resolution\x18\x01 \x01(\x08\x12.\n&dynamically_adjust_resolution_OBSOLETE\x18\x02 \x01(\x08\x12\x1c\n\x14\x65nable_capture_nvfbc\x18\x03 \x01(\x08\x12\x30\n(enable_hardware_encoding_nvidia_OBSOLETE\x18\x04 \x01(\x08\x12-\n%enable_hardware_encoding_amd_OBSOLETE\x18\x05 \x01(\x08\x12/\n\'enable_hardware_encoding_intel_OBSOLETE\x18\x06 \x01(\x08\x12!\n\x19software_encoding_threads\x18\x07 \x01(\x05\x12\x1f\n\x17\x65nable_traffic_priority\x18\x08 \x01(\x08\x12W\n\x0fhost_play_audio\x18\t \x01(\x0e\x32\x1f.EStreamHostPlayAudioPreference:\x1dk_EStreamHostPlayAudioDefault\x12 \n\x18\x65nable_hardware_encoding\x18\n \x01(\x08\"\xd1\x02\n\x11\x43NegotiatedConfig\x12\x15\n\rreliable_data\x18\x01 \x01(\x08\x12I\n\x14selected_audio_codec\x18\x02 \x01(\x0e\x32\x12.EStreamAudioCodec:\x17k_EStreamAudioCodecNone\x12I\n\x14selected_video_codec\x18\x03 \x01(\x0e\x32\x12.EStreamVideoCodec:\x17k_EStreamVideoCodecNone\x12\x39\n\x1e\x61vailable_video_modes_OBSOLETE\x18\x04 \x03(\x0b\x32\x11.CStreamVideoMode\x12\x19\n\x11\x65nable_remote_hid\x18\x05 \x01(\x08\x12\x1a\n\x12\x65nable_touch_input\x18\x06 \x01(\x08\x12\x1d\n\x15\x64isable_client_cursor\x18\x07 \x01(\x08\"\xcf\x01\n\x13\x43NegotiationInitMsg\x12\x15\n\rreliable_data\x18\x01 \x01(\x08\x12\x32\n\x16supported_audio_codecs\x18\x02 \x03(\x0e\x32\x12.EStreamAudioCodec\x12\x32\n\x16supported_video_codecs\x18\x03 \x03(\x0e\x32\x12.EStreamVideoCodec\x12\x1b\n\x13supports_remote_hid\x18\x04 \x01(\x08\x12\x1c\n\x14supports_touch_input\x18\x05 \x01(\x08\"\xae\x01\n\x18\x43NegotiationSetConfigMsg\x12\"\n\x06\x63onfig\x18\x01 \x02(\x0b\x32\x12.CNegotiatedConfig\x12\x38\n\x17streaming_client_config\x18\x02 \x01(\x0b\x32\x17.CStreamingClientConfig\x12\x34\n\x15streaming_client_caps\x18\x03 \x01(\x0b\x32\x15.CStreamingClientCaps\"\x19\n\x17\x43NegotiationCompleteMsg\"\x9a\x01\n\x12\x43StartAudioDataMsg\x12\x0f\n\x07\x63hannel\x18\x02 \x02(\r\x12:\n\x05\x63odec\x18\x03 \x01(\x0e\x32\x12.EStreamAudioCodec:\x17k_EStreamAudioCodecNone\x12\x12\n\ncodec_data\x18\x04 \x01(\x0c\x12\x11\n\tfrequency\x18\x05 \x01(\r\x12\x10\n\x08\x63hannels\x18\x06 \x01(\r\"\x13\n\x11\x43StopAudioDataMsg\"\x94\x01\n\x12\x43StartVideoDataMsg\x12\x0f\n\x07\x63hannel\x18\x01 \x02(\r\x12:\n\x05\x63odec\x18\x02 \x01(\x0e\x32\x12.EStreamVideoCodec:\x17k_EStreamVideoCodecNone\x12\x12\n\ncodec_data\x18\x03 \x01(\x0c\x12\r\n\x05width\x18\x04 \x01(\r\x12\x0e\n\x06height\x18\x05 \x01(\r\"\x13\n\x11\x43StopVideoDataMsg\"\'\n\x14\x43StartNeptuneDataMsg\x12\x0f\n\x07\x63hannel\x18\x01 \x02(\r\"\x15\n\x13\x43StopNeptuneDataMsg\"\xc5\x04\n\x0e\x43RecordedInput\x12K\n\x04type\x18\x01 \x01(\x0e\x32\x16.EStreamControlMessage:%k_EStreamControlAuthenticationRequest\x12\x11\n\ttimestamp\x18\x02 \x01(\r\x12\x30\n\x0b\x66inger_down\x18\x03 \x01(\x0b\x32\x19.CInputTouchFingerDownMsgH\x00\x12\x34\n\rfinger_motion\x18\x04 \x01(\x0b\x32\x1b.CInputTouchFingerMotionMsgH\x00\x12,\n\tfinger_up\x18\x05 \x01(\x0b\x32\x17.CInputTouchFingerUpMsgH\x00\x12-\n\x0cmouse_motion\x18\x06 \x01(\x0b\x32\x15.CInputMouseMotionMsgH\x00\x12+\n\x0bmouse_wheel\x18\x07 \x01(\x0b\x32\x14.CInputMouseWheelMsgH\x00\x12)\n\nmouse_down\x18\x08 \x01(\x0b\x32\x13.CInputMouseDownMsgH\x00\x12%\n\x08mouse_up\x18\t \x01(\x0b\x32\x11.CInputMouseUpMsgH\x00\x12%\n\x08key_down\x18\n \x01(\x0b\x32\x11.CInputKeyDownMsgH\x00\x12!\n\x06key_up\x18\x0b \x01(\x0b\x32\x0f.CInputKeyUpMsgH\x00\x12\x1e\n\x04text\x18\x0c \x01(\x0b\x32\x0e.CInputTextMsgH\x00\x12\x1d\n\x03hid\x18\r \x01(\x0b\x32\x0e.CRemoteHIDMsgH\x00\x42\x06\n\x04\x64\x61ta\"8\n\x14\x43RecordedInputStream\x12 \n\x07\x65ntries\x18\x01 \x03(\x0b\x32\x0f.CRecordedInput\"9\n\x14\x43InputLatencyTestMsg\x12\x12\n\ninput_mark\x18\x01 \x02(\r\x12\r\n\x05\x63olor\x18\x02 \x01(\r\"l\n\x18\x43InputTouchFingerDownMsg\x12\x12\n\ninput_mark\x18\x01 \x01(\r\x12\x10\n\x08\x66ingerid\x18\x02 \x01(\x04\x12\x14\n\x0cx_normalized\x18\x03 \x01(\x02\x12\x14\n\x0cy_normalized\x18\x04 \x01(\x02\"n\n\x1a\x43InputTouchFingerMotionMsg\x12\x12\n\ninput_mark\x18\x01 \x01(\r\x12\x10\n\x08\x66ingerid\x18\x02 \x01(\x04\x12\x14\n\x0cx_normalized\x18\x03 \x01(\x02\x12\x14\n\x0cy_normalized\x18\x04 \x01(\x02\"|\n\x16\x43InputTouchFingerUpMsg\x12\x12\n\ninput_mark\x18\x01 \x01(\r\x12\x10\n\x08\x66ingerid\x18\x02 \x01(\x04\x12\x14\n\x0cx_normalized\x18\x03 \x01(\x02\x12\x14\n\x0cy_normalized\x18\x04 \x01(\x02\x12\x10\n\x08\x63\x61nceled\x18\x05 \x01(\x08\"n\n\x14\x43InputMouseMotionMsg\x12\x12\n\ninput_mark\x18\x01 \x01(\r\x12\x14\n\x0cx_normalized\x18\x02 \x01(\x02\x12\x14\n\x0cy_normalized\x18\x03 \x01(\x02\x12\n\n\x02\x64x\x18\x04 \x01(\x05\x12\n\n\x02\x64y\x18\x05 \x01(\x05\"\x83\x01\n\x13\x43InputMouseWheelMsg\x12\x12\n\ninput_mark\x18\x01 \x01(\r\x12\x45\n\tdirection\x18\x02 \x02(\x0e\x32\x1b.EStreamMouseWheelDirection:\x15k_EStreamMouseWheelUp\x12\x11\n\x06\x61mount\x18\x03 \x01(\x02:\x01\x31\"g\n\x12\x43InputMouseDownMsg\x12\x12\n\ninput_mark\x18\x01 \x01(\r\x12=\n\x06\x62utton\x18\x02 \x02(\x0e\x32\x13.EStreamMouseButton:\x18k_EStreamMouseButtonLeft\"e\n\x10\x43InputMouseUpMsg\x12\x12\n\ninput_mark\x18\x01 \x01(\r\x12=\n\x06\x62utton\x18\x02 \x02(\x0e\x32\x13.EStreamMouseButton:\x18k_EStreamMouseButtonLeft\"\\\n\x10\x43InputKeyDownMsg\x12\x12\n\ninput_mark\x18\x01 \x01(\r\x12\x10\n\x08scancode\x18\x02 \x02(\r\x12\x11\n\tmodifiers\x18\x03 \x01(\r\x12\x0f\n\x07keycode\x18\x04 \x01(\r\"Z\n\x0e\x43InputKeyUpMsg\x12\x12\n\ninput_mark\x18\x01 \x01(\r\x12\x10\n\x08scancode\x18\x02 \x02(\r\x12\x11\n\tmodifiers\x18\x03 \x01(\r\x12\x0f\n\x07keycode\x18\x04 \x01(\r\"6\n\rCInputTextMsg\x12\x12\n\ninput_mark\x18\x01 \x01(\r\x12\x11\n\ttext_utf8\x18\x02 \x02(\t\"\x1c\n\x0c\x43SetTitleMsg\x12\x0c\n\x04text\x18\x01 \x01(\t\"3\n\x12\x43SetCaptureSizeMsg\x12\r\n\x05width\x18\x01 \x01(\x05\x12\x0e\n\x06height\x18\x02 \x01(\x05\";\n\x0b\x43SetIconMsg\x12\r\n\x05width\x18\x01 \x01(\x05\x12\x0e\n\x06height\x18\x02 \x01(\x05\x12\r\n\x05image\x18\x03 \x01(\x0c\"E\n\x11\x43SetFlashStateMsg\x12\r\n\x05\x66lags\x18\x01 \x01(\r\x12\r\n\x05\x63ount\x18\x02 \x01(\r\x12\x12\n\ntimeout_ms\x18\x03 \x01(\r\"<\n\x0e\x43ShowCursorMsg\x12\x14\n\x0cx_normalized\x18\x01 \x01(\x02\x12\x14\n\x0cy_normalized\x18\x02 \x01(\x02\"\x10\n\x0e\x43HideCursorMsg\"\"\n\rCSetCursorMsg\x12\x11\n\tcursor_id\x18\x01 \x02(\x04\"\'\n\x12\x43GetCursorImageMsg\x12\x11\n\tcursor_id\x18\x01 \x02(\x04\"s\n\x12\x43SetCursorImageMsg\x12\x11\n\tcursor_id\x18\x01 \x02(\x04\x12\r\n\x05width\x18\x02 \x01(\x05\x12\x0e\n\x06height\x18\x03 \x01(\x05\x12\r\n\x05hot_x\x18\x04 \x01(\x05\x12\r\n\x05hot_y\x18\x05 \x01(\x05\x12\r\n\x05image\x18\x06 \x01(\x0c\"#\n\x12\x43SetCursorScaleMsg\x12\r\n\x05scale\x18\x01 \x01(\x02\"5\n\x14\x43VideoDecoderInfoMsg\x12\x0c\n\x04info\x18\x01 \x01(\t\x12\x0f\n\x07threads\x18\x02 \x01(\x05\"$\n\x14\x43VideoEncoderInfoMsg\x12\x0c\n\x04info\x18\x01 \x01(\t\"\x0b\n\tCPauseMsg\"\x0c\n\nCResumeMsg\"\x1a\n\x18\x43\x45nableHighResCaptureMsg\"\x1b\n\x19\x43\x44isableHighResCaptureMsg\"\x17\n\x15\x43\x45nableNeptuneDataMsg\"\x18\n\x16\x43\x44isableNeptuneDataMsg\"\x1a\n\x18\x43PauseControllerInputMsg\"\x1b\n\x19\x43ResumeControllerInputMsg\"\x19\n\x17\x43ToggleMagnificationMsg\"\"\n\x0f\x43SetCapslockMsg\x12\x0f\n\x07pressed\x18\x01 \x01(\x08\"\x8c\x02\n\x15\x43StreamingKeymapEntry\x12\x10\n\x08scancode\x18\x01 \x01(\x05\x12\x16\n\x0enormal_keycode\x18\x02 \x01(\x05\x12\x15\n\rshift_keycode\x18\x03 \x01(\x05\x12\x18\n\x10\x63\x61pslock_keycode\x18\x04 \x01(\x05\x12\x1e\n\x16shift_capslock_keycode\x18\x05 \x01(\x05\x12\x15\n\raltgr_keycode\x18\x06 \x01(\x05\x12\x1b\n\x13\x61ltgr_shift_keycode\x18\x07 \x01(\x05\x12\x1e\n\x16\x61ltgr_capslock_keycode\x18\x08 \x01(\x05\x12$\n\x1c\x61ltgr_shift_capslock_keycode\x18\t \x01(\x05\";\n\x10\x43StreamingKeymap\x12\'\n\x07\x65ntries\x18\x01 \x03(\x0b\x32\x16.CStreamingKeymapEntry\"2\n\rCSetKeymapMsg\x12!\n\x06keymap\x18\x01 \x01(\x0b\x32\x11.CStreamingKeymap\"\x0e\n\x0c\x43StopRequest\"\x0e\n\x0c\x43QuitRequest\"%\n\x10\x43\x44\x65leteCursorMsg\x12\x11\n\tcursor_id\x18\x01 \x02(\x04\"D\n\x19\x43SetStreamingClientConfig\x12\'\n\x06\x63onfig\x18\x01 \x02(\x0b\x32\x17.CStreamingClientConfig\"\x1d\n\nCSetQoSMsg\x12\x0f\n\x07use_qos\x18\x01 \x02(\x08\"x\n\x16\x43SetTargetFramerateMsg\x12\x11\n\tframerate\x18\x01 \x02(\r\x12\x0f\n\x07reasons\x18\x02 \x01(\r\x12\x1b\n\x13\x66ramerate_numerator\x18\x03 \x01(\r\x12\x1d\n\x15\x66ramerate_denominator\x18\x04 \x01(\r\"\'\n\x14\x43SetTargetBitrateMsg\x12\x0f\n\x07\x62itrate\x18\x01 \x02(\x05\"%\n\x12\x43OverlayEnabledMsg\x12\x0f\n\x07\x65nabled\x18\x01 \x02(\x08\"&\n\x10\x43SetGammaRampMsg\x12\x12\n\ngamma_ramp\x18\x01 \x01(\x0c\"~\n\x0f\x43SetActivityMsg\x12\x39\n\x08\x61\x63tivity\x18\x01 \x01(\x0e\x32\x10.EStreamActivity:\x15k_EStreamActivityIdle\x12\r\n\x05\x61ppid\x18\x02 \x01(\r\x12\x0e\n\x06gameid\x18\x03 \x01(\x04\x12\x11\n\tgame_name\x18\x04 \x01(\t\"\x13\n\x11\x43SystemSuspendMsg\"*\n\x16\x43VirtualHereRequestMsg\x12\x10\n\x08hostname\x18\x01 \x01(\t\"5\n\x14\x43VirtualHereReadyMsg\x12\x1d\n\x15licensed_device_count\x18\x01 \x01(\r\"4\n\x1a\x43VirtualHereShareDeviceMsg\x12\x16\n\x0e\x64\x65vice_address\x18\x01 \x01(\t\"\'\n\x14\x43SetSpectatorModeMsg\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\"3\n\rCRemoteHIDMsg\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\x0c\x12\x14\n\x0c\x61\x63tive_input\x18\x02 \x01(\x08\"I\n\x15\x43TouchConfigActiveMsg\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x10\n\x08revision\x18\x02 \x01(\r\x12\x0f\n\x07\x63reator\x18\x03 \x01(\x04\"\'\n\x16\x43GetTouchConfigDataMsg\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\"h\n\x16\x43SetTouchConfigDataMsg\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x10\n\x08revision\x18\x02 \x01(\r\x12\x0c\n\x04\x64\x61ta\x18\x03 \x01(\x0c\x12\x0e\n\x06layout\x18\x04 \x01(\x0c\x12\x0f\n\x07\x63reator\x18\x05 \x01(\x04\":\n\x19\x43SaveTouchConfigLayoutMsg\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x0e\n\x06layout\x18\x04 \x01(\x0c\"?\n\x18\x43TouchActionSetActiveMsg\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x14\n\x0c\x61\x63tionset_id\x18\x02 \x01(\x05\"C\n\x1c\x43TouchActionSetLayerAddedMsg\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x14\n\x0c\x61\x63tionset_id\x18\x02 \x01(\x05\"E\n\x1e\x43TouchActionSetLayerRemovedMsg\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x14\n\x0c\x61\x63tionset_id\x18\x02 \x01(\x05\"3\n\x14\x43GetTouchIconDataMsg\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x0c\n\x04icon\x18\x02 \x01(\t\"A\n\x14\x43SetTouchIconDataMsg\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x0c\n\x04icon\x18\x02 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x03 \x01(\x0c\"\x80\x03\n!CRemotePlayTogetherGroupUpdateMsg\x12:\n\x07players\x18\x01 \x03(\x0b\x32).CRemotePlayTogetherGroupUpdateMsg.Player\x12\x14\n\x0cplayer_index\x18\x02 \x01(\x05\x12\x1c\n\x14miniprofile_location\x18\x03 \x01(\t\x12\x11\n\tgame_name\x18\x04 \x01(\t\x12\x17\n\x0f\x61vatar_location\x18\x05 \x01(\t\x12\x14\n\x0c\x64irect_input\x18\x06 \x01(\x08\x1a\xa8\x01\n\x06Player\x12\x11\n\taccountid\x18\x01 \x01(\r\x12\x0f\n\x07guestid\x18\x02 \x01(\r\x12\x18\n\x10keyboard_enabled\x18\x03 \x01(\x08\x12\x15\n\rmouse_enabled\x18\x04 \x01(\x08\x12\x1a\n\x12\x63ontroller_enabled\x18\x05 \x01(\x08\x12\x18\n\x10\x63ontroller_slots\x18\x06 \x03(\r\x12\x13\n\x0b\x61vatar_hash\x18\x07 \x01(\x0c\"3\n\x1f\x43SetInputTemporarilyDisabledMsg\x12\x10\n\x08\x64isabled\x18\x01 \x01(\x08\"\'\n\x16\x43SetQualityOverrideMsg\x12\r\n\x05value\x18\x01 \x01(\x05\"\'\n\x16\x43SetBitrateOverrideMsg\x12\r\n\x05value\x18\x01 \x01(\x05\"\x1a\n\x18\x43ShowOnScreenKeyboardMsg\"~\n#CControllerPersonalizationUpdateMsg\x12\x17\n\x0f\x63ontroller_path\x18\x01 \x01(\t\x12\x17\n\x0f\x63ontroller_name\x18\x02 \x01(\t\x12%\n\x1dreverse_diamond_button_layout\x18\x03 \x01(\x08\",\n\x12\x43VRConnectionReady\x12\x16\n\x0e\x63onnect_params\x18\x01 \x01(\t\"%\n\x12\x43StreamDataLostMsg\x12\x0f\n\x07packets\x18\x01 \x03(\r\"f\n\x0c\x43\x41udioFormat\x12\x31\n\x06\x66ormat\x18\x01 \x02(\x0e\x32\r.EAudioFormat:\x12k_EAudioFormatNone\x12\x11\n\tfrequency\x18\x02 \x01(\r\x12\x10\n\x08\x63hannels\x18\x03 \x01(\r\"`\n\x0c\x43VideoFormat\x12\x31\n\x06\x66ormat\x18\x01 \x02(\x0e\x32\r.EVideoFormat:\x12k_EVideoFormatNone\x12\r\n\x05width\x18\x02 \x01(\r\x12\x0e\n\x06height\x18\x03 \x01(\r\"`\n\x0b\x43\x46rameEvent\x12>\n\x08\x65vent_id\x18\x01 \x02(\x0e\x32\x12.EStreamFrameEvent:\x18k_EStreamInputEventStart\x12\x11\n\ttimestamp\x18\x02 \x02(\r\"\xcf\x02\n\x0b\x43\x46rameStats\x12\x10\n\x08\x66rame_id\x18\x01 \x02(\r\x12\x12\n\ninput_mark\x18\x02 \x01(\r\x12\x1c\n\x06\x65vents\x18\x03 \x03(\x0b\x32\x0c.CFrameEvent\x12@\n\x06result\x18\x04 \x02(\x0e\x32\x13.EStreamFrameResult:\x1bk_EStreamFrameResultPending\x12\x19\n\x11\x66rame_start_delta\x18\x05 \x01(\x02\x12\x1b\n\x13\x66rame_display_delta\x18\x06 \x01(\x02\x12\x11\n\tping_time\x18\x07 \x01(\x02\x12\x16\n\x0eserver_bitrate\x18\x08 \x01(\x02\x12\x16\n\x0e\x63lient_bitrate\x18\t \x01(\x02\x12\x16\n\x0elink_bandwidth\x18\n \x01(\x02\x12\x13\n\x0bpacket_loss\x18\x0b \x01(\x02\x12\x12\n\nframe_size\x18\x0c \x01(\r\"\x88\x01\n\x1a\x43\x46rameStatAccumulatedValue\x12:\n\tstat_type\x18\x01 \x02(\x0e\x32\x16.EFrameAccumulatedStat:\x0fk_EFrameStatFPS\x12\r\n\x05\x63ount\x18\x02 \x02(\x05\x12\x0f\n\x07\x61verage\x18\x03 \x02(\x02\x12\x0e\n\x06stddev\x18\x04 \x01(\x02\"\xc1\x01\n\x12\x43\x46rameStatsListMsg\x12=\n\tdata_type\x18\x01 \x02(\x0e\x32\x13.EStreamingDataType:\x15k_EStreamingAudioData\x12\x1b\n\x05stats\x18\x02 \x03(\x0b\x32\x0c.CFrameStats\x12\x36\n\x11\x61\x63\x63umulated_stats\x18\x03 \x03(\x0b\x32\x1b.CFrameStatAccumulatedValue\x12\x17\n\x0flatest_frame_id\x18\x04 \x02(\x05\"\x8b\x01\n\x16\x43StreamingSessionStats\x12\x1d\n\x15\x66rame_loss_percentage\x18\x01 \x01(\x02\x12\x1f\n\x17\x61verage_network_time_ms\x18\x02 \x01(\x02\x12\x1e\n\x16stddev_network_time_ms\x18\x03 \x01(\x02\x12\x11\n\ttest_data\x18\x04 \x01(\t\"#\n\rCDebugDumpMsg\x12\x12\n\nscreenshot\x18\x01 \x01(\x0c\"(\n\x07\x43LogMsg\x12\x0c\n\x04type\x18\x01 \x01(\x05\x12\x0f\n\x07message\x18\x02 \x01(\t\"P\n\rCLogUploadMsg\x12\x31\n\x04type\x18\x01 \x01(\x0e\x32\r.ELogFileType:\x14k_ELogFileSystemBoot\x12\x0c\n\x04\x64\x61ta\x18\x03 \x01(\x0c\"\xb3\x02\n\x13\x43TransportSignalMsg\x12\x32\n\x06webrtc\x18\x01 \x01(\x0b\x32\".CTransportSignalMsg.WebRTCMessage\x12\x0b\n\x03sdr\x18\x02 \x03(\x0c\x1a\xda\x01\n\rWebRTCMessage\x12\x12\n\x08greeting\x18\x01 \x01(\x08H\x00\x12\x0f\n\x05offer\x18\x02 \x01(\tH\x00\x12\x10\n\x06\x61nswer\x18\x03 \x01(\tH\x00\x12\x41\n\tcandidate\x18\x04 \x01(\x0b\x32,.CTransportSignalMsg.WebRTCMessage.CandidateH\x00\x1aH\n\tCandidate\x12\x0f\n\x07sdp_mid\x18\x01 \x01(\t\x12\x17\n\x0fsdp_mline_index\x18\x02 \x01(\x05\x12\x11\n\tcandidate\x18\x03 \x01(\tB\x05\n\x03msg\"\xde\x06\n\x14\x43\x43ontrollerConfigMsg\x12\\\n\x04type\x18\x01 \x02(\x0e\x32\x1b.EStreamControllerConfigMsg:1k_EStreamControllerConfigMsg_RequestConfigsForApp\x12\x16\n\x0e\x63ontrollerPath\x18\x02 \x01(\t\x12\r\n\x05\x61ppid\x18\x03 \x01(\r\x12X\n\x17personalizationResponse\x18\x04 \x01(\x0b\x32\x37.CControllerConfigMsg.ControllerPersonalizationResponse\x12\x46\n\x0e\x63onfigResponse\x18\x06 \x03(\x0b\x32..CControllerConfigMsg.ControllerConfigResponse\x12N\n\x15\x61\x63tiveConfigChangeMsg\x18\x07 \x01(\x0b\x32/.CControllerConfigMsg.ControllerActiveConfigMsg\x1a\x99\x01\n\x18\x43ontrollerConfigResponse\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x11\n\tconfigURL\x18\x02 \x01(\t\x12\x16\n\x0e\x63ontrollerType\x18\x03 \x01(\r\x12\x16\n\x0e\x63ontrollerData\x18\x04 \x01(\t\x12\x16\n\x0eselectionOrder\x18\x05 \x01(\r\x12\x13\n\x0b\x61\x63tionBlock\x18\x06 \x01(\x08\x1a@\n!ControllerPersonalizationResponse\x12\x1b\n\x13personalizationData\x18\x01 \x01(\t\x1a\x81\x01\n$ControllerActiveConfigChangeResponse\x12\x11\n\tconfigURL\x18\x02 \x01(\t\x12\x16\n\x0e\x63ontrollerType\x18\x03 \x01(\r\x12\x16\n\x0e\x63ontrollerData\x18\x04 \x01(\t\x12\x16\n\x0eselectionOrder\x18\x05 \x01(\r\x1am\n\x19\x43ontrollerActiveConfigMsg\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x11\n\tconfigURL\x18\x02 \x01(\t\x12\x16\n\x0e\x63ontrollerType\x18\x03 \x01(\r\x12\x16\n\x0e\x63ontrollerData\x18\x04 \x01(\t*\xb3\x01\n\x0e\x45StreamChannel\x12$\n\x17k_EStreamChannelInvalid\x10\xff\xff\xff\xff\xff\xff\xff\xff\xff\x01\x12\x1d\n\x19k_EStreamChannelDiscovery\x10\x00\x12\x1b\n\x17k_EStreamChannelControl\x10\x01\x12\x19\n\x15k_EStreamChannelStats\x10\x02\x12$\n k_EStreamChannelDataChannelStart\x10\x03*`\n\x17\x45StreamDiscoveryMessage\x12!\n\x1dk_EStreamDiscoveryPingRequest\x10\x01\x12\"\n\x1ek_EStreamDiscoveryPingResponse\x10\x02*\xa8\x1f\n\x15\x45StreamControlMessage\x12)\n%k_EStreamControlAuthenticationRequest\x10\x01\x12*\n&k_EStreamControlAuthenticationResponse\x10\x02\x12#\n\x1fk_EStreamControlNegotiationInit\x10\x03\x12(\n$k_EStreamControlNegotiationSetConfig\x10\x04\x12\'\n#k_EStreamControlNegotiationComplete\x10\x05\x12#\n\x1fk_EStreamControlClientHandshake\x10\x06\x12#\n\x1fk_EStreamControlServerHandshake\x10\x07\x12$\n k_EStreamControlStartNetworkTest\x10\x08\x12\x1d\n\x19k_EStreamControlKeepAlive\x10\t\x12\'\n#k_EStreamControl_LAST_SETUP_MESSAGE\x10\x0f\x12\"\n\x1ek_EStreamControlStartAudioData\x10\x32\x12!\n\x1dk_EStreamControlStopAudioData\x10\x33\x12\"\n\x1ek_EStreamControlStartVideoData\x10\x34\x12!\n\x1dk_EStreamControlStopVideoData\x10\x35\x12$\n k_EStreamControlInputMouseMotion\x10\x36\x12#\n\x1fk_EStreamControlInputMouseWheel\x10\x37\x12\"\n\x1ek_EStreamControlInputMouseDown\x10\x38\x12 \n\x1ck_EStreamControlInputMouseUp\x10\x39\x12 \n\x1ck_EStreamControlInputKeyDown\x10:\x12\x1e\n\x1ak_EStreamControlInputKeyUp\x10;\x12\x31\n-k_EStreamControlInputGamepadAttached_OBSOLETE\x10<\x12.\n*k_EStreamControlInputGamepadEvent_OBSOLETE\x10=\x12\x31\n-k_EStreamControlInputGamepadDetached_OBSOLETE\x10>\x12\x1e\n\x1ak_EStreamControlShowCursor\x10?\x12\x1e\n\x1ak_EStreamControlHideCursor\x10@\x12\x1d\n\x19k_EStreamControlSetCursor\x10\x41\x12\"\n\x1ek_EStreamControlGetCursorImage\x10\x42\x12\"\n\x1ek_EStreamControlSetCursorImage\x10\x43\x12 \n\x1ck_EStreamControlDeleteCursor\x10\x44\x12&\n\"k_EStreamControlSetTargetFramerate\x10\x45\x12$\n k_EStreamControlInputLatencyTest\x10\x46\x12*\n&k_EStreamControlGamepadRumble_OBSOLETE\x10G\x12\"\n\x1ek_EStreamControlOverlayEnabled\x10J\x12\x34\n0k_EStreamControlInputControllerAttached_OBSOLETE\x10K\x12\x31\n-k_EStreamControlInputControllerState_OBSOLETE\x10L\x12/\n+k_EStreamControlTriggerHapticPulse_OBSOLETE\x10M\x12\x34\n0k_EStreamControlInputControllerDetached_OBSOLETE\x10N\x12$\n k_EStreamControlVideoDecoderInfo\x10P\x12\x1c\n\x18k_EStreamControlSetTitle\x10Q\x12\x1b\n\x17k_EStreamControlSetIcon\x10R\x12\x1f\n\x1bk_EStreamControlQuitRequest\x10S\x12\x1a\n\x16k_EStreamControlSetQoS\x10W\x12<\n8k_EStreamControlInputControllerWirelessPresence_OBSOLETE\x10X\x12 \n\x1ck_EStreamControlSetGammaRamp\x10Y\x12$\n k_EStreamControlVideoEncoderInfo\x10Z\x12\x34\n0k_EStreamControlInputControllerStateHID_OBSOLETE\x10]\x12$\n k_EStreamControlSetTargetBitrate\x10^\x12\x38\n4k_EStreamControlSetControllerPairingEnabled_OBSOLETE\x10_\x12\x37\n3k_EStreamControlSetControllerPairingResult_OBSOLETE\x10`\x12\x38\n4k_EStreamControlTriggerControllerDisconnect_OBSOLETE\x10\x61\x12\x1f\n\x1bk_EStreamControlSetActivity\x10\x62\x12,\n(k_EStreamControlSetStreamingClientConfig\x10\x63\x12!\n\x1dk_EStreamControlSystemSuspend\x10\x64\x12\x32\n.k_EStreamControlSetControllerSettings_OBSOLETE\x10\x65\x12&\n\"k_EStreamControlVirtualHereRequest\x10\x66\x12$\n k_EStreamControlVirtualHereReady\x10g\x12*\n&k_EStreamControlVirtualHereShareDevice\x10h\x12$\n k_EStreamControlSetSpectatorMode\x10i\x12\x1d\n\x19k_EStreamControlRemoteHID\x10j\x12\'\n#k_EStreamControlStartMicrophoneData\x10k\x12&\n\"k_EStreamControlStopMicrophoneData\x10l\x12\x1d\n\x19k_EStreamControlInputText\x10m\x12%\n!k_EStreamControlTouchConfigActive\x10n\x12&\n\"k_EStreamControlGetTouchConfigData\x10o\x12&\n\"k_EStreamControlSetTouchConfigData\x10p\x12)\n%k_EStreamControlSaveTouchConfigLayout\x10q\x12(\n$k_EStreamControlTouchActionSetActive\x10r\x12$\n k_EStreamControlGetTouchIconData\x10s\x12$\n k_EStreamControlSetTouchIconData\x10t\x12(\n$k_EStreamControlInputTouchFingerDown\x10u\x12*\n&k_EStreamControlInputTouchFingerMotion\x10v\x12&\n\"k_EStreamControlInputTouchFingerUp\x10w\x12\"\n\x1ek_EStreamControlSetCaptureSize\x10x\x12!\n\x1dk_EStreamControlSetFlashState\x10y\x12\x19\n\x15k_EStreamControlPause\x10z\x12\x1a\n\x16k_EStreamControlResume\x10{\x12(\n$k_EStreamControlEnableHighResCapture\x10|\x12)\n%k_EStreamControlDisableHighResCapture\x10}\x12\'\n#k_EStreamControlToggleMagnification\x10~\x12\x1f\n\x1bk_EStreamControlSetCapslock\x10\x7f\x12\x1e\n\x19k_EStreamControlSetKeymap\x10\x80\x01\x12 \n\x1bk_EStreamControlStopRequest\x10\x81\x01\x12-\n(k_EStreamControlTouchActionSetLayerAdded\x10\x82\x01\x12/\n*k_EStreamControlTouchActionSetLayerRemoved\x10\x83\x01\x12\x32\n-k_EStreamControlRemotePlayTogetherGroupUpdate\x10\x84\x01\x12\x30\n+k_EStreamControlSetInputTemporarilyDisabled\x10\x85\x01\x12\'\n\"k_EStreamControlSetQualityOverride\x10\x86\x01\x12\'\n\"k_EStreamControlSetBitrateOverride\x10\x87\x01\x12)\n$k_EStreamControlShowOnScreenKeyboard\x10\x88\x01\x12(\n#k_EStreamControlControllerConfigMsg\x10\x89\x01\x12\x34\n/k_EStreamControlControllerPersonalizationUpdate\x10\x8a\x01\x12&\n!k_EStreamControlEnableNeptuneData\x10\x8b\x01\x12\'\n\"k_EStreamControlDisableNeptuneData\x10\x8c\x01\x12%\n k_EStreamControlStartNeptuneData\x10\x8d\x01\x12$\n\x1fk_EStreamControlStopNeptuneData\x10\x8e\x01\x12)\n$k_EStreamControlPauseControllerInput\x10\x8f\x01\x12*\n%k_EStreamControlResumeControllerInput\x10\x90\x01\x12&\n!k_EStreamControlVRConnectionReady\x10\x91\x01\x12#\n\x1ek_EStreamControlSetCursorScale\x10\x92\x01*G\n\x0e\x45StreamVersion\x12\x18\n\x14k_EStreamVersionNone\x10\x00\x12\x1b\n\x17k_EStreamVersionCurrent\x10\x01*\xc0\x01\n\x11\x45StreamAudioCodec\x12\x1b\n\x17k_EStreamAudioCodecNone\x10\x00\x12\x1a\n\x16k_EStreamAudioCodecRaw\x10\x01\x12\x1d\n\x19k_EStreamAudioCodecVorbis\x10\x02\x12\x1b\n\x17k_EStreamAudioCodecOpus\x10\x03\x12\x1a\n\x16k_EStreamAudioCodecMP3\x10\x04\x12\x1a\n\x16k_EStreamAudioCodecAAC\x10\x05*\x96\x02\n\x11\x45StreamVideoCodec\x12\x1b\n\x17k_EStreamVideoCodecNone\x10\x00\x12\x1a\n\x16k_EStreamVideoCodecRaw\x10\x01\x12\x1a\n\x16k_EStreamVideoCodecVP8\x10\x02\x12\x1a\n\x16k_EStreamVideoCodecVP9\x10\x03\x12\x1b\n\x17k_EStreamVideoCodecH264\x10\x04\x12\x1b\n\x17k_EStreamVideoCodecHEVC\x10\x05\x12\x1c\n\x18k_EStreamVideoCodecORBX1\x10\x06\x12\x1c\n\x18k_EStreamVideoCodecORBX2\x10\x07\x12\x1a\n\x16k_EStreamVideoCodecAV1\x10\x08*\x99\x01\n\x18\x45StreamQualityPreference\x12&\n\x19k_EStreamQualityAutomatic\x10\xff\xff\xff\xff\xff\xff\xff\xff\xff\x01\x12\x18\n\x14k_EStreamQualityFast\x10\x01\x12\x1c\n\x18k_EStreamQualityBalanced\x10\x02\x12\x1d\n\x19k_EStreamQualityBeautiful\x10\x03*X\n\x0e\x45StreamBitrate\x12\'\n\x1ak_EStreamBitrateAutodetect\x10\xff\xff\xff\xff\xff\xff\xff\xff\xff\x01\x12\x1d\n\x19k_EStreamBitrateUnlimited\x10\x00*\xd9\x01\n\x11\x45StreamColorspace\x12\x1f\n\x1bk_EStreamColorspace_Unknown\x10\x00\x12\x1d\n\x19k_EStreamColorspace_BT601\x10\x01\x12\"\n\x1ek_EStreamColorspace_BT601_Full\x10\x02\x12\x1d\n\x19k_EStreamColorspace_BT709\x10\x03\x12\"\n\x1ek_EStreamColorspace_BT709_Full\x10\x04\x12\x1d\n\x19k_EStreamColorspace_HDR10\x10\x05*\xaa\x01\n\x0f\x45StreamP2PScope\x12\x1e\n\x1ak_EStreamP2PScopeAutomatic\x10\x00\x12\x1d\n\x19k_EStreamP2PScopeDisabled\x10\x01\x12\x1b\n\x17k_EStreamP2PScopeOnlyMe\x10\x02\x12\x1c\n\x18k_EStreamP2PScopeFriends\x10\x03\x12\x1d\n\x19k_EStreamP2PScopeEveryone\x10\x04*e\n\x1e\x45StreamHostPlayAudioPreference\x12!\n\x1dk_EStreamHostPlayAudioDefault\x10\x00\x12 \n\x1ck_EStreamHostPlayAudioAlways\x10\x01*\x87\x01\n\x12\x45StreamingDataType\x12\x19\n\x15k_EStreamingAudioData\x10\x00\x12\x19\n\x15k_EStreamingVideoData\x10\x01\x12\x1e\n\x1ak_EStreamingMicrophoneData\x10\x02\x12\x1b\n\x17k_EStreamingNeptuneData\x10\x03*\xcb\x01\n\x12\x45StreamMouseButton\x12\x1c\n\x18k_EStreamMouseButtonLeft\x10\x01\x12\x1d\n\x19k_EStreamMouseButtonRight\x10\x02\x12\x1e\n\x1ak_EStreamMouseButtonMiddle\x10\x10\x12\x1a\n\x16k_EStreamMouseButtonX1\x10 \x12\x1a\n\x16k_EStreamMouseButtonX2\x10@\x12 \n\x1bk_EStreamMouseButtonUnknown\x10\x80 *\x98\x01\n\x1a\x45StreamMouseWheelDirection\x12\x19\n\x15k_EStreamMouseWheelUp\x10x\x12$\n\x17k_EStreamMouseWheelDown\x10\x88\xff\xff\xff\xff\xff\xff\xff\xff\x01\x12\x1b\n\x17k_EStreamMouseWheelLeft\x10\x03\x12\x1c\n\x18k_EStreamMouseWheelRight\x10\x04*\x89\x02\n\x17\x45StreamFramerateLimiter\x12!\n\x1dk_EStreamFramerateSlowCapture\x10\x01\x12!\n\x1dk_EStreamFramerateSlowConvert\x10\x02\x12 \n\x1ck_EStreamFramerateSlowEncode\x10\x04\x12!\n\x1dk_EStreamFramerateSlowNetwork\x10\x08\x12 \n\x1ck_EStreamFramerateSlowDecode\x10\x10\x12\x1e\n\x1ak_EStreamFramerateSlowGame\x10 \x12!\n\x1dk_EStreamFramerateSlowDisplay\x10@*\xa5\x01\n\x0f\x45StreamActivity\x12\x19\n\x15k_EStreamActivityIdle\x10\x01\x12\x19\n\x15k_EStreamActivityGame\x10\x02\x12\x1c\n\x18k_EStreamActivityDesktop\x10\x03\x12\"\n\x1ek_EStreamActivitySecureDesktop\x10\x04\x12\x1a\n\x16k_EStreamActivityMusic\x10\x05*D\n\x12\x45StreamDataMessage\x12\x17\n\x13k_EStreamDataPacket\x10\x01\x12\x15\n\x11k_EStreamDataLost\x10\x02*d\n\x0c\x45\x41udioFormat\x12\x16\n\x12k_EAudioFormatNone\x10\x00\x12#\n\x1fk_EAudioFormat16BitLittleEndian\x10\x01\x12\x17\n\x13k_EAudioFormatFloat\x10\x02*W\n\x0c\x45VideoFormat\x12\x16\n\x12k_EVideoFormatNone\x10\x00\x12\x16\n\x12k_EVideoFormatYV12\x10\x01\x12\x17\n\x13k_EVideoFormatAccel\x10\x02*\xd7\x01\n\x13\x45StreamStatsMessage\x12\x1d\n\x19k_EStreamStatsFrameEvents\x10\x01\x12\x1b\n\x17k_EStreamStatsDebugDump\x10\x02\x12\x1c\n\x18k_EStreamStatsLogMessage\x10\x03\x12 \n\x1ck_EStreamStatsLogUploadBegin\x10\x04\x12\x1f\n\x1bk_EStreamStatsLogUploadData\x10\x05\x12#\n\x1fk_EStreamStatsLogUploadComplete\x10\x06*\x85\x05\n\x11\x45StreamFrameEvent\x12\x1c\n\x18k_EStreamInputEventStart\x10\x00\x12\x1b\n\x17k_EStreamInputEventSend\x10\x01\x12\x1b\n\x17k_EStreamInputEventRecv\x10\x02\x12\x1d\n\x19k_EStreamInputEventQueued\x10\x03\x12\x1e\n\x1ak_EStreamInputEventHandled\x10\x04\x12\x1c\n\x18k_EStreamFrameEventStart\x10\x05\x12#\n\x1fk_EStreamFrameEventCaptureBegin\x10\x06\x12!\n\x1dk_EStreamFrameEventCaptureEnd\x10\x07\x12#\n\x1fk_EStreamFrameEventConvertBegin\x10\x08\x12!\n\x1dk_EStreamFrameEventConvertEnd\x10\t\x12\"\n\x1ek_EStreamFrameEventEncodeBegin\x10\n\x12 \n\x1ck_EStreamFrameEventEncodeEnd\x10\x0b\x12\x1b\n\x17k_EStreamFrameEventSend\x10\x0c\x12\x1b\n\x17k_EStreamFrameEventRecv\x10\r\x12\"\n\x1ek_EStreamFrameEventDecodeBegin\x10\x0e\x12 \n\x1ck_EStreamFrameEventDecodeEnd\x10\x0f\x12\"\n\x1ek_EStreamFrameEventUploadBegin\x10\x10\x12 \n\x1ck_EStreamFrameEventUploadEnd\x10\x11\x12\x1f\n\x1bk_EStreamFrameEventComplete\x10\x12*\xd4\x02\n\x12\x45StreamFrameResult\x12\x1f\n\x1bk_EStreamFrameResultPending\x10\x00\x12!\n\x1dk_EStreamFrameResultDisplayed\x10\x01\x12*\n&k_EStreamFrameResultDroppedNetworkSlow\x10\x02\x12*\n&k_EStreamFrameResultDroppedNetworkLost\x10\x03\x12)\n%k_EStreamFrameResultDroppedDecodeSlow\x10\x04\x12,\n(k_EStreamFrameResultDroppedDecodeCorrupt\x10\x05\x12#\n\x1fk_EStreamFrameResultDroppedLate\x10\x06\x12$\n k_EStreamFrameResultDroppedReset\x10\x07*\xa2\x05\n\x15\x45\x46rameAccumulatedStat\x12\x13\n\x0fk_EFrameStatFPS\x10\x00\x12!\n\x1dk_EFrameStatCaptureDurationMS\x10\x01\x12!\n\x1dk_EFrameStatConvertDurationMS\x10\x02\x12 \n\x1ck_EFrameStatEncodeDurationMS\x10\x03\x12\x1f\n\x1bk_EFrameStatSteamDurationMS\x10\x04\x12 \n\x1ck_EFrameStatServerDurationMS\x10\x05\x12!\n\x1dk_EFrameStatNetworkDurationMS\x10\x06\x12 \n\x1ck_EFrameStatDecodeDurationMS\x10\x07\x12!\n\x1dk_EFrameStatDisplayDurationMS\x10\x08\x12 \n\x1ck_EFrameStatClientDurationMS\x10\t\x12\x1f\n\x1bk_EFrameStatFrameDurationMS\x10\n\x12\x1e\n\x1ak_EFrameStatInputLatencyMS\x10\x0b\x12\x1d\n\x19k_EFrameStatGameLatencyMS\x10\x0c\x12\"\n\x1ek_EFrameStatRoundTripLatencyMS\x10\r\x12\x1a\n\x16k_EFrameStatPingTimeMS\x10\x0e\x12\'\n#k_EFrameStatServerBitrateKbitPerSec\x10\x0f\x12\'\n#k_EFrameStatClientBitrateKbitPerSec\x10\x10\x12\'\n#k_EFrameStatLinkBandwidthKbitPerSec\x10\x11\x12$\n k_EFrameStatPacketLossPercentage\x10\x12*^\n\x0c\x45LogFileType\x12\x18\n\x14k_ELogFileSystemBoot\x10\x00\x12\x19\n\x15k_ELogFileSystemReset\x10\x01\x12\x19\n\x15k_ELogFileSystemDebug\x10\x02*\xa9\x02\n\x1a\x45StreamControllerConfigMsg\x12\x35\n1k_EStreamControllerConfigMsg_RequestConfigsForApp\x10\x00\x12/\n+k_EStreamControllerConfigMsg_ConfigResponse\x10\x01\x12\x38\n4k_EStreamControllerConfigMsg_PersonalizationResponse\x10\x02\x12\x33\n/k_EStreamControllerConfigMsg_ActiveConfigChange\x10\x03\x12\x34\n0k_EStreamControllerConfigMsg_RequestActiveConfig\x10\x04\x42\x05H\x01\x90\x01\x00')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'steammessages_remoteplay_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'H\001\220\001\000'
  _ESTREAMCHANNEL._serialized_start=12107
  _ESTREAMCHANNEL._serialized_end=12286
  _ESTREAMDISCOVERYMESSAGE._serialized_start=12288
  _ESTREAMDISCOVERYMESSAGE._serialized_end=12384
  _ESTREAMCONTROLMESSAGE._serialized_start=12387
  _ESTREAMCONTROLMESSAGE._serialized_end=16395
  _ESTREAMVERSION._serialized_start=16397
  _ESTREAMVERSION._serialized_end=16468
  _ESTREAMAUDIOCODEC._serialized_start=16471
  _ESTREAMAUDIOCODEC._serialized_end=16663
  _ESTREAMVIDEOCODEC._serialized_start=16666
  _ESTREAMVIDEOCODEC._serialized_end=16944
  _ESTREAMQUALITYPREFERENCE._serialized_start=16947
  _ESTREAMQUALITYPREFERENCE._serialized_end=17100
  _ESTREAMBITRATE._serialized_start=17102
  _ESTREAMBITRATE._serialized_end=17190
  _ESTREAMCOLORSPACE._serialized_start=17193
  _ESTREAMCOLORSPACE._serialized_end=17410
  _ESTREAMP2PSCOPE._serialized_start=17413
  _ESTREAMP2PSCOPE._serialized_end=17583
  _ESTREAMHOSTPLAYAUDIOPREFERENCE._serialized_start=17585
  _ESTREAMHOSTPLAYAUDIOPREFERENCE._serialized_end=17686
  _ESTREAMINGDATATYPE._serialized_start=17689
  _ESTREAMINGDATATYPE._serialized_end=17824
  _ESTREAMMOUSEBUTTON._serialized_start=17827
  _ESTREAMMOUSEBUTTON._serialized_end=18030
  _ESTREAMMOUSEWHEELDIRECTION._serialized_start=18033
  _ESTREAMMOUSEWHEELDIRECTION._serialized_end=18185
  _ESTREAMFRAMERATELIMITER._serialized_start=18188
  _ESTREAMFRAMERATELIMITER._serialized_end=18453
  _ESTREAMACTIVITY._serialized_start=18456
  _ESTREAMACTIVITY._serialized_end=18621
  _ESTREAMDATAMESSAGE._serialized_start=18623
  _ESTREAMDATAMESSAGE._serialized_end=18691
  _EAUDIOFORMAT._serialized_start=18693
  _EAUDIOFORMAT._serialized_end=18793
  _EVIDEOFORMAT._serialized_start=18795
  _EVIDEOFORMAT._serialized_end=18882
  _ESTREAMSTATSMESSAGE._serialized_start=18885
  _ESTREAMSTATSMESSAGE._serialized_end=19100
  _ESTREAMFRAMEEVENT._serialized_start=19103
  _ESTREAMFRAMEEVENT._serialized_end=19748
  _ESTREAMFRAMERESULT._serialized_start=19751
  _ESTREAMFRAMERESULT._serialized_end=20091
  _EFRAMEACCUMULATEDSTAT._serialized_start=20094
  _EFRAMEACCUMULATEDSTAT._serialized_end=20768
  _ELOGFILETYPE._serialized_start=20770
  _ELOGFILETYPE._serialized_end=20864
  _ESTREAMCONTROLLERCONFIGMSG._serialized_start=20867
  _ESTREAMCONTROLLERCONFIGMSG._serialized_end=21164
  _CDISCOVERYPINGREQUEST._serialized_start=34
  _CDISCOVERYPINGREQUEST._serialized_end=106
  _CDISCOVERYPINGRESPONSE._serialized_start=108
  _CDISCOVERYPINGRESPONSE._serialized_end=180
  _CSTREAMINGCLIENTHANDSHAKEINFO._serialized_start=182
  _CSTREAMINGCLIENTHANDSHAKEINFO._serialized_end=235
  _CCLIENTHANDSHAKEMSG._serialized_start=237
  _CCLIENTHANDSHAKEMSG._serialized_end=304
  _CSTREAMINGSERVERHANDSHAKEINFO._serialized_start=306
  _CSTREAMINGSERVERHANDSHAKEINFO._serialized_end=350
  _CSERVERHANDSHAKEMSG._serialized_start=352
  _CSERVERHANDSHAKEMSG._serialized_end=419
  _CAUTHENTICATIONREQUESTMSG._serialized_start=421
  _CAUTHENTICATIONREQUESTMSG._serialized_end=536
  _CAUTHENTICATIONRESPONSEMSG._serialized_start=539
  _CAUTHENTICATIONRESPONSEMSG._serialized_end=751
  _CAUTHENTICATIONRESPONSEMSG_AUTHENTICATIONRESULT._serialized_start=702
  _CAUTHENTICATIONRESPONSEMSG_AUTHENTICATIONRESULT._serialized_end=751
  _CKEEPALIVEMSG._serialized_start=753
  _CKEEPALIVEMSG._serialized_end=768
  _CSTARTNETWORKTESTMSG._serialized_start=771
  _CSTARTNETWORKTESTMSG._serialized_end=902
  _CSTREAMVIDEOMODE._serialized_start=905
  _CSTREAMVIDEOMODE._serialized_end=1042
  _CSTREAMVIDEOLIMIT._serialized_start=1045
  _CSTREAMVIDEOLIMIT._serialized_end=1207
  _CSTREAMINGCLIENTCAPS._serialized_start=1210
  _CSTREAMINGCLIENTCAPS._serialized_end=1782
  _CSTREAMINGCLIENTCONFIG._serialized_start=1785
  _CSTREAMINGCLIENTCONFIG._serialized_end=2825
  _CSTREAMINGSERVERCONFIG._serialized_start=2828
  _CSTREAMINGSERVERCONFIG._serialized_end=3302
  _CNEGOTIATEDCONFIG._serialized_start=3305
  _CNEGOTIATEDCONFIG._serialized_end=3642
  _CNEGOTIATIONINITMSG._serialized_start=3645
  _CNEGOTIATIONINITMSG._serialized_end=3852
  _CNEGOTIATIONSETCONFIGMSG._serialized_start=3855
  _CNEGOTIATIONSETCONFIGMSG._serialized_end=4029
  _CNEGOTIATIONCOMPLETEMSG._serialized_start=4031
  _CNEGOTIATIONCOMPLETEMSG._serialized_end=4056
  _CSTARTAUDIODATAMSG._serialized_start=4059
  _CSTARTAUDIODATAMSG._serialized_end=4213
  _CSTOPAUDIODATAMSG._serialized_start=4215
  _CSTOPAUDIODATAMSG._serialized_end=4234
  _CSTARTVIDEODATAMSG._serialized_start=4237
  _CSTARTVIDEODATAMSG._serialized_end=4385
  _CSTOPVIDEODATAMSG._serialized_start=4387
  _CSTOPVIDEODATAMSG._serialized_end=4406
  _CSTARTNEPTUNEDATAMSG._serialized_start=4408
  _CSTARTNEPTUNEDATAMSG._serialized_end=4447
  _CSTOPNEPTUNEDATAMSG._serialized_start=4449
  _CSTOPNEPTUNEDATAMSG._serialized_end=4470
  _CRECORDEDINPUT._serialized_start=4473
  _CRECORDEDINPUT._serialized_end=5054
  _CRECORDEDINPUTSTREAM._serialized_start=5056
  _CRECORDEDINPUTSTREAM._serialized_end=5112
  _CINPUTLATENCYTESTMSG._serialized_start=5114
  _CINPUTLATENCYTESTMSG._serialized_end=5171
  _CINPUTTOUCHFINGERDOWNMSG._serialized_start=5173
  _CINPUTTOUCHFINGERDOWNMSG._serialized_end=5281
  _CINPUTTOUCHFINGERMOTIONMSG._serialized_start=5283
  _CINPUTTOUCHFINGERMOTIONMSG._serialized_end=5393
  _CINPUTTOUCHFINGERUPMSG._serialized_start=5395
  _CINPUTTOUCHFINGERUPMSG._serialized_end=5519
  _CINPUTMOUSEMOTIONMSG._serialized_start=5521
  _CINPUTMOUSEMOTIONMSG._serialized_end=5631
  _CINPUTMOUSEWHEELMSG._serialized_start=5634
  _CINPUTMOUSEWHEELMSG._serialized_end=5765
  _CINPUTMOUSEDOWNMSG._serialized_start=5767
  _CINPUTMOUSEDOWNMSG._serialized_end=5870
  _CINPUTMOUSEUPMSG._serialized_start=5872
  _CINPUTMOUSEUPMSG._serialized_end=5973
  _CINPUTKEYDOWNMSG._serialized_start=5975
  _CINPUTKEYDOWNMSG._serialized_end=6067
  _CINPUTKEYUPMSG._serialized_start=6069
  _CINPUTKEYUPMSG._serialized_end=6159
  _CINPUTTEXTMSG._serialized_start=6161
  _CINPUTTEXTMSG._serialized_end=6215
  _CSETTITLEMSG._serialized_start=6217
  _CSETTITLEMSG._serialized_end=6245
  _CSETCAPTURESIZEMSG._serialized_start=6247
  _CSETCAPTURESIZEMSG._serialized_end=6298
  _CSETICONMSG._serialized_start=6300
  _CSETICONMSG._serialized_end=6359
  _CSETFLASHSTATEMSG._serialized_start=6361
  _CSETFLASHSTATEMSG._serialized_end=6430
  _CSHOWCURSORMSG._serialized_start=6432
  _CSHOWCURSORMSG._serialized_end=6492
  _CHIDECURSORMSG._serialized_start=6494
  _CHIDECURSORMSG._serialized_end=6510
  _CSETCURSORMSG._serialized_start=6512
  _CSETCURSORMSG._serialized_end=6546
  _CGETCURSORIMAGEMSG._serialized_start=6548
  _CGETCURSORIMAGEMSG._serialized_end=6587
  _CSETCURSORIMAGEMSG._serialized_start=6589
  _CSETCURSORIMAGEMSG._serialized_end=6704
  _CSETCURSORSCALEMSG._serialized_start=6706
  _CSETCURSORSCALEMSG._serialized_end=6741
  _CVIDEODECODERINFOMSG._serialized_start=6743
  _CVIDEODECODERINFOMSG._serialized_end=6796
  _CVIDEOENCODERINFOMSG._serialized_start=6798
  _CVIDEOENCODERINFOMSG._serialized_end=6834
  _CPAUSEMSG._serialized_start=6836
  _CPAUSEMSG._serialized_end=6847
  _CRESUMEMSG._serialized_start=6849
  _CRESUMEMSG._serialized_end=6861
  _CENABLEHIGHRESCAPTUREMSG._serialized_start=6863
  _CENABLEHIGHRESCAPTUREMSG._serialized_end=6889
  _CDISABLEHIGHRESCAPTUREMSG._serialized_start=6891
  _CDISABLEHIGHRESCAPTUREMSG._serialized_end=6918
  _CENABLENEPTUNEDATAMSG._serialized_start=6920
  _CENABLENEPTUNEDATAMSG._serialized_end=6943
  _CDISABLENEPTUNEDATAMSG._serialized_start=6945
  _CDISABLENEPTUNEDATAMSG._serialized_end=6969
  _CPAUSECONTROLLERINPUTMSG._serialized_start=6971
  _CPAUSECONTROLLERINPUTMSG._serialized_end=6997
  _CRESUMECONTROLLERINPUTMSG._serialized_start=6999
  _CRESUMECONTROLLERINPUTMSG._serialized_end=7026
  _CTOGGLEMAGNIFICATIONMSG._serialized_start=7028
  _CTOGGLEMAGNIFICATIONMSG._serialized_end=7053
  _CSETCAPSLOCKMSG._serialized_start=7055
  _CSETCAPSLOCKMSG._serialized_end=7089
  _CSTREAMINGKEYMAPENTRY._serialized_start=7092
  _CSTREAMINGKEYMAPENTRY._serialized_end=7360
  _CSTREAMINGKEYMAP._serialized_start=7362
  _CSTREAMINGKEYMAP._serialized_end=7421
  _CSETKEYMAPMSG._serialized_start=7423
  _CSETKEYMAPMSG._serialized_end=7473
  _CSTOPREQUEST._serialized_start=7475
  _CSTOPREQUEST._serialized_end=7489
  _CQUITREQUEST._serialized_start=7491
  _CQUITREQUEST._serialized_end=7505
  _CDELETECURSORMSG._serialized_start=7507
  _CDELETECURSORMSG._serialized_end=7544
  _CSETSTREAMINGCLIENTCONFIG._serialized_start=7546
  _CSETSTREAMINGCLIENTCONFIG._serialized_end=7614
  _CSETQOSMSG._serialized_start=7616
  _CSETQOSMSG._serialized_end=7645
  _CSETTARGETFRAMERATEMSG._serialized_start=7647
  _CSETTARGETFRAMERATEMSG._serialized_end=7767
  _CSETTARGETBITRATEMSG._serialized_start=7769
  _CSETTARGETBITRATEMSG._serialized_end=7808
  _COVERLAYENABLEDMSG._serialized_start=7810
  _COVERLAYENABLEDMSG._serialized_end=7847
  _CSETGAMMARAMPMSG._serialized_start=7849
  _CSETGAMMARAMPMSG._serialized_end=7887
  _CSETACTIVITYMSG._serialized_start=7889
  _CSETACTIVITYMSG._serialized_end=8015
  _CSYSTEMSUSPENDMSG._serialized_start=8017
  _CSYSTEMSUSPENDMSG._serialized_end=8036
  _CVIRTUALHEREREQUESTMSG._serialized_start=8038
  _CVIRTUALHEREREQUESTMSG._serialized_end=8080
  _CVIRTUALHEREREADYMSG._serialized_start=8082
  _CVIRTUALHEREREADYMSG._serialized_end=8135
  _CVIRTUALHERESHAREDEVICEMSG._serialized_start=8137
  _CVIRTUALHERESHAREDEVICEMSG._serialized_end=8189
  _CSETSPECTATORMODEMSG._serialized_start=8191
  _CSETSPECTATORMODEMSG._serialized_end=8230
  _CREMOTEHIDMSG._serialized_start=8232
  _CREMOTEHIDMSG._serialized_end=8283
  _CTOUCHCONFIGACTIVEMSG._serialized_start=8285
  _CTOUCHCONFIGACTIVEMSG._serialized_end=8358
  _CGETTOUCHCONFIGDATAMSG._serialized_start=8360
  _CGETTOUCHCONFIGDATAMSG._serialized_end=8399
  _CSETTOUCHCONFIGDATAMSG._serialized_start=8401
  _CSETTOUCHCONFIGDATAMSG._serialized_end=8505
  _CSAVETOUCHCONFIGLAYOUTMSG._serialized_start=8507
  _CSAVETOUCHCONFIGLAYOUTMSG._serialized_end=8565
  _CTOUCHACTIONSETACTIVEMSG._serialized_start=8567
  _CTOUCHACTIONSETACTIVEMSG._serialized_end=8630
  _CTOUCHACTIONSETLAYERADDEDMSG._serialized_start=8632
  _CTOUCHACTIONSETLAYERADDEDMSG._serialized_end=8699
  _CTOUCHACTIONSETLAYERREMOVEDMSG._serialized_start=8701
  _CTOUCHACTIONSETLAYERREMOVEDMSG._serialized_end=8770
  _CGETTOUCHICONDATAMSG._serialized_start=8772
  _CGETTOUCHICONDATAMSG._serialized_end=8823
  _CSETTOUCHICONDATAMSG._serialized_start=8825
  _CSETTOUCHICONDATAMSG._serialized_end=8890
  _CREMOTEPLAYTOGETHERGROUPUPDATEMSG._serialized_start=8893
  _CREMOTEPLAYTOGETHERGROUPUPDATEMSG._serialized_end=9277
  _CREMOTEPLAYTOGETHERGROUPUPDATEMSG_PLAYER._serialized_start=9109
  _CREMOTEPLAYTOGETHERGROUPUPDATEMSG_PLAYER._serialized_end=9277
  _CSETINPUTTEMPORARILYDISABLEDMSG._serialized_start=9279
  _CSETINPUTTEMPORARILYDISABLEDMSG._serialized_end=9330
  _CSETQUALITYOVERRIDEMSG._serialized_start=9332
  _CSETQUALITYOVERRIDEMSG._serialized_end=9371
  _CSETBITRATEOVERRIDEMSG._serialized_start=9373
  _CSETBITRATEOVERRIDEMSG._serialized_end=9412
  _CSHOWONSCREENKEYBOARDMSG._serialized_start=9414
  _CSHOWONSCREENKEYBOARDMSG._serialized_end=9440
  _CCONTROLLERPERSONALIZATIONUPDATEMSG._serialized_start=9442
  _CCONTROLLERPERSONALIZATIONUPDATEMSG._serialized_end=9568
  _CVRCONNECTIONREADY._serialized_start=9570
  _CVRCONNECTIONREADY._serialized_end=9614
  _CSTREAMDATALOSTMSG._serialized_start=9616
  _CSTREAMDATALOSTMSG._serialized_end=9653
  _CAUDIOFORMAT._serialized_start=9655
  _CAUDIOFORMAT._serialized_end=9757
  _CVIDEOFORMAT._serialized_start=9759
  _CVIDEOFORMAT._serialized_end=9855
  _CFRAMEEVENT._serialized_start=9857
  _CFRAMEEVENT._serialized_end=9953
  _CFRAMESTATS._serialized_start=9956
  _CFRAMESTATS._serialized_end=10291
  _CFRAMESTATACCUMULATEDVALUE._serialized_start=10294
  _CFRAMESTATACCUMULATEDVALUE._serialized_end=10430
  _CFRAMESTATSLISTMSG._serialized_start=10433
  _CFRAMESTATSLISTMSG._serialized_end=10626
  _CSTREAMINGSESSIONSTATS._serialized_start=10629
  _CSTREAMINGSESSIONSTATS._serialized_end=10768
  _CDEBUGDUMPMSG._serialized_start=10770
  _CDEBUGDUMPMSG._serialized_end=10805
  _CLOGMSG._serialized_start=10807
  _CLOGMSG._serialized_end=10847
  _CLOGUPLOADMSG._serialized_start=10849
  _CLOGUPLOADMSG._serialized_end=10929
  _CTRANSPORTSIGNALMSG._serialized_start=10932
  _CTRANSPORTSIGNALMSG._serialized_end=11239
  _CTRANSPORTSIGNALMSG_WEBRTCMESSAGE._serialized_start=11021
  _CTRANSPORTSIGNALMSG_WEBRTCMESSAGE._serialized_end=11239
  _CTRANSPORTSIGNALMSG_WEBRTCMESSAGE_CANDIDATE._serialized_start=11160
  _CTRANSPORTSIGNALMSG_WEBRTCMESSAGE_CANDIDATE._serialized_end=11232
  _CCONTROLLERCONFIGMSG._serialized_start=11242
  _CCONTROLLERCONFIGMSG._serialized_end=12104
  _CCONTROLLERCONFIGMSG_CONTROLLERCONFIGRESPONSE._serialized_start=11642
  _CCONTROLLERCONFIGMSG_CONTROLLERCONFIGRESPONSE._serialized_end=11795
  _CCONTROLLERCONFIGMSG_CONTROLLERPERSONALIZATIONRESPONSE._serialized_start=11797
  _CCONTROLLERCONFIGMSG_CONTROLLERPERSONALIZATIONRESPONSE._serialized_end=11861
  _CCONTROLLERCONFIGMSG_CONTROLLERACTIVECONFIGCHANGERESPONSE._serialized_start=11864
  _CCONTROLLERCONFIGMSG_CONTROLLERACTIVECONFIGCHANGERESPONSE._serialized_end=11993
  _CCONTROLLERCONFIGMSG_CONTROLLERACTIVECONFIGMSG._serialized_start=11995
  _CCONTROLLERCONFIGMSG_CONTROLLERACTIVECONFIGMSG._serialized_end=12104
# @@protoc_insertion_point(module_scope)
