# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: webuimessages_systemmanager.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import steam.protobufs.steammessages_base_pb2 as steammessages__base__pb2
import steam.protobufs.webuimessages_base_pb2 as webuimessages__base__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!webuimessages_systemmanager.proto\x1a\x18steammessages_base.proto\x1a\x18webuimessages_base.proto\"\"\n CSystemManager_Hibernate_Request\"#\n!CSystemManager_Hibernate_Response\">\n CSystemManager_WriteFile_Request\x12\x0c\n\x04path\x18\x01 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x02 \x01(\x0c\"#\n!CSystemManager_WriteFile_Response2\xbd\x01\n\rSystemManager\x12R\n\tHibernate\x12!.CSystemManager_Hibernate_Request\x1a\".CSystemManager_Hibernate_Response\x12R\n\tWriteFile\x12!.CSystemManager_WriteFile_Request\x1a\".CSystemManager_WriteFile_Response\x1a\x04\x80\x97\"\x02\x42\x05H\x01\x90\x01\x01')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'webuimessages_systemmanager_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'H\001\220\001\001'
  _SYSTEMMANAGER._options = None
  _SYSTEMMANAGER._serialized_options = b'\200\227\"\002'
  _CSYSTEMMANAGER_HIBERNATE_REQUEST._serialized_start=89
  _CSYSTEMMANAGER_HIBERNATE_REQUEST._serialized_end=123
  _CSYSTEMMANAGER_HIBERNATE_RESPONSE._serialized_start=125
  _CSYSTEMMANAGER_HIBERNATE_RESPONSE._serialized_end=160
  _CSYSTEMMANAGER_WRITEFILE_REQUEST._serialized_start=162
  _CSYSTEMMANAGER_WRITEFILE_REQUEST._serialized_end=224
  _CSYSTEMMANAGER_WRITEFILE_RESPONSE._serialized_start=226
  _CSYSTEMMANAGER_WRITEFILE_RESPONSE._serialized_end=261
  _SYSTEMMANAGER._serialized_start=264
  _SYSTEMMANAGER._serialized_end=453
_builder.BuildServices(DESCRIPTOR, 'webuimessages_systemmanager_pb2', globals())
# @@protoc_insertion_point(module_scope)
