# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: webuimessages_leds.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import steam.protobufs.enums_pb2 as enums__pb2
import steam.protobufs.steammessages_base_pb2 as steammessages__base__pb2
import steam.protobufs.webuimessages_base_pb2 as webuimessages__base__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18webuimessages_leds.proto\x1a\x0b\x65nums.proto\x1a\x18steammessages_base.proto\x1a\x18webuimessages_base.proto\"/\n\x0c\x43MsgLEDColor\x12\t\n\x01r\x18\x01 \x01(\x02\x12\t\n\x01g\x18\x02 \x01(\x02\x12\t\n\x01\x62\x18\x03 \x01(\x02\"\xfa\x01\n\x14\x43MsgLEDManagerDevice\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x0f\n\x07\x65nabled\x18\x02 \x01(\x08\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x19\n\x11\x65\x66\x66\x65\x63ts_available\x18\x04 \x03(\t\x12\x0e\n\x06\x65\x66\x66\x65\x63t\x18\x05 \x01(\t\x12\x16\n\x0esupports_color\x18\t \x01(\x08\x12\x1c\n\x05\x63olor\x18\n \x01(\x0b\x32\r.CMsgLEDColor\x12\x16\n\x0esupports_speed\x18\x0b \x01(\x08\x12\r\n\x05speed\x18\x0c \x01(\x02\x12\x1b\n\x13supports_brightness\x18\r \x01(\x08\x12\x12\n\nbrightness\x18\x0e \x01(\x02\"[\n\x13\x43MsgLEDManagerState\x12\x1c\n\x14is_service_available\x18\x01 \x01(\x08\x12&\n\x07\x64\x65vices\x18\x02 \x03(\x0b\x32\x15.CMsgLEDManagerDevice\"\x1e\n\x1c\x43LEDManager_GetState_Request\"D\n\x1d\x43LEDManager_GetState_Response\x12#\n\x05state\x18\x01 \x01(\x0b\x32\x14.CMsgLEDManagerState\"\'\n%CLEDManager_StateChanged_Notification\"O\n\x1c\x43LEDManager_SetColor_Request\x12\x11\n\tdevice_id\x18\x01 \x01(\x05\x12\x1c\n\x05\x63olor\x18\x02 \x01(\x0b\x32\r.CMsgLEDColor\"\x1f\n\x1d\x43LEDManager_SetColor_Response\"D\n\x1e\x43LEDManager_SetEnabled_Request\x12\x11\n\tdevice_id\x18\x01 \x01(\x05\x12\x0f\n\x07\x65nabled\x18\x02 \x01(\x08\"!\n\x1f\x43LEDManager_SetEnabled_Response\"B\n\x1d\x43LEDManager_SetEffect_Request\x12\x11\n\tdevice_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x65\x66\x66\x65\x63t\x18\x02 \x01(\t\" \n\x1e\x43LEDManager_SetEffect_Response\"@\n\x1c\x43LEDManager_SetSpeed_Request\x12\x11\n\tdevice_id\x18\x01 \x01(\x05\x12\r\n\x05speed\x18\x02 \x01(\x02\"\x1f\n\x1d\x43LEDManager_SetSpeed_Response\"J\n!CLEDManager_SetBrightness_Request\x12\x11\n\tdevice_id\x18\x01 \x01(\x05\x12\x12\n\nbrightness\x18\x02 \x01(\x02\"$\n\"CLEDManager_SetBrightness_Response2\xbc\x04\n\nLEDManager\x12I\n\x08GetState\x12\x1d.CLEDManager_GetState_Request\x1a\x1e.CLEDManager_GetState_Response\x12N\n\x12NotifyStateChanged\x12&.CLEDManager_StateChanged_Notification\x1a\x10.WebUINoResponse\x12O\n\nSetEnabled\x12\x1f.CLEDManager_SetEnabled_Request\x1a .CLEDManager_SetEnabled_Response\x12I\n\x08SetColor\x12\x1d.CLEDManager_SetColor_Request\x1a\x1e.CLEDManager_SetColor_Response\x12L\n\tSetEffect\x12\x1e.CLEDManager_SetEffect_Request\x1a\x1f.CLEDManager_SetEffect_Response\x12I\n\x08SetSpeed\x12\x1d.CLEDManager_SetSpeed_Request\x1a\x1e.CLEDManager_SetSpeed_Response\x12X\n\rSetBrightness\x12\".CLEDManager_SetBrightness_Request\x1a#.CLEDManager_SetBrightness_Response\x1a\x04\x80\x97\"\x01\x42\x05H\x01\x90\x01\x01')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'webuimessages_leds_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'H\001\220\001\001'
  _LEDMANAGER._options = None
  _LEDMANAGER._serialized_options = b'\200\227\"\001'
  _CMSGLEDCOLOR._serialized_start=93
  _CMSGLEDCOLOR._serialized_end=140
  _CMSGLEDMANAGERDEVICE._serialized_start=143
  _CMSGLEDMANAGERDEVICE._serialized_end=393
  _CMSGLEDMANAGERSTATE._serialized_start=395
  _CMSGLEDMANAGERSTATE._serialized_end=486
  _CLEDMANAGER_GETSTATE_REQUEST._serialized_start=488
  _CLEDMANAGER_GETSTATE_REQUEST._serialized_end=518
  _CLEDMANAGER_GETSTATE_RESPONSE._serialized_start=520
  _CLEDMANAGER_GETSTATE_RESPONSE._serialized_end=588
  _CLEDMANAGER_STATECHANGED_NOTIFICATION._serialized_start=590
  _CLEDMANAGER_STATECHANGED_NOTIFICATION._serialized_end=629
  _CLEDMANAGER_SETCOLOR_REQUEST._serialized_start=631
  _CLEDMANAGER_SETCOLOR_REQUEST._serialized_end=710
  _CLEDMANAGER_SETCOLOR_RESPONSE._serialized_start=712
  _CLEDMANAGER_SETCOLOR_RESPONSE._serialized_end=743
  _CLEDMANAGER_SETENABLED_REQUEST._serialized_start=745
  _CLEDMANAGER_SETENABLED_REQUEST._serialized_end=813
  _CLEDMANAGER_SETENABLED_RESPONSE._serialized_start=815
  _CLEDMANAGER_SETENABLED_RESPONSE._serialized_end=848
  _CLEDMANAGER_SETEFFECT_REQUEST._serialized_start=850
  _CLEDMANAGER_SETEFFECT_REQUEST._serialized_end=916
  _CLEDMANAGER_SETEFFECT_RESPONSE._serialized_start=918
  _CLEDMANAGER_SETEFFECT_RESPONSE._serialized_end=950
  _CLEDMANAGER_SETSPEED_REQUEST._serialized_start=952
  _CLEDMANAGER_SETSPEED_REQUEST._serialized_end=1016
  _CLEDMANAGER_SETSPEED_RESPONSE._serialized_start=1018
  _CLEDMANAGER_SETSPEED_RESPONSE._serialized_end=1049
  _CLEDMANAGER_SETBRIGHTNESS_REQUEST._serialized_start=1051
  _CLEDMANAGER_SETBRIGHTNESS_REQUEST._serialized_end=1125
  _CLEDMANAGER_SETBRIGHTNESS_RESPONSE._serialized_start=1127
  _CLEDMANAGER_SETBRIGHTNESS_RESPONSE._serialized_end=1163
  _LEDMANAGER._serialized_start=1166
  _LEDMANAGER._serialized_end=1738
_builder.BuildServices(DESCRIPTOR, 'webuimessages_leds_pb2', globals())
# @@protoc_insertion_point(module_scope)
